(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     28131,        868]*)
(*NotebookOutlinePosition[     28761,        890]*)
(*  CellTagsIndexPosition[     28717,        886]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\(\( (*\ 
      c15 : \ High\ voltage\ electrostatic\ parametric\ generator\ US\ patent\
\ 4.622  .510\ *) \)\(\n\)\( (*\ 
      Pumping\ function\ G\ of\ the\ capacitor\ \
*) \)\(\[IndentingNewLine]\)\(\(G[t] = \(1/C[t] = 
        Series[1/\((1 + C0*Cos[2*\[Omega]*t])\), {t, 0, 
            5}]\)\)\(\[IndentingNewLine]\)
    \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(Clear[G, F]\)\(;\)\(C0 = 1. \)\(;\)\( (*\ 
      u = 2*\[Omega]*t\ *) \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(G[u] = Series[1/\((1 + C0*Cos[u])\), {u, 0, 5}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "0.5`", "+", \(0.125`\ u\^2\), "+", \(0.020833333333333336`\ u\^4\), 
        "+", 
        InterpretationBox[\(O[u]\^6\),
          SeriesData[ u, 0, {}, 0, 6, 1]]}],
      SeriesData[ 
      u, 0, {0.5, 0, 0.125, 0, 0.020833333333333336}, 0, 6, 1]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(F[u_] = Normal[G[u]]; Table[F[u], {u, 0, Pi, Pi/8}]\)], "Input"],

Cell[BoxData[
    \({0.5`, 0.5197720193534969`, 0.5850334565054184`, 0.7136204487300568`, 
      0.9352598914845665`, 1.2915694384089629`, 1.8360575013261233`, 
      2.634123250241787`, 3.763056613344554`}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(<< Calculus`FourierTransform`\)], "Input"],

Cell[BoxData[
    \(\(\(Clear[F]\)\(;\)\(F[u_] = 
      FourierTrigSeries[1/\((1 + Cos[4*u])\), u, 3]\)\(;\)\( (*\ 
      These\ calculations\ need\ some\ \(time!\)\ *) \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[F[u], {u, \(-Pi\)/2, Pi/2}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.303152 -0.270014 0.611286 [
[.04527 .32877 -12 -9 ]
[.04527 .32877 12 0 ]
[.19685 .32877 -6 -9 ]
[.19685 .32877 6 0 ]
[.34842 .32877 -12 -9 ]
[.34842 .32877 12 0 ]
[.65158 .32877 -9 -9 ]
[.65158 .32877 9 0 ]
[.80315 .32877 -3 -9 ]
[.80315 .32877 3 0 ]
[.95473 .32877 -9 -9 ]
[.95473 .32877 9 0 ]
[.4875 .09676 -18 -4.5 ]
[.4875 .09676 0 4.5 ]
[.4875 .21902 -18 -4.5 ]
[.4875 .21902 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .58579 -18 -4.5 ]
[.4875 .58579 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .34127 m
.04527 .34752 L
s
[(-1.5)] .04527 .32877 0 1 Mshowa
.19685 .34127 m
.19685 .34752 L
s
[(-1)] .19685 .32877 0 1 Mshowa
.34842 .34127 m
.34842 .34752 L
s
[(-0.5)] .34842 .32877 0 1 Mshowa
.65158 .34127 m
.65158 .34752 L
s
[(0.5)] .65158 .32877 0 1 Mshowa
.80315 .34127 m
.80315 .34752 L
s
[(1)] .80315 .32877 0 1 Mshowa
.95473 .34127 m
.95473 .34752 L
s
[(1.5)] .95473 .32877 0 1 Mshowa
.125 Mabswid
.07559 .34127 m
.07559 .34502 L
s
.1059 .34127 m
.1059 .34502 L
s
.13622 .34127 m
.13622 .34502 L
s
.16653 .34127 m
.16653 .34502 L
s
.22716 .34127 m
.22716 .34502 L
s
.25748 .34127 m
.25748 .34502 L
s
.28779 .34127 m
.28779 .34502 L
s
.31811 .34127 m
.31811 .34502 L
s
.37874 .34127 m
.37874 .34502 L
s
.40905 .34127 m
.40905 .34502 L
s
.43937 .34127 m
.43937 .34502 L
s
.46968 .34127 m
.46968 .34502 L
s
.53032 .34127 m
.53032 .34502 L
s
.56063 .34127 m
.56063 .34502 L
s
.59095 .34127 m
.59095 .34502 L
s
.62126 .34127 m
.62126 .34502 L
s
.68189 .34127 m
.68189 .34502 L
s
.71221 .34127 m
.71221 .34502 L
s
.74252 .34127 m
.74252 .34502 L
s
.77284 .34127 m
.77284 .34502 L
s
.83347 .34127 m
.83347 .34502 L
s
.86378 .34127 m
.86378 .34502 L
s
.8941 .34127 m
.8941 .34502 L
s
.92441 .34127 m
.92441 .34502 L
s
.01496 .34127 m
.01496 .34502 L
s
.98504 .34127 m
.98504 .34502 L
s
.25 Mabswid
0 .34127 m
1 .34127 L
s
.5 .09676 m
.50625 .09676 L
s
[(0.6)] .4875 .09676 1 0 Mshowa
.5 .21902 m
.50625 .21902 L
s
[(0.8)] .4875 .21902 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.2)] .4875 .46353 1 0 Mshowa
.5 .58579 m
.50625 .58579 L
s
[(1.4)] .4875 .58579 1 0 Mshowa
.125 Mabswid
.5 .12732 m
.50375 .12732 L
s
.5 .15789 m
.50375 .15789 L
s
.5 .18845 m
.50375 .18845 L
s
.5 .24958 m
.50375 .24958 L
s
.5 .28014 m
.50375 .28014 L
s
.5 .31071 m
.50375 .31071 L
s
.5 .37184 m
.50375 .37184 L
s
.5 .4024 m
.50375 .4024 L
s
.5 .43297 m
.50375 .43297 L
s
.5 .49409 m
.50375 .49409 L
s
.5 .52466 m
.50375 .52466 L
s
.5 .55522 m
.50375 .55522 L
s
.5 .06619 m
.50375 .06619 L
s
.5 .03563 m
.50375 .03563 L
s
.5 .00507 m
.50375 .00507 L
s
.5 .61635 m
.50375 .61635 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .49913 m
.02846 .53707 L
.03279 .56586 L
.03523 .57881 L
.03754 .58866 L
.03881 .59306 L
.0402 .59697 L
.04146 .59972 L
.04262 .60158 L
.04376 .60275 L
.04498 .6033 L
.04614 .60313 L
.0472 .6024 L
.04843 .60085 L
.04913 .59963 L
.04978 .59829 L
.05224 .59139 L
.05483 .58107 L
.05718 .56915 L
.06244 .53438 L
.08269 .3399 L
.09333 .23813 L
.09915 .19245 L
.10458 .15813 L
.10938 .1348 L
.11453 .1168 L
.11746 .10947 L
.12024 .10424 L
.12273 .10077 L
.12413 .09927 L
.12545 .0981 L
.12775 .09658 L
.12897 .09598 L
.13028 .09548 L
.13159 .0951 L
.13296 .09478 L
.13542 .09437 L
.13755 .09406 L
.13983 .09366 L
.14113 .09336 L
.14232 .09302 L
.14465 .09212 L
.14696 .09087 L
.14949 .08901 L
.15215 .08646 L
.15463 .0835 L
.16383 .06793 L
.1745 .04456 L
.17976 .03345 L
.18463 .02477 L
Mistroke
.18705 .0213 L
.18933 .01864 L
.19059 .01745 L
.19196 .0164 L
.1932 .01566 L
.19433 .01516 L
.19561 .01482 L
.19679 .01472 L
.19809 .01482 L
.19882 .01499 L
.19948 .01521 L
.20018 .0155 L
.20082 .01583 L
.20227 .01678 L
.20492 .01922 L
.20712 .02193 L
.20919 .02497 L
.21391 .03339 L
.22345 .0541 L
.23331 .07452 L
.23826 .08242 L
.2411 .08597 L
.24367 .08855 L
.24607 .09043 L
.24832 .09177 L
.2507 .09279 L
.25204 .09322 L
.25327 .09353 L
.25534 .09393 L
.25761 .09428 L
.25999 .09465 L
.26219 .09512 L
.26341 .09548 L
.2647 .09597 L
.26599 .0966 L
.26742 .09749 L
.26998 .09968 L
.27238 .10261 L
.27471 .10641 L
.27685 .11085 L
.28168 .12471 L
.28419 .1343 L
.28654 .14479 L
.29186 .17441 L
.30258 .25772 L
.3213 .44565 L
.33115 .53364 L
.33612 .56693 L
.33895 .58147 L
.3416 .59187 L
Mistroke
.34303 .59614 L
.34439 .5993 L
.34561 .60136 L
.3463 .6022 L
.34694 .60277 L
.34769 .60319 L
.3484 .60332 L
.34972 .6029 L
.35046 .60229 L
.35115 .60149 L
.35189 .60034 L
.35269 .59883 L
.3539 .59592 L
.35521 .59201 L
.35756 .58295 L
.36037 .56896 L
.36292 .55338 L
.37327 .46798 L
.38306 .36858 L
.39273 .27188 L
.39802 .22524 L
.40299 .18766 L
.40756 .15909 L
.41175 .13817 L
.4164 .12064 L
.41884 .11366 L
.42141 .1078 L
.42399 .10331 L
.42642 .10016 L
.4286 .0981 L
.42983 .09721 L
.43097 .09654 L
.4321 .09599 L
.43333 .09552 L
.43467 .09512 L
.43592 .09482 L
.43866 .09436 L
.44117 .09399 L
.4423 .09379 L
.44351 .09355 L
.44568 .09295 L
.44701 .09247 L
.44826 .09191 L
.4506 .09056 L
.45284 .08885 L
.4549 .08689 L
.45954 .08106 L
.46943 .06283 L
.48002 .03941 L
.48515 .0292 L
Mistroke
.48768 .02493 L
.49001 .02155 L
.49208 .01906 L
.49437 .01694 L
.49555 .01611 L
.49666 .0155 L
.49784 .01505 L
.4991 .01477 L
.50032 .01472 L
.50162 .0149 L
.50285 .01529 L
.50397 .01582 L
.50528 .01667 L
.5067 .01785 L
.50928 .02064 L
.51432 .02827 L
.51896 .03726 L
.52774 .05663 L
.53714 .07573 L
.54223 .08351 L
.54687 .08859 L
.54911 .09035 L
.55154 .0918 L
.55265 .09232 L
.55383 .09279 L
.55596 .09342 L
.55723 .0937 L
.5584 .09392 L
.56102 .09431 L
.56221 .09449 L
.56349 .09471 L
.56578 .09524 L
.5671 .09567 L
.5683 .09617 L
.56972 .09693 L
.57106 .09784 L
.57373 .10032 L
.57523 .10219 L
.57662 .10425 L
.58129 .11399 L
.58391 .12163 L
.58631 .13013 L
.59096 .15111 L
.59537 .17673 L
.60525 .25329 L
.61601 .35895 L
.62616 .46245 L
.63571 .54399 L
.641 .57623 L
.64245 .58303 L
Mistroke
.64398 .58919 L
.64531 .59365 L
.64672 .59751 L
.64801 .60018 L
.64918 .6019 L
.65036 .60295 L
.65148 .60332 L
.65278 .60296 L
.65398 .60189 L
.6553 .5999 L
.65596 .59857 L
.65669 .59686 L
.65905 .58963 L
.66162 .57879 L
.66681 .54841 L
.67607 .47128 L
.68701 .36034 L
.69694 .26207 L
.70179 .22021 L
.70705 .18152 L
.71159 .1543 L
.71658 .13118 L
.71932 .12138 L
.72188 .11395 L
.72459 .10776 L
.72749 .1028 L
.72878 .10108 L
.73019 .09952 L
.73142 .09837 L
.73274 .09737 L
.73393 .09665 L
.73523 .096 L
.73754 .09519 L
.74241 .09427 L
.74478 .09391 L
.74694 .09348 L
.74812 .09317 L
.74923 .09282 L
.75167 .09178 L
.75416 .09028 L
.75685 .08807 L
.7596 .08516 L
.7625 .08133 L
.76772 .07264 L
.7777 .05152 L
.78711 .03141 L
.78982 .02656 L
.7924 .02259 L
.79474 .01961 L
.79603 .01825 L
Mistroke
.79724 .01716 L
.79838 .01631 L
.79962 .0156 L
.80074 .01513 L
.80178 .01485 L
.80275 .01473 L
.80383 .01475 L
.80494 .01494 L
.80599 .01528 L
.80723 .01588 L
.8084 .01665 L
.8106 .01857 L
.81297 .02132 L
.81554 .02503 L
.85633 .09254 L
.86608 .09461 L
.86746 .09487 L
.86875 .09519 L
.87009 .09561 L
.87156 .09623 L
.87284 .09691 L
.87399 .09768 L
.87659 .1 L
.87903 .10311 L
.88128 .10691 L
.88375 .11227 L
.88637 .11945 L
.89077 .13542 L
.8956 .15915 L
.90501 .22424 L
.91511 .31752 L
.93336 .49997 L
.93827 .53971 L
.9435 .57283 L
.94651 .58678 L
.94923 .59587 L
.95055 .599 L
.95124 .60031 L
.95197 .60143 L
.95261 .60221 L
.95331 .60282 L
.95454 .60331 L
.95519 .60327 L
.95589 .60298 L
.95717 .60184 L
.95842 .59995 L
.95957 .59754 L
.96081 .59422 L
.96218 .58971 L
.96495 .57797 L
Mistroke
.96995 .54845 L
.97465 .51244 L
.97619 .49913 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooohoG00<0emL0S]L008oG0P2?e`00SmL00`3G
e`2>e`00SmL00`3Ge`2>e`00=mL405;G1@1Be`@0>=L003KG00<0emL00]L00`3Ge`1?e`040=L0e`80
D=L200?G00<0emL0=ML003GG00<0emL00mL00`3Ge`1>e`040=OG00;G00<0emL0C]L00`3Ge`03e`03
0=OG03CG000ee`030=OG00CG00<0emL0C=L01@3GemL000?G00<0emL0C=L00`3Ge`04e`030=OG03CG
000de`030=OG00GG00<0emL0C=L01@3GemL000?G00<0emL0BmL00`3Ge`06e`030=OG03?G000ce`03
0=OG00OG00<0emL0B]L00`3Ge`02e`050=OGe`00CML00`3Ge`06e`030=OG03?G000ce`030=OG00OG
00<0emL0B]L00`3Ge`02e`800mL00`3Ge`1:e`030=OG00OG00<0emL0<]L003;G00<0emL02ML00`3G
e`18e`030=OG00?G00<0emL00]L00`3Ge`19e`030=OG00WG00<0emL0<ML003;G00<0emL02ML00`3G
e`18e`030=OG00?G00<0emL00mL00`3Ge`18e`030=OG00WG00<0emL0<ML003;G00<0emL02]L00`3G
e`16e`030=OG00CG00<0emL00mL00`3Ge`17e`030=OG00_G00<0emL0<=L0037G00<0emL02mL00`3G
e`16e`030=OG00CG00<0emL01=L00`3Ge`16e`030=OG00_G00<0emL0<=L0037G00<0emL03=L00`3G
e`14e`030=OG00GG00<0emL01=L00`3Ge`15e`030=OG00gG00<0emL0;mL0033G00<0emL03ML00`3G
e`14e`030=OG00GG00<0emL01ML00`3Ge`14e`030=OG00kG00<0emL0;]L0033G00<0emL03]L00`3G
e`12e`030=OG00KG00<0emL01]L00`3Ge`12e`030=OG00oG00<0emL0;]L002oG00<0emL03mL00`3G
e`12e`030=OG00KG00<0emL01]L00`3Ge`12e`030=OG013G00<0emL0;ML002oG00<0emL04=L00`3G
e`10e`030=OG00OG0P08e`030=OG043G00<0emL04]L00`3Ge`0/e`00;]L00`3Ge`0Ae`030=OG043G
00<0emL01mL00`3Ge`07e`030=OG043G00<0emL04]L00`3Ge`0/e`00;ML00`3Ge`0Ce`030=OG03kG
00<0emL02=L00`3Ge`08e`030=OG03kG00<0emL05=L00`3Ge`0[e`00;ML00`3Ge`0Ce`030=OG03kG
00<0emL02=L00`3Ge`08e`030=OG03kG00<0emL05=L00`3Ge`0[e`00;=L00`3Ge`0Ee`030=OG03cG
00<0emL02ML00`3Ge`09e`030=OG03cG00<0emL05]L00`3Ge`0Ze`00:mL00`3Ge`0Ge`030=OG03[G
00<0emL02]L00`3Ge`09e`030=OG03_G00<0emL06=L00`3Ge`0Ye`00:mL00`3Ge`0He`030=OG03;G
0P04e`801=L200KG00<0emL02]L203[G0P0Je`030=OG02WG000We`@07=L3033G00<0emL01005e`04
0=OG00GG00<0emL03=L303CG0`0Me`80:ML002CG100Re`<0;ML400SG00@0emL01ML300kG100^e`<0
8]L402GG000Se`80:=L00`3Ge`0Ze`8000?G0=L01mL300KG00<0emL04ML202_G0P0Xe`809=L002;G
00<0emL0:ML00`3Ge`0Xe`800]L00`3Ge`06e`030=OG00KG00<0emL04mL00`3Ge`0Xe`030=OG02WG
00<0emL08ML0027G00<0emL0:mL00`3Ge`0We`800]L00`3Ge`06e`030=OG00KG00<0emL04mL00`3G
e`0We`030=OG02[G00<0emL08ML0027G00<0emL0:mL00`3Ge`0Ve`030=OG00802]L300GG00<0emL0
5=L00`3Ge`0Ve`030=OG02[G00<0emL08ML0027G00<0emL0:mL00`3Ge`0Ve`030=OG01CG00<0emL0
5=L00`3Ge`0Ve`030=OG02_G00<0emL08=L0027G00<0emL0:mL00`3Ge`0Ue`030=OG01GG00<0emL0
5=L00`3Ge`0Ue`030=OG02cG00<0emL08=L0027G00<0emL0;=L00`3Ge`0Te`030=OG01GG00<0emL0
5ML00`3Ge`0Te`030=OG02gG00<0emL07mL0023G00<0emL0;ML00`3Ge`0Te`030=OG01GG00<0emL0
5ML00`3Ge`0Te`030=OG02gG00<0emL07mL0023G00<0emL0;ML00`3Ge`0Te`030=OG01GG0P0Ge`03
0=OG02;G00<0emL0;]L00`3Ge`0Oe`007mL00`3Ge`0_e`030=OG02;G00<0emL05]L00`3Ge`0Fe`03
0=OG02;G00<0emL0;mL00`3Ge`0Ne`007mL00`3Ge`0_e`030=OG02;G00<0emL05]L00`3Ge`0Fe`03
0=OG02;G00<0emL0;mL00`3Ge`0Ne`007mL00`3Ge`0_e`030=OG02;G00<0emL05]L00`3Ge`0Fe`03
0=OG02;G00<0emL0;mL00`3Ge`0Ne`007mL00`3Ge`0`e`030=OG027G00<0emL05]L00`3Ge`0Fe`03
0=OG02;G00<0emL0;mL00`3Ge`0Ne`007mL00`3Ge`0`e`030=OG027G00<0emL05]L00`3Ge`0Ge`03
0=OG023G00<0emL0<=L00`3Ge`0Ne`007]L00`3Ge`0ae`030=OG023G00<0emL05mL00`3Ge`0Ge`03
0=OG023G00<0emL0<ML00`3Ge`0Me`007]L00`3Ge`0ae`030=OG023G00<0emL05mL00`3Ge`0Ge`03
0=OG023G00<0emL0<ML00`3Ge`0Me`007]L00`3Ge`0ae`030=OG023G00<0emL05mL00`3Ge`0Ge`03
0=OG023G00<0emL0<ML00`3Ge`0Me`007]L00`3Ge`0ae`030=OG023G00<0emL05mL201SG00<0emL0
8=L00`3Ge`0ae`030=OG01gG000Ne`030=OG03;G00<0emL07mL00`3Ge`0Ge`030=OG01OG00<0emL0
7mL00`3Ge`0be`030=OG01gG000Ne`030=OG03;G00<0emL07]L00`3Ge`0He`030=OG01SG00<0emL0
7]L00`3Ge`0be`030=OG01gG000Me`030=OG03?G00<0emL07]L00`3Ge`0He`030=OG01SG00<0emL0
7]L00`3Ge`0be`030=OG01gG000Me`030=OG03?G00<0emL07]L00`3Ge`0He`030=OG01SG00<0emL0
7]L00`3Ge`0ce`030=OG01cG000Me`030=OG03?G00<0emL07]L00`3Ge`0He`030=OG01SG00<0emL0
7ML00`3Ge`0de`030=OG01cG000Me`030=OG03?G00<0emL07ML00`3Ge`0Ie`030=OG01SG00<0emL0
7ML00`3Ge`0de`030=OG01cG000Me`030=OG03?G00<0emL07ML00`3Ge`0Ie`030=OG01SG00<0emL0
7ML00`3Ge`0de`030=OG01cG000Le`030=OG03CG00<0emL07ML00`3Ge`0Ie`030=OG01SG00<0emL0
7ML00`3Ge`0de`030=OG01cG000Le`030=OG03GG00<0emL07=L00`3Ge`0Ie`806]L00`3Ge`0Le`03
0=OG03CG00<0emL07=L001cG00<0emL0=ML00`3Ge`0Le`030=OG01WG00<0emL06ML00`3Ge`0Le`03
0=OG03GG00<0emL06mL001cG00<0emL0=ML00`3Ge`0Le`030=OG01WG00<0emL06ML00`3Ge`0Le`03
0=OG03GG00<0emL06mL001cG00<0emL0=ML00`3Ge`0Le`030=OG01WG00<0emL06ML00`3Ge`0Le`03
0=OG03GG00<0emL06mL001cG00<0emL0=ML00`3Ge`0Le`030=OG01WG00<0emL06ML00`3Ge`0Ke`03
0=OG03KG00<0emL06mL001cG00<0emL0=ML00`3Ge`0Ke`030=OG01[G00<0emL06ML00`3Ge`0Ke`03
0=OG03KG00<0emL06mL001cG00<0emL0=ML00`3Ge`0Ke`030=OG00KG0P04e`030=OG00?G0P06e`03
0=OG01WG00<0emL06mL00`3Ge`0fe`030=OG01_G000Le`030=OG03GG00<0emL06mL00`3Ge`05e`04
0=OG00SG00@0emL01ML00`3Ge`0Ie`030=OG01_G00<0emL0=mL00`3Ge`0Je`006mL00`3Ge`0ge`03
0=OG01[G00<0emL01ML0103Ge`08e`040=OG00GG0`0Je`030=OG01[G00<0emL0=mL00`3Ge`0Je`00
6mL00`3Ge`0ge`030=OG01[G00<0emL01ML0103Ge`09e`801]L00`3Ge`0Je`030=OG01[G00<0emL0
=mL00`3Ge`0Je`006mL00`3Ge`0ge`030=OG01[G00<0emL01ML0103Ge`08e`040=OG00GG00<0emL0
6]L00`3Ge`0Je`030=OG03OG00<0emL06]L001_G00<0emL0=mL00`3Ge`0Je`030=OG00GG00@0emL0
2=L0103Ge`05e`030=OG01[G00<0emL06]L00`3Ge`0ge`030=OG01[G000Ke`030=OG03OG00<0emL0
6]L00`3Ge`06e`802]L200KG00<0emL06]L00`3Ge`0Ie`030=OG03SG00<0emL06]L001_G00<0emL0
=mL00`3Ge`0Je`030=OG01[G00<0emL06]L00`3Ge`0Ie`030=OG03SG00<0emL06]L001_G00<0emL0
=mL00`3Ge`0Ie`030=OG01_G00<0emL06]L00`3Ge`0Ie`030=OG03SG00<0emL06]L001_G00<0emL0
=mL00`3Ge`0Ie`030=OG01_G00<0emL06mL00`3Ge`0He`030=OG03WG00<0emL06ML001_G00<0emL0
>=L00`3Ge`0He`030=OG01_G00<0emL06mL00`3Ge`0He`030=OG03WG00<0emL06ML001_G00<0emL0
>=L00`3Ge`0He`030=OG01_G0P0Le`030=OG01SG00<0emL0>ML00`3Ge`0Ie`006mL00`3Ge`0he`03
0=OG01SG00<0emL06mL00`3Ge`0Ke`030=OG01OG00<0emL0>]L00`3Ge`0Ie`006]L00`3Ge`0ie`03
0=OG01SG00<0emL06mL00`3Ge`0Ke`030=OG01OG00<0emL0>]L00`3Ge`0Ie`006]L00`3Ge`0ie`03
0=OG01OG00<0emL07=L00`3Ge`0Ke`030=OG01OG00<0emL0>]L00`3Ge`0Ie`006]L00`3Ge`0ie`03
0=OG01OG00<0emL07=L00`3Ge`0Ke`030=OG01OG00<0emL0>]L00`3Ge`0Ie`006]L00`3Ge`0ie`03
0=OG01OG00<0emL07=L00`3Ge`0Ke`030=OG01OG00<0emL0>]L00`3Ge`0Ie`006]L00`3Ge`0ie`03
0=OG01OG00<0emL07=L00`3Ge`0Ke`030=OG01OG00<0emL0>]L00`3Ge`0Ie`006]L00`3Ge`0je`03
0=OG01KG00<0emL07=L00`3Ge`0Le`030=OG01KG00<0emL0>mL00`3Ge`0He`006]L00`3Ge`0je`03
0=OG01KG00<0emL07=L00`3Ge`0Le`030=OG01KG00<0emL0>mL00`3Ge`0He`006]L00`3Ge`0je`03
0=OG01KG00<0emL07=L201gG00<0emL05]L00`3Ge`0ke`030=OG01SG000Je`030=OG03[G00<0emL0
5]L00`3Ge`0Le`030=OG01cG00<0emL05]L00`3Ge`0ke`030=OG01SG000Je`030=OG03[G00<0emL0
5]L00`3Ge`0Le`030=OG01cG00<0emL05ML00`3Ge`0le`030=OG01SG000Ie`030=OG03_G00<0emL0
5]L00`3Ge`0Le`030=OG01cG00<0emL05ML00`3Ge`0le`030=OG01SG000Ie`030=OG03_G00<0emL0
5ML00`3Ge`0Me`030=OG01cG00<0emL05ML00`3Ge`0le`030=OG01SG000Ie`030=OG03_G00<0emL0
5ML00`3Ge`0Me`030=OG01cG00<0emL05ML00`3Ge`0le`030=OG01SG000Ie`030=OG03_G00<0emL0
5ML00`3Ge`0Me`030=OG01cG00<0emL05ML00`3Ge`0me`030=OG01OG0008e`@00mL00`3Ge`02e`<0
0]L00`3Ge`0Me`@06mL00`3Ge`05e`801=L00`3Ge`02e`<000?G0=L07]L00`3Ge`0Le`030=OG00;G
0P04e`030=OG00;G0`05e`030=OG01_G100Ne`030=OG00@00mL00`3Ge`02e`<02=L000[G00<0emL0
2]L00`3G000Qe`030=OG01[G00<0emL01=L0103Ge`0;e`807mL00`3Ge`0Me`040=OG00;G00<0emL0
2ML00`3Ge`02e`030=OG01gG00<0emL07ML00`3Ge`02e`030=OG00[G00<0emL01ML000[G00<0emL0
2]L00`3G000Qe`030=OG01[G00<0emL01=L0103Ge`0;e`807mL201kG00@0emL00]L00`3Ge`09e`03
0=OG00;G00<0emL07ML00`3Ge`0Me`030=OG00;G00<0emL02]L00`3Ge`05e`000]L400CG00<0emL0
1mL300;G00<0emL05mL400CG00<0emL06]L500;G00@0emL02=L30003e`3G01kG00<0emL07ML0103G
e`02e`030=OG00KG0`05e`030=OG01gG00<0emL07ML00`3Ge`02e`030=OG00OG0`08e`002]L00`3G
e`07e`030=OG00;G00<0emL07mL00`3Ge`0Je`030=OG00CG00@0emL02=L01@3GemL001oG00<0emL0
7ML0103Ge`02e`030=OG00KG00<0emL01ML00`3Ge`0Me`030=OG01gG00<0emL00]L00`3Ge`07e`03
0=OG00SG0008e`<02ML00`3Ge`02e`030=OG01gG0`0Le`030=OG00CG00@0emL02=L01@3GemL001oG
00<0emL07ML0103Ge`02e`030=OG00KG00<0emL01ML00`3Ge`0Ke`<07mL00`3Ge`0300WG00<0emL0
2=L000[G00<0emL01mL502;G00<0emL06]L00`3Ge`05e`802ML501oG00<0emL07ML0103GemL200WG
1004e`030=OG01gG00<0emL07ML00`3Ge`02e`030=OG00OG1007e`006=L00`3Ge`0me`030=OG01CG
00<0emL07ML00`3Ge`0Me`030=OG01CG00<0emL0?ML00`3Ge`0Ge`006=L00`3Ge`0me`030=OG01CG
00<0emL07ML00`3Ge`0Me`030=OG01CG00<0emL0?ML00`3Ge`0Ge`006=L00`3Ge`0ne`030=OG01?G
00<0emL07ML00`3Ge`0Me`030=OG01?G00<0emL0?mL00`3Ge`0Fe`00o`0P007G0004e`030=OG00KG
00<0emL01ML0103Ge`05e`030=OG00KG00<0emL01]L00`3Ge`05e`030=OG00KG00<0emL01]L00`3G
e`05e`030=OG00CG00<0e`002=L00`3Ge`05e`030=L000KG00<0emL01]L00`3Ge`05e`030=OG00KG
00<0emL01]L00`3Ge`05e`030=OG00KG00<0emL01=L00`3G0007e`030=OG00KG00<0e`001]L00`3G
e`05e`030=OG00KG00<0emL01]L00`3Ge`05e`030=OG00KG00<0emL01]L00`3Ge`04e`030=L000OG
00<0emL01]L00`3Ge`03e`003ML00`3Ge`08e`030=OG01gG00<0emL07]L00`3Ge`08e`030=OG00OG
00<0emL07]L00`3Ge`0Ne`030=OG00OG00<0emL02=L00`3Ge`0Ne`030=OG01kG00<0emL01mL00`3G
e`0<e`006=L00`3Ge`0ne`030=OG01;G00<0emL07]L00`3Ge`0Ne`030=OG01;G00<0emL0?mL00`3G
e`0Fe`006=L00`3Ge`0ne`030=OG01;G00<0emL07]L00`3Ge`0Ne`030=OG01;G00<0emL0?mL00`3G
e`0Fe`005mL00`3Ge`0oe`030=OG01;G00<0emL07]L00`3Ge`0Ne`030=OG01;G00<0emL0?mL00`3G
e`0Fe`005mL00`3Ge`0oe`030=OG01;G00<0emL07]L00`3Ge`0Ne`030=OG01;G00<0emL0?mL00`3G
e`0Fe`005mL00`3Ge`0oe`030=OG01;G00<0emL07]L00`3Ge`0Ne`030=OG01;G00<0emL0?mL00`3G
e`0Fe`005mL00`3Ge`10e`030=OG017G00<0emL07]L00`3Ge`0Ne`030=OG01;G00<0emL0?mL00`3G
e`0Fe`005mL00`3Ge`10e`030=OG017G00<0emL07]L201oG00<0emL04]L00`3Ge`10e`030=OG01GG
000Ge`030=OG043G00<0emL04ML00`3Ge`0Ne`030=OG01kG00<0emL04ML00`3Ge`11e`030=OG01GG
000Ge`030=OG043G00<0emL04ML00`3Ge`0Ne`030=OG01oG00<0emL04=L00`3Ge`11e`030=OG01GG
000Ge`030=OG043G00<0emL04ML00`3Ge`0Ne`030=OG01oG00<0emL04=L00`3Ge`11e`030=OG01GG
000Ge`030=OG043G00<0emL04=L00`3Ge`0Oe`030=OG01oG00<0emL04=L00`3Ge`11e`030=OG01GG
000Fe`030=OG047G00<0emL04=L00`3Ge`0Oe`030=OG01oG00<0emL04=L00`3Ge`11e`030=OG01GG
000Fe`030=OG047G00<0emL04=L00`3Ge`0Oe`030=OG01oG00<0emL04=L00`3Ge`11e`030=OG01GG
000Fe`030=OG047G00<0emL04=L00`3Ge`0Oe`030=OG01oG00<0emL04=L00`3Ge`11e`030=OG01GG
000Fe`030=OG04;G00<0emL03mL00`3Ge`0Oe`030=OG01oG00<0emL04=L00`3Ge`11e`030=OG01GG
000Fe`030=OG04;G00<0emL03mL00`3Ge`0Oe`808=L00`3Ge`0?e`030=OG04;G00<0emL05ML001KG
00<0emL0@]L00`3Ge`0?e`030=OG01oG00<0emL07mL00`3Ge`0?e`030=OG04;G00<0emL05ML001KG
00<0emL0@]L00`3Ge`0?e`030=OG01oG00<0emL07mL00`3Ge`0?e`030=OG04?G00<0emL05=L001KG
00<0emL0@]L00`3Ge`0?e`030=OG01oG00<0emL08=L00`3Ge`0>e`030=OG04?G00<0emL05=L001KG
00<0emL0@]L00`3Ge`0?e`030=OG01oG00<0emL08=L00`3Ge`0>e`030=OG04?G00<0emL05=L001KG
00<0emL0@]L00`3Ge`0>e`030=OG023G00<0emL08=L00`3Ge`0>e`030=OG04?G00<0emL05=L001GG
00<0emL0@mL00`3Ge`0>e`030=OG023G00<0emL08=L00`3Ge`0>e`030=OG04?G00<0emL05=L001GG
00<0emL0@mL00`3Ge`0>e`030=OG023G00<0emL08=L00`3Ge`0>e`030=OG04?G00<0emL05=L001GG
00<0emL0A=L00`3Ge`0=e`030=OG023G00<0emL08=L00`3Ge`0=e`030=OG04CG00<0emL05=L001GG
00<0emL0A=L00`3Ge`0=e`030=OG023G0P0Qe`030=OG00gG00<0emL0A=L00`3Ge`0De`005ML00`3G
e`14e`030=OG00gG00<0emL08=L00`3Ge`0Pe`030=OG00gG00<0emL0A=L00`3Ge`0De`005ML00`3G
e`14e`030=OG00gG00<0emL08=L00`3Ge`0Pe`030=OG00gG00<0emL0A=L00`3Ge`0De`005ML00`3G
e`14e`030=OG00gG00<0emL08=L00`3Ge`0Pe`030=OG00gG00<0emL0A=L00`3Ge`0De`005ML00`3G
e`14e`030=OG00gG00<0emL08=L00`3Ge`0Qe`030=OG00cG00<0emL0AML00`3Ge`0Ce`005ML00`3G
e`14e`030=OG00gG00<0emL08=L00`3Ge`0Qe`030=OG00cG00<0emL0AML00`3Ge`0Ce`005=L00`3G
e`15e`030=OG00cG00<0emL03=L400?G00<0emL00]L400GG00<0emL08ML00`3Ge`0<e`030=OG04GG
00<0emL04mL001CG00<0emL0AML00`3Ge`0<e`030=OG00kG00<0emL01mL00`3Ge`06e`030=OG027G
00<0emL02mL00`3Ge`16e`030=OG01?G000De`030=OG04KG00<0emL02mL00`3Ge`0>e`030=OG00SG
00<0emL01ML3027G00<0emL02mL00`3Ge`16e`030=OG01?G000De`030=OG04KG00<0emL02mL00`3G
e`0>e`030=OG00WG00<0emL01=L00`3Ge`0Qe`030=OG00_G00<0emL0A]L00`3Ge`0Ce`005=L00`3G
e`16e`030=OG00_G00<0emL03]L00`3Ge`0:e`030=OG00?G00<0emL08ML00`3Ge`0;e`030=OG04KG
00<0emL04mL001CG00<0emL0A]L00`3Ge`0;e`030=OG00cG0`09e`040=OG00GG00<0emL08ML00`3G
e`0;e`030=OG04KG00<0emL04mL001CG00<0emL0A]L00`3Ge`0;e`030=OG00kG00<0emL02=L200KG
00<0emL08]L00`3Ge`0:e`030=OG04KG00<0emL04mL001CG00<0emL0A]L00`3Ge`0;e`030=OG027G
00<0emL08]L00`3Ge`0:e`030=OG04KG00<0emL04mL001CG00<0emL0A]L00`3Ge`0:e`030=OG02;G
00<0emL08]L00`3Ge`0:e`030=OG04OG00<0emL04]L001?G00<0emL0AmL00`3Ge`0:e`030=OG02;G
00<0emL08]L00`3Ge`0:e`030=OG04OG00<0emL04]L001?G00<0emL0B=L00`3Ge`09e`030=OG02;G
00<0emL08]L00`3Ge`09e`030=OG04SG00<0emL04]L001?G00<0emL0B=L00`3Ge`09e`030=OG02;G
0P0Se`030=OG00WG00<0emL0B=L00`3Ge`0Be`001mL00`3Ge`09e`030=OG04SG00<0emL02ML00`3G
e`0Re`030=OG02;G00<0emL02ML00`3Ge`18e`030=OG00WG00<0emL01]L000OG00<0emL02ML00`3G
e`18e`030=OG00WG00<0emL08]L00`3Ge`0Re`030=OG00WG00<0emL0B=L00`3Ge`09e`030=OG00KG
0007e`030=OG00WG00<0emL0B=L00`3Ge`09e`030=OG02;G00<0emL08mL00`3Ge`08e`030=OG04SG
00<0emL02ML00`3Ge`06e`001mL00`3Ge`09e`030=OG04SG00<0emL02ML00`3Ge`0Re`030=OG02?G
00<0emL02=L00`3Ge`18e`030=OG00WG00<0emL01]L000OG00<0emL02ML00`3Ge`18e`030=OG00SG
00<0emL08mL00`3Ge`0Se`030=OG00SG00<0emL0B=L00`3Ge`09e`030=OG00KG0007e`030=OG00WG
00<0emL0B=L00`3Ge`08e`030=OG02?G00<0emL08mL00`3Ge`08e`030=OG04SG00<0emL02ML00`3G
e`06e`002=L00`3Ge`08e`030=OG04WG00<0emL01mL00`3Ge`0Se`030=OG02?G00<0emL02=L00`3G
e`18e`030=OG00WG00<0emL01]L000SG00<0emL01mL00`3Ge`1:e`030=OG00OG00<0emL08mL00`3G
e`0Se`030=OG00SG00<0emL0BML00`3Ge`08e`030=OG00KG0008e`030=OG00OG00<0emL0B]L00`3G
e`07e`030=OG02?G0P0Te`030=OG00SG00<0emL0BML00`3Ge`08e`030=OG00KG0008e`030=OG00OG
00<0emL0B]L00`3Ge`07e`030=OG02?G00<0emL08mL00`3Ge`08e`030=OG04WG00<0emL02=L00`3G
e`06e`002=L00`3Ge`07e`030=OG04[G00<0emL01mL00`3Ge`0Se`030=OG02CG00<0emL01]L00`3G
e`1:e`030=OG00OG00<0emL01mL000SG00<0emL01mL00`3Ge`1:e`030=OG00OG00<0emL08mL00`3G
e`0Te`030=OG00KG00<0emL0B]L00`3Ge`07e`030=OG00OG0008e`030=OG00OG00<0emL0B]L00`3G
e`06e`030=OG02CG00<0emL09=L00`3Ge`06e`030=OG04[G00<0emL01mL00`3Ge`07e`002=L00`3G
e`07e`030=OG04[G00<0emL01]L00`3Ge`0Te`030=OG02CG00<0emL01]L00`3Ge`1:e`030=OG00OG
00<0emL01mL000SG00<0emL01]L00`3Ge`1;e`030=OG00KG00<0emL09=L00`3Ge`0Te`030=OG00KG
00<0emL0B]L00`3Ge`07e`030=OG00OG0008e`030=OG00KG00<0emL0BmL00`3Ge`06e`030=OG02CG
00<0emL09=L00`3Ge`06e`030=OG04_G00<0emL01]L00`3Ge`07e`002ML00`3Ge`05e`030=OG04cG
00<0emL01ML00`3Ge`0Te`030=OG02CG00<0emL01]L00`3Ge`1;e`030=OG00KG00<0emL01mL000WG
00<0emL01ML00`3Ge`1<e`030=OG00GG00<0emL09=L202GG00<0emL01ML00`3Ge`1<e`030=OG00GG
00<0emL02=L000WG00<0emL01ML00`3Ge`1<e`030=OG00CG00<0emL09ML00`3Ge`0Te`030=OG00GG
00<0emL0C=L00`3Ge`05e`030=OG00SG0009e`030=OG00CG00<0emL0CML00`3Ge`04e`030=OG02GG
00<0emL09ML00`3Ge`04e`030=OG04cG00<0emL01ML00`3Ge`08e`002ML00`3Ge`04e`030=OG04gG
00<0emL01=L00`3Ge`0Ue`030=OG02GG00<0emL01=L00`3Ge`1=e`030=OG00CG00<0emL02=L000WG
00<0emL01=L00`3Ge`1=e`030=OG00CG00<0emL09ML00`3Ge`0Ue`030=OG00?G00<0emL0C]L00`3G
e`03e`030=OG00WG000:e`030=OG00?G00<0emL0CML00`3Ge`03e`030=OG02KG00<0emL09ML00`3G
e`03e`030=OG04kG00<0emL00mL00`3Ge`09e`002]L00`3Ge`03e`030=OG04kG00<0emL00]L00`3G
e`0Ae`@00mL00`3Ge`04e`030=OG00CG00<0emL09ML00`3Ge`03e`030=OG04kG00<0emL00mL00`3G
e`09e`002]L00`3Ge`03e`030=OG04kG00<0emL00]L00`3Ge`0Ce`030=OG00WG00<0emL01=L00`3G
e`0Ve`030=OG00;G00<0emL0C]L00`3Ge`03e`030=OG00WG000;e`030=OG00;G00<0emL0C]L00`3G
e`02e`030=OG01?G00<0emL01]L500GG0`0Ve`030=OG00;G00<0emL0CmL01@3GemL000cG000;e`05
0=OGe`00D]L01@3GemL001GG00<0emL01]L0103Ge`06e`030=OG02KG00<0emL00]L00`3Ge`1?e`05
0=OGe`003=L000_G00D0emOG001Be`050=OGe`005ML00`3Ge`07e`030=L000KG00<0emL09]L01@3G
emL005;G00D0emOG000<e`002mL0103Ge`1Ce`040=OG01CG0`0:e`801]L00`3Ge`0We`040=OG05?G
00@0emL03=L000cG00<0e`00DmL0103Ge`0Fe`030=OG00WG00<0emL01=L00`3Ge`0We`040=L005?G
00@0e`003=L000cG0`1De`80:]L00`3Ge`0Xe`80E=L300gG002?e`030=OG08kG002?e`030=OG08kG
002?e`030=OG08kG002?e`80SmL00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.65343, 0.44171, \
0.0115222, 0.00571412}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{975, 606},
WindowMargins->{{96, Automatic}, {Automatic, 69}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 365, 8, 101, "Input"],
Cell[2073, 60, 111, 2, 32, "Input"],

Cell[CellGroupData[{
Cell[2209, 66, 80, 1, 32, "Input"],
Cell[2292, 69, 320, 8, 36, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2649, 82, 84, 1, 32, "Input"],
Cell[2736, 85, 220, 3, 31, "Output"]
}, Open  ]],
Cell[2971, 91, 62, 1, 32, "Input"],
Cell[3036, 94, 186, 3, 55, "Input"],

Cell[CellGroupData[{
Cell[3247, 101, 65, 1, 32, "Input"],
Cell[3315, 104, 24667, 756, 186, 8031, 546, "GraphicsData", "PostScript", \
"Graphics"],
Cell[27985, 862, 130, 3, 31, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

