(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16890,        656]*)
(*NotebookOutlinePosition[     17521,        678]*)
(*  CellTagsIndexPosition[     17477,        674]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(\(\( (*\ 
      c16 : \ Phase\ portrait\ of\ the\ DUFFING\ equation\ \((2.6  .42)\)\ \
*) \)\(\n\)\(Clear[a, b, n, Duff, x1, x2]; a = 1. ; b = 0.1; n = 2. ; 
    Duff = NDSolve[{\(x1'\)[t] \[Equal] 
            x2[t], \(x2'\)[t] \[Equal] \(-a\)*x1[t] - b*x1[t]^3, 
          x1[0] \[Equal] n, x2[0] \[Equal] 0}, {x1, x2}, {t, 0, 8*Pi}]; 
    ParametricPlot[
      Evaluate[{x1[t], x2[t]} /. Duff], {t, 0, 4. *Pi}]\)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499998 0.238096 0.309017 0.13433 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.73809 .29652 -3 -9 ]
[.73809 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 .04036 -12 -4.5 ]
[.4875 .04036 0 4.5 ]
[.4875 .17469 -12 -4.5 ]
[.4875 .17469 0 4.5 ]
[.4875 .44335 -6 -4.5 ]
[.4875 .44335 0 4.5 ]
[.4875 .57768 -6 -4.5 ]
[.4875 .57768 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-1)] .2619 .29652 0 1 Mshowa
.73809 .30902 m
.73809 .31527 L
s
[(1)] .73809 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07142 .30902 m
.07142 .31277 L
s
.11904 .30902 m
.11904 .31277 L
s
.16666 .30902 m
.16666 .31277 L
s
.21428 .30902 m
.21428 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .04036 m
.50625 .04036 L
s
[(-2)] .4875 .04036 1 0 Mshowa
.5 .17469 m
.50625 .17469 L
s
[(-1)] .4875 .17469 1 0 Mshowa
.5 .44335 m
.50625 .44335 L
s
[(1)] .4875 .44335 1 0 Mshowa
.5 .57768 m
.50625 .57768 L
s
[(2)] .4875 .57768 1 0 Mshowa
.125 Mabswid
.5 .06722 m
.50375 .06722 L
s
.5 .09409 m
.50375 .09409 L
s
.5 .12095 m
.50375 .12095 L
s
.5 .14782 m
.50375 .14782 L
s
.5 .20155 m
.50375 .20155 L
s
.5 .22842 m
.50375 .22842 L
s
.5 .25528 m
.50375 .25528 L
s
.5 .28215 m
.50375 .28215 L
s
.5 .33588 m
.50375 .33588 L
s
.5 .36275 m
.50375 .36275 L
s
.5 .38962 m
.50375 .38962 L
s
.5 .41648 m
.50375 .41648 L
s
.5 .47021 m
.50375 .47021 L
s
.5 .49708 m
.50375 .49708 L
s
.5 .52395 m
.50375 .52395 L
s
.5 .55081 m
.50375 .55081 L
s
.5 .01349 m
.50375 .01349 L
s
.5 .60454 m
.50375 .60454 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.97619 .30902 m
.97611 .30318 L
.9759 .29788 L
.97549 .29176 L
.97494 .28599 L
.97357 .27575 L
.97153 .2647 L
.9686 .25263 L
.96475 .23997 L
.95589 .21774 L
.94422 .19557 L
.93104 .17567 L
.89347 .13407 L
.86998 .11464 L
.84546 .09776 L
.79433 .07041 L
.73312 .04732 L
.69622 .03709 L
.66082 .02938 L
.62727 .02374 L
.60938 .02133 L
.59033 .01919 L
.57353 .01767 L
.555 .01636 L
.54684 .01591 L
.53808 .0155 L
.53041 .01521 L
.52226 .01498 L
.51371 .01482 L
.50579 .01473 L
.49727 .01472 L
.49242 .01474 L
.48787 .01479 L
.47969 .01494 L
.47219 .01513 L
.46397 .01542 L
.45533 .0158 L
.44029 .01665 L
.42635 .01768 L
.39492 .02081 L
.36115 .02551 L
.32527 .03219 L
.29443 .03946 L
.26275 .04862 L
.20619 .07018 L
.15889 .09506 L
.11505 .12658 L
.09404 .14613 L
.07637 .16602 L
.06209 .18552 L
Mistroke
.04897 .20781 L
.03934 .22886 L
.03244 .24893 L
.0291 .2618 L
.02675 .27375 L
.02579 .28003 L
.02496 .28695 L
.02462 .29044 L
.02433 .29418 L
.02411 .29772 L
.02396 .30094 L
.02381 .30727 L
.02385 .31312 L
.02407 .31954 L
.02425 .32278 L
.02451 .32634 L
.02509 .3323 L
.02589 .3387 L
.02783 .35022 L
.03031 .36127 L
.03368 .37322 L
.04254 .39681 L
.05316 .41795 L
.06503 .43686 L
.08145 .45814 L
.10198 .47973 L
.14586 .51464 L
.19575 .54299 L
.24682 .56408 L
.27531 .57327 L
.30691 .5817 L
.33496 .58783 L
.36614 .59331 L
.38537 .59604 L
.40333 .59818 L
.42027 .59984 L
.43908 .6013 L
.44718 .6018 L
.45594 .60227 L
.46352 .6026 L
.47183 .60289 L
.48069 .60312 L
.48553 .60321 L
.49004 .60327 L
.49812 .60332 L
.50677 .6033 L
.51523 .60319 L
.52003 .6031 L
.52453 .60299 L
.53359 .60271 L
Mistroke
.54332 .6023 L
.56088 .6013 L
.57687 .60009 L
.59534 .59832 L
.61534 .59595 L
.65128 .59041 L
.6842 .58377 L
.7183 .57511 L
.7765 .55527 L
.80656 .54187 L
.83264 .52801 L
.85881 .51145 L
.88504 .49137 L
.92261 .45327 L
.93928 .43042 L
.95218 .40799 L
.96242 .38461 L
.96697 .37108 L
.97039 .3584 L
.97273 .34724 L
.97462 .33483 L
.97529 .32857 L
.97557 .32528 L
.9758 .32181 L
.97609 .31542 L
.97619 .30956 L
.97612 .30378 L
.97593 .29854 L
.97554 .29249 L
.97502 .28679 L
.97371 .27667 L
.97175 .26577 L
.96893 .25383 L
.9652 .24134 L
.95664 .21939 L
.94499 .19687 L
.93211 .17714 L
.91598 .15694 L
.89588 .1363 L
.85421 .10345 L
.8085 .07712 L
.7787 .06367 L
.74924 .05259 L
.69111 .03586 L
.65704 .02867 L
.62505 .02342 L
.58934 .01909 L
.57119 .01748 L
.56081 .01673 L
.5512 .01614 L
Mistroke
.54297 .01572 L
.53389 .01534 L
.52475 .01505 L
.51974 .01493 L
.51505 .01484 L
.50644 .01474 L
.49855 .01472 L
.48945 .01477 L
.4808 .01491 L
.47311 .01511 L
.46492 .01538 L
.4502 .01606 L
.43275 .01718 L
.41699 .01849 L
.38204 .02243 L
.34487 .02832 L
.31058 .03546 L
.27988 .04344 L
.22163 .06353 L
.17191 .08743 L
.12386 .11938 L
.10038 .13983 L
.08139 .15997 L
.06577 .18012 L
.05172 .20266 L
.0419 .2227 L
.03346 .24552 L
.02988 .25851 L
.02731 .27055 L
.02617 .27744 L
.0253 .28387 L
.02461 .29059 L
.02433 .29416 L
.0241 .29797 L
.02386 .30441 L
.02381 .30805 L
.02382 .3114 L
.02398 .31757 L
.02434 .32409 L
.02484 .32992 L
.02545 .33536 L
.02735 .3477 L
.03007 .36031 L
.03327 .37189 L
.04288 .39759 L
.05402 .41947 L
.06852 .44177 L
.10326 .48094 L
.14195 .51198 L
.19325 .54178 L
Mistroke
.24597 .56378 L
.27532 .57327 L
.30864 .58211 L
.3445 .58965 L
.37872 .59515 L
.41255 .59913 L
.43183 .60079 L
.44975 .60195 L
.46543 .60267 L
.47437 .60296 L
.48276 .60316 L
.49159 .60328 L
.49967 .60332 L
.50855 .60328 L
.513 .60323 L
.51788 .60315 L
.52651 .60294 L
.53465 .60267 L
.54984 .60197 L
.56615 .60093 L
.58374 .59948 L
.61519 .59597 L
.64376 .59171 L
.67443 .58591 L
.70656 .57831 L
.76197 .5609 L
.79379 .54786 L
.8223 .53378 L
.87065 .50289 L
.9104 .46725 L
.92729 .44736 L
.94324 .42409 L
.95443 .40341 L
.96398 .38029 L
.96746 .36943 L
.97051 .35787 L
.9726 .34791 L
.97435 .33693 L
.97511 .33044 L
.97563 .32444 L
.97583 .32129 L
.97601 .31783 L
.97612 .31422 L
.97618 .31083 L
.97614 .30461 L
.97595 .29892 L
.97578 .29579 L
.97553 .29236 L
.97495 .28614 L
.97421 .28008 L
Mistroke
.97338 .2746 L
.97102 .26237 L
.96819 .25115 L
.96498 .24068 L
.95508 .21601 L
.94336 .19414 L
.92772 .17123 L
.9082 .14846 L
.86865 .11364 L
.81835 .08214 L
.76466 .05814 L
.71153 .04105 L
.68096 .03354 L
.64764 .02699 L
.61864 .02253 L
.58617 .01879 L
.56787 .01723 L
.55101 .01613 L
.54215 .01568 L
.53245 .01529 L
.52754 .01513 L
.5223 .01498 L
.51739 .01488 L
.51286 .0148 L
.50391 .01472 L
.4992 .01472 L
.49421 .01473 L
.48583 .01482 L
.48106 .01491 L
.47661 .01501 L
.46832 .01526 L
.46076 .01555 L
.44378 .01643 L
.43251 .0172 L
.42027 .01819 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooohoG00<0emL0S]L008oG00<0emL0S]L008oG
00<0emL0S]L008oG0P2?e`00N]L[07_G001ce`X04]L00`3Ge`0@e``0L]L006_G2`0Ie`030=OG01[G
2P1Ze`00IML802;G00<0emL08mL706CG001Pe`H0:ML00`3Ge`0Xe`L0GmL005_G1P0Ue`@01ML00`3G
e`0]e`L0F]L005OG1@0Ze`030=OG00KG00<0emL0<]L605KG001Be`D0<=L00`3Ge`05e`<0=]L605;G
001>e`D0;ML400CG00<0emL01=L00`3Ge`0ie`H0CmL004[G1@0je`030=OG00?G00<0emL0?=L604cG
0018e`@0>]L0103Ge`05e`030=OG043G1@19e`00A]L303kG0P06e`030=OG04?G1@16e`00A=L304SG
00<0emL0A]L504?G0011e`<0BmL00`3Ge`19e`@0@ML003oG0P1>e`030=OG04_G100oe`00?ML2053G
0P1?e`<0?ML003_G0P1Be`030=OG053G0`0ke`00>ML205CG00<0emL0D]L303WG000ge`80E]L00`3G
e`1De`<0=mL003GG0P1He`030=OG05KG0`0ee`00<mL205[G00<0emL0F=L303?G000ae`80G=L00`3G
e`1Je`<0<ML002oG0P1Ne`80GML2033G000]e`80H=L00`3Ge`1Ne`80;]L002cG0P1Qe`030=OG063G
0P0/e`00:]L206?G00<0emL0HML202_G000Ye`80I=L00`3Ge`1Se`80:ML002OG0P1Ve`030=OG06CG
0`0We`009]L206OG00<0emL0IML302KG000Te`80JML00`3Ge`1We`809ML002?G0P1Ze`80JML202CG
000Re`80JmL00`3Ge`1Ye`<08]L0027G00<0emL0JmL00`3Ge`1Ze`<08ML0023G00<0emL0K=L00`3G
e`1[e`<08=L001oG00<0emL0KML00`3Ge`1]e`807mL001gG0P1`e`030=OG06kG0P0Ne`007=L2077G
00<0emL0KmL201gG000Ke`80L]L00`3Ge`1`e`807=L001[G0P1ce`80L]L201_G000Ie`80M=L00`3G
e`1be`806]L001SG00<0emL0M=L00`3Ge`1ce`806ML001OG0P1fe`030=OG07CG0P0He`005]L207OG
00<0emL0MML201OG000Fe`030=OG07KG00<0emL0MML201OG000Ee`030=OG06kG1005e`030=OG07KG
0P0Fe`005=L207;G00<0emL01=L00`3Ge`1ge`805ML001CG00<0emL0LML00`3Ge`04e`<0N=L201CG
000Ce`030=OG06[G1004e`030=OG00CG00<0emL0NML00`3Ge`0Be`004]L207CG00<0emL01=L00`3G
e`1ie`804mL001;G00<0emL0LML300KG00<0emL0N]L00`3Ge`0Ae`004ML00`3Ge`1de`030=OG00CG
00<0emL0NmL00`3Ge`0@e`004ML00`3Ge`1ke`030=OG07_G0P0Ae`004=L00`3Ge`1le`030=OG07cG
00<0emL03mL000oG0P1ne`80O]L00`3Ge`0>e`003mL00`3Ge`1me`030=OG07gG00<0emL03]L000kG
00<0emL0O]L00`3Ge`1ne`030=OG00gG000=e`80P=L00`3Ge`1ne`803]L000gG00<0emL0OmL00`3G
e`1oe`030=OG00cG000<e`80PML00`3Ge`1oe`803ML000cG00<0emL0P=L00`3Ge`20e`030=OG00_G
000;e`80P]L00`3Ge`20e`803=L000_G00<0emL0PML208;G00<0emL02]L000_G00<0emL0PML00`3G
e`21e`030=OG00[G000:e`030=OG08;G00<0emL0PML200_G000:e`030=OG08;G00<0emL0P]L00`3G
e`09e`002ML208CG00<0emL0P]L00`3Ge`09e`002ML00`3Ge`23e`030=OG08;G0P0:e`002ML00`3G
e`23e`030=OG08?G00<0emL02=L000SG0P25e`030=OG08?G00<0emL02=L000SG00<0emL0Q=L208CG
00<0emL02=L000SG00<0emL0Q=L00`3Ge`23e`802ML000SG00<0emL0Q=L00`3Ge`24e`030=OG00OG
0008e`030=OG08CG00<0emL0Q=L00`3Ge`07e`002=L4043G100oe`030=OG03oG1010e`@01mL000OG
0P15e`030=OG03kG00<0emL0@ML00`3Ge`0oe`030=L000SG0007e`030=L004CG00<0emL0?]L00`3G
e`11e`030=OG043G0P08e`000]L40005e`3Ge`00>mL400CG00<0emL0?]L204;G00<0emL0@ML00`3G
e`06e`001mL01@3GemL004;G00<0emL0?]L00`3Ge`11e`030=OG047G0P07e`001mL200;G00<0emL0
?]L3043G00<0emL0?mL3047G00@0e`001mL000OG00@0e`00@mL00`3Ge`0ne`030=OG047G00<0emL0
@=L200SG0007e`030=OG08GG00<0emL0QML00`3Ge`06e`001mL00`3Ge`25e`030=OG08GG00<0emL0
1]L000OG00<0emL0QML00`3Ge`25e`030=OG00KG0007e`030=OG08GG00<0emL0QML00`3Ge`06e`00
o`0P007G0007e`030=OG00[G00<0emL02mL00`3Ge`0;e`030=OG00[G00<0emL02mL00`3Ge`0:e`03
0=OG00_G00<0emL02mL00`3Ge`0:e`030=OG00_G00<0emL02mL00`3Ge`0:e`030=OG00_G00<0emL0
2mL00`3Ge`0:e`030=OG00_G00<0emL02]L00`3Ge`0;e`030=OG00_G00<0emL02]L00`3Ge`06e`00
1mL00`3Ge`11e`030=OG047G00<0emL0@ML00`3Ge`11e`030=OG00KG0007e`030=OG08GG00<0emL0
QML00`3Ge`06e`001mL00`3Ge`25e`030=OG08GG00<0emL01]L000OG00<0emL0QML00`3Ge`25e`03
0=OG00KG0007e`030=OG08GG00<0emL0QML00`3Ge`06e`001mL00`3Ge`25e`030=OG08GG00<0emL0
1]L000OG00<0emL0QML208KG00<0emL01]L000OG00<0emL0QML00`3Ge`24e`802=L000OG0P26e`03
0=OG08CG00<0emL01mL000SG00<0emL0Q=L00`3Ge`24e`030=OG00OG0008e`030=OG08CG00<0emL0
Q=L00`3Ge`07e`002=L00`3Ge`24e`030=OG08CG00<0emL01mL000SG0P25e`030=OG08CG00<0emL0
1mL000SG0P25e`80QML00`3Ge`07e`002=L208GG00<0emL0PmL00`3Ge`08e`002ML00`3Ge`23e`03
0=OG08?G00<0emL02=L000WG00<0emL0PmL00`3Ge`23e`030=OG00SG0009e`030=OG08?G00<0emL0
P]L00`3Ge`09e`002]L00`3Ge`22e`030=OG08;G00<0emL02ML000[G00<0emL0P]L00`3Ge`21e`80
2mL000_G00<0emL0PML00`3Ge`21e`030=OG00[G000;e`030=OG087G0P21e`803=L000cG00<0emL0
P=L00`3Ge`20e`030=OG00_G000<e`030=OG083G00<0emL0OmL200gG000<e`030=OG083G00<0emL0
OmL00`3Ge`0<e`003ML00`3Ge`1oe`030=OG07kG0P0>e`003ML00`3Ge`1oe`030=OG07kG00<0emL0
3ML000kG00<0emL0O]L00`3Ge`1ne`030=OG00gG000>e`030=OG07kG00<0emL0OML00`3Ge`0>e`00
3mL00`3Ge`1me`80O]L00`3Ge`0>e`003mL00`3Ge`1me`030=OG07cG00<0emL03mL0013G00<0emL0
O=L00`3Ge`1le`030=OG00oG000@e`030=OG07cG00<0emL0NmL00`3Ge`0@e`004ML00`3Ge`1ke`03
0=OG07_G00<0emL04=L0017G0P1ce`@01ML00`3Ge`1je`030=OG017G000Be`030=OG07?G00<0emL0
1=L00`3Ge`1ie`030=OG01;G000Ce`030=OG07;G00<0emL01=L307SG00<0emL04mL001CG00<0emL0
LML00`3Ge`04e`030=OG07SG00<0emL04mL001CG0P1be`030=OG00CG00<0emL0MmL00`3Ge`0De`00
5ML206oG0`06e`030=OG07KG00<0emL05ML001KG0P1`e`030=OG00CG00<0emL0MML00`3Ge`0Fe`00
5mL207KG00<0emL0M=L00`3Ge`0Ge`006=L00`3Ge`1de`030=OG07?G00<0emL06=L001WG00<0emL0
LmL00`3Ge`1be`030=OG01WG000Je`030=OG07;G0P1be`030=OG01[G000Ke`030=OG077G00<0emL0
L=L00`3Ge`0Ke`007=L00`3Ge`1`e`030=OG06oG00<0emL07=L001gG00<0emL0KmL00`3Ge`1^e`03
0=OG01gG000Ne`030=OG06kG00<0emL0KML00`3Ge`0Ne`007mL206kG00<0emL0K=L00`3Ge`0Oe`00
8ML00`3Ge`1[e`030=OG06_G00<0emL08=L002;G00<0emL0J]L00`3Ge`1Ze`030=OG027G000Se`80
J]L206[G00<0emL08]L002CG0P1Ye`030=OG06OG0P0Ue`009ML206SG00<0emL0I]L202KG000We`80
I]L00`3Ge`1Ue`809mL002SG0P1Ue`030=OG06?G0P0Ye`00:ML206CG00<0emL0HML302[G000[e`80
H]L00`3Ge`1Pe`80;=L002gG0P1Pe`030=OG05kG0`0]e`00;]L305kG0P1Me`<0;mL0033G0P1Me`03
0=OG05[G0`0ae`00<]L205_G00<0emL0FML303;G000ce`<0FML00`3Ge`1Ge`<0==L003GG0`1Ge`03
0=OG05GG0`0fe`00=mL305GG00<0emL0DmL303SG000ie`<0DmL00`3Ge`1@e`@0>]L003_G101@e`80
CmL403cG000ne`<0C]L00`3Ge`1<e`@0?]L0043G101;e`030=OG04[G1010e`00@mL304WG00<0emL0
AmL404?G0015e`@0A]L00`3Ge`14e`<0AmL004SG0`14e`030=OG047G0`1:e`00BmL303SG1005e`03
0=OG03gG101=e`00C]L403CG00<0emL01]L00`3Ge`0je`<0DML005;G100ae`030=OG00GG0`0fe`@0
E=L005KG1@0]e`030=OG00CG00<0emL0<]L505OG001Je`H0:ML00`3Ge`03e`030=OG02gG1`1Je`00
G]L7027G00@0emL01ML00`3Ge`0Ye`L0G]L006GG1`0Ke`801]L00`3Ge`0Se`P0HmL006[G1`0Ne`03
0=OG01[G2P1Ze`00LML:01CG00<0emL04ML;07;G001ieb`0NmL008oG0P2?e`00SmL00`3Ge`2>e`00
SmL00`3Ge`2>e`00SmL00`3Ge`2>e`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.10519, -2.30045, \
0.0146704, 0.0260029}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{1109, 640},
WindowMargins->{{77, Automatic}, {Automatic, 28}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 450, 8, 124, "Input"],
Cell[2180, 62, 14561, 586, 186, 7240, 491, "GraphicsData", "PostScript", \
"Graphics"],
Cell[16744, 650, 130, 3, 31, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

