(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18295,        666]*)
(*NotebookOutlinePosition[     18927,        688]*)
(*  CellTagsIndexPosition[     18883,        684]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(\(\( (*\ 
      c17 : \ Phase\ portrait\ of\ the\ Mathieu\ equation\ *) \)\(\n\
\)\(Clear[\[Lambda], n, Ma, x1, x2]; \[Lambda] = 0.5; n = 2. ; 
    Ma = NDSolve[{\(x1'\)[t] \[Equal] 
            x2[t], \(x2'\)[t] \[Equal] \(-\[Lambda]\)*\((1 + Sin[t])\)*x1[t], 
          x1[0] \[Equal] n, x2[0] \[Equal] 0}, {x1, x2}, {t, 0, 8*Pi}]; 
    ParametricPlot[
      Evaluate[{x1[t], x2[t]} /. Ma], {t, 0, 4. *Pi}]\)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.497929 0.17264 0.347254 0.177225 [
[.15265 .33475 -6 -9 ]
[.15265 .33475 6 0 ]
[.32529 .33475 -6 -9 ]
[.32529 .33475 6 0 ]
[.67057 .33475 -3 -9 ]
[.67057 .33475 3 0 ]
[.84321 .33475 -3 -9 ]
[.84321 .33475 3 0 ]
[.48543 .08142 -24 -4.5 ]
[.48543 .08142 0 4.5 ]
[.48543 .17003 -12 -4.5 ]
[.48543 .17003 0 4.5 ]
[.48543 .25864 -24 -4.5 ]
[.48543 .25864 0 4.5 ]
[.48543 .43587 -18 -4.5 ]
[.48543 .43587 0 4.5 ]
[.48543 .52448 -6 -4.5 ]
[.48543 .52448 0 4.5 ]
[.48543 .61309 -18 -4.5 ]
[.48543 .61309 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15265 .34725 m
.15265 .3535 L
s
[(-2)] .15265 .33475 0 1 Mshowa
.32529 .34725 m
.32529 .3535 L
s
[(-1)] .32529 .33475 0 1 Mshowa
.67057 .34725 m
.67057 .3535 L
s
[(1)] .67057 .33475 0 1 Mshowa
.84321 .34725 m
.84321 .3535 L
s
[(2)] .84321 .33475 0 1 Mshowa
.125 Mabswid
.18718 .34725 m
.18718 .351 L
s
.22171 .34725 m
.22171 .351 L
s
.25623 .34725 m
.25623 .351 L
s
.29076 .34725 m
.29076 .351 L
s
.35982 .34725 m
.35982 .351 L
s
.39435 .34725 m
.39435 .351 L
s
.42887 .34725 m
.42887 .351 L
s
.4634 .34725 m
.4634 .351 L
s
.53246 .34725 m
.53246 .351 L
s
.56699 .34725 m
.56699 .351 L
s
.60151 .34725 m
.60151 .351 L
s
.63604 .34725 m
.63604 .351 L
s
.7051 .34725 m
.7051 .351 L
s
.73962 .34725 m
.73962 .351 L
s
.77415 .34725 m
.77415 .351 L
s
.80868 .34725 m
.80868 .351 L
s
.11812 .34725 m
.11812 .351 L
s
.08359 .34725 m
.08359 .351 L
s
.04907 .34725 m
.04907 .351 L
s
.01454 .34725 m
.01454 .351 L
s
.87774 .34725 m
.87774 .351 L
s
.91226 .34725 m
.91226 .351 L
s
.94679 .34725 m
.94679 .351 L
s
.98132 .34725 m
.98132 .351 L
s
.25 Mabswid
0 .34725 m
1 .34725 L
s
.49793 .08142 m
.50418 .08142 L
s
[(-1.5)] .48543 .08142 1 0 Mshowa
.49793 .17003 m
.50418 .17003 L
s
[(-1)] .48543 .17003 1 0 Mshowa
.49793 .25864 m
.50418 .25864 L
s
[(-0.5)] .48543 .25864 1 0 Mshowa
.49793 .43587 m
.50418 .43587 L
s
[(0.5)] .48543 .43587 1 0 Mshowa
.49793 .52448 m
.50418 .52448 L
s
[(1)] .48543 .52448 1 0 Mshowa
.49793 .61309 m
.50418 .61309 L
s
[(1.5)] .48543 .61309 1 0 Mshowa
.125 Mabswid
.49793 .09914 m
.50168 .09914 L
s
.49793 .11686 m
.50168 .11686 L
s
.49793 .13458 m
.50168 .13458 L
s
.49793 .15231 m
.50168 .15231 L
s
.49793 .18775 m
.50168 .18775 L
s
.49793 .20547 m
.50168 .20547 L
s
.49793 .2232 m
.50168 .2232 L
s
.49793 .24092 m
.50168 .24092 L
s
.49793 .27636 m
.50168 .27636 L
s
.49793 .29409 m
.50168 .29409 L
s
.49793 .31181 m
.50168 .31181 L
s
.49793 .32953 m
.50168 .32953 L
s
.49793 .36498 m
.50168 .36498 L
s
.49793 .3827 m
.50168 .3827 L
s
.49793 .40042 m
.50168 .40042 L
s
.49793 .41814 m
.50168 .41814 L
s
.49793 .45359 m
.50168 .45359 L
s
.49793 .47131 m
.50168 .47131 L
s
.49793 .48903 m
.50168 .48903 L
s
.49793 .50676 m
.50168 .50676 L
s
.49793 .5422 m
.50168 .5422 L
s
.49793 .55992 m
.50168 .55992 L
s
.49793 .57765 m
.50168 .57765 L
s
.49793 .59537 m
.50168 .59537 L
s
.49793 .06369 m
.50168 .06369 L
s
.49793 .04597 m
.50168 .04597 L
s
.49793 .02825 m
.50168 .02825 L
s
.49793 .01053 m
.50168 .01053 L
s
.25 Mabswid
.49793 0 m
.49793 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.84321 .34725 m
.84319 .34448 L
.84313 .34193 L
.84302 .33893 L
.84288 .33606 L
.84251 .33085 L
.84195 .32505 L
.84114 .3185 L
.84005 .31137 L
.83747 .29813 L
.82983 .27011 L
.81736 .23738 L
.80027 .20322 L
.77672 .16633 L
.72095 .10376 L
.68754 .07684 L
.64738 .05205 L
.62793 .0426 L
.60658 .03394 L
.58744 .02763 L
.56685 .0223 L
.55614 .0201 L
.54432 .01812 L
.53351 .01671 L
.52339 .01573 L
.51724 .0153 L
.51421 .01513 L
.5114 .015 L
.50616 .01482 L
.5034 .01476 L
.50046 .01472 L
.49756 .01472 L
.49443 .01473 L
.49148 .01478 L
.48877 .01485 L
.48577 .01494 L
.48248 .01509 L
.47587 .01547 L
.47007 .01592 L
.4646 .01643 L
.45439 .01764 L
.44345 .01929 L
.43165 .02148 L
.41063 .02643 L
.39156 .03208 L
.35317 .04688 L
.31912 .06391 L
.24996 .11056 L
.19476 .16068 L
.15558 .20418 L
Mistroke
.10185 .27346 L
.09282 .28473 L
.08553 .29284 L
.07928 .29862 L
.07406 .30229 L
.07143 .30368 L
.06875 .3048 L
.06611 .30559 L
.06463 .30592 L
.06326 .30616 L
.06183 .30634 L
.06112 .30641 L
.06047 .30646 L
.05926 .30654 L
.05862 .30657 L
.05794 .30659 L
.05727 .3066 L
.0569 .30661 L
.05655 .30661 L
.05592 .30662 L
.05525 .30662 L
.05489 .30662 L
.05451 .30662 L
.05383 .30662 L
.05341 .30662 L
.05301 .30662 L
.05266 .30663 L
.05228 .30663 L
.05163 .30663 L
.05104 .30664 L
.05036 .30665 L
.04972 .30667 L
.04912 .3067 L
.04857 .30672 L
.04733 .30681 L
.04669 .30687 L
.04608 .30694 L
.04471 .30713 L
.04338 .30739 L
.04196 .30774 L
.04067 .30815 L
.03928 .30871 L
.03794 .30936 L
.03654 .3102 L
.03411 .3121 L
.03198 .31438 L
.02984 .31752 L
.02807 .32106 L
.02642 .32573 L
.02571 .32842 L
Mistroke
.02505 .33165 L
.02457 .33472 L
.02423 .33773 L
.02409 .33947 L
.02402 .34042 L
.02396 .34144 L
.02391 .34245 L
.02388 .34337 L
.02383 .34522 L
.02381 .34712 L
.02382 .34891 L
.02386 .35093 L
.0239 .35197 L
.02395 .35313 L
.02405 .35513 L
.0242 .35732 L
.02455 .36143 L
.0251 .36629 L
.02586 .37172 L
.02772 .38217 L
.03456 .40917 L
.04379 .43609 L
.05806 .46927 L
.09674 .53734 L
.12346 .57441 L
.15812 .61492 L
Mfstroke
.15812 .61492 m
.16163 .61803 L
s
.83543 .61803 m
.85979 .59172 L
.89155 .55107 L
.93371 .48271 L
.95012 .44831 L
.96129 .41966 L
.96902 .39448 L
.97205 .38177 L
.97401 .37134 L
.97469 .3669 L
.97527 .36234 L
.97568 .35826 L
.97595 .35471 L
.97605 .35283 L
.97612 .35113 L
.97617 .34931 L
.97619 .34832 L
.97619 .34743 L
.97618 .34569 L
.97616 .34473 L
.97613 .34386 L
.97607 .3423 L
.97602 .34153 L
.97597 .3407 L
.97573 .33804 L
.97556 .33661 L
.97538 .33533 L
.97492 .33269 L
.97442 .33049 L
.97335 .32694 L
.972 .32375 L
.97035 .32095 L
.96942 .31973 L
.96838 .3186 L
.96744 .31774 L
.96638 .31694 L
.96445 .31583 L
.96344 .3154 L
.96232 .31502 L
.96125 .31474 L
.96025 .31454 L
.95926 .3144 L
.95835 .3143 L
.95785 .31426 L
.95731 .31423 L
.95679 .3142 L
.95632 .31418 L
.95577 .31417 L
.95547 .31416 L
.95518 .31416 L
Mistroke
.95466 .31416 L
.9541 .31415 L
.95379 .31415 L
.95351 .31415 L
.95319 .31415 L
.95286 .31415 L
.95257 .31415 L
.95226 .31415 L
.95172 .31415 L
.95121 .31414 L
.95066 .31413 L
.95014 .31412 L
.94967 .3141 L
.94912 .31407 L
.94852 .31402 L
.94742 .31392 L
.94645 .31378 L
.94537 .31358 L
.94424 .31331 L
.94317 .31299 L
.94123 .31223 L
.93909 .31112 L
.93645 .30934 L
.93382 .30712 L
.92839 .30139 L
.89613 .25526 L
.85419 .19778 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooohkG00<0emL0SmL008kG00<0emL0SmL008kG
00<0emL0SmL008kG0P2@e`00Q=LF08KG001ne`H02]L00`3Ge`09e`L0OmL007[G100@e`030=OG013G
101ke`00MML501CG00<0emL05=L507KG001ce`806ML201[G0P1de`00L=L301_G00<0emL06mL207;G
001]e`<07]L00`3Ge`0Me`80L=L006_G0P0Qe`030=OG01oG0P1^e`00J=L302?G0P0Re`<0JmL006KG
0P0Ve`030=OG02CG0P1Ye`00I=L202SG00<0emL09]L206OG001Re`80:]L00`3Ge`0Xe`80IML0063G
0P0/e`030=OG02[G0P1Se`00G]L202kG0P0]e`030=OG063G001Le`80<=L00`3Ge`0]e`80H=L005[G
0P0be`030=OG02oG0P1Ne`00FML00`3Ge`0Ne`@00mL00`3Ge`02e`<01ML00`3Ge`0ae`80G=L005OG
0P0Se`030=OG00[G00<0emL00]L00`3Ge`0ce`030=OG05WG001Fe`030=OG02?G00<0emL02]L00`3G
e`02e`<0==L00`3Ge`1He`00E=L201kG1004e`030=OG00OG0`05e`030=OG03GG00<0emL0EmL005?G
00<0emL09]L00`3Ge`07e`030=OG00GG00<0emL0=]L00`3Ge`1Fe`00D]L00`3Ge`0Ue`<02ML00`3G
e`05e`030=OG03OG0P1Fe`00D=L202[G00<0emL01mL400CG00<0emL0>ML00`3Ge`1Ce`00CmL00`3G
e`0le`80>mL00`3Ge`1Be`00CML203oG00<0emL0>mL00`3Ge`1Ae`00C=L00`3Ge`0oe`030=OG03cG
00<0emL0D=L004[G0P12e`030=OG03gG00<0emL0CmL004WG00<0emL0@]L00`3Ge`0ne`030=OG04kG
0018e`030=OG04?G0P10e`030=OG04gG0017e`030=OG04CG00<0emL0@=L00`3Ge`1<e`00A]L00`3G
e`15e`030=OG047G00<0emL0BmL004CG0P18e`030=OG04;G00<0emL0B]L004?G00<0emL0B=L00`3G
e`13e`030=OG04WG0012e`030=OG04WG0P15e`030=OG04SG0011e`030=OG04[G00<0emL0A=L00`3G
e`18e`00@=L00`3Ge`1;e`030=OG04GG00<0emL0AmL003oG00<0emL0C=L00`3Ge`16e`030=OG04KG
000ne`030=OG04gG00<0emL0AmL00`3Ge`15e`00?=L2053G0P19e`030=OG04CG000ke`030=OG053G
00<0emL0BML00`3Ge`13e`00>]L00`3Ge`1Ae`030=OG04[G00<0emL0@]L003WG00<0emL0B]L400CG
00<0emL0BmL00`3Ge`11e`00>=L00`3Ge`1=e`030=OG00?G00<0emL0C=L00`3Ge`10e`00=mL00`3G
e`1>e`030=OG00?G0`1=e`030=OG03oG000fe`030=OG04OG1004e`030=OG00?G00<0emL0CML00`3G
e`0oe`00=ML00`3Ge`1@e`030=OG00?G00<0emL0C]L00`3Ge`0ne`00==L00`3Ge`1?e`<01ML00`3G
e`1>e`030=OG03kG000ce`030=OG05;G00<0emL00mL00`3Ge`1?e`030=OG03gG000ce`030=OG05SG
0P1@e`030=OG03gG000be`030=OG05WG00<0emL0D=L00`3Ge`0le`00<ML00`3Ge`1Je`030=OG053G
00<0emL0?=L0033G00<0emL0FmL00`3Ge`1Ae`030=OG00kG00<0emL0:]L002oG00<0emL0G=L00`3G
e`1Ae`030=OG00oG00<0emL0:ML002kG00<0emL0GML205?G00<0emL03]L00`3Ge`0Ye`00;ML00`3G
e`1Ne`030=OG05?G00<0emL03]L00`3Ge`0Xe`00;=L00`3Ge`1Oe`030=OG05?G00<0emL03mL00`3G
e`0We`00;=L00`3Ge`1Oe`030=OG05CG00<0emL03]L00`3Ge`0We`00:mL00`3Ge`1Pe`030=OG05CG
00<0emL03mL00`3Ge`0Ve`00:]L00`3Ge`1Qe`80E]L00`3Ge`0?e`030=OG02GG000Ye`030=OG06;G
00<0emL0EML00`3Ge`0?e`030=OG02GG000Xe`030=OG06?G00<0emL0E]L00`3Ge`0?e`030=OG02CG
000Xe`030=OG06?G00<0emL0E]L00`3Ge`0@e`030=OG02?G000We`030=OG06CG00<0emL0EmL00`3G
e`0@e`030=OG02;G000Ve`030=OG06GG0P1He`030=OG013G00<0emL08]L002GG00<0emL0I]L00`3G
e`1He`030=OG013G00<0emL08ML002GG00<0emL0I]L00`3Ge`1He`030=OG017G00<0emL08=L002CG
00<0emL0E=L200CG00<0emL00]L300GG00<0emL0FML00`3Ge`0@e`030=OG023G000Se`030=OG05CG
00@0emL02mL00`3Ge`02e`030=OG05WG00<0emL04ML00`3Ge`0Oe`008]L00`3Ge`1Ee`040=OG00_G
00<0emL00]L305WG00<0emL04]L00`3Ge`0Ne`008ML00`3Ge`1@e`@00]L0103Ge`08e`<01ML00`3G
e`1Je`030=OG017G00<0emL07]L0027G00<0emL0E]L0103Ge`08e`030=OG00GG00<0emL0F]L00`3G
e`0Be`030=OG01gG000Pe`030=OG05OG00@0emL02=L00`3Ge`05e`030=OG05_G00<0emL04]L00`3G
e`0Le`007mL00`3Ge`1Ie`802ML400CG00<0emL0FmL00`3Ge`0Be`030=OG01cG000Ne`030=OG06gG
0P1Le`030=OG01?G00<0emL06mL001gG00<0emL0K]L00`3Ge`1Le`030=OG01?G00<0emL06]L001gG
00<0emL0K]L00`3Ge`1Le`030=OG01CG00<0emL06ML001cG00<0emL0KmL00`3Ge`1Le`030=OG01CG
00<0emL06ML001_G00<0emL0L=L00`3Ge`1Le`030=OG01GG00<0emL06=L001[G00<0emL0LML205kG
00<0emL05ML00`3Ge`0Ge`006ML00`3Ge`1be`030=OG05gG00<0emL05ML00`3Ge`0Ge`006ML00`3G
e`1be`030=OG05gG00<0emL05]L00`3Ge`0Fe`005]L307GG00<0emL0GML00`3Ge`0Ge`030=OG01GG
000=e`T0N=L00`3Ge`1Ne`030=OG01OG00<0emL05=L000cG0P0Pe`@0;ML402_G0P0]e`@0;ML401SG
0P0De`002mL00`3Ge`0Pe`030=OG033G00<0emL0:]L00`3Ge`0^e`030=OG02cG0P0Le`L03ML000_G
00<0emL08ML00`3Ge`0_e`030=OG02[G00<0emL0;]L00`3Ge`0]e`030=OG023G0P0<e`002]L00`3G
e`0Ke`@01=L00`3Ge`0Ve`@01=L00`3Ge`0Ze`030=OG02kG00<0emL0;ML202;G00<0emL02]L000[G
00<0emL09=L00`3Ge`0]e`030=OG02[G00<0emL0;]L00`3Ge`0]e`030=L002;G00<0emL02ML000[G
00<0emL08ML0103Ge`0]e`<0;=L202gG0`0^e`8000?G0=L08ML00`3Ge`09e`002ML00`3Ge`0Se`80
<=L00`3Ge`0Ze`030=OG02kG00<0emL0;ML202?G0P0:e`002ML00`3Ge`22e`030=OG05kG00<0emL0
8mL00`3Ge`08e`002ML00`3Ge`22e`030=OG05kG00<0emL08mL00`3Ge`08e`002ML00`3Ge`22e`03
0=OG05oG00<0emL08]L00`3Ge`08e`000]Oo01`00mL000KG00@0emL01]L00`3Ge`07e`030=OG00OG
00<0emL01]L00`3Ge`07e`030=OG00OG00<0emL01]L00`3Ge`07e`030=OG00OG00<0emL01mL00`3G
e`06e`030=OG00OG00<0emL01mL00`3Ge`06e`030=OG00OG00<0emL01mL00`3Ge`07e`030=OG00KG
00<0emL01mL00`3Ge`07e`030=OG00KG00<0emL01mL00`3Ge`07e`030=OG00OG00<0emL01]L00`3G
e`07e`030=OG00OG00<0emL01ML200WG0009e`030=OG027G00<0emL0;]L00`3Ge`0]e`030=OG02kG
00<0emL0;]L00`3Ge`0Re`030=OG00SG0009e`030=OG08;G00<0emL0Q=L00`3Ge`08e`002ML00`3G
e`22e`030=OG08CG00<0emL02=L000WG00<0emL0P]L208GG00<0emL02=L000WG00<0emL0P]L00`3G
e`24e`030=OG00SG000:e`030=OG087G00<0emL0PmL00`3Ge`09e`002]L00`3Ge`21e`030=OG08?G
00<0emL02ML000[G00<0emL0PML00`3Ge`23e`030=OG00WG000:e`030=OG087G0P24e`030=OG00WG
000:e`030=OG087G00<0emL0PmL00`3Ge`09e`002]L00`3Ge`21e`030=OG08;G00<0emL02]L000_G
00<0emL0P=L00`3Ge`22e`030=OG00[G000;e`030=OG083G00<0emL0P]L00`3Ge`0:e`002mL00`3G
e`20e`80PmL00`3Ge`0:e`002mL00`3Ge`20e`030=OG087G00<0emL02mL000cG00<0emL0OmL00`3G
e`21e`030=OG00_G000<e`030=OG07oG00<0emL0PML00`3Ge`0;e`003=L00`3Ge`1oe`030=OG087G
00<0emL02mL000gG00<0emL0O]L2087G00<0emL03=L000gG00<0emL0O]L00`3Ge`20e`030=OG00cG
000>e`030=OG07gG00<0emL0P=L00`3Ge`0<e`003]L00`3Ge`1Ze`801=L00`3Ge`02e`<01ML00`3G
e`1oe`030=OG00gG000?e`030=OG06SG00@0emL02mL00`3Ge`02e`030=OG07oG00<0emL03ML000oG
00<0emL0J=L0103Ge`0;e`030=OG00;G0`1ne`030=OG00kG000?e`030=OG06SG00@0emL02=L300GG
00<0emL0O]L00`3Ge`0>e`004=L00`3Ge`1We`040=OG00SG00<0emL01ML00`3Ge`1ne`030=OG00kG
000@e`030=OG06OG00@0emL02=L00`3Ge`05e`030=OG07gG00<0emL03mL0017G00<0emL0ImL200WG
1004e`030=OG07gG00<0emL03mL0017G00<0emL0N]L207gG00<0emL04=L0017G00<0emL0N]L00`3G
e`1le`030=OG013G000Be`030=OG07WG00<0emL0NmL00`3Ge`0Ae`004]L00`3Ge`1ie`030=OG07_G
00<0emL04ML001?G00<0emL0N=L00`3Ge`1je`030=OG01;G000Ce`030=OG07SG0P1ke`030=OG01;G
000De`030=OG07OG00<0emL0NML00`3Ge`0Ce`005=L00`3Ge`1ge`030=OG07WG00<0emL04mL001GG
00<0emL0M]L00`3Ge`1he`030=OG01CG000Ee`030=OG07KG00<0emL0MmL00`3Ge`0Ee`005]L00`3G
e`1ee`80N=L00`3Ge`0Ee`005]L00`3Ge`1ee`030=OG07KG00<0emL05]L001OG00<0emL0M=L00`3G
e`1fe`030=OG01KG000He`030=OG07?G00<0emL0MML00`3Ge`0Ge`006=L00`3Ge`1ce`030=OG07CG
00<0emL06=L001WG00<0emL0L]L207GG00<0emL06=L001WG00<0emL0L]L00`3Ge`1ce`030=OG01WG
000Je`030=OG077G00<0emL0LmL00`3Ge`0Ie`006mL00`3Ge`1Xe`@01=L00`3Ge`1be`030=OG01[G
000Ke`030=OG06[G00<0emL00mL00`3Ge`1ae`030=OG01_G000Le`030=OG06WG00<0emL00mL3077G
00<0emL06mL001cG00<0emL0JML00`3Ge`03e`030=OG073G00<0emL07=L001gG00<0emL0J=L00`3G
e`03e`030=OG073G00<0emL07=L001gG00<0emL0I]L300GG00<0emL0KmL00`3Ge`0Me`007]L00`3G
e`1We`030=OG00?G00<0emL0K]L00`3Ge`0Ne`007mL00`3Ge`1/e`80KmL00`3Ge`0Ne`007mL00`3G
e`1/e`030=OG06gG00<0emL07mL0023G00<0emL0JmL00`3Ge`1]e`030=OG01oG000Qe`030=OG06[G
00<0emL0K=L00`3Ge`0Pe`008ML00`3Ge`1Ze`030=OG06_G00<0emL08ML002;G00<0emL0JML206_G
00<0emL08]L002?G00<0emL0J=L00`3Ge`1Ze`030=OG02;G000Te`030=OG06OG00<0emL0JML00`3G
e`0Se`009=L00`3Ge`1We`030=OG06SG00<0emL09=L002GG00<0emL0I]L00`3Ge`1We`030=OG02GG
000Ve`030=OG06GG0P1We`030=OG02KG000We`030=OG06CG00<0emL0IML00`3Ge`0We`009mL00`3G
e`1Te`030=OG06GG00<0emL09mL002SG00<0emL0HmL00`3Ge`1Te`030=OG02SG000Ye`030=OG06;G
00<0emL0HmL00`3Ge`0Ye`00:]L00`3Ge`1Qe`80HmL00`3Ge`0Ze`00:mL00`3Ge`1Pe`030=OG067G
00<0emL0:mL002cG00<0emL0GmL00`3Ge`1Pe`030=OG02cG000/e`030=OG04_G1003e`030=OG00;G
0`05e`030=OG05oG00<0emL0;ML002gG00<0emL0C=L00`3Ge`0:e`030=OG00;G00<0emL0G]L00`3G
e`0^e`00;]L00`3Ge`1;e`030=OG00[G00<0emL00]L305gG00<0emL0;mL002oG0P1;e`030=OG00OG
0`05e`030=OG05cG00<0emL0<=L007cG00<0emL01mL00`3Ge`2Ge`00N]L300WG00<0emL0UmL007cG
00<0emL01mL409KG0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.94334, -1.95941, \
0.0205947, 0.0200619}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ Play\ with\ several\ values\ of\ \[Lambda]\ *) \)], "Input"]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{1010, 583},
WindowMargins->{{Automatic, 64}, {Automatic, 102}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 445, 8, 124, "Input"],
Cell[2175, 62, 15883, 593, 186, 6873, 477, "GraphicsData", "PostScript", \
"Graphics"],
Cell[18061, 657, 130, 3, 31, "Output"]
}, Open  ]],
Cell[18206, 663, 85, 1, 32, "Input"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

