(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     93045,       4234]*)
(*NotebookOutlinePosition[     93677,       4256]*)
(*  CellTagsIndexPosition[     93633,       4252]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(\(\( (*\ 
      c18 : \ Phase\ portrait\ of\ the\ pendulum\ equation\ \((2.7  .17)\)\ \
*) \)\(\n\)\(InputForm[
      Integrate[\(x''\)[t]*\(x'\)[t] + Sin[x[t]]*\(x'\)[t], 
          t] /. {x[t] \[Rule] x, \(x'\)[t] \[Rule] y}]\)\)\)], "Input"],

Cell["y^2/2 - Cos[x]", "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(F[x_, y_] = \((y^2 - 2*Cos[x])\)/2\)], "Input"],

Cell[BoxData[
    \(1\/2\ \((y\^2 - 2\ Cos[x])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ContourPlot[F[x, y], {x, \(-5. \), 5. }, {y, \(-4. \), 4. }, 
      ContourShading \[Rule] False, 
      Contours \[Rule] Range[\(-5. \), 5. , 0.45], 
      PlotPoints \[Rule] 100]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0961538 0.5 0.120192 [
[.11538 -0.0125 -6 -9 ]
[.11538 -0.0125 6 0 ]
[.30769 -0.0125 -6 -9 ]
[.30769 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -3 -9 ]
[.69231 -0.0125 3 0 ]
[.88462 -0.0125 -3 -9 ]
[.88462 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -12 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -12 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -6 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-4)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-2)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(2)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(4)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.06731 0 m
.06731 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-4)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(-2)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(2)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(4)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .07933 m
.00375 .07933 L
s
0 .13942 m
.00375 .13942 L
s
0 .19952 m
.00375 .19952 L
s
0 .31971 m
.00375 .31971 L
s
0 .37981 m
.00375 .37981 L
s
0 .4399 m
.00375 .4399 L
s
0 .5601 m
.00375 .5601 L
s
0 .62019 m
.00375 .62019 L
s
0 .68029 m
.00375 .68029 L
s
0 .80048 m
.00375 .80048 L
s
0 .86058 m
.00375 .86058 L
s
0 .92067 m
.00375 .92067 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.25962 .99625 m
.25962 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.74038 .99625 m
.74038 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.06731 .99625 m
.06731 1 L
s
.01923 .99625 m
.01923 1 L
s
.93269 .99625 m
.93269 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .07933 m
1 .07933 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .31971 m
1 .31971 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .4399 m
1 .4399 L
s
.99625 .5601 m
1 .5601 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .68029 m
1 .68029 L
s
.99625 .80048 m
1 .80048 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .92067 m
1 .92067 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.01923 .887 m
.0281 .88364 L
.02894 .88332 L
.03866 .87953 L
.04837 .87567 L
.05271 .87393 L
.05808 .87177 L
.06779 .86789 L
.07705 .86422 L
.07751 .86404 L
.08722 .86029 L
.09693 .85666 L
.10291 .85451 L
.10664 .8532 L
.11636 .84995 L
.12607 .84696 L
.13373 .84479 L
.13578 .84425 L
.14549 .84186 L
.15521 .83983 L
.16492 .83818 L
.17463 .83693 L
.18434 .83611 L
.19406 .83571 L
.20377 .83576 L
.21348 .83624 L
.22319 .83715 L
.23291 .83848 L
.24262 .84021 L
.25233 .84232 L
.26204 .84477 L
.26212 .84479 L
.27176 .84754 L
.28147 .8506 L
.29118 .85389 L
.29294 .85451 L
.30089 .85738 L
.31061 .86104 L
.31879 .86422 L
.32032 .86482 L
.33003 .86867 L
.33974 .87257 L
.34314 .87393 L
.34946 .87646 L
.35917 .88031 L
.36775 .88364 L
.36888 .88408 L
.37859 .88773 L
.38831 .89124 L
.39442 .89336 L
Mistroke
.39802 .89457 L
.40773 .89768 L
.41744 .90057 L
.42668 .90307 L
.42716 .90319 L
.43687 .90553 L
.44658 .90758 L
.45629 .90931 L
.46601 .9107 L
.47572 .91176 L
.48543 .91247 L
.49301 .91278 L
.49514 .91283 L
.50486 .91283 L
.50699 .91278 L
.51457 .91247 L
.52428 .91176 L
.53399 .9107 L
.54371 .90931 L
.55342 .90758 L
.56313 .90553 L
.57284 .90319 L
.57332 .90307 L
.58256 .90057 L
.59227 .89768 L
.60198 .89457 L
.60558 .89336 L
.61169 .89124 L
.62141 .88773 L
.63112 .88408 L
.63225 .88364 L
.64083 .88031 L
.65054 .87646 L
.65686 .87393 L
.66026 .87257 L
.66997 .86867 L
.67968 .86482 L
.68121 .86422 L
.68939 .86104 L
.69911 .85738 L
.70706 .85451 L
.70882 .85389 L
.71853 .8506 L
.72824 .84754 L
.73788 .84479 L
.73796 .84477 L
.74767 .84232 L
.75738 .84021 L
.76709 .83848 L
.77681 .83715 L
Mistroke
.78652 .83624 L
.79623 .83576 L
.80594 .83571 L
.81566 .83611 L
.82537 .83693 L
.83508 .83818 L
.84479 .83983 L
.85451 .84186 L
.86422 .84425 L
.86627 .84479 L
.87393 .84696 L
.88364 .84995 L
.89336 .8532 L
.89709 .85451 L
.90307 .85666 L
.91278 .86029 L
.92249 .86404 L
.92295 .86422 L
.93221 .86789 L
.94192 .87177 L
.94729 .87393 L
.95163 .87567 L
.96134 .87953 L
.97106 .88332 L
.9719 .88364 L
.98077 .887 L
Mfstroke
.01923 .113 m
.0281 .11636 L
.02894 .11668 L
.03866 .12047 L
.04837 .12433 L
.05271 .12607 L
.05808 .12823 L
.06779 .13211 L
.07705 .13578 L
.07751 .13596 L
.08722 .13971 L
.09693 .14334 L
.10291 .14549 L
.10664 .1468 L
.11636 .15005 L
.12607 .15304 L
.13373 .15521 L
.13578 .15575 L
.14549 .15814 L
.15521 .16017 L
.16492 .16182 L
.17463 .16307 L
.18434 .16389 L
.19406 .16429 L
.20377 .16424 L
.21348 .16376 L
.22319 .16285 L
.23291 .16152 L
.24262 .15979 L
.25233 .15768 L
.26204 .15523 L
.26212 .15521 L
.27176 .15246 L
.28147 .1494 L
.29118 .14611 L
.29294 .14549 L
.30089 .14262 L
.31061 .13896 L
.31879 .13578 L
.32032 .13518 L
.33003 .13133 L
.33974 .12743 L
.34314 .12607 L
.34946 .12354 L
.35917 .11969 L
.36775 .11636 L
.36888 .11592 L
.37859 .11227 L
.38831 .10876 L
.39442 .10664 L
Mistroke
.39802 .10543 L
.40773 .10232 L
.41744 .09943 L
.42668 .09693 L
.42716 .09681 L
.43687 .09447 L
.44658 .09242 L
.45629 .09069 L
.46601 .0893 L
.47572 .08824 L
.48543 .08753 L
.49301 .08722 L
.49514 .08717 L
.50486 .08717 L
.50699 .08722 L
.51457 .08753 L
.52428 .08824 L
.53399 .0893 L
.54371 .09069 L
.55342 .09242 L
.56313 .09447 L
.57284 .09681 L
.57332 .09693 L
.58256 .09943 L
.59227 .10232 L
.60198 .10543 L
.60558 .10664 L
.61169 .10876 L
.62141 .11227 L
.63112 .11592 L
.63225 .11636 L
.64083 .11969 L
.65054 .12354 L
.65686 .12607 L
.66026 .12743 L
.66997 .13133 L
.67968 .13518 L
.68121 .13578 L
.68939 .13896 L
.69911 .14262 L
.70706 .14549 L
.70882 .14611 L
.71853 .1494 L
.72824 .15246 L
.73788 .15521 L
.73796 .15523 L
.74767 .15768 L
.75738 .15979 L
.76709 .16152 L
.77681 .16285 L
Mistroke
.78652 .16376 L
.79623 .16424 L
.80594 .16429 L
.81566 .16389 L
.82537 .16307 L
.83508 .16182 L
.84479 .16017 L
.85451 .15814 L
.86422 .15575 L
.86627 .15521 L
.87393 .15304 L
.88364 .15005 L
.89336 .1468 L
.89709 .14549 L
.90307 .14334 L
.91278 .13971 L
.92249 .13596 L
.92295 .13578 L
.93221 .13211 L
.94192 .12823 L
.94729 .12607 L
.95163 .12433 L
.96134 .12047 L
.97106 .11668 L
.9719 .11636 L
.98077 .113 L
Mfstroke
.01923 .86982 m
.02894 .86597 L
.03325 .86422 L
.03866 .862 L
.04837 .85795 L
.05654 .85451 L
.05808 .85386 L
.06779 .84977 L
.07751 .84572 L
.07976 .84479 L
.08722 .84177 L
.09693 .83794 L
.10449 .83508 L
.10664 .83429 L
.11636 .83086 L
.12607 .82769 L
.13382 .82537 L
.13578 .82482 L
.14549 .82229 L
.15521 .82013 L
.16492 .81838 L
.17463 .81705 L
.18434 .81617 L
.19406 .81576 L
.20377 .8158 L
.21348 .81632 L
.22319 .81729 L
.23291 .8187 L
.24262 .82054 L
.25233 .82277 L
.26203 .82537 L
.26204 .82537 L
.27176 .82831 L
.28147 .83154 L
.29118 .83502 L
.29136 .83508 L
.30089 .83871 L
.31061 .84256 L
.31608 .84479 L
.32032 .84654 L
.33003 .8506 L
.33931 .85451 L
.33974 .85469 L
.34946 .85878 L
.35917 .86281 L
.3626 .86422 L
.36888 .86676 L
.37859 .87059 L
.38743 .87393 L
.38831 .87425 L
Mistroke
.39802 .87773 L
.40773 .88099 L
.41626 .88364 L
.41744 .884 L
.42716 .88673 L
.43687 .88917 L
.44658 .8913 L
.45629 .8931 L
.4578 .89336 L
.46601 .89456 L
.47572 .89566 L
.48543 .8964 L
.49514 .89677 L
.50486 .89677 L
.51457 .8964 L
.52428 .89566 L
.53399 .89456 L
.5422 .89336 L
.54371 .8931 L
.55342 .8913 L
.56313 .88917 L
.57284 .88673 L
.58256 .884 L
.58374 .88364 L
.59227 .88099 L
.60198 .87773 L
.61169 .87425 L
.61257 .87393 L
.62141 .87059 L
.63112 .86676 L
.6374 .86422 L
.64083 .86281 L
.65054 .85878 L
.66026 .85469 L
.66069 .85451 L
.66997 .8506 L
.67968 .84654 L
.68392 .84479 L
.68939 .84256 L
.69911 .83871 L
.70864 .83508 L
.70882 .83502 L
.71853 .83154 L
.72824 .82831 L
.73796 .82537 L
.73797 .82537 L
.74767 .82277 L
.75738 .82054 L
.76709 .8187 L
.77681 .81729 L
Mistroke
.78652 .81632 L
.79623 .8158 L
.80594 .81576 L
.81566 .81617 L
.82537 .81705 L
.83508 .81838 L
.84479 .82013 L
.85451 .82229 L
.86422 .82482 L
.86618 .82537 L
.87393 .82769 L
.88364 .83086 L
.89336 .83429 L
.89551 .83508 L
.90307 .83794 L
.91278 .84177 L
.92024 .84479 L
.92249 .84572 L
.93221 .84977 L
.94192 .85386 L
.94346 .85451 L
.95163 .85795 L
.96134 .862 L
.96675 .86422 L
.97106 .86597 L
.98077 .86982 L
Mfstroke
.01923 .13018 m
.02894 .13403 L
.03325 .13578 L
.03866 .138 L
.04837 .14205 L
.05654 .14549 L
.05808 .14614 L
.06779 .15023 L
.07751 .15428 L
.07976 .15521 L
.08722 .15823 L
.09693 .16206 L
.10449 .16492 L
.10664 .16571 L
.11636 .16914 L
.12607 .17231 L
.13382 .17463 L
.13578 .17518 L
.14549 .17771 L
.15521 .17987 L
.16492 .18162 L
.17463 .18295 L
.18434 .18383 L
.19406 .18424 L
.20377 .1842 L
.21348 .18368 L
.22319 .18271 L
.23291 .1813 L
.24262 .17946 L
.25233 .17723 L
.26203 .17463 L
.26204 .17463 L
.27176 .17169 L
.28147 .16846 L
.29118 .16498 L
.29136 .16492 L
.30089 .16129 L
.31061 .15744 L
.31608 .15521 L
.32032 .15346 L
.33003 .1494 L
.33931 .14549 L
.33974 .14531 L
.34946 .14122 L
.35917 .13719 L
.3626 .13578 L
.36888 .13324 L
.37859 .12941 L
.38743 .12607 L
.38831 .12575 L
Mistroke
.39802 .12227 L
.40773 .11901 L
.41626 .11636 L
.41744 .116 L
.42716 .11327 L
.43687 .11083 L
.44658 .1087 L
.45629 .1069 L
.4578 .10664 L
.46601 .10544 L
.47572 .10434 L
.48543 .1036 L
.49514 .10323 L
.50486 .10323 L
.51457 .1036 L
.52428 .10434 L
.53399 .10544 L
.5422 .10664 L
.54371 .1069 L
.55342 .1087 L
.56313 .11083 L
.57284 .11327 L
.58256 .116 L
.58374 .11636 L
.59227 .11901 L
.60198 .12227 L
.61169 .12575 L
.61257 .12607 L
.62141 .12941 L
.63112 .13324 L
.6374 .13578 L
.64083 .13719 L
.65054 .14122 L
.66026 .14531 L
.66069 .14549 L
.66997 .1494 L
.67968 .15346 L
.68392 .15521 L
.68939 .15744 L
.69911 .16129 L
.70864 .16492 L
.70882 .16498 L
.71853 .16846 L
.72824 .17169 L
.73796 .17463 L
.73797 .17463 L
.74767 .17723 L
.75738 .17946 L
.76709 .1813 L
.77681 .18271 L
Mistroke
.78652 .18368 L
.79623 .1842 L
.80594 .18424 L
.81566 .18383 L
.82537 .18295 L
.83508 .18162 L
.84479 .17987 L
.85451 .17771 L
.86422 .17518 L
.86618 .17463 L
.87393 .17231 L
.88364 .16914 L
.89336 .16571 L
.89551 .16492 L
.90307 .16206 L
.91278 .15823 L
.92024 .15521 L
.92249 .15428 L
.93221 .15023 L
.94192 .14614 L
.94346 .14549 L
.95163 .14205 L
.96134 .138 L
.96675 .13578 L
.97106 .13403 L
.98077 .13018 L
Mfstroke
.01923 .8518 m
.02894 .84775 L
.03583 .84479 L
.03866 .84357 L
.04837 .8393 L
.05786 .83508 L
.05808 .83498 L
.06779 .83066 L
.07751 .82638 L
.07982 .82537 L
.08722 .82218 L
.09693 .81812 L
.10304 .81566 L
.10664 .81424 L
.11636 .81059 L
.12607 .80721 L
.12994 .80594 L
.13578 .80414 L
.14549 .80144 L
.15521 .79914 L
.16492 .79726 L
.17147 .79623 L
.17463 .79584 L
.18434 .7949 L
.19406 .79445 L
.20377 .7945 L
.21348 .79505 L
.22319 .79609 L
.22429 .79623 L
.23291 .7976 L
.24262 .79957 L
.25233 .80196 L
.26204 .80474 L
.26591 .80594 L
.27176 .80787 L
.28147 .81131 L
.29118 .81501 L
.29281 .81566 L
.30089 .81894 L
.31061 .82303 L
.31603 .82537 L
.32032 .82725 L
.33003 .83154 L
.33799 .83508 L
.33974 .83586 L
.34946 .84017 L
.35917 .84443 L
.36001 .84479 L
.36888 .84859 L
.37859 .85261 L
Mistroke
.38332 .85451 L
.38831 .85646 L
.39802 .86011 L
.40773 .86352 L
.4098 .86422 L
.41744 .86668 L
.42716 .86954 L
.43687 .8721 L
.44476 .87393 L
.44658 .87432 L
.45629 .8762 L
.46601 .87772 L
.47572 .87887 L
.48543 .87965 L
.49514 .88003 L
.50486 .88003 L
.51457 .87965 L
.52428 .87887 L
.53399 .87772 L
.54371 .8762 L
.55342 .87432 L
.55524 .87393 L
.56313 .8721 L
.57284 .86954 L
.58256 .86668 L
.5902 .86422 L
.59227 .86352 L
.60198 .86011 L
.61169 .85646 L
.61668 .85451 L
.62141 .85261 L
.63112 .84859 L
.63999 .84479 L
.64083 .84443 L
.65054 .84017 L
.66026 .83586 L
.66201 .83508 L
.66997 .83154 L
.67968 .82725 L
.68397 .82537 L
.68939 .82303 L
.69911 .81894 L
.70719 .81566 L
.70882 .81501 L
.71853 .81131 L
.72824 .80787 L
.73409 .80594 L
.73796 .80474 L
.74767 .80196 L
.75738 .79957 L
Mistroke
.76709 .7976 L
.77571 .79623 L
.77681 .79609 L
.78652 .79505 L
.79623 .7945 L
.80594 .79445 L
.81566 .7949 L
.82537 .79584 L
.82853 .79623 L
.83508 .79726 L
.84479 .79914 L
.85451 .80144 L
.86422 .80414 L
.87006 .80594 L
.87393 .80721 L
.88364 .81059 L
.89336 .81424 L
.89696 .81566 L
.90307 .81812 L
.91278 .82218 L
.92018 .82537 L
.92249 .82638 L
.93221 .83066 L
.94192 .83498 L
.94214 .83508 L
.95163 .8393 L
.96134 .84357 L
.96417 .84479 L
.97106 .84775 L
.98077 .8518 L
Mfstroke
.01923 .1482 m
.02894 .15225 L
.03583 .15521 L
.03866 .15643 L
.04837 .1607 L
.05786 .16492 L
.05808 .16502 L
.06779 .16934 L
.07751 .17362 L
.07982 .17463 L
.08722 .17782 L
.09693 .18188 L
.10304 .18434 L
.10664 .18576 L
.11636 .18941 L
.12607 .19279 L
.12994 .19406 L
.13578 .19586 L
.14549 .19856 L
.15521 .20086 L
.16492 .20274 L
.17147 .20377 L
.17463 .20416 L
.18434 .2051 L
.19406 .20555 L
.20377 .2055 L
.21348 .20495 L
.22319 .20391 L
.22429 .20377 L
.23291 .2024 L
.24262 .20043 L
.25233 .19804 L
.26204 .19526 L
.26591 .19406 L
.27176 .19213 L
.28147 .18869 L
.29118 .18499 L
.29281 .18434 L
.30089 .18106 L
.31061 .17697 L
.31603 .17463 L
.32032 .17275 L
.33003 .16846 L
.33799 .16492 L
.33974 .16414 L
.34946 .15983 L
.35917 .15557 L
.36001 .15521 L
.36888 .15141 L
.37859 .14739 L
Mistroke
.38332 .14549 L
.38831 .14354 L
.39802 .13989 L
.40773 .13648 L
.4098 .13578 L
.41744 .13332 L
.42716 .13046 L
.43687 .1279 L
.44476 .12607 L
.44658 .12568 L
.45629 .1238 L
.46601 .12228 L
.47572 .12113 L
.48543 .12035 L
.49514 .11997 L
.50486 .11997 L
.51457 .12035 L
.52428 .12113 L
.53399 .12228 L
.54371 .1238 L
.55342 .12568 L
.55524 .12607 L
.56313 .1279 L
.57284 .13046 L
.58256 .13332 L
.5902 .13578 L
.59227 .13648 L
.60198 .13989 L
.61169 .14354 L
.61668 .14549 L
.62141 .14739 L
.63112 .15141 L
.63999 .15521 L
.64083 .15557 L
.65054 .15983 L
.66026 .16414 L
.66201 .16492 L
.66997 .16846 L
.67968 .17275 L
.68397 .17463 L
.68939 .17697 L
.69911 .18106 L
.70719 .18434 L
.70882 .18499 L
.71853 .18869 L
.72824 .19213 L
.73409 .19406 L
.73796 .19526 L
.74767 .19804 L
.75738 .20043 L
Mistroke
.76709 .2024 L
.77571 .20377 L
.77681 .20391 L
.78652 .20495 L
.79623 .2055 L
.80594 .20555 L
.81566 .2051 L
.82537 .20416 L
.82853 .20377 L
.83508 .20274 L
.84479 .20086 L
.85451 .19856 L
.86422 .19586 L
.87006 .19406 L
.87393 .19279 L
.88364 .18941 L
.89336 .18576 L
.89696 .18434 L
.90307 .18188 L
.91278 .17782 L
.92018 .17463 L
.92249 .17362 L
.93221 .16934 L
.94192 .16502 L
.94214 .16492 L
.95163 .1607 L
.96134 .15643 L
.96417 .15521 L
.97106 .15225 L
.98077 .1482 L
Mfstroke
.01923 .83281 m
.02894 .82852 L
.03589 .82537 L
.03866 .8241 L
.04837 .81957 L
.05665 .81566 L
.05808 .81498 L
.06779 .81038 L
.07723 .80594 L
.07751 .80581 L
.08722 .80133 L
.09693 .79699 L
.09865 .79623 L
.10664 .79282 L
.11636 .7889 L
.12261 .78652 L
.12607 .78526 L
.13578 .78196 L
.14549 .77904 L
.15411 .77681 L
.15521 .77655 L
.16492 .77452 L
.17463 .77298 L
.18434 .77196 L
.19406 .77148 L
.20377 .77153 L
.21348 .77213 L
.22319 .77325 L
.23291 .77489 L
.24174 .77681 L
.24262 .77702 L
.25233 .7796 L
.26204 .7826 L
.27176 .78598 L
.27323 .78652 L
.28147 .78968 L
.29118 .79365 L
.2972 .79623 L
.30089 .79786 L
.31061 .80224 L
.31862 .80594 L
.32032 .80674 L
.33003 .81131 L
.3392 .81566 L
.33974 .81591 L
.34946 .82049 L
.35917 .82501 L
.35996 .82537 L
.36888 .82941 L
.37859 .83366 L
Mistroke
.38192 .83508 L
.38831 .83773 L
.39802 .84158 L
.40666 .84479 L
.40773 .84518 L
.41744 .8485 L
.42716 .85151 L
.43687 .85419 L
.43808 .85451 L
.44658 .85653 L
.45629 .85851 L
.46601 .8601 L
.47572 .86131 L
.48543 .86212 L
.49514 .86252 L
.50486 .86252 L
.51457 .86212 L
.52428 .86131 L
.53399 .8601 L
.54371 .85851 L
.55342 .85653 L
.56192 .85451 L
.56313 .85419 L
.57284 .85151 L
.58256 .8485 L
.59227 .84518 L
.59334 .84479 L
.60198 .84158 L
.61169 .83773 L
.61808 .83508 L
.62141 .83366 L
.63112 .82941 L
.64004 .82537 L
.64083 .82501 L
.65054 .82049 L
.66026 .81591 L
.6608 .81566 L
.66997 .81131 L
.67968 .80674 L
.68138 .80594 L
.68939 .80224 L
.69911 .79786 L
.7028 .79623 L
.70882 .79365 L
.71853 .78968 L
.72677 .78652 L
.72824 .78598 L
.73796 .7826 L
.74767 .7796 L
.75738 .77702 L
Mistroke
.75826 .77681 L
.76709 .77489 L
.77681 .77325 L
.78652 .77213 L
.79623 .77153 L
.80594 .77148 L
.81566 .77196 L
.82537 .77298 L
.83508 .77452 L
.84479 .77655 L
.84589 .77681 L
.85451 .77904 L
.86422 .78196 L
.87393 .78526 L
.87739 .78652 L
.88364 .7889 L
.89336 .79282 L
.90135 .79623 L
.90307 .79699 L
.91278 .80133 L
.92249 .80581 L
.92277 .80594 L
.93221 .81038 L
.94192 .81498 L
.94335 .81566 L
.95163 .81957 L
.96134 .8241 L
.96411 .82537 L
.97106 .82852 L
.98077 .83281 L
Mfstroke
.01923 .16719 m
.02894 .17148 L
.03589 .17463 L
.03866 .1759 L
.04837 .18043 L
.05665 .18434 L
.05808 .18502 L
.06779 .18962 L
.07723 .19406 L
.07751 .19419 L
.08722 .19867 L
.09693 .20301 L
.09865 .20377 L
.10664 .20718 L
.11636 .2111 L
.12261 .21348 L
.12607 .21474 L
.13578 .21804 L
.14549 .22096 L
.15411 .22319 L
.15521 .22345 L
.16492 .22548 L
.17463 .22702 L
.18434 .22804 L
.19406 .22852 L
.20377 .22847 L
.21348 .22787 L
.22319 .22675 L
.23291 .22511 L
.24174 .22319 L
.24262 .22298 L
.25233 .2204 L
.26204 .2174 L
.27176 .21402 L
.27323 .21348 L
.28147 .21032 L
.29118 .20635 L
.2972 .20377 L
.30089 .20214 L
.31061 .19776 L
.31862 .19406 L
.32032 .19326 L
.33003 .18869 L
.3392 .18434 L
.33974 .18409 L
.34946 .17951 L
.35917 .17499 L
.35996 .17463 L
.36888 .17059 L
.37859 .16634 L
Mistroke
.38192 .16492 L
.38831 .16227 L
.39802 .15842 L
.40666 .15521 L
.40773 .15482 L
.41744 .1515 L
.42716 .14849 L
.43687 .14581 L
.43808 .14549 L
.44658 .14347 L
.45629 .14149 L
.46601 .1399 L
.47572 .13869 L
.48543 .13788 L
.49514 .13748 L
.50486 .13748 L
.51457 .13788 L
.52428 .13869 L
.53399 .1399 L
.54371 .14149 L
.55342 .14347 L
.56192 .14549 L
.56313 .14581 L
.57284 .14849 L
.58256 .1515 L
.59227 .15482 L
.59334 .15521 L
.60198 .15842 L
.61169 .16227 L
.61808 .16492 L
.62141 .16634 L
.63112 .17059 L
.64004 .17463 L
.64083 .17499 L
.65054 .17951 L
.66026 .18409 L
.6608 .18434 L
.66997 .18869 L
.67968 .19326 L
.68138 .19406 L
.68939 .19776 L
.69911 .20214 L
.7028 .20377 L
.70882 .20635 L
.71853 .21032 L
.72677 .21348 L
.72824 .21402 L
.73796 .2174 L
.74767 .2204 L
.75738 .22298 L
Mistroke
.75826 .22319 L
.76709 .22511 L
.77681 .22675 L
.78652 .22787 L
.79623 .22847 L
.80594 .22852 L
.81566 .22804 L
.82537 .22702 L
.83508 .22548 L
.84479 .22345 L
.84589 .22319 L
.85451 .22096 L
.86422 .21804 L
.87393 .21474 L
.87739 .21348 L
.88364 .2111 L
.89336 .20718 L
.90135 .20377 L
.90307 .20301 L
.91278 .19867 L
.92249 .19419 L
.92277 .19406 L
.93221 .18962 L
.94192 .18502 L
.94335 .18434 L
.95163 .18043 L
.96134 .1759 L
.96411 .17463 L
.97106 .17148 L
.98077 .16719 L
Mfstroke
.01923 .81267 m
.02894 .8081 L
.03341 .80594 L
.03866 .80337 L
.04837 .79853 L
.05292 .79623 L
.05808 .79362 L
.06779 .78868 L
.07204 .78652 L
.07751 .78376 L
.08722 .77893 L
.09155 .77681 L
.09693 .77422 L
.10664 .76971 L
.11252 .76709 L
.11636 .76545 L
.12607 .76148 L
.13578 .75788 L
.1372 .75738 L
.14549 .75468 L
.15521 .75195 L
.16492 .74972 L
.17463 .74803 L
.17666 .74767 L
.18434 .7469 L
.19406 .74637 L
.20377 .74643 L
.21348 .74709 L
.21909 .74767 L
.22319 .74833 L
.23291 .75013 L
.24262 .75247 L
.25233 .7553 L
.25865 .75738 L
.26204 .75858 L
.27176 .76226 L
.28147 .76629 L
.28332 .76709 L
.29118 .77061 L
.30089 .77517 L
.30429 .77681 L
.31061 .7799 L
.32032 .78476 L
.32381 .78652 L
.33003 .78968 L
.33974 .79462 L
.34292 .79623 L
.34946 .79952 L
.35917 .80435 L
.36244 .80594 L
Mistroke
.36888 .80905 L
.37859 .81358 L
.3832 .81566 L
.38831 .8179 L
.39802 .82199 L
.40659 .82537 L
.40773 .8258 L
.41744 .82931 L
.42716 .8325 L
.43593 .83508 L
.43687 .83534 L
.44658 .83781 L
.45629 .83989 L
.46601 .84157 L
.47572 .84284 L
.48543 .8437 L
.49514 .84412 L
.50486 .84412 L
.51457 .8437 L
.52428 .84284 L
.53399 .84157 L
.54371 .83989 L
.55342 .83781 L
.56313 .83534 L
.56407 .83508 L
.57284 .8325 L
.58256 .82931 L
.59227 .8258 L
.59341 .82537 L
.60198 .82199 L
.61169 .8179 L
.6168 .81566 L
.62141 .81358 L
.63112 .80905 L
.63756 .80594 L
.64083 .80435 L
.65054 .79952 L
.65708 .79623 L
.66026 .79462 L
.66997 .78968 L
.67619 .78652 L
.67968 .78476 L
.68939 .7799 L
.69571 .77681 L
.69911 .77517 L
.70882 .77061 L
.71668 .76709 L
.71853 .76629 L
.72824 .76226 L
.73796 .75858 L
Mistroke
.74135 .75738 L
.74767 .7553 L
.75738 .75247 L
.76709 .75013 L
.77681 .74833 L
.78091 .74767 L
.78652 .74709 L
.79623 .74643 L
.80594 .74637 L
.81566 .7469 L
.82334 .74767 L
.82537 .74803 L
.83508 .74972 L
.84479 .75195 L
.85451 .75468 L
.8628 .75738 L
.86422 .75788 L
.87393 .76148 L
.88364 .76545 L
.88748 .76709 L
.89336 .76971 L
.90307 .77422 L
.90845 .77681 L
.91278 .77893 L
.92249 .78376 L
.92796 .78652 L
.93221 .78868 L
.94192 .79362 L
.94708 .79623 L
.95163 .79853 L
.96134 .80337 L
.96659 .80594 L
.97106 .8081 L
.98077 .81267 L
Mfstroke
.01923 .18733 m
.02894 .1919 L
.03341 .19406 L
.03866 .19663 L
.04837 .20147 L
.05292 .20377 L
.05808 .20638 L
.06779 .21132 L
.07204 .21348 L
.07751 .21624 L
.08722 .22107 L
.09155 .22319 L
.09693 .22578 L
.10664 .23029 L
.11252 .23291 L
.11636 .23455 L
.12607 .23852 L
.13578 .24212 L
.1372 .24262 L
.14549 .24532 L
.15521 .24805 L
.16492 .25028 L
.17463 .25197 L
.17666 .25233 L
.18434 .2531 L
.19406 .25363 L
.20377 .25357 L
.21348 .25291 L
.21909 .25233 L
.22319 .25167 L
.23291 .24987 L
.24262 .24753 L
.25233 .2447 L
.25865 .24262 L
.26204 .24142 L
.27176 .23774 L
.28147 .23371 L
.28332 .23291 L
.29118 .22939 L
.30089 .22483 L
.30429 .22319 L
.31061 .2201 L
.32032 .21524 L
.32381 .21348 L
.33003 .21032 L
.33974 .20538 L
.34292 .20377 L
.34946 .20048 L
.35917 .19565 L
.36244 .19406 L
Mistroke
.36888 .19095 L
.37859 .18642 L
.3832 .18434 L
.38831 .1821 L
.39802 .17801 L
.40659 .17463 L
.40773 .1742 L
.41744 .17069 L
.42716 .1675 L
.43593 .16492 L
.43687 .16466 L
.44658 .16219 L
.45629 .16011 L
.46601 .15843 L
.47572 .15716 L
.48543 .1563 L
.49514 .15588 L
.50486 .15588 L
.51457 .1563 L
.52428 .15716 L
.53399 .15843 L
.54371 .16011 L
.55342 .16219 L
.56313 .16466 L
.56407 .16492 L
.57284 .1675 L
.58256 .17069 L
.59227 .1742 L
.59341 .17463 L
.60198 .17801 L
.61169 .1821 L
.6168 .18434 L
.62141 .18642 L
.63112 .19095 L
.63756 .19406 L
.64083 .19565 L
.65054 .20048 L
.65708 .20377 L
.66026 .20538 L
.66997 .21032 L
.67619 .21348 L
.67968 .21524 L
.68939 .2201 L
.69571 .22319 L
.69911 .22483 L
.70882 .22939 L
.71668 .23291 L
.71853 .23371 L
.72824 .23774 L
.73796 .24142 L
Mistroke
.74135 .24262 L
.74767 .2447 L
.75738 .24753 L
.76709 .24987 L
.77681 .25167 L
.78091 .25233 L
.78652 .25291 L
.79623 .25357 L
.80594 .25363 L
.81566 .2531 L
.82334 .25233 L
.82537 .25197 L
.83508 .25028 L
.84479 .24805 L
.85451 .24532 L
.8628 .24262 L
.86422 .24212 L
.87393 .23852 L
.88364 .23455 L
.88748 .23291 L
.89336 .23029 L
.90307 .22578 L
.90845 .22319 L
.91278 .22107 L
.92249 .21624 L
.92796 .21348 L
.93221 .21132 L
.94192 .20638 L
.94708 .20377 L
.95163 .20147 L
.96134 .19663 L
.96659 .19406 L
.97106 .1919 L
.98077 .18733 L
Mfstroke
.01923 .79114 m
.02837 .78652 L
.02894 .78623 L
.03866 .78113 L
.0467 .77681 L
.04837 .7759 L
.05808 .77057 L
.06437 .76709 L
.06779 .7652 L
.07751 .75984 L
.082 .75738 L
.08722 .75455 L
.09693 .74939 L
.10025 .74767 L
.10664 .74442 L
.11636 .73971 L
.12013 .73796 L
.12607 .73531 L
.13578 .7313 L
.14401 .72824 L
.14549 .72773 L
.15521 .72467 L
.16492 .72217 L
.17463 .72026 L
.18434 .719 L
.19061 .71853 L
.19406 .71839 L
.20377 .71846 L
.20524 .71853 L
.21348 .7192 L
.22319 .7206 L
.23291 .72263 L
.24262 .72525 L
.25184 .72824 L
.25233 .72842 L
.26204 .73208 L
.27176 .73618 L
.27572 .73796 L
.28147 .74064 L
.29118 .74542 L
.2956 .74767 L
.30089 .75043 L
.31061 .75562 L
.31384 .75738 L
.32032 .76093 L
.33003 .7663 L
.33148 .76709 L
.33974 .77166 L
.34915 .77681 L
.34946 .77697 L
Mistroke
.35917 .78218 L
.36747 .78652 L
.36888 .78724 L
.37859 .79211 L
.3872 .79623 L
.38831 .79675 L
.39802 .80112 L
.40773 .8052 L
.4096 .80594 L
.41744 .80894 L
.42716 .81234 L
.43687 .81536 L
.4379 .81566 L
.44658 .81798 L
.45629 .82019 L
.46601 .82198 L
.47572 .82333 L
.48543 .82423 L
.49514 .82469 L
.50486 .82469 L
.51457 .82423 L
.52428 .82333 L
.53399 .82198 L
.54371 .82019 L
.55342 .81798 L
.5621 .81566 L
.56313 .81536 L
.57284 .81234 L
.58256 .80894 L
.5904 .80594 L
.59227 .8052 L
.60198 .80112 L
.61169 .79675 L
.6128 .79623 L
.62141 .79211 L
.63112 .78724 L
.63253 .78652 L
.64083 .78218 L
.65054 .77697 L
.65085 .77681 L
.66026 .77166 L
.66852 .76709 L
.66997 .7663 L
.67968 .76093 L
.68616 .75738 L
.68939 .75562 L
.69911 .75043 L
.7044 .74767 L
.70882 .74542 L
.71853 .74064 L
Mistroke
.72428 .73796 L
.72824 .73618 L
.73796 .73208 L
.74767 .72842 L
.74816 .72824 L
.75738 .72525 L
.76709 .72263 L
.77681 .7206 L
.78652 .7192 L
.79476 .71853 L
.79623 .71846 L
.80594 .71839 L
.80939 .71853 L
.81566 .719 L
.82537 .72026 L
.83508 .72217 L
.84479 .72467 L
.85451 .72773 L
.85599 .72824 L
.86422 .7313 L
.87393 .73531 L
.87987 .73796 L
.88364 .73971 L
.89336 .74442 L
.89975 .74767 L
.90307 .74939 L
.91278 .75455 L
.918 .75738 L
.92249 .75984 L
.93221 .7652 L
.93563 .76709 L
.94192 .77057 L
.95163 .7759 L
.9533 .77681 L
.96134 .78113 L
.97106 .78623 L
.97163 .78652 L
.98077 .79114 L
Mfstroke
.01923 .20886 m
.02837 .21348 L
.02894 .21377 L
.03866 .21887 L
.0467 .22319 L
.04837 .2241 L
.05808 .22943 L
.06437 .23291 L
.06779 .2348 L
.07751 .24016 L
.082 .24262 L
.08722 .24545 L
.09693 .25061 L
.10025 .25233 L
.10664 .25558 L
.11636 .26029 L
.12013 .26204 L
.12607 .26469 L
.13578 .2687 L
.14401 .27176 L
.14549 .27227 L
.15521 .27533 L
.16492 .27783 L
.17463 .27974 L
.18434 .281 L
.19061 .28147 L
.19406 .28161 L
.20377 .28154 L
.20524 .28147 L
.21348 .2808 L
.22319 .2794 L
.23291 .27737 L
.24262 .27475 L
.25184 .27176 L
.25233 .27158 L
.26204 .26792 L
.27176 .26382 L
.27572 .26204 L
.28147 .25936 L
.29118 .25458 L
.2956 .25233 L
.30089 .24957 L
.31061 .24438 L
.31384 .24262 L
.32032 .23907 L
.33003 .2337 L
.33148 .23291 L
.33974 .22834 L
.34915 .22319 L
.34946 .22303 L
Mistroke
.35917 .21782 L
.36747 .21348 L
.36888 .21276 L
.37859 .20789 L
.3872 .20377 L
.38831 .20325 L
.39802 .19888 L
.40773 .1948 L
.4096 .19406 L
.41744 .19106 L
.42716 .18766 L
.43687 .18464 L
.4379 .18434 L
.44658 .18202 L
.45629 .17981 L
.46601 .17802 L
.47572 .17667 L
.48543 .17577 L
.49514 .17531 L
.50486 .17531 L
.51457 .17577 L
.52428 .17667 L
.53399 .17802 L
.54371 .17981 L
.55342 .18202 L
.5621 .18434 L
.56313 .18464 L
.57284 .18766 L
.58256 .19106 L
.5904 .19406 L
.59227 .1948 L
.60198 .19888 L
.61169 .20325 L
.6128 .20377 L
.62141 .20789 L
.63112 .21276 L
.63253 .21348 L
.64083 .21782 L
.65054 .22303 L
.65085 .22319 L
.66026 .22834 L
.66852 .23291 L
.66997 .2337 L
.67968 .23907 L
.68616 .24262 L
.68939 .24438 L
.69911 .24957 L
.7044 .25233 L
.70882 .25458 L
.71853 .25936 L
Mistroke
.72428 .26204 L
.72824 .26382 L
.73796 .26792 L
.74767 .27158 L
.74816 .27176 L
.75738 .27475 L
.76709 .27737 L
.77681 .2794 L
.78652 .2808 L
.79476 .28147 L
.79623 .28154 L
.80594 .28161 L
.80939 .28147 L
.81566 .281 L
.82537 .27974 L
.83508 .27783 L
.84479 .27533 L
.85451 .27227 L
.85599 .27176 L
.86422 .2687 L
.87393 .26469 L
.87987 .26204 L
.88364 .26029 L
.89336 .25558 L
.89975 .25233 L
.90307 .25061 L
.91278 .24545 L
.918 .24262 L
.92249 .24016 L
.93221 .2348 L
.93563 .23291 L
.94192 .22943 L
.95163 .2241 L
.9533 .22319 L
.96134 .21887 L
.97106 .21377 L
.97163 .21348 L
.98077 .20886 L
Mfstroke
.01923 .76788 m
.02068 .76709 L
.02894 .76253 L
.03795 .75738 L
.03866 .75697 L
.04837 .75123 L
.05429 .74767 L
.05808 .74537 L
.06779 .73944 L
.07021 .73796 L
.07751 .73349 L
.08613 .72824 L
.08722 .72759 L
.09693 .7218 L
.10255 .71853 L
.10664 .7162 L
.11636 .71085 L
.1202 .70882 L
.12607 .70584 L
.13578 .70124 L
.14065 .69911 L
.14549 .69713 L
.15521 .69359 L
.16492 .69067 L
.16997 .68939 L
.17463 .68845 L
.18434 .68697 L
.19406 .68626 L
.20377 .68634 L
.21348 .68721 L
.22319 .68885 L
.22581 .68939 L
.23291 .69121 L
.24262 .69426 L
.25233 .69792 L
.25519 .69911 L
.26204 .70214 L
.27176 .70683 L
.27564 .70882 L
.28147 .71191 L
.29118 .71732 L
.2933 .71853 L
.30089 .72297 L
.30972 .72824 L
.31061 .72878 L
.32032 .7347 L
.32564 .73796 L
.33003 .74065 L
.33974 .74657 L
.34156 .74767 L
Mistroke
.34946 .75241 L
.3579 .75738 L
.35917 .75812 L
.36888 .76364 L
.37516 .76709 L
.37859 .76894 L
.38831 .77397 L
.39405 .77681 L
.39802 .7787 L
.40773 .7831 L
.41591 .78652 L
.41744 .78713 L
.42716 .79078 L
.43687 .79402 L
.44436 .79623 L
.44658 .79683 L
.45629 .7992 L
.46601 .80111 L
.47572 .80255 L
.48543 .80352 L
.49514 .804 L
.50486 .804 L
.51457 .80352 L
.52428 .80255 L
.53399 .80111 L
.54371 .7992 L
.55342 .79683 L
.55564 .79623 L
.56313 .79402 L
.57284 .79078 L
.58256 .78713 L
.58409 .78652 L
.59227 .7831 L
.60198 .7787 L
.60595 .77681 L
.61169 .77397 L
.62141 .76894 L
.62484 .76709 L
.63112 .76364 L
.64083 .75812 L
.6421 .75738 L
.65054 .75241 L
.65844 .74767 L
.66026 .74657 L
.66997 .74065 L
.67436 .73796 L
.67968 .7347 L
.68939 .72878 L
.69028 .72824 L
.69911 .72297 L
Mistroke
.7067 .71853 L
.70882 .71732 L
.71853 .71191 L
.72436 .70882 L
.72824 .70683 L
.73796 .70214 L
.74481 .69911 L
.74767 .69792 L
.75738 .69426 L
.76709 .69121 L
.77419 .68939 L
.77681 .68885 L
.78652 .68721 L
.79623 .68634 L
.80594 .68626 L
.81566 .68697 L
.82537 .68845 L
.83003 .68939 L
.83508 .69067 L
.84479 .69359 L
.85451 .69713 L
.85935 .69911 L
.86422 .70124 L
.87393 .70584 L
.8798 .70882 L
.88364 .71085 L
.89336 .7162 L
.89745 .71853 L
.90307 .7218 L
.91278 .72759 L
.91387 .72824 L
.92249 .73349 L
.92979 .73796 L
.93221 .73944 L
.94192 .74537 L
.94571 .74767 L
.95163 .75123 L
.96134 .75697 L
.96205 .75738 L
.97106 .76253 L
.97932 .76709 L
.98077 .76788 L
Mfstroke
.01923 .23212 m
.02068 .23291 L
.02894 .23747 L
.03795 .24262 L
.03866 .24303 L
.04837 .24877 L
.05429 .25233 L
.05808 .25463 L
.06779 .26056 L
.07021 .26204 L
.07751 .26651 L
.08613 .27176 L
.08722 .27241 L
.09693 .2782 L
.10255 .28147 L
.10664 .2838 L
.11636 .28915 L
.1202 .29118 L
.12607 .29416 L
.13578 .29876 L
.14065 .30089 L
.14549 .30287 L
.15521 .30641 L
.16492 .30933 L
.16997 .31061 L
.17463 .31155 L
.18434 .31303 L
.19406 .31374 L
.20377 .31366 L
.21348 .31279 L
.22319 .31115 L
.22581 .31061 L
.23291 .30879 L
.24262 .30574 L
.25233 .30208 L
.25519 .30089 L
.26204 .29786 L
.27176 .29317 L
.27564 .29118 L
.28147 .28809 L
.29118 .28268 L
.2933 .28147 L
.30089 .27703 L
.30972 .27176 L
.31061 .27122 L
.32032 .2653 L
.32564 .26204 L
.33003 .25935 L
.33974 .25343 L
.34156 .25233 L
Mistroke
.34946 .24759 L
.3579 .24262 L
.35917 .24188 L
.36888 .23636 L
.37516 .23291 L
.37859 .23106 L
.38831 .22603 L
.39405 .22319 L
.39802 .2213 L
.40773 .2169 L
.41591 .21348 L
.41744 .21287 L
.42716 .20922 L
.43687 .20598 L
.44436 .20377 L
.44658 .20317 L
.45629 .2008 L
.46601 .19889 L
.47572 .19745 L
.48543 .19648 L
.49514 .196 L
.50486 .196 L
.51457 .19648 L
.52428 .19745 L
.53399 .19889 L
.54371 .2008 L
.55342 .20317 L
.55564 .20377 L
.56313 .20598 L
.57284 .20922 L
.58256 .21287 L
.58409 .21348 L
.59227 .2169 L
.60198 .2213 L
.60595 .22319 L
.61169 .22603 L
.62141 .23106 L
.62484 .23291 L
.63112 .23636 L
.64083 .24188 L
.6421 .24262 L
.65054 .24759 L
.65844 .25233 L
.66026 .25343 L
.66997 .25935 L
.67436 .26204 L
.67968 .2653 L
.68939 .27122 L
.69028 .27176 L
.69911 .27703 L
Mistroke
.7067 .28147 L
.70882 .28268 L
.71853 .28809 L
.72436 .29118 L
.72824 .29317 L
.73796 .29786 L
.74481 .30089 L
.74767 .30208 L
.75738 .30574 L
.76709 .30879 L
.77419 .31061 L
.77681 .31115 L
.78652 .31279 L
.79623 .31366 L
.80594 .31374 L
.81566 .31303 L
.82537 .31155 L
.83003 .31061 L
.83508 .30933 L
.84479 .30641 L
.85451 .30287 L
.85935 .30089 L
.86422 .29876 L
.87393 .29416 L
.8798 .29118 L
.88364 .28915 L
.89336 .2838 L
.89745 .28147 L
.90307 .2782 L
.91278 .27241 L
.91387 .27176 L
.92249 .26651 L
.92979 .26204 L
.93221 .26056 L
.94192 .25463 L
.94571 .25233 L
.95163 .24877 L
.96134 .24303 L
.96205 .24262 L
.97106 .23747 L
.97932 .23291 L
.98077 .23212 L
Mfstroke
.01923 .7424 m
.02656 .73796 L
.02894 .73648 L
.03866 .73029 L
.04178 .72824 L
.04837 .72387 L
.05624 .71853 L
.05808 .71727 L
.06779 .71054 L
.07027 .70882 L
.07751 .70375 L
.08415 .69911 L
.08722 .69696 L
.09693 .69025 L
.09818 .68939 L
.10664 .68368 L
.11273 .67968 L
.11636 .67736 L
.12607 .67137 L
.12844 .66997 L
.13578 .66582 L
.14549 .66081 L
.14663 .66026 L
.15521 .65644 L
.16492 .65282 L
.17253 .65054 L
.17463 .65004 L
.18434 .64818 L
.19406 .64729 L
.20377 .64739 L
.21348 .64848 L
.22319 .65054 L
.22322 .65054 L
.23291 .65349 L
.24262 .65727 L
.24923 .66026 L
.25233 .66178 L
.26204 .66691 L
.26741 .66997 L
.27176 .67256 L
.28147 .67862 L
.28311 .67968 L
.29118 .685 L
.29767 .68939 L
.30089 .6916 L
.31061 .69834 L
.3117 .69911 L
.32032 .70514 L
.32558 .70882 L
.33003 .71192 L
Mistroke
.33961 .71853 L
.33974 .71862 L
.34946 .72519 L
.35407 .72824 L
.35917 .73157 L
.36888 .73771 L
.36929 .73796 L
.37859 .74357 L
.38572 .74767 L
.38831 .74911 L
.39802 .75431 L
.40413 .75738 L
.40773 .75912 L
.41744 .76352 L
.42613 .76709 L
.42716 .76749 L
.43687 .77101 L
.44658 .77406 L
.45629 .77662 L
.45705 .77681 L
.46601 .77869 L
.47572 .78025 L
.48543 .78129 L
.49514 .78181 L
.50486 .78181 L
.51457 .78129 L
.52428 .78025 L
.53399 .77869 L
.54295 .77681 L
.54371 .77662 L
.55342 .77406 L
.56313 .77101 L
.57284 .76749 L
.57387 .76709 L
.58256 .76352 L
.59227 .75912 L
.59587 .75738 L
.60198 .75431 L
.61169 .74911 L
.61428 .74767 L
.62141 .74357 L
.63071 .73796 L
.63112 .73771 L
.64083 .73157 L
.64593 .72824 L
.65054 .72519 L
.66026 .71862 L
.66039 .71853 L
.66997 .71192 L
.67442 .70882 L
Mistroke
.67968 .70514 L
.6883 .69911 L
.68939 .69834 L
.69911 .6916 L
.70233 .68939 L
.70882 .685 L
.71689 .67968 L
.71853 .67862 L
.72824 .67256 L
.73259 .66997 L
.73796 .66691 L
.74767 .66178 L
.75077 .66026 L
.75738 .65727 L
.76709 .65349 L
.77678 .65054 L
.77681 .65054 L
.78652 .64848 L
.79623 .64739 L
.80594 .64729 L
.81566 .64818 L
.82537 .65004 L
.82747 .65054 L
.83508 .65282 L
.84479 .65644 L
.85337 .66026 L
.85451 .66081 L
.86422 .66582 L
.87156 .66997 L
.87393 .67137 L
.88364 .67736 L
.88727 .67968 L
.89336 .68368 L
.90182 .68939 L
.90307 .69025 L
.91278 .69696 L
.91585 .69911 L
.92249 .70375 L
.92973 .70882 L
.93221 .71054 L
.94192 .71727 L
.94376 .71853 L
.95163 .72387 L
.95822 .72824 L
.96134 .73029 L
.97106 .73648 L
.97344 .73796 L
.98077 .7424 L
Mfstroke
.01923 .2576 m
.02656 .26204 L
.02894 .26352 L
.03866 .26971 L
.04178 .27176 L
.04837 .27613 L
.05624 .28147 L
.05808 .28273 L
.06779 .28946 L
.07027 .29118 L
.07751 .29625 L
.08415 .30089 L
.08722 .30304 L
.09693 .30975 L
.09818 .31061 L
.10664 .31632 L
.11273 .32032 L
.11636 .32264 L
.12607 .32863 L
.12844 .33003 L
.13578 .33418 L
.14549 .33919 L
.14663 .33974 L
.15521 .34356 L
.16492 .34718 L
.17253 .34946 L
.17463 .34996 L
.18434 .35182 L
.19406 .35271 L
.20377 .35261 L
.21348 .35152 L
.22319 .34946 L
.22322 .34946 L
.23291 .34651 L
.24262 .34273 L
.24923 .33974 L
.25233 .33822 L
.26204 .33309 L
.26741 .33003 L
.27176 .32744 L
.28147 .32138 L
.28311 .32032 L
.29118 .315 L
.29767 .31061 L
.30089 .3084 L
.31061 .30166 L
.3117 .30089 L
.32032 .29486 L
.32558 .29118 L
.33003 .28808 L
Mistroke
.33961 .28147 L
.33974 .28138 L
.34946 .27481 L
.35407 .27176 L
.35917 .26843 L
.36888 .26229 L
.36929 .26204 L
.37859 .25643 L
.38572 .25233 L
.38831 .25089 L
.39802 .24569 L
.40413 .24262 L
.40773 .24088 L
.41744 .23648 L
.42613 .23291 L
.42716 .23251 L
.43687 .22899 L
.44658 .22594 L
.45629 .22338 L
.45705 .22319 L
.46601 .22131 L
.47572 .21975 L
.48543 .21871 L
.49514 .21819 L
.50486 .21819 L
.51457 .21871 L
.52428 .21975 L
.53399 .22131 L
.54295 .22319 L
.54371 .22338 L
.55342 .22594 L
.56313 .22899 L
.57284 .23251 L
.57387 .23291 L
.58256 .23648 L
.59227 .24088 L
.59587 .24262 L
.60198 .24569 L
.61169 .25089 L
.61428 .25233 L
.62141 .25643 L
.63071 .26204 L
.63112 .26229 L
.64083 .26843 L
.64593 .27176 L
.65054 .27481 L
.66026 .28138 L
.66039 .28147 L
.66997 .28808 L
.67442 .29118 L
Mistroke
.67968 .29486 L
.6883 .30089 L
.68939 .30166 L
.69911 .3084 L
.70233 .31061 L
.70882 .315 L
.71689 .32032 L
.71853 .32138 L
.72824 .32744 L
.73259 .33003 L
.73796 .33309 L
.74767 .33822 L
.75077 .33974 L
.75738 .34273 L
.76709 .34651 L
.77678 .34946 L
.77681 .34946 L
.78652 .35152 L
.79623 .35261 L
.80594 .35271 L
.81566 .35182 L
.82537 .34996 L
.82747 .34946 L
.83508 .34718 L
.84479 .34356 L
.85337 .33974 L
.85451 .33919 L
.86422 .33418 L
.87156 .33003 L
.87393 .32863 L
.88364 .32264 L
.88727 .32032 L
.89336 .31632 L
.90182 .31061 L
.90307 .30975 L
.91278 .30304 L
.91585 .30089 L
.92249 .29625 L
.92973 .29118 L
.93221 .28946 L
.94192 .28273 L
.94376 .28147 L
.95163 .27613 L
.95822 .27176 L
.96134 .26971 L
.97106 .26352 L
.97344 .26204 L
.98077 .2576 L
Mfstroke
.01923 .71391 m
.02662 .70882 L
.02894 .70717 L
.03866 .70008 L
.03995 .69911 L
.04837 .69265 L
.05251 .68939 L
.05808 .68494 L
.06454 .67968 L
.06779 .677 L
.07619 .66997 L
.07751 .66886 L
.08722 .6606 L
.08762 .66026 L
.09693 .65229 L
.09897 .65054 L
.10664 .64401 L
.1104 .64083 L
.11636 .63585 L
.12211 .63112 L
.12607 .62793 L
.13444 .62141 L
.13578 .62039 L
.14549 .61339 L
.14798 .61169 L
.15521 .60711 L
.16445 .60198 L
.16492 .60175 L
.17463 .59753 L
.18434 .59464 L
.19406 .59323 L
.20377 .59339 L
.21348 .59511 L
.22319 .59829 L
.23146 .60198 L
.23291 .60276 L
.24262 .60832 L
.24787 .61169 L
.25233 .61477 L
.26141 .62141 L
.26204 .62189 L
.27176 .62952 L
.27374 .63112 L
.28147 .63749 L
.28545 .64083 L
.29118 .64569 L
.29688 .65054 L
.30089 .65398 L
.30823 .66026 L
.31061 .66229 L
Mistroke
.31965 .66997 L
.32032 .67053 L
.33003 .67863 L
.33131 .67968 L
.33974 .68653 L
.34333 .68939 L
.34946 .69419 L
.3559 .69911 L
.35917 .70155 L
.36888 .70857 L
.36923 .70882 L
.37859 .71523 L
.38364 .71853 L
.38831 .72148 L
.39802 .72731 L
.39965 .72824 L
.40773 .73268 L
.41744 .73757 L
.41824 .73796 L
.42716 .74197 L
.43687 .74586 L
.44191 .74767 L
.44658 .74921 L
.45629 .75203 L
.46601 .75429 L
.47572 .756 L
.48543 .75714 L
.48848 .75738 L
.49514 .75771 L
.50486 .75771 L
.51152 .75738 L
.51457 .75714 L
.52428 .756 L
.53399 .75429 L
.54371 .75203 L
.55342 .74921 L
.55809 .74767 L
.56313 .74586 L
.57284 .74197 L
.58176 .73796 L
.58256 .73757 L
.59227 .73268 L
.60035 .72824 L
.60198 .72731 L
.61169 .72148 L
.61636 .71853 L
.62141 .71523 L
.63077 .70882 L
.63112 .70857 L
.64083 .70155 L
Mistroke
.6441 .69911 L
.65054 .69419 L
.65667 .68939 L
.66026 .68653 L
.66869 .67968 L
.66997 .67863 L
.67968 .67053 L
.68035 .66997 L
.68939 .66229 L
.69177 .66026 L
.69911 .65398 L
.70312 .65054 L
.70882 .64569 L
.71455 .64083 L
.71853 .63749 L
.72626 .63112 L
.72824 .62952 L
.73796 .62189 L
.73859 .62141 L
.74767 .61477 L
.75213 .61169 L
.75738 .60832 L
.76709 .60276 L
.76854 .60198 L
.77681 .59829 L
.78652 .59511 L
.79623 .59339 L
.80594 .59323 L
.81566 .59464 L
.82537 .59753 L
.83508 .60175 L
.83555 .60198 L
.84479 .60711 L
.85202 .61169 L
.85451 .61339 L
.86422 .62039 L
.86556 .62141 L
.87393 .62793 L
.87789 .63112 L
.88364 .63585 L
.8896 .64083 L
.89336 .64401 L
.90103 .65054 L
.90307 .65229 L
.91238 .66026 L
.91278 .6606 L
.92249 .66886 L
.92381 .66997 L
.93221 .677 L
.93546 .67968 L
Mistroke
.94192 .68494 L
.94749 .68939 L
.95163 .69265 L
.96005 .69911 L
.96134 .70008 L
.97106 .70717 L
.97338 .70882 L
.98077 .71391 L
Mfstroke
.01923 .28609 m
.02662 .29118 L
.02894 .29283 L
.03866 .29992 L
.03995 .30089 L
.04837 .30735 L
.05251 .31061 L
.05808 .31506 L
.06454 .32032 L
.06779 .323 L
.07619 .33003 L
.07751 .33114 L
.08722 .3394 L
.08762 .33974 L
.09693 .34771 L
.09897 .34946 L
.10664 .35599 L
.1104 .35917 L
.11636 .36415 L
.12211 .36888 L
.12607 .37207 L
.13444 .37859 L
.13578 .37961 L
.14549 .38661 L
.14798 .38831 L
.15521 .39289 L
.16445 .39802 L
.16492 .39825 L
.17463 .40247 L
.18434 .40536 L
.19406 .40677 L
.20377 .40661 L
.21348 .40489 L
.22319 .40171 L
.23146 .39802 L
.23291 .39724 L
.24262 .39168 L
.24787 .38831 L
.25233 .38523 L
.26141 .37859 L
.26204 .37811 L
.27176 .37048 L
.27374 .36888 L
.28147 .36251 L
.28545 .35917 L
.29118 .35431 L
.29688 .34946 L
.30089 .34602 L
.30823 .33974 L
.31061 .33771 L
Mistroke
.31965 .33003 L
.32032 .32947 L
.33003 .32137 L
.33131 .32032 L
.33974 .31347 L
.34333 .31061 L
.34946 .30581 L
.3559 .30089 L
.35917 .29845 L
.36888 .29143 L
.36923 .29118 L
.37859 .28477 L
.38364 .28147 L
.38831 .27852 L
.39802 .27269 L
.39965 .27176 L
.40773 .26732 L
.41744 .26243 L
.41824 .26204 L
.42716 .25803 L
.43687 .25414 L
.44191 .25233 L
.44658 .25079 L
.45629 .24797 L
.46601 .24571 L
.47572 .244 L
.48543 .24286 L
.48848 .24262 L
.49514 .24229 L
.50486 .24229 L
.51152 .24262 L
.51457 .24286 L
.52428 .244 L
.53399 .24571 L
.54371 .24797 L
.55342 .25079 L
.55809 .25233 L
.56313 .25414 L
.57284 .25803 L
.58176 .26204 L
.58256 .26243 L
.59227 .26732 L
.60035 .27176 L
.60198 .27269 L
.61169 .27852 L
.61636 .28147 L
.62141 .28477 L
.63077 .29118 L
.63112 .29143 L
.64083 .29845 L
Mistroke
.6441 .30089 L
.65054 .30581 L
.65667 .31061 L
.66026 .31347 L
.66869 .32032 L
.66997 .32137 L
.67968 .32947 L
.68035 .33003 L
.68939 .33771 L
.69177 .33974 L
.69911 .34602 L
.70312 .34946 L
.70882 .35431 L
.71455 .35917 L
.71853 .36251 L
.72626 .36888 L
.72824 .37048 L
.73796 .37811 L
.73859 .37859 L
.74767 .38523 L
.75213 .38831 L
.75738 .39168 L
.76709 .39724 L
.76854 .39802 L
.77681 .40171 L
.78652 .40489 L
.79623 .40661 L
.80594 .40677 L
.81566 .40536 L
.82537 .40247 L
.83508 .39825 L
.83555 .39802 L
.84479 .39289 L
.85202 .38831 L
.85451 .38661 L
.86422 .37961 L
.86556 .37859 L
.87393 .37207 L
.87789 .36888 L
.88364 .36415 L
.8896 .35917 L
.89336 .35599 L
.90103 .34946 L
.90307 .34771 L
.91238 .33974 L
.91278 .3394 L
.92249 .33114 L
.92381 .33003 L
.93221 .323 L
.93546 .32032 L
Mistroke
.94192 .31506 L
.94749 .31061 L
.95163 .30735 L
.96005 .30089 L
.96134 .29992 L
.97106 .29283 L
.97338 .29118 L
.98077 .28609 L
Mfstroke
.47572 .2708 m
.48543 .26952 L
.49514 .26888 L
.50486 .26888 L
.51457 .26952 L
.52428 .2708 L
.52971 .27176 L
.53399 .2727 L
.54371 .27524 L
.55342 .2784 L
.56142 .28147 L
.56313 .28218 L
.57284 .28658 L
.58183 .29118 L
.58256 .29158 L
.59227 .29717 L
.59822 .30089 L
.60198 .30336 L
.61169 .31012 L
.61236 .31061 L
.62141 .31746 L
.62501 .32032 L
.63112 .32535 L
.63657 .33003 L
.64083 .33381 L
.6473 .33974 L
.65054 .34281 L
.65735 .34946 L
.66026 .35238 L
.66683 .35917 L
.66997 .3625 L
.67583 .36888 L
.67968 .3732 L
.68438 .37859 L
.68939 .38451 L
.69252 .38831 L
.69911 .39651 L
.70028 .39802 L
.70765 .40773 L
.70882 .40932 L
.71462 .41744 L
.71853 .42316 L
.72116 .42716 L
.72723 .43687 L
.72824 .43856 L
.73275 .44658 L
.73766 .45629 L
.73796 .45691 L
.74181 .46601 L
.7451 .47572 L
Mistroke
.7474 .48543 L
.74767 .48699 L
.74857 .49514 L
.74857 .50486 L
.74767 .51301 L
.7474 .51457 L
.7451 .52428 L
.74181 .53399 L
.73796 .54309 L
.73766 .54371 L
.73275 .55342 L
.72824 .56144 L
.72723 .56313 L
.72116 .57284 L
.71853 .57684 L
.71462 .58256 L
.70882 .59068 L
.70765 .59227 L
.70028 .60198 L
.69911 .60349 L
.69252 .61169 L
.68939 .61549 L
.68438 .62141 L
.67968 .6268 L
.67583 .63112 L
.66997 .6375 L
.66683 .64083 L
.66026 .64762 L
.65735 .65054 L
.65054 .65719 L
.6473 .66026 L
.64083 .66619 L
.63657 .66997 L
.63112 .67465 L
.62501 .67968 L
.62141 .68254 L
.61236 .68939 L
.61169 .68988 L
.60198 .69664 L
.59822 .69911 L
.59227 .70283 L
.58256 .70842 L
.58183 .70882 L
.57284 .71342 L
.56313 .71782 L
.56142 .71853 L
.55342 .7216 L
.54371 .72476 L
.53399 .7273 L
.52971 .72824 L
Mistroke
.52428 .7292 L
.51457 .73048 L
.50486 .73112 L
.49514 .73112 L
.48543 .73048 L
.47572 .7292 L
.47029 .72824 L
.46601 .7273 L
.45629 .72476 L
.44658 .7216 L
.43858 .71853 L
.43687 .71782 L
.42716 .71342 L
.41817 .70882 L
.41744 .70842 L
.40773 .70283 L
.40178 .69911 L
.39802 .69664 L
.38831 .68988 L
.38764 .68939 L
.37859 .68254 L
.37499 .67968 L
.36888 .67465 L
.36343 .66997 L
.35917 .66619 L
.3527 .66026 L
.34946 .65719 L
.34265 .65054 L
.33974 .64762 L
.33317 .64083 L
.33003 .6375 L
.32417 .63112 L
.32032 .6268 L
.31562 .62141 L
.31061 .61549 L
.30748 .61169 L
.30089 .60349 L
.29972 .60198 L
.29235 .59227 L
.29118 .59068 L
.28538 .58256 L
.28147 .57684 L
.27884 .57284 L
.27277 .56313 L
.27176 .56144 L
.26725 .55342 L
.26234 .54371 L
.26204 .54309 L
.25819 .53399 L
.2549 .52428 L
Mistroke
.2526 .51457 L
.25233 .51301 L
.25143 .50486 L
.25143 .49514 L
.25233 .48699 L
.2526 .48543 L
.2549 .47572 L
.25819 .46601 L
.26204 .45691 L
.26234 .45629 L
.26725 .44658 L
.27176 .43856 L
.27277 .43687 L
.27884 .42716 L
.28147 .42316 L
.28538 .41744 L
.29118 .40932 L
.29235 .40773 L
.29972 .39802 L
.30089 .39651 L
.30748 .38831 L
.31061 .38451 L
.31562 .37859 L
.32032 .3732 L
.32417 .36888 L
.33003 .3625 L
.33317 .35917 L
.33974 .35238 L
.34265 .34946 L
.34946 .34281 L
.3527 .33974 L
.35917 .33381 L
.36343 .33003 L
.36888 .32535 L
.37499 .32032 L
.37859 .31746 L
.38764 .31061 L
.38831 .31012 L
.39802 .30336 L
.40178 .30089 L
.40773 .29717 L
.41744 .29158 L
.41817 .29118 L
.42716 .28658 L
.43687 .28218 L
.43858 .28147 L
.44658 .2784 L
.45629 .27524 L
.46601 .2727 L
.47029 .27176 L
Mistroke
.47572 .2708 L
Mfstroke
.01923 .68098 m
.02085 .67968 L
.02894 .67297 L
.03242 .66997 L
.03866 .6644 L
.04315 .66026 L
.04837 .65528 L
.0532 .65054 L
.05808 .64561 L
.06268 .64083 L
.06779 .63537 L
.07167 .63112 L
.07751 .62455 L
.08023 .62141 L
.08722 .6131 L
.08837 .61169 L
.09613 .60198 L
.09693 .60095 L
.1035 .59227 L
.10664 .58796 L
.11046 .58256 L
.11636 .57385 L
.11701 .57284 L
.12308 .56313 L
.12607 .55803 L
.1286 .55342 L
.1335 .54371 L
.13578 .5387 L
.13766 .53399 L
.14095 .52428 L
.14324 .51457 L
.14442 .50486 L
.14442 .49514 L
.14324 .48543 L
.14095 .47572 L
.13766 .46601 L
.13578 .4613 L
.1335 .45629 L
.1286 .44658 L
.12607 .44197 L
.12308 .43687 L
.11701 .42716 L
.11636 .42615 L
.11046 .41744 L
.10664 .41204 L
.1035 .40773 L
.09693 .39905 L
.09613 .39802 L
.08837 .38831 L
.08722 .3869 L
Mistroke
.08023 .37859 L
.07751 .37545 L
.07167 .36888 L
.06779 .36463 L
.06268 .35917 L
.05808 .35439 L
.0532 .34946 L
.04837 .34472 L
.04315 .33974 L
.03866 .3356 L
.03242 .33003 L
.02894 .32703 L
.02085 .32032 L
.01923 .31902 L
Mfstroke
.98077 .68098 m
.97915 .67968 L
.97106 .67297 L
.96758 .66997 L
.96134 .6644 L
.95685 .66026 L
.95163 .65528 L
.9468 .65054 L
.94192 .64561 L
.93732 .64083 L
.93221 .63537 L
.92833 .63112 L
.92249 .62455 L
.91977 .62141 L
.91278 .6131 L
.91163 .61169 L
.90387 .60198 L
.90307 .60095 L
.8965 .59227 L
.89336 .58796 L
.88954 .58256 L
.88364 .57385 L
.88299 .57284 L
.87692 .56313 L
.87393 .55803 L
.8714 .55342 L
.8665 .54371 L
.86422 .5387 L
.86234 .53399 L
.85905 .52428 L
.85676 .51457 L
.85558 .50486 L
.85558 .49514 L
.85676 .48543 L
.85905 .47572 L
.86234 .46601 L
.86422 .4613 L
.8665 .45629 L
.8714 .44658 L
.87393 .44197 L
.87692 .43687 L
.88299 .42716 L
.88364 .42615 L
.88954 .41744 L
.89336 .41204 L
.8965 .40773 L
.90307 .39905 L
.90387 .39802 L
.91163 .38831 L
.91278 .3869 L
Mistroke
.91977 .37859 L
.92249 .37545 L
.92833 .36888 L
.93221 .36463 L
.93732 .35917 L
.94192 .35439 L
.9468 .34946 L
.95163 .34472 L
.95685 .33974 L
.96134 .3356 L
.96758 .33003 L
.97106 .32703 L
.97915 .32032 L
.98077 .31902 L
Mfstroke
.48543 .2997 m
.49514 .29897 L
.50486 .29897 L
.51457 .2997 L
.52308 .30089 L
.52428 .30117 L
.53399 .30337 L
.54371 .30631 L
.55342 .30999 L
.55488 .31061 L
.56313 .31441 L
.57284 .31959 L
.57411 .32032 L
.58256 .32553 L
.58918 .33003 L
.59227 .33226 L
.60192 .33974 L
.60198 .33979 L
.61169 .34817 L
.6131 .34946 L
.62141 .35745 L
.6231 .35917 L
.63112 .36771 L
.63216 .36888 L
.64043 .37859 L
.64083 .37909 L
.64798 .38831 L
.65054 .39181 L
.65489 .39802 L
.66026 .40624 L
.66119 .40773 L
.66689 .41744 L
.66997 .42315 L
.67201 .42716 L
.67653 .43687 L
.67968 .44452 L
.68046 .44658 L
.68377 .45629 L
.68645 .46601 L
.68848 .47572 L
.68939 .48116 L
.68984 .48543 L
.69052 .49514 L
.69052 .50486 L
.68984 .51457 L
.68939 .51884 L
.68848 .52428 L
.68645 .53399 L
.68377 .54371 L
.68046 .55342 L
Mistroke
.67968 .55548 L
.67653 .56313 L
.67201 .57284 L
.66997 .57685 L
.66689 .58256 L
.66119 .59227 L
.66026 .59376 L
.65489 .60198 L
.65054 .60819 L
.64798 .61169 L
.64083 .62091 L
.64043 .62141 L
.63216 .63112 L
.63112 .63229 L
.6231 .64083 L
.62141 .64255 L
.6131 .65054 L
.61169 .65183 L
.60198 .66021 L
.60192 .66026 L
.59227 .66774 L
.58918 .66997 L
.58256 .67447 L
.57411 .67968 L
.57284 .68041 L
.56313 .68559 L
.55488 .68939 L
.55342 .69001 L
.54371 .69369 L
.53399 .69663 L
.52428 .69883 L
.52308 .69911 L
.51457 .7003 L
.50486 .70103 L
.49514 .70103 L
.48543 .7003 L
.47692 .69911 L
.47572 .69883 L
.46601 .69663 L
.45629 .69369 L
.44658 .69001 L
.44512 .68939 L
.43687 .68559 L
.42716 .68041 L
.42589 .67968 L
.41744 .67447 L
.41082 .66997 L
.40773 .66774 L
.39808 .66026 L
.39802 .66021 L
Mistroke
.38831 .65183 L
.3869 .65054 L
.37859 .64255 L
.3769 .64083 L
.36888 .63229 L
.36784 .63112 L
.35957 .62141 L
.35917 .62091 L
.35202 .61169 L
.34946 .60819 L
.34511 .60198 L
.33974 .59376 L
.33881 .59227 L
.33311 .58256 L
.33003 .57685 L
.32799 .57284 L
.32347 .56313 L
.32032 .55548 L
.31954 .55342 L
.31623 .54371 L
.31355 .53399 L
.31152 .52428 L
.31061 .51884 L
.31016 .51457 L
.30948 .50486 L
.30948 .49514 L
.31016 .48543 L
.31061 .48116 L
.31152 .47572 L
.31355 .46601 L
.31623 .45629 L
.31954 .44658 L
.32032 .44452 L
.32347 .43687 L
.32799 .42716 L
.33003 .42315 L
.33311 .41744 L
.33881 .40773 L
.33974 .40624 L
.34511 .39802 L
.34946 .39181 L
.35202 .38831 L
.35917 .37909 L
.35957 .37859 L
.36784 .36888 L
.36888 .36771 L
.3769 .35917 L
.37859 .35745 L
.3869 .34946 L
.38831 .34817 L
Mistroke
.39802 .33979 L
.39808 .33974 L
.40773 .33226 L
.41082 .33003 L
.41744 .32553 L
.42589 .32032 L
.42716 .31959 L
.43687 .31441 L
.44512 .31061 L
.44658 .30999 L
.45629 .30631 L
.46601 .30337 L
.47572 .30117 L
.47692 .30089 L
.48543 .2997 L
Mfstroke
.01923 .64054 m
.02801 .63112 L
.02894 .63007 L
.03627 .62141 L
.03866 .61844 L
.04383 .61169 L
.04837 .60541 L
.05074 .60198 L
.05703 .59227 L
.05808 .59056 L
.06274 .58256 L
.06779 .57297 L
.06785 .57284 L
.07238 .56313 L
.07631 .55342 L
.07751 .55013 L
.07962 .54371 L
.0823 .53399 L
.08432 .52428 L
.08568 .51457 L
.08637 .50486 L
.08637 .49514 L
.08568 .48543 L
.08432 .47572 L
.0823 .46601 L
.07962 .45629 L
.07751 .44987 L
.07631 .44658 L
.07238 .43687 L
.06785 .42716 L
.06779 .42703 L
.06274 .41744 L
.05808 .40944 L
.05703 .40773 L
.05074 .39802 L
.04837 .39459 L
.04383 .38831 L
.03866 .38156 L
.03627 .37859 L
.02894 .36993 L
.02801 .36888 L
.01923 .35946 L
s
.98077 .64054 m
.97199 .63112 L
.97106 .63007 L
.96373 .62141 L
.96134 .61844 L
.95617 .61169 L
.95163 .60541 L
.94926 .60198 L
.94297 .59227 L
.94192 .59056 L
.93726 .58256 L
.93221 .57297 L
.93215 .57284 L
.92762 .56313 L
.92369 .55342 L
.92249 .55013 L
.92038 .54371 L
.9177 .53399 L
.91568 .52428 L
.91432 .51457 L
.91363 .50486 L
.91363 .49514 L
.91432 .48543 L
.91568 .47572 L
.9177 .46601 L
.92038 .45629 L
.92249 .44987 L
.92369 .44658 L
.92762 .43687 L
.93215 .42716 L
.93221 .42703 L
.93726 .41744 L
.94192 .40944 L
.94297 .40773 L
.94926 .39802 L
.95163 .39459 L
.95617 .38831 L
.96134 .38156 L
.96373 .37859 L
.97106 .36993 L
.97199 .36888 L
.98077 .35946 L
s
.47572 .33711 m
.48543 .33533 L
.49514 .33444 L
.50486 .33444 L
.51457 .33533 L
.52428 .33711 L
.5338 .33974 L
.53399 .33981 L
.54371 .34343 L
.55342 .348 L
.55614 .34946 L
.56313 .35357 L
.57144 .35917 L
.57284 .36019 L
.58256 .36795 L
.58363 .36888 L
.59227 .37697 L
.59387 .37859 L
.60198 .38746 L
.6027 .38831 L
.61042 .39802 L
.61169 .39975 L
.6172 .40773 L
.62141 .41445 L
.62316 .41744 L
.62836 .42716 L
.63112 .43292 L
.63286 .43687 L
.63668 .44658 L
.63985 .45629 L
.64083 .45974 L
.64237 .46601 L
.64426 .47572 L
.64552 .48543 L
.64615 .49514 L
.64615 .50486 L
.64552 .51457 L
.64426 .52428 L
.64237 .53399 L
.64083 .54026 L
.63985 .54371 L
.63668 .55342 L
.63286 .56313 L
.63112 .56708 L
.62836 .57284 L
.62316 .58256 L
.62141 .58555 L
.6172 .59227 L
.61169 .60025 L
.61042 .60198 L
Mistroke
.6027 .61169 L
.60198 .61254 L
.59387 .62141 L
.59227 .62303 L
.58363 .63112 L
.58256 .63205 L
.57284 .63981 L
.57144 .64083 L
.56313 .64643 L
.55614 .65054 L
.55342 .652 L
.54371 .65657 L
.53399 .66019 L
.5338 .66026 L
.52428 .66289 L
.51457 .66467 L
.50486 .66556 L
.49514 .66556 L
.48543 .66467 L
.47572 .66289 L
.4662 .66026 L
.46601 .66019 L
.45629 .65657 L
.44658 .652 L
.44386 .65054 L
.43687 .64643 L
.42856 .64083 L
.42716 .63981 L
.41744 .63205 L
.41637 .63112 L
.40773 .62303 L
.40613 .62141 L
.39802 .61254 L
.3973 .61169 L
.38958 .60198 L
.38831 .60025 L
.3828 .59227 L
.37859 .58555 L
.37684 .58256 L
.37164 .57284 L
.36888 .56708 L
.36714 .56313 L
.36332 .55342 L
.36015 .54371 L
.35917 .54026 L
.35763 .53399 L
.35574 .52428 L
.35448 .51457 L
.35385 .50486 L
.35385 .49514 L
Mistroke
.35448 .48543 L
.35574 .47572 L
.35763 .46601 L
.35917 .45974 L
.36015 .45629 L
.36332 .44658 L
.36714 .43687 L
.36888 .43292 L
.37164 .42716 L
.37684 .41744 L
.37859 .41445 L
.3828 .40773 L
.38831 .39975 L
.38958 .39802 L
.3973 .38831 L
.39802 .38746 L
.40613 .37859 L
.40773 .37697 L
.41637 .36888 L
.41744 .36795 L
.42716 .36019 L
.42856 .35917 L
.43687 .35357 L
.44386 .34946 L
.44658 .348 L
.45629 .34343 L
.46601 .33981 L
.4662 .33974 L
.47572 .33711 L
Mfstroke
.01923 .58217 m
.02421 .57284 L
.02871 .56313 L
.02894 .56258 L
.03253 .55342 L
.0357 .54371 L
.03822 .53399 L
.03866 .53212 L
.04011 .52428 L
.04137 .51457 L
.042 .50486 L
.042 .49514 L
.04137 .48543 L
.04011 .47572 L
.03866 .46788 L
.03822 .46601 L
.0357 .45629 L
.03253 .44658 L
.02894 .43742 L
.02871 .43687 L
.02421 .42716 L
.01923 .41783 L
s
.98077 .58217 m
.97579 .57284 L
.97129 .56313 L
.97106 .56258 L
.96747 .55342 L
.9643 .54371 L
.96178 .53399 L
.96134 .53212 L
.95989 .52428 L
.95863 .51457 L
.958 .50486 L
.958 .49514 L
.95863 .48543 L
.95989 .47572 L
.96134 .46788 L
.96178 .46601 L
.9643 .45629 L
.96747 .44658 L
.97106 .43742 L
.97129 .43687 L
.97579 .42716 L
.98077 .41783 L
s
.46601 .38749 m
.47572 .38368 L
.48543 .38119 L
.49514 .37996 L
.50486 .37996 L
.51457 .38119 L
.52428 .38368 L
.53399 .38749 L
.53575 .38831 L
.54371 .3927 L
.55152 .39802 L
.55342 .39949 L
.56273 .40773 L
.56313 .40813 L
.57152 .41744 L
.57284 .4191 L
.57866 .42716 L
.58256 .43339 L
.58452 .43687 L
.58931 .44658 L
.59227 .45379 L
.59317 .45629 L
.59619 .46601 L
.59841 .47572 L
.59988 .48543 L
.6006 .49514 L
.6006 .50486 L
.59988 .51457 L
.59841 .52428 L
.59619 .53399 L
.59317 .54371 L
.59227 .54621 L
.58931 .55342 L
.58452 .56313 L
.58256 .56661 L
.57866 .57284 L
.57284 .5809 L
.57152 .58256 L
.56313 .59187 L
.56273 .59227 L
.55342 .60051 L
.55152 .60198 L
.54371 .6073 L
.53575 .61169 L
.53399 .61251 L
.52428 .61632 L
.51457 .61881 L
.50486 .62004 L
.49514 .62004 L
.48543 .61881 L
Mistroke
.47572 .61632 L
.46601 .61251 L
.46425 .61169 L
.45629 .6073 L
.44848 .60198 L
.44658 .60051 L
.43727 .59227 L
.43687 .59187 L
.42848 .58256 L
.42716 .5809 L
.42134 .57284 L
.41744 .56661 L
.41548 .56313 L
.41069 .55342 L
.40773 .54621 L
.40683 .54371 L
.40381 .53399 L
.40159 .52428 L
.40012 .51457 L
.3994 .50486 L
.3994 .49514 L
.40012 .48543 L
.40159 .47572 L
.40381 .46601 L
.40683 .45629 L
.40773 .45379 L
.41069 .44658 L
.41548 .43687 L
.41744 .43339 L
.42134 .42716 L
.42716 .4191 L
.42848 .41744 L
.43687 .40813 L
.43727 .40773 L
.44658 .39949 L
.44848 .39802 L
.45629 .3927 L
.46425 .38831 L
.46601 .38749 L
Mfstroke
.49514 .46243 m
.50486 .46243 L
.51361 .46601 L
.51457 .46659 L
.52364 .47572 L
.52428 .47673 L
.52832 .48543 L
.53042 .49514 L
.53042 .50486 L
.52832 .51457 L
.52428 .52327 L
.52364 .52428 L
.51457 .53341 L
.51361 .53399 L
.50486 .53757 L
.49514 .53757 L
.48639 .53399 L
.48543 .53341 L
.47636 .52428 L
.47572 .52327 L
.47168 .51457 L
.46958 .50486 L
.46958 .49514 L
.47168 .48543 L
.47572 .47673 L
.47636 .47572 L
.48543 .46659 L
.48639 .46601 L
.49514 .46243 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML00?oG8ML00?oG8ML00?oG8ML0037G
00<0emL0;mL402oG0P0ae`@0<]L00`3Ge`0Ne`00<ML00`3Ge`0_e`030=OG02oG00@0emL0<=L00`3G
e`0ce`030=OG01kG000^e`D0<ML00`3Ge`0^e`040=OG037G00<0emL0;mL501oG000Ye`@000GG0=OG
000[e`@01=L00`3Ge`0]e`040=OG03;G00<0emL0;]L0103Ge`0Pe`00;mL00`3G000de`030=OG02cG
00@0emL0<mL00`3Ge`0^e`030=L0023G000`e`80<ML0103Ge`0^e`040=OG033G00@0emL0<ML2023G
000ae`030=OG033G0P0`e`80<]L203?G00<0emL07]L00?oG8ML00?oG8ML00?oG8ML000oGo`0A007G
000?e`030=OG00;G00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00[G
00<0emL02]L00`3Ge`0;e`030=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL02]L00`3G
e`0:e`030=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00;G
0@01e`003mL00`3Ge`0Le`030=OG037G00<0emL0<]L00`3Ge`0ae`030=OG037G00<0emL07=L1007G
000?e`030=OG0?oG3ML1007G0009e`030=OG00?G00<0emL0omL=e`400ML000WG00<0emL00mL00`3G
e`3oe`gG0@01e`001]L500CG0`3oe`cG0P01e`0000?G00000P001ML0emL000GG00<0emL0omL=e`40
0ML000OG00<0e`001ML00`3Ge`3oe`gG0@01e`002=L200GG00<0emL0omL=e`400ML000WG00<0emL0
0mL00`3Ge`3oe`gG0@01e`003mL00`3Ge`3oe`gG0@01e`003mL00`3Ge`3oe`gG0@01e`003mL00`3G
e`3oe`gG0@01e`003mL00`3Ge`3oe`gG0@01e`003mL00`3Ge`3oe`gG0@01e`003mL00`3Ge`3oe`gG
0@01e`003mL00`3Ge`3oe`gG0@01e`003mL00`3Ge`3oe`gG0@01e`003mL00`3Ge`3oe`gG0@01e`00
3mL00`3Ge`3oe`gG0@01e`003mL00`3Ge`3oe`gG0@01e`003mL20?oG3ML2007G000?e`030=OG0?oG
3ML1007G000?e`030=OG07gG401oe`400ML000oG00<0emL0N=L5013G1@1je`400ML000oG00<0emL0
LmL501[G1@1ee`400ML000oG00<0emL0K]L502CG1P1_e`400ML000oG00<0emL0JmL301GG1@0Ee`80
KML1007G000?e`030=OG06SG0`0=e`/01ML:00gG0`1Ze`400ML000oG00<0emL0I]L200gG0`0Je`<0
3ML306OG0@01e`003mL00`3Ge`02e`80GmL300[G1@0Pe`D02mL2063G00<0emL00]L1007G000?e`03
0=OG00CG0P1Je`<02mL202[G0`0:e`<0F]L300GG0@01e`003mL00`3Ge`06e`<0EML200_G0`0?ea00
4=L200_G0`1De`<02=L1007G000?e`030=OG00WG0P1Ae`802]L300gG1@0@e`D03ML300_G0P1@e`80
2mL1007G000?e`030=OG00_G0`1:e`@02]L200_G1@0Je`D02mL300[G0`1:e`<03ML1007G000?e`03
0=OG00;G0P0:e`<0AML200_G0`0:e`<09=L300_G0P0;e`80AML300_G00<0emL00]L1007G000?e`03
0=OG00CG0`0:e`<0?mL300WG1009e`@0:]L400WG1009e`<0@=L200[G1005e`400ML000oG0P08e`80
2mL203_G0P0;e`030=OG00OG1@0>eaD03]L400WG0P0:e`<0>]L300[G0P08e`800ML000oG00<0emL0
2ML200_G0P0fe`<02]L300SG0P0>e`D05ML400kG0P09e`802mL203KG0P0;e`802mL1007G000?e`03
0=OG00_G0`0:e`<0<=L300[G0`09e`803ML301kG0`0=e`<02=L300[G0`0`e`<02]L300gG0@01e`00
3mL00`3Ge`02e`802]L300[G0`0[e`802mL200[G0P0<e`<09=L300gG00<0emL02=L200_G0`0Ze`<0
2]L300_G00<0emL00]L1007G000?e`030=OG00CG0P0;e`802mL202CG00<0e`000P0;e`802mL00`3G
e`08e`@0:]L500WG0P0:e`803=L20003e`3G02?G0P0;e`803=L200GG0@01e`003mL00`3Ge`06e`<0
2]L300[G1P0Ke`D02mL300[G0`08e`<03mLE00kG0`09e`<02ML400[G1P0Je`H02]L400WG1007e`40
0ML000oG00<0emL02ML300[G0P0>e`D04=L600gG0`0:e`<02ML200cG1P0Ee`D03=L200[G0P0;e`80
3]L5013G1@0>e`802mL200_G0@01e`003mL00`3Ge`0<e`802]L3013G400@e`<02]L300[G0P0<e`80
8=L200cG0`09e`<02]L3013G400@e`<02]L300gG0@01e`003mL00`3Ge`02e`802]L200_G0`0[e`80
2mL200_G0P0;e`<09=L300cG00<0emL02ML200_G0`0Ze`<02mL200_G00<0emL00]L1007G000?e`03
0=OG00CG0P0:e`803=L202KG0`0;e`802mL200_G0P0Ze`<02]L300[G0P0<e`809]L200cG0P0;e`80
1ML1007G000?e`030=OG00KG0`09e`803=L3023G0`0;e`<02]L300[G0`0?ea004=L200_G0`09e`<0
2mL3023G0`0=e`030=OG00OG1007e`400ML000oG00<0emL02ML200WG0P0=e`H05ML500gG00<0emL0
2=L300[G0`0=e`D04=L500gG0`0;e`802]L200cG1@0Fe`D03ML300SG0P0;e`400ML000oG00<0emL0
2mL200WG100?eaD03]L400WG0P0:e`<03=L401[G100<e`<02]L200[G0`0>eaH03]L400WG0P0=e`40
0ML000oG00<0emL00]L00`3Ge`08e`030=OG00[G00<0emL0;]L200[G0P0:e`802mL402;G100;e`80
2]L200[G0P0`e`030=OG00[G0P09e`030=OG00;G0@01e`003mL00`3Ge`03e`802ML300[G0`0[e`80
2mL00`3Ge`08e`802mL202[G0P0;e`802]L00`3Ge`09e`<0:]L300[G0`0:e`030=OG00?G0@01e`00
3mL00`3Ge`05e`802]L300[G0`0Re`H02]L300WG0P0:e`<0;]L300[G0P09e`<02mL502;G0`0;e`80
2]L300KG0@01e`003mL00`3Ge`07e`802mL200_G1@0Ke`803]L200_G00<0emL02=L2013G5@0?e`80
2]L200[G0`0=e`<06]L500cG0P0:e`802ML1007G000?e`802]L200_G00<0emL03ML5017G1@0>e`80
2mL200WG0P0?e`<05ML200oG0P0:e`802mL200kG100Be`@03mL200[G0P0:e`800ML000oG00<0emL0
2mL300WG0P0Bea404=L300[G0`0:e`030=OG00[G1@0Je`D03=L200[G0P0;e`804=LB017G0P0:e`80
3ML1007G000?e`030=OG00;G0P0:e`030=OG00SG0P0_e`802mL200[G0`0:e`<09=L300_G0P0:e`80
2mL202oG0P0:e`802]L00`3Ge`02e`400ML000oG00<0emL01=L200WG0P0:e`@0:=L300_G0P0:e`80
2mL202[G0`0:e`<02ML200_G0`0Xe`@02]L200[G0P05e`400ML000oG00<0emL01]L00`3Ge`08e`<0
2mL202;G1@0;e`802]L200_G0P0_e`802mL00`3Ge`08e`803=L402?G00<0emL02]L200[G0P07e`40
0ML000oG00<0emL01mL200_G0P0;e`D06mL200kG0P0;e`030=OG00WG0P0Aea004]L00`3Ge`09e`80
2]L200kG0`0Ke`D02mL200_G00<0emL01mL1007G000?e`030=OG00WG0P0;e`030=OG00gG0`0Ee`<0
3]L200[G0`0:e`803]L5013G1@0>e`802mL200[G0`0>e`805]L300oG00<0emL02=L300[G0@01e`00
3mL00`3Ge`0;e`802]L2013G5@0?e`802]L200_G0P0=e`<06]L300gG0`0:e`802mL00`3Ge`0=eaH0
3mL300[G00<0emL02mL1007G000?e`030=OG00;G00<0emL02=L00`3Ge`09e`80<ML00`3Ge`09e`03
0=OG00WG0P0=e`808=L200kG0P0:e`030=OG00WG00<0emL0;mL200cG00<0emL01mL00`3Ge`02e`40
0ML000oG00<0emL00mL00`3Ge`08e`802mL302_G0`0:e`802mL00`3Ge`0:e`<09=L300gG00<0emL0
2=L200[G100Ze`<02mL300[G00<0emL00]L1007G000?e`030=OG00CG0P0:e`803=L302GG0`0;e`80
2]L300_G0P0Ze`<02mL200[G0P0<e`809]L200cG0P0:e`<01ML1007G000?e`030=OG00KG0P0:e`80
3ML2023G0`0<e`802]L200_G0`0Be`X04mL300[G0P0:e`803=L3023G0`0<e`802]L200SG0@01e`00
3mL00`3Ge`08e`802]L200gG0`0Ke`803]L00`3Ge`09e`030=OG00WG0P0@e`D02]L6013G00<0emL0
2ML200[G0P0=e`<06]L300gG0P0:e`802]L1007G000?e`030=OG00[G00<0emL02ML200kG1@0@e`H0
3]L200_G00<0emL02=L200oG0`0Ee`803mL200_G00<0emL02ML200kG1@0@e`D03]L200_G00<0emL0
2]L1007G0007e`@01=L00`3Ge`0;e`802mL00`3Ge`0@ea004]L200[G0`0:e`030=OG00[G1@0Je`D0
3=L200[G0P0;e`030=OG013G400Be`030=OG00[G00<0emL02mL1007G0007e`030=OG00GG00<0emL0
0]L00`3Ge`08e`030=OG00WG0P0`e`802]L200_G0P0<e`030=OG02;G00<0emL02mL200[G0P0:e`80
<=L200_G0P09e`030=OG00;G0@01e`002=L00`3Ge`04e`<00mL00`3Ge`08e`802mL202cG0P0;e`03
0=OG00WG0P0<e`809]L200gG00<0emL02ML00`3Ge`09e`80;=L200_G0P0:e`030=OG00;G0P01e`00
00?G00000P04e`030=OG00?G00<0emL01=L200[G00<0emL02]L402GG0`0;e`802]L200cG0P0Ze`<0
2mL200[G0P0;e`<09]L300cG00<0emL02ML00`3Ge`04e`400ML000[G00<0emL00]L00`3Ge`06e`03
0=OG00SG0P0>e`808=L300cG0P0:e`802mL301GG1@0Ee`802mL200[G0P0<e`<08=L300gG0P0:e`80
1mL1007G0007e`040=OG00CG00<0emL01mL200[G0`0=e`<06mL200kG00<0emL02ML00`3Ge`09e`80
4=L800GG200?e`802mL00`3Ge`09e`030=OG00cG0`0Je`<03]L200[G0P09e`400ML000SG0P05e`03
0=OG00WG0P0;e`030=OG00gG0`0Ee`<03mL00`3Ge`09e`030=OG00SG0P0?e`<05ML200oG0P0:e`80
2]L200oG0P0Fe`803mL200[G0P0;e`400ML000oG00<0emL02mL00`3Ge`09e`030=OG00oG1@0;e`D0
4ML00`3Ge`08e`802]L00`3Ge`0=e`806]L200oG00<0emL02ML00`3Ge`09e`030=OG00kG1@0;e`H0
4=L00`3Ge`09e`030=OG00_G0@01e`003mL00`3Ge`0<e`802]L201CG2`0Ce`<02]L00`3Ge`09e`03
0=OG00_G0`0Ne`<03ML00`3Ge`09e`030=OG00WG0P0Ce`/05ML00`3Ge`09e`030=OG00cG0@01e`00
3mL00`3Ge`02e`030=OG00WG00<0emL02ML00`3Ge`0]e`802mL200_G00<0emL02]L202CG0P0<e`80
2]L200_G0P0_e`802]L200[G00<0emL00]L1007G000?e`030=OG00?G00<0emL02ML00`3Ge`09e`80
;=L00`3Ge`0:e`030=OG00WG0P0;e`80:=L200cG00<0emL02ML00`3Ge`0:e`030=OG02[G0P0;e`03
0=OG00WG00<0emL00mL1007G000?e`030=OG00CG0P0:e`030=OG00[G0`0Ve`<03=L00`3Ge`08e`80
3=L00`3Ge`0Ze`802mL200[G00<0emL02]L302KG0`0<e`030=OG00WG00<0emL01=L1007G000?e`03
0=OG00KG00<0emL02=L200gG0P0Re`803]L00`3Ge`07e`803=L202oG0P0;e`802ML200gG0P0Se`03
0=OG00_G0P0:e`801mL1007G000?e`030=OG00OG0P0:e`803ML201gG0`0=e`<02]L00`3Ge`09e`80
4ML@01;G00<0emL02]L00`3Ge`08e`803ML401cG0`0=e`030=OG00WG00<0emL01mL1007G000?e`03
0=OG00WG00<0emL02ML00`3Ge`0<e`806=L300oG00<0emL02ML200_G00<0emL03mL2013G0`0@e`03
0=OG00[G0P0:e`803mL201SG0P0?e`030=OG00SG0P0:e`400ML000oG00<0emL02]L00`3Ge`09e`03
0=OG00gG1@0Ae`804ML00`3Ge`09e`030=OG00WG0P0?e`<05ML200oG0P0;e`030=OG00[G00<0emL0
3]L201;G100?e`802]L00`3Ge`0:e`400ML000oG00<0emL02mL00`3Ge`09e`804]L600GG1P0Be`03
0=OG00WG00<0emL02ML00`3Ge`0<e`<06]L300kG00<0emL02ML00`3Ge`0:e`030=OG00oG1P06e`H0
4ML200_G00<0emL02mL1007G000?e`030=OG00cG0P0;e`805]L501KG0P0;e`030=OG00WG00<0emL0
2mL2023G0P0=e`802]L00`3Ge`0:e`805ML601GG0P0<e`030=OG00cG0@01e`003mL200?G0P0:e`03
0=OG00[G0P0]e`802mL200[G0P0<e`809=L300cG0P09e`803=L202gG00<0emL02]L200[G00@0emOG
0P01e`003mL00`3Ge`04e`030=OG00SG00<0emL02]L00`3Ge`0Ze`030=OG00[G00<0emL02ML00`3G
e`0:e`80:ML00`3Ge`0:e`030=OG00WG00<0emL02]L202_G00<0emL02]L00`3Ge`09e`030=OG00?G
0@01e`003mL00`3Ge`05e`030=OG00SG0P0;e`80:=L200cG00<0emL02ML00`3Ge`0:e`030=OG02[G
00<0emL02]L00`3Ge`09e`030=OG00_G0P0We`803=L00`3Ge`09e`030=OG00CG0@01e`003mL00`3G
e`06e`030=OG00WG00<0emL02]L202CG0P0=e`030=OG00WG00<0emL02ML202kG0P0;e`802]L200gG
00<0emL08mL00`3Ge`0:e`802mL00`3Ge`05e`400ML000oG00<0emL01]L00`3Ge`0:e`030=OG00_G
0P0Pe`803ML200[G0P0<e`030=OG017G2P0De`030=OG00[G00<0emL02ML00`3Ge`0;e`808ML200cG
00<0emL02]L00`3Ge`06e`400ML000oG00<0emL01mL00`3Ge`0:e`030=OG00cG00<0emL06mL200kG
00<0emL02ML00`3Ge`09e`<04ML300[G0`0Be`030=OG00[G00<0emL02ML00`3Ge`0<e`807ML200kG
00<0emL02ML00`3Ge`07e`400ML000oG00<0emL02=L200_G00<0emL03=L201WG0`0?e`030=OG00WG
00<0emL02ML00`3Ge`0?e`804=L3013G00<0emL02]L00`3Ge`09e`030=OG00gG0`0He`803mL00`3G
e`09e`030=OG00SG0@01e`003mL00`3Ge`0:e`030=OG00WG00<0emL03ML301CG0P0@e`802mL00`3G
e`08e`803mL301GG0P0?e`802mL00`3Ge`09e`804=L00`3Ge`0Ce`803mL200[G0P0;e`400ML000oG
00<0emL02mL00`3Ge`09e`804=L500_G100@e`802mL200[G00<0emL03=L301[G0`0>e`030=OG00WG
00<0emL02]L00`3Ge`0>e`@02mL6013G00<0emL02ML00`3Ge`0;e`400ML000oG00<0emL03=L00`3G
e`0:e`030=OG01;G2`0Ce`030=OG00[G00<0emL02ML00`3Ge`0;e`808=L200gG0P0:e`030=OG00WG
00<0emL04]L;01CG0P0;e`030=OG00cG0@01e`003mL00`3Ge`0=e`030=OG00[G00<0emL0;mL00`3G
e`09e`030=OG00WG00<0emL02mL00`3Ge`0Re`030=OG00cG00<0emL02=L00`3Ge`09e`030=OG02oG
00<0emL02mL00`3Ge`0<e`400ML000oG00<0emL00]L00`3Ge`09e`030=OG00[G00<0emL0;=L200_G
00<0emL02ML00`3Ge`0;e`030=OG02CG00<0emL02mL00`3Ge`09e`030=OG00WG0P0^e`030=OG00[G
0P0:e`030=OG00;G0@01e`003mL00`3Ge`03e`030=OG00WG00<0emL02]L00`3Ge`0Ze`030=OG00[G
00<0emL02ML00`3Ge`0:e`80:=L200cG00<0emL02ML00`3Ge`0:e`030=OG02[G00<0emL02]L00`3G
e`09e`030=OG00?G0@01e`003mL00`3Ge`04e`030=OG00SG00<0emL02mL00`3Ge`0Xe`030=OG00[G
00<0emL02ML00`3Ge`0:e`030=OG02[G00<0emL02]L00`3Ge`08e`030=OG00_G00<0emL0:=L00`3G
e`0:e`030=OG00[G00<0emL00mL1007G000?e`030=OG00GG00<0emL02=L00`3Ge`0;e`809mL00`3G
e`0;e`030=OG00WG00<0emL02]L00`3Ge`0Ze`030=OG00_G00<0emL02=L00`3Ge`0;e`809]L200gG
00<0emL02ML00`3Ge`04e`400ML000oG00<0emL01]L00`3Ge`08e`803ML00`3Ge`0Re`803ML00`3G
e`09e`030=OG00[G00<0emL0;=L200cG00<0emL02=L00`3Ge`0<e`030=OG02;G00<0emL02mL200_G
00<0emL01ML1007G000?e`030=OG00OG00<0emL02ML00`3Ge`0;e`030=OG023G00<0emL03=L00`3G
e`08e`802mL2037G00<0emL02]L00`3Ge`08e`803ML00`3Ge`0Pe`030=OG00cG00<0emL02ML00`3G
e`06e`400ML000oG0P08e`030=OG00[G00<0emL02mL00`3Ge`0Me`803]L00`3Ge`08e`030=OG00[G
00<0emL04mL:01GG00<0emL02]L00`3Ge`08e`030=OG00cG0P0Oe`803ML00`3Ge`09e`030=OG00KG
0P01e`003mL00`3Ge`08e`030=OG00[G00<0emL02mL201cG00<0emL03ML00`3Ge`09e`030=OG00[G
00<0emL04=L300[G0`0Be`030=OG00[G00<0emL02ML00`3Ge`0=e`030=OG01[G0P0>e`030=OG00WG
00<0emL02=L1007G000?e`030=OG00WG00<0emL02ML00`3Ge`0=e`030=OG01SG00<0emL03ML00`3G
e`09e`030=OG00[G00<0emL03mL2013G0`0@e`802mL00`3Ge`09e`030=OG00gG00<0emL06=L00`3G
e`0=e`030=OG00WG00<0emL02ML1007G000?e`030=OG00WG00<0emL02]L00`3Ge`0=e`805]L200oG
00<0emL02]L00`3Ge`09e`030=OG00kG0P0Ee`804=L00`3Ge`09e`030=OG00WG00<0emL03ML201KG
0P0?e`030=OG00WG00<0emL02]L1007G000?e`030=OG00[G00<0emL02ML00`3Ge`0?e`804]L2017G
00<0emL02ML00`3Ge`0:e`030=OG00gG00<0emL05mL00`3Ge`0=e`030=OG00WG00<0emL02]L00`3G
e`0>e`804mL00`3Ge`0?e`030=OG00WG00<0emL02]L1007G000?e`030=OG00_G00<0emL02ML00`3G
e`0@e`030=OG00kG0P0Ae`030=OG00[G00<0emL02=L200kG0P0Ke`030=OG00gG00<0emL02ML00`3G
e`09e`030=OG013G00<0emL03]L2017G00<0emL02]L00`3Ge`0:e`400ML000oG00<0emL02mL00`3G
e`0:e`030=OG013G0`08e`D04]L00`3Ge`0:e`030=OG00SG00<0emL03ML00`3Ge`0Le`803ML00`3G
e`09e`030=OG00[G00<0emL04=L500SG0`0Be`030=OG00[G00<0emL02mL1007G000?e`030=OG00cG
00<0emL02]L00`3Ge`0Be`P05]L00`3Ge`0:e`030=OG00WG00<0emL02mL2027G00<0emL02mL00`3G
e`09e`030=OG00[G00<0emL05=L801CG00<0emL02]L00`3Ge`0<e`400ML000oG00<0emL03ML00`3G
e`0:e`030=OG02oG00<0emL02ML00`3Ge`09e`030=OG00_G00<0emL08]L00`3Ge`0;e`030=OG00WG
00<0emL02ML00`3Ge`0_e`030=OG00_G00<0emL03=L1007G000?e`030=OG00gG00<0emL02]L00`3G
e`0^e`030=OG00[G00<0emL02ML00`3Ge`0;e`030=OG02;G00<0emL03=L00`3Ge`08e`030=OG00[G
00<0emL0;ML00`3Ge`0;e`030=OG00gG0@01e`003mL00`3Ge`02e`030=OG00WG00<0emL02]L00`3G
e`0/e`030=OG00[G00<0emL02ML00`3Ge`0;e`030=OG02CG00<0emL02mL00`3Ge`09e`030=OG00[G
00<0emL0;=L00`3Ge`0:e`030=OG00WG00<0emL00]L1007G000?e`030=OG00;G00<0emL02ML00`3G
e`0:e`030=OG02_G00<0emL02]L00`3Ge`09e`030=OG00_G00<0emL09]L00`3Ge`0:e`030=OG00[G
00<0emL02]L00`3Ge`0Ze`030=OG00[G00<0emL02ML00`3Ge`03e`400ML000oG00<0emL00mL00`3G
e`09e`030=OG00[G0P0[e`030=OG00[G00<0emL02ML00`3Ge`0:e`030=OG02SG00<0emL02]L00`3G
e`09e`030=OG00_G00<0emL0:ML00`3Ge`0:e`030=OG00WG00<0emL00mL1007G000?e`030=OG00CG
00<0emL02ML00`3Ge`0:e`030=OG02SG00<0emL02mL00`3Ge`08e`030=OG00[G00<0emL0:ML00`3G
e`0:e`030=OG00[G00<0emL02]L00`3Ge`0Xe`030=OG00_G00<0emL02ML00`3Ge`03e`400ML000oG
00<0emL01=L00`3Ge`09e`030=OG00_G00<0emL09mL00`3Ge`0:e`030=OG00WG00<0emL02]L00`3G
e`0Ze`030=OG00[G00<0emL02ML00`3Ge`0;e`030=OG02OG00<0emL02]L00`3Ge`09e`030=OG00CG
0@01e`003mL00`3Ge`05e`030=OG00WG00<0emL02]L00`3Ge`0Ve`030=OG00_G00<0emL02ML00`3G
e`0:e`030=OG02_G00<0emL02]L00`3Ge`09e`030=OG00[G00<0emL09]L00`3Ge`0;e`030=OG00WG
00<0emL01=L1007G000?e`801]L00`3Ge`09e`030=OG00_G00<0emL09ML00`3Ge`0:e`030=OG00[G
00<0emL02ML00`3Ge`0/e`030=OG00[G00<0emL02ML00`3Ge`0;e`030=OG02CG00<0emL03=L00`3G
e`09e`030=OG00?G0P01e`003mL00`3Ge`06e`030=OG00WG00<0emL02]L00`3Ge`0Te`030=OG00_G
00<0emL02ML00`3Ge`0:e`030=OG02gG00<0emL02]L00`3Ge`08e`030=OG00_G00<0emL08mL00`3G
e`0<e`030=OG00WG00<0emL01ML1007G000?e`030=OG00KG00<0emL02ML00`3Ge`0;e`030=OG02;G
00<0emL03=L00`3Ge`09e`030=OG00WG00<0emL0;]L00`3Ge`0:e`030=OG00WG00<0emL02mL00`3G
e`0Re`030=OG00cG00<0emL02ML00`3Ge`05e`400ML000oG00<0emL01]L00`3Ge`09e`030=OG00_G
00<0emL08ML00`3Ge`0<e`030=OG00WG00<0emL02]L00`3Ge`0^e`030=OG00[G00<0emL02ML00`3G
e`0;e`030=OG027G00<0emL03=L00`3Ge`09e`030=OG00KG0@01e`003mL00`3Ge`07e`030=OG00WG
00<0emL02mL00`3Ge`0Pe`030=OG00cG00<0emL02ML00`3Ge`09e`80<ML00`3Ge`0:e`030=OG00WG
00<0emL02mL00`3Ge`0Pe`030=OG00cG00<0emL02ML00`3Ge`06e`400ML000oG00<0emL01mL00`3G
e`09e`030=OG00_G00<0emL08=L00`3Ge`0<e`030=OG00SG00<0emL02]L00`3Ge`0`e`030=OG00[G
00<0emL02ML00`3Ge`0;e`030=OG023G00<0emL03=L00`3Ge`09e`030=OG00KG0@01e`003mL00`3G
e`07e`030=OG00WG00<0emL03=L00`3Ge`0Ne`030=OG00cG00<0emL02ML00`3Ge`0:e`030=OG01GG
100He`030=OG00WG00<0emL02ML00`3Ge`0<e`030=OG01oG00<0emL02mL00`3Ge`09e`030=OG00OG
0@01e`003mL00`3Ge`07e`030=OG00WG00<0emL03=L00`3Ge`0Ne`030=OG00cG00<0emL02ML00`3G
e`0:e`030=OG01?G0P04e`<05ML00`3Ge`09e`030=OG00WG00<0emL03=L00`3Ge`0Ne`030=OG00cG
00<0emL02ML00`3Ge`07e`400ML000oG00<0emL01mL00`3Ge`09e`030=OG00cG00<0emL07]L00`3G
e`0<e`030=OG00WG00<0emL02]L00`3Ge`0Be`030=OG00OG00<0emL04]L00`3Ge`09e`030=OG00WG
00<0emL03=L00`3Ge`0Ne`030=OG00cG00<0emL02ML00`3Ge`07e`400ML000oG00<0emL02=L00`3G
e`09e`030=OG00cG00<0emL07=L00`3Ge`0<e`030=OG00WG00<0emL02]L00`3Ge`0Be`030=OG00SG
00<0emL04]L00`3Ge`0:e`030=OG00WG00<0emL03=L00`3Ge`0Le`030=OG00cG00<0emL02ML00`3G
e`08e`400ML000oG00<0emL02=L00`3Ge`09e`030=OG00cG00<0emL07=L00`3Ge`0<e`030=OG00WG
00<0emL02]L00`3Ge`0Ae`030=OG00[G00<0emL04ML00`3Ge`0:e`030=OG00WG00<0emL03=L00`3G
e`0Le`030=OG00cG00<0emL02ML00`3Ge`08e`400ML000oG00<0emL02=L00`3Ge`09e`030=OG00cG
00<0emL06mL00`3Ge`0=e`030=OG00WG00<0emL02]L00`3Ge`0@e`030=OG00_G00<0emL04ML00`3G
e`0:e`030=OG00WG00<0emL03=L00`3Ge`0Ke`030=OG00gG00<0emL02ML00`3Ge`08e`400ML000oG
00<0emL02=L00`3Ge`09e`030=OG00gG00<0emL06]L00`3Ge`0=e`030=OG00WG00<0emL02]L00`3G
e`0@e`030=OG00cG00<0emL04ML00`3Ge`09e`030=OG00WG00<0emL03ML00`3Ge`0Je`030=OG00gG
00<0emL02ML00`3Ge`08e`400ML000oG00<0emL02=L00`3Ge`09e`030=OG00gG00<0emL06]L00`3G
e`0=e`030=OG00WG00<0emL02]L00`3Ge`0@e`030=OG00cG00<0emL04ML00`3Ge`09e`030=OG00WG
00<0emL03ML00`3Ge`0Je`030=OG00gG00<0emL02ML00`3Ge`08e`400ML000SG0P05e`030=OG00SG
00<0emL02ML00`3Ge`0=e`030=OG01[G00<0emL03ML00`3Ge`09e`030=OG00WG00<0emL04=L00`3G
e`0>e`030=OG013G00<0emL02ML00`3Ge`09e`030=OG00gG00<0emL06]L00`3Ge`0=e`030=OG00WG
00<0emL02=L1007G0007e`040=OG00CG00<0emL02=L00`3Ge`09e`030=OG00gG00<0emL06]L00`3G
e`0=e`030=OG00WG00<0emL02ML00`3Ge`0@e`030=OG00kG00<0emL04=L00`3Ge`09e`030=OG00WG
00<0emL03ML00`3Ge`0Je`030=OG00gG00<0emL02ML00`3Ge`08e`400ML000OG00@0emL01=L300SG
00<0emL02ML00`3Ge`0=e`030=OG01[G00<0emL03ML00`3Ge`09e`030=OG00WG00<0emL04=L00`3G
e`0>e`030=OG013G00<0emL02ML00`3Ge`09e`030=OG00gG00<0emL06]L00`3Ge`0=e`030=OG00WG
00<0emL01mL2007G0007e`040=OG00CG00<0emL02=L00`3Ge`09e`030=OG00gG00<0emL06]L00`3G
e`0=e`030=OG00WG00<0emL02ML00`3Ge`0@e`030=OG00kG00<0emL04=L00`3Ge`09e`030=OG00WG
00<0emL03ML00`3Ge`0Je`030=OG00gG00<0emL02ML00`3Ge`08e`400ML000OG00@0emL01=L00`3G
e`08e`030=OG00WG00<0emL03ML00`3Ge`0Je`030=OG00gG00<0emL02ML00`3Ge`09e`030=OG013G
00<0emL03]L00`3Ge`0@e`030=OG00WG00<0emL02ML00`3Ge`0=e`030=OG01[G00<0emL03ML00`3G
e`09e`030=OG00SG0@01e`001mL0103Ge`04e`030=OG00SG00<0emL02ML00`3Ge`0=e`030=OG01[G
00<0emL03ML00`3Ge`09e`030=OG00WG00<0emL04=L00`3Ge`0=e`030=OG017G00<0emL02ML00`3G
e`09e`030=OG00gG00<0emL06]L00`3Ge`0=e`030=OG00WG00<0emL02=L1007G0008e`801ML00`3G
e`08e`030=OG00WG00<0emL03ML00`3Ge`0Je`030=OG00gG00<0emL02ML00`3Ge`0:e`030=OG013G
00<0emL03=L00`3Ge`0Ae`030=OG00WG00<0emL02ML00`3Ge`0=e`030=OG01[G00<0emL03ML00`3G
e`09e`030=OG00SG0@01e`003mL00`3Ge`08e`030=OG00WG00<0emL03ML00`3Ge`0Je`030=OG00gG
00<0emL02ML00`3Ge`0:e`030=OG013G00<0emL03=L00`3Ge`0Ae`030=OG00WG00<0emL02ML00`3G
e`0=e`030=OG01[G00<0emL03ML00`3Ge`09e`030=OG00SG0@01e`003mL00`3Ge`08e`030=OG00WG
00<0emL03=L00`3Ge`0Le`030=OG00cG00<0emL02ML00`3Ge`0:e`030=OG017G00<0emL02]L00`3G
e`0Ae`030=OG00[G00<0emL02ML00`3Ge`0<e`030=OG01cG00<0emL03=L00`3Ge`09e`030=OG00SG
0@01e`003mL00`3Ge`08e`030=OG00WG00<0emL03=L00`3Ge`0Le`030=OG00cG00<0emL02ML00`3G
e`0:e`030=OG017G00<0emL02]L00`3Ge`0Ae`030=OG00[G00<0emL02ML00`3Ge`0<e`030=OG01cG
00<0emL03=L00`3Ge`09e`030=OG00SG0@01e`003mL00`3Ge`07e`030=OG00WG00<0emL03=L00`3G
e`0Me`030=OG00cG00<0emL02ML00`3Ge`0:e`030=OG01;G0P09e`030=OG01;G00<0emL02ML00`3G
e`09e`030=OG00cG00<0emL07ML00`3Ge`0<e`030=OG00WG00<0emL02=L1007G000?e`030=OG00OG
00<0emL02ML00`3Ge`0<e`030=OG01kG00<0emL03=L00`3Ge`09e`030=OG00[G00<0emL04mL00`3G
e`04e`805ML00`3Ge`09e`030=OG00WG00<0emL03=L00`3Ge`0Ne`030=OG00cG00<0emL02ML00`3G
e`07e`400ML000oG00<0emL01mL00`3Ge`09e`030=OG00cG00<0emL07]L00`3Ge`0<e`030=OG00WG
00<0emL02]L00`3Ge`0De`H05mL00`3Ge`09e`030=OG00WG00<0emL03=L00`3Ge`0Ne`030=OG00cG
00<0emL02ML00`3Ge`07e`400ML000oG00<0emL01mL00`3Ge`09e`030=OG00cG00<0emL07mL00`3G
e`0<e`030=OG00SG00<0emL02]L00`3Ge`0`e`030=OG00[G00<0emL02ML00`3Ge`0;e`030=OG023G
00<0emL03=L00`3Ge`09e`030=OG00KG0@01e`003mL00`3Ge`07e`030=OG00WG00<0emL02mL00`3G
e`0Pe`030=OG00cG00<0emL02ML00`3Ge`09e`030=OG033G00<0emL02]L00`3Ge`09e`030=OG00_G
00<0emL08=L00`3Ge`0<e`030=OG00WG00<0emL01]L1007G000?e`030=OG00OG00<0emL02=L00`3G
e`0<e`030=OG023G00<0emL03=L00`3Ge`09e`030=OG00[G00<0emL0;mL00`3Ge`0:e`030=OG00WG
00<0emL02mL00`3Ge`0Pe`030=OG00cG00<0emL02ML00`3Ge`06e`400ML000oG00<0emL01]L00`3G
e`09e`030=OG00_G00<0emL08]L00`3Ge`0<e`030=OG00WG00<0emL02ML00`3Ge`0^e`030=OG00[G
00<0emL02ML00`3Ge`0;e`030=OG02;G00<0emL02mL00`3Ge`0:e`030=OG00GG0@01e`003mL00`3G
e`06e`030=OG00WG00<0emL02mL00`3Ge`0Re`030=OG00cG00<0emL02ML00`3Ge`09e`030=OG02kG
00<0emL02]L00`3Ge`08e`803ML00`3Ge`0Re`030=OG00cG00<0emL02ML00`3Ge`05e`400ML000oG
00<0emL01ML00`3Ge`09e`030=OG00_G00<0emL09=L00`3Ge`0;e`030=OG00WG00<0emL02]L00`3G
e`0/e`030=OG00[G00<0emL02ML00`3Ge`0;e`030=OG02CG00<0emL02mL00`3Ge`09e`030=OG00GG
0@01e`003mL200KG00<0emL02ML00`3Ge`0:e`030=OG02KG00<0emL02mL00`3Ge`09e`030=OG00[G
00<0emL0:mL00`3Ge`0:e`030=OG00WG00<0emL02]L202OG00<0emL02mL00`3Ge`09e`030=OG00?G
0P01e`003mL00`3Ge`04e`030=OG00WG00<0emL02mL00`3Ge`0We`030=OG00[G00<0emL02ML00`3G
e`0:e`030=OG02[G00<0emL02]L00`3Ge`09e`030=OG00_G00<0emL09mL00`3Ge`0:e`030=OG00WG
00<0emL01=L1007G000?e`030=OG00CG00<0emL02ML00`3Ge`0:e`030=OG02SG00<0emL02mL00`3G
e`08e`030=OG00[G00<0emL0:ML00`3Ge`0:e`030=OG00[G00<0emL02]L00`3Ge`0Xe`030=OG00_G
00<0emL02ML00`3Ge`03e`400ML000oG00<0emL00mL00`3Ge`09e`030=OG00[G0P0[e`030=OG00[G
00<0emL02ML00`3Ge`0:e`030=OG02SG00<0emL02]L00`3Ge`09e`030=OG00_G00<0emL0:ML00`3G
e`0:e`030=OG00WG00<0emL00mL1007G000?e`030=OG00?G00<0emL02ML00`3Ge`0:e`030=OG02[G
00<0emL02]L00`3Ge`09e`030=OG00_G00<0emL09]L00`3Ge`0;e`030=OG00WG00<0emL02]L00`3G
e`0Ze`030=OG00[G00<0emL02ML00`3Ge`03e`400ML000oG00<0emL00]L00`3Ge`09e`030=OG00[G
00<0emL0:mL00`3Ge`0:e`030=OG00[G00<0emL02mL00`3Ge`0Te`030=OG00_G00<0emL02ML00`3G
e`0:e`030=OG02cG00<0emL02]L00`3Ge`09e`030=OG00;G0@01e`003mL00`3Ge`02e`030=OG00WG
00<0emL02]L00`3Ge`0/e`030=OG00[G00<0emL02ML200cG00<0emL09=L00`3Ge`0;e`030=OG00WG
00<0emL02]L00`3Ge`0/e`030=OG00[G00<0emL02ML00`3Ge`02e`400ML000oG00<0emL03ML00`3G
e`0:e`030=OG02kG00<0emL02]L00`3Ge`09e`030=OG00_G00<0emL08]L00`3Ge`0;e`030=OG00WG
00<0emL02]L00`3Ge`0^e`030=OG00[G00<0emL03ML1007G000?e`030=OG00cG0P0;e`030=OG033G
00<0emL02]L00`3Ge`09e`030=OG00_G0P0Qe`030=OG00_G00<0emL02ML00`3Ge`0:e`030=OG033G
00<0emL02]L00`3Ge`0<e`400ML000oG00<0emL03=L00`3Ge`09e`030=OG01?G2P0Ee`030=OG00WG
00<0emL02ML00`3Ge`0=e`030=OG01cG0P0=e`030=OG00[G00<0emL02ML00`3Ge`0Ce`X05ML00`3G
e`0:e`030=OG00_G0@01e`003mL00`3Ge`0;e`030=OG00[G00<0emL04ML200[G0`0Be`030=OG00[G
00<0emL02ML00`3Ge`0=e`030=OG01[G00<0emL03ML00`3Ge`09e`030=OG00[G00<0emL04ML200[G
0`0Be`030=OG00[G00<0emL02mL1007G000?e`030=OG00_G00<0emL02ML00`3Ge`0?e`<03mL2017G
0P0;e`030=OG00WG00<0emL03ML00`3Ge`0Ie`030=OG00gG00<0emL02ML00`3Ge`09e`030=OG00oG
0`0?e`804ML00`3Ge`0:e`030=OG00[G0@01e`003mL00`3Ge`0:e`030=OG00WG00<0emL03]L201CG
0P0@e`030=OG00WG00<0emL02]L00`3Ge`0=e`805mL200oG00<0emL02ML00`3Ge`09e`030=OG00oG
00<0emL04]L2013G00<0emL02ML00`3Ge`0:e`400ML000oG00<0emL02ML00`3Ge`0:e`030=OG00gG
00<0emL05]L00`3Ge`0>e`030=OG00WG00<0emL02ML00`3Ge`0?e`030=OG01;G0P0Ae`030=OG00WG
00<0emL02ML00`3Ge`0>e`030=OG01GG00<0emL03ML00`3Ge`09e`030=OG00[G0@01e`003mL00`3G
e`09e`030=OG00WG00<0emL03=L201[G0P0>e`030=OG00WG00<0emL02]L00`3Ge`0?e`804=L2017G
0P0;e`030=OG00WG00<0emL03=L301WG0P0>e`802]L00`3Ge`09e`400ML000oG00<0emL01mL200_G
00<0emL03=L00`3Ge`0Le`803ML00`3Ge`09e`030=OG00[G00<0emL04=L500KG1@0Be`030=OG00[G
00<0emL02ML00`3Ge`0;e`807]L200kG00<0emL02=L200WG0@01e`003mL200SG00<0emL02ML00`3G
e`0;e`808ML00`3Ge`0;e`802]L200_G00<0emL05=L601KG00<0emL02]L00`3Ge`09e`030=OG00_G
00<0emL08=L00`3Ge`0<e`030=OG00WG00<0emL01ML2007G000?e`030=OG00KG00<0emL02ML00`3G
e`0;e`030=OG02;G0P0<e`030=OG00[G00<0emL02ML00`3Ge`0_e`030=OG00WG00<0emL02ML00`3G
e`0;e`030=OG02;G00<0emL02mL00`3Ge`0:e`030=OG00GG0@01e`003mL00`3Ge`06e`030=OG00SG
00<0emL02mL00`3Ge`0Ue`030=OG00[G00<0emL02ML00`3Ge`0:e`030=OG02cG0P0<e`030=OG00SG
00<0emL02mL00`3Ge`0Te`030=OG00_G00<0emL02ML00`3Ge`05e`400ML000oG00<0emL01ML00`3G
e`08e`030=OG00_G00<0emL09]L00`3Ge`0;e`030=OG00WG00<0emL02]L00`3Ge`0Ze`030=OG00[G
0P0:e`030=OG00_G00<0emL09]L00`3Ge`0;e`030=OG00WG00<0emL01=L1007G000?e`030=OG00?G
0P0:e`030=OG00[G0P0Ze`030=OG00[G00<0emL02]L00`3Ge`0:e`80:=L200cG00<0emL02ML00`3G
e`0;e`030=OG02SG0P0<e`030=OG00WG00<0emL00mL1007G000?e`030=OG00;G00<0emL02ML00`3G
e`0:e`030=OG02_G0P0;e`802mL00`3Ge`0;e`030=OG02CG00<0emL02mL00`3Ge`09e`802mL202gG
00<0emL02]L00`3Ge`09e`030=OG00;G0@01e`003mL00`3Ge`0=e`030=OG00[G00<0emL0;]L00`3G
e`0:e`030=OG00WG00<0emL02mL00`3Ge`0Re`030=OG00cG00<0emL02=L00`3Ge`0:e`030=OG02kG
00<0emL02]L00`3Ge`0=e`400ML000oG00<0emL03ML00`3Ge`09e`030=OG01;G200Fe`030=OG00[G
00<0emL02ML00`3Ge`0;e`030=OG023G00<0emL02mL200[G00<0emL02]L00`3Ge`0De`P05=L200_G
00<0emL03=L1007G000?e`030=OG00_G0P0;e`030=OG017G0P08e`D04]L00`3Ge`0:e`030=OG00WG
00<0emL02mL301cG0`0=e`030=OG00WG00<0emL02]L00`3Ge`0@e`D02=L301?G00<0emL02ML00`3G
e`0;e`400ML000oG00<0emL02]L00`3Ge`0:e`030=OG00oG0`0?e`<04=L200_G00<0emL02ML00`3G
e`0=e`806ML00`3Ge`0=e`030=OG00WG00<0emL02]L00`3Ge`0?e`804=L2017G00<0emL02]L00`3G
e`0:e`400ML000oG00<0emL02ML00`3Ge`0:e`030=OG00kG0P0Ee`804=L00`3Ge`09e`030=OG00WG
0P0?e`030=OG01CG0P0?e`030=OG00[G00<0emL02ML00`3Ge`0>e`805=L300oG0P0;e`030=OG00WG
0@01e`003mL00`3Ge`09e`030=OG00WG00<0emL03=L301WG0P0?e`030=OG00WG00<0emL02ML00`3G
e`0>e`H02mL5013G00<0emL02]L00`3Ge`08e`803]L301WG0`0>e`030=OG00WG00<0emL02=L1007G
000?e`030=OG00OG0P0:e`803ML201kG0P0>e`802]L00`3Ge`09e`805=L;01CG00<0emL02ML200[G
00<0emL03=L201oG0P0=e`030=OG00WG00<0emL01mL1007G000?e`030=OG00KG00<0emL02ML00`3G
e`0;e`808]L200kG00<0emL02=L200_G00<0emL0;]L200_G00<0emL02=L200gG0P0Se`803=L200[G
0P07e`400ML000oG00<0emL01ML00`3Ge`08e`803=L202KG0P0=e`030=OG00SG00<0emL02]L00`3G
e`0/e`030=OG00[G00<0emL02=L00`3Ge`0<e`030=OG02CG0P0=e`030=OG00WG00<0emL01=L1007G
000?e`030=OG00CG00<0emL02=L00`3Ge`0:e`80:]L00`3Ge`0:e`030=OG00WG00<0emL02]L202_G
00<0emL02]L00`3Ge`09e`030=OG00[G0P0Ye`803=L00`3Ge`09e`030=OG00?G0@01e`003mL200?G
0P0:e`030=OG00_G00<0emL0:]L200_G0P0:e`803=L202KG0`0<e`030=OG00SG0P0;e`80;ML00`3G
e`0:e`030=OG00WG00@0emOG0P01e`003mL00`3Ge`0=e`030=OG00[G0P0_e`802mL00`3Ge`09e`03
0=OG00_G00<0emL08]L00`3Ge`0<e`030=OG00SG00<0emL02ML2033G00<0emL02]L200kG0@01e`00
3mL00`3Ge`0<e`030=OG00[G00<0emL04=L>01?G00<0emL02ML00`3Ge`09e`030=OG00_G0P0Qe`03
0=OG00_G0P0:e`030=OG00WG00<0emL04ML>01;G0P0;e`030=OG00cG0@01e`003mL00`3Ge`0:e`80
2mL2013G0`0>e`@04=L200[G00<0emL02ML00`3Ge`0<e`<06mL300gG00<0emL02ML00`3Ge`09e`80
4=L300kG0`0Ae`030=OG00WG0P0<e`400ML000oG00<0emL02ML00`3Ge`0:e`030=OG00gG0`0Ee`80
4=L00`3Ge`08e`802]L200oG0P0Fe`<03]L200_G00<0emL02=L200oG0`0De`<03mL200_G0P0:e`40
0ML000oG00<0emL02=L00`3Ge`09e`803ML301[G0`0>e`802]L200[G0P0?e`H02mL500oG0P0;e`80
2]L00`3Ge`0<e`<06]L300kG0P0;e`030=OG00OG0@01e`003mL00`3Ge`07e`030=OG00WG00<0emL0
2mL2023G0`0=e`030=OG00SG00<0emL02]L201?G2`0Ce`030=OG00[G00<0emL02=L200gG0P0Pe`80
3ML00`3Ge`09e`802=L1007G000?e`030=OG00GG0P0;e`030=OG00[G0P0Ue`803=L00`3Ge`08e`80
3=L00`3Ge`0/e`802mL200[G00<0emL02mL202CG0P0<e`030=OG00[G0P06e`400ML000oG00<0emL0
1=L00`3Ge`08e`<02]L302WG00<0emL02]L00`3Ge`09e`030=OG00[G0P0Ze`803=L00`3Ge`09e`03
0=OG00_G00<0emL09]L300[G0`0:e`030=OG00CG0@01e`003mL00`3Ge`02e`802]L00`3Ge`0:e`03
0=OG02_G0P0;e`030=OG00WG0P0<e`809]L200gG00<0emL02ML00`3Ge`09e`<0;=L00`3Ge`0:e`80
2ML200CG0@01e`003mL00`3Ge`0=e`030=OG00[G00<0emL05ML00`3Ge`0Fe`802]L200_G00<0emL0
2mL202;G0P0>e`030=OG00OG0`0:e`806=L201KG00<0emL02mL00`3Ge`0<e`400ML000oG00<0emL0
3=L00`3Ge`08e`<04]L60003e`0000H04]L00`3Ge`09e`802]L200gG100Ke`<03ML300[G00<0emL0
2]L00`3Ge`0?e`P00]L6017G0`0:e`030=OG00cG0@01e`003mL00`3Ge`0:e`802]L00`3Ge`0=e`H0
3mL500kG0P0;e`802]L200oG0P0Fe`<03]L200_G0P0:e`<03ML5013G1@0?e`802ML200cG0@01e`00
3mL00`3Ge`08e`802]L200kG0P0Je`<03ML200_G00<0emL02ML200oG1P0;e`D04=L00`3Ge`09e`80
2]L200gG0`0Je`<03]L00`3Ge`08e`802]L1007G0007e`@01=L00`3Ge`07e`030=OG00WG00<0emL0
2mL301oG0`0<e`802]L00`3Ge`0:e`804mL;01?G0P0;e`030=OG00SG0P0=e`808=L200gG00<0emL0
2ML200SG0@01e`001mL00`3Ge`05e`030=OG00GG0P0;e`030=OG00[G0P0Ue`803=L00`3Ge`08e`80
3=L00`3Ge`0/e`802mL200[G00<0emL02mL202CG0P0<e`030=OG00[G0P06e`400ML000SG00<0emL0
1=L300CG00<0emL02=L300[G0`0Ye`030=OG00[G00<0emL02ML200_G0P0Ze`803=L00`3Ge`09e`03
0=OG00_G00<0emL09]L300[G0`0:e`030=OG00?G0P01e`002ML00`3Ge`03e`030=OG00;G0P0:e`03
0=OG00[G00<0emL0:mL200_G0P0;e`802mL202KG0P0<e`802]L200_G0`0/e`030=OG00[G0P09e`80
1=L1007G000:e`030=OG00;G00<0emL03=L200[G0`0Be``04]L300[G0`0:e`802mL401kG100<e`80
2]L200[G0`0Be``04]L300_G0P0=e`400ML000OG00@0emL01=L00`3Ge`0:e`802mL00`3Ge`0?e`@0
3=L5013G0P0;e`030=OG00SG0P0>e`806mL00`3Ge`0<e`802mL00`3Ge`09e`030=OG00oG100<e`@0
4ML200_G00<0emL02]L1007G0008e`801ML00`3Ge`08e`802mL200gG1@0Ee`804=L00`3Ge`09e`03
0=OG00WG0P0>e`D04=L600gG0P0;e`802]L200oG0`0De`D03]L200[G0P0:e`400ML000oG00<0emL0
1mL00`3Ge`09e`803=L301cG1P0;e`802]L200_G0P0Aea004]L00`3Ge`09e`802]L200cG1@0Le`<0
3ML00`3Ge`09e`802=L1007G000?e`030=OG00GG0P0:e`802mL302GG0P0;e`802]L200_G00<0emL0
;]L200[G0P0:e`802mL302CG0`0;e`802mL200KG0@01e`003mL00`3Ge`04e`030=OG00SG0P0;e`80
:]L200_G0P0:e`030=OG00WG0`0[e`802mL00`3Ge`08e`802mL202[G0P0;e`802mL00`3Ge`03e`40
0ML000oG00<0emL00]L200[G00<0emL02ML202kG00<0emL02]L00`3Ge`08e`<02mL202KG0`0;e`80
2]L00`3Ge`0:e`030=OG02cG0P0;e`030=OG00WG00<0emL00]L1007G000?e`030=OG00cG0P0:e`80
4]L?013G0`0:e`<02]L00`3Ge`0:e`<08=L300cG0P0:e`802mL2013G400Ae`802]L200kG0@01e`00
3mL00`3Ge`0:e`802]L200kG1P0?e`D03]L300[G0P09e`<03=L501KG1@0<e`<02]L200[G0`0=e`D0
4=L500kG0`09e`<02mL1007G000?e`030=OG00SG0P0:e`803]L201[G0`0>e`030=OG00WG00<0emL0
2ML200oG1P0;e`D04=L00`3Ge`09e`802]L200gG0`0Je`<03]L00`3Ge`09e`030=OG00SG0@01e`00
3mL00`3Ge`07e`030=OG00SG0P0=e`<07mL300cG0P0:e`802mL201?G2`0Be`<02mL00`3Ge`08e`80
3ML2023G0P0=e`802]L200SG0@01e`003mL00`3Ge`04e`<02ML200cG0`0Ue`803=L200[G0`0:e`<0
:]L300_G0`09e`803=L302CG0`0<e`802]L200KG0@01e`003mL00`3Ge`02e`802mL00`3Ge`0:e`80
:]L300_G0P0;e`802mL202KG0P0<e`802]L200_G0`0Ze`803=L200[G0P04e`400ML000oG00<0emL0
3ML200_G0P0Be`X04mL200_G0P0;e`030=OG00[G0`0Qe`803=L200[G0P0;e`804mL:01;G0`0;e`80
3]L1007G000?e`030=OG00[G0`0:e`<03=L800[G1P0?e`<02]L00`3Ge`09e`803ML501KG1P0<e`80
2mL00`3Ge`08e`<04=L500[G200=e`<02]L200cG0@01e`003mL200WG0P0:e`<03ML201SG1@0=e`80
2ML200_G0`0?e`H02mL5013G0P0;e`802ML200gG1P0Ge`<03ML200[G0P09e`800ML000oG00<0emL0
1]L200WG0`0<e`@07mL300cG0`08e`<02mL201?G2`0Be`<02]L300SG0`0<e`<08=L300cG0`09e`80
2=L1007G000?e`030=OG00CG0P09e`803ML202KG0P0=e`030=OG00SG0`0:e`<0:]L300_G0P0:e`03
0=OG00_G0P0Ve`803ML200WG0P06e`400ML000oG00<0emL00]L200[G00<0emL02mL202[G0`0;e`80
2mL200_G0P0Ve`803=L200[G0P0;e`<0:]L200gG0P09e`801=L1007G000?e`030=OG00cG0P0;e`<0
4=L?013G0`0:e`<02]L200_G0`0Pe`<02mL300[G0P0;e`804=L@00oG0`0<e`030=OG00cG0@01e`00
3mL00`3Ge`09e`<02mL200gG1P0?e`D03]L200_G0P0:e`803=L501KG1@0<e`802]L300[G0`0=e`D0
4=L500gG0`0:e`<02mL1007G000?e`030=OG00OG0P0<e`802mL401[G0`000mL0e`0:e`802mL200[G
00<0emL03]LF013G00<0emL02=L200_G0P0;e`030=L000806]L500_G0P0;e`802ML1007G000?e`03
0=OG00GG0`09e`@02ML4027G1@0:e`<02]L00`3Ge`08e`<0<=L300[G0P09e`<02]L5027G100:e`<0
2]L300KG0@01e`003mL00`3Ge`03e`802]L200_G0P0Ze`<02]L300SG0`0:e`D09]L500_G0P09e`80
2]L302[G0P0;e`<02]L00`3Ge`03e`400ML000oG00<0emL00]L00`3Ge`07e`<02]L301;G2P0Ce`<0
2]L200WG0`0<e`<08=L300gG0`08e`<02]L201?G2P0Be`<02mL200WG00<0emL00]L1007G000?e`03
0=OG00WG0`0;e`803ML800[G1P0@e`802]L200[G0P0=e`D05]L500gG0`0:e`030=OG00SG0`0@e`D0
2]L800gG0`0:e`<02mL1007G000?e`030=OG00OG0P0<e`803ML201SG1@0=e`802]L00`3Ge`09e`80
4=L600_G1@0@e`802mL200WG0P0=e`H05mL300gG0P0;e`802ML1007G000?e`030=OG00OG00<0emL0
1mL400WG1P0Oe`<03=L300SG0`0:e`<04mL;01;G0`0:e`<02=L300gG0P0Pe`D02]L300[G00<0emL0
1]L1007G000?e`030=OG00CG0`08e`802mL202SG1@0:e`<02=L300[G0`0Ze`<02mL200SG0`0:e`H0
9mL200_G0`08e`801]L1007G000?e`030=OG00;G0P08e`<02]L302oG0`0:e`802ML300[G1@0Pe`D0
2]L400SG0P0;e`80;mL300_G0P08e`801=L1007G000?e`030=OG00WG0`0;e`80=ML200[G0P0:e`80
3ML301_G0P0=e`802mL00`3Ge`08e`<0==L300[G0`0;e`400ML000oG0P08e`802mL303WG0P0:e`03
0=OG00WG0`0=e`P02mL800gG0P0;e`802ML203[G0P0;e`802=L2007G000?e`030=OG00KG00<0emL0
2=L303kG0`08e`<02mL201?G2`0Be`<02]L300SG0`0ne`<02]L00`3Ge`06e`400ML000oG00<0emL0
1=L200WG0P14e`<02=L300[G0`0Ze`<02mL200SG0`14e`<02=L200KG0@01e`003mL00`3Ge`02e`80
2ML204WG0P09e`802mL5027G100;e`<02=L204[G0P08e`801=L1007G000?e`030=OG00WG101=e`<0
2=L300gG1@0Fe`H03=L300SG0`1>e`<02mL1007G000?e`030=OG00OG0P1De`<02=L300oG5P0@e`80
2ML205CG0`08e`400ML000oG00<0emL01=L305WG0`08e`D0:]L600SG0`1Ie`801]L1007G000?e`03
0=OG00;G0P1Oe`802mL202KG0P0;e`<0G]L200CG0@01e`003mL00`3Ge`1Ue`802mL601_G1@0;e`80
ImL1007G000?e`030=OG06OG100=e`D04=L600gG0`1Ye`400ML000oG00<0emL0JmL2013G400@e`<0
K=L1007G000?e`030=OG06gG0`0[e`80KmL1007G000?e`030=OG073G1@0Pe`H0LML1007G000?e`03
0=OG07GG1@0Fe`D0MmL1007G000?e`030=OG07[G5P1le`400ML000oG00<0emL0omL=e`400ML000oG
0P3oe`gG0P01e`003mL00`3Ge`3oe`gG0@01e`003mL00`3Ge`3oe`gG0@01e`003mL00`3Ge`3oe`gG
0@01e`003mL00`3Ge`3oe`gG0@01e`003mL00`3Ge`3oe`gG0@01e`003mL00`3Ge`3oe`gG0@01e`00
3mL00`3Ge`3oe`gG0@01e`003mL00`3Ge`3oe`gG0@01e`003mL00`3Ge`3oe`gG0@01e`003mL00`3G
e`3oe`gG0@01e`003mL00`3Ge`3oe`gG0@01e`003mL00`3Ge`3oe`gG0@01e`003mL00`3Ge`3oe`gG
0@01e`003mL00`3Ge`3oe`gG0@01e`002ML00`3Ge`03e`030=OG0?oG3ML1007G0009e`030=OG00?G
00<0emL0omL=e`400ML000KG1@04e`<0omL<e`800ML000KG00@0emL01ML00`3Ge`3oe`gG0@01e`00
1mL00`3G0005e`030=OG0?oG3ML1007G0008e`801ML00`3Ge`0Le`030=OG037G00<0emL0<]L00`3G
e`0ae`030=OG037G00<0emL07=L1007G0009e`030=OG00?G00<0emL00]L00`3Ge`0:e`030=OG00[G
00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00_G00<0emL02]L00`3G
e`0:e`030=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00[G
00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL00]L1007G000?eol04@01e`00omLQe`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.78976, -4.58776, 0.0383087, \
0.030647}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  ContourGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{1030, 538},
WindowMargins->{{Automatic, 22}, {Automatic, 127}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 264, 5, 55, "Input"],
Cell[1994, 59, 32, 0, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2063, 64, 67, 1, 32, "Input"],
Cell[2133, 67, 62, 1, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2232, 73, 213, 4, 55, "Input"],
Cell[2448, 79, 90441, 4147, 296, 57331, 3734, "GraphicsData", "PostScript", \
"Graphics"],
Cell[92892, 4228, 137, 3, 31, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

