(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    262746,       7193]*)
(*NotebookOutlinePosition[    263377,       7215]*)
(*  CellTagsIndexPosition[    263333,       7211]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
(* c44: Program Homcircplate: Clamped circular plate in 
Cartesian coordinates, no load. Eigenvalue problem
of the homogeneous equation with two homogeneous
boundary conditions.Check the solution of the plate equation *)
Clear[u,m,x,y,A,B,b,n] 
 
u[x,y]=A[n]*Cos[Sqrt[k^2-b[n]^2]*x]*Cos[b[n]*y]+
B[n]*Cosh[b[n]*y]*Cosh[Sqrt[k^2-b[n]^2]*x];
Simplify[D[u[x,y],{x,4}]+2*D[u[x,y],{x,2},{y,2}]+
D[u[x,y],{y,4}]-k^4*u[x,y]] 

(* Later on we need : *)
ux=InputForm[D[u[x,y],x]]\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(0\)], "Output"],

Cell["\<\
-(A[n]*Sqrt[k^2 - b[n]^2]*Cos[y*b[n]]*Sin[x*Sqrt[k^2 - b[n]^2]]) + 
 Sqrt[k^2 - b[n]^2]*B[n]*Cosh[y*b[n]]*Sinh[x*Sqrt[k^2 - b[n]^2]]\
\>", \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["uy=InputForm[D[u[x,y],y]]", "Input"],

Cell["\<\
-(A[n]*b[n]*Cos[x*Sqrt[k^2 - b[n]^2]]*Sin[y*b[n]]) + 
 b[n]*B[n]*Cosh[x*Sqrt[k^2 - b[n]^2]]*Sinh[y*b[n]]\
\>", "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(* START HERE: Step 1: Define the radius R of the circular plate \
and nn collocation points, x,y *)
Clear[x,y,k,R,nn];
nn=14; dth=N[Pi/(2*nn),6];R=1.;
Table[x[l]=R*Cos[l*dth],{l,1,nn,2}];
Table[y[l]=Sqrt[R-x[l]^2],{l,1,nn,2}];
Table[x[l]=R*Cos[l*dth-0.001],{l,2,nn,2}];
Table[y[l]=Sqrt[R-x[l]^2],{l,2,nn,2}];
TA=Table[{x[l],y[l]},{l,1,nn}]
pl1=ListPlot[TA, AspectRatio->1,Prolog->AbsolutePointSize[7]]\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0.9937122098932426`, 0.11196447610330758`}, {0.9751499456147776`, 
        0.22154589494616272`}, {0.9438833303083676`, 
        0.330279061955167`}, {0.9014023010848263`, 
        0.43298255345796566`}, {0.8467241992282841`, 
        0.5320320765153366`}, {0.7824545812502649`, 
        0.6227076587616959`}, {0.7071067811865476`, 
        0.7071067811865475`}, {0.6242713214660214`, 
        0.7812076018543773`}, {0.5320320765153366`, 
        0.8467241992282841`}, {0.4347844908934475`, 
        0.9005345337512192`}, {0.33027906195516715`, 
        0.9438833303083676`}, {0.22349575044555048`, 
        0.9747049038210387`}, {0.11196447610330791`, 
        0.9937122098932426`}, {0.0009999998333332927`, 
        0.9999995000000417`}}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.958407 0.0238095 0.952381 [
[.21549 .01131 -9 -9 ]
[.21549 .01131 9 0 ]
[.40717 .01131 -9 -9 ]
[.40717 .01131 9 0 ]
[.59885 .01131 -9 -9 ]
[.59885 .01131 9 0 ]
[.79054 .01131 -9 -9 ]
[.79054 .01131 9 0 ]
[.98222 .01131 -3 -9 ]
[.98222 .01131 3 0 ]
[.01131 .21429 -18 -4.5 ]
[.01131 .21429 0 4.5 ]
[.01131 .40476 -18 -4.5 ]
[.01131 .40476 0 4.5 ]
[.01131 .59524 -18 -4.5 ]
[.01131 .59524 0 4.5 ]
[.01131 .78571 -18 -4.5 ]
[.01131 .78571 0 4.5 ]
[.01131 .97619 -6 -4.5 ]
[.01131 .97619 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21549 .02381 m
.21549 .03006 L
s
[(0.2)] .21549 .01131 0 1 Mshowa
.40717 .02381 m
.40717 .03006 L
s
[(0.4)] .40717 .01131 0 1 Mshowa
.59885 .02381 m
.59885 .03006 L
s
[(0.6)] .59885 .01131 0 1 Mshowa
.79054 .02381 m
.79054 .03006 L
s
[(0.8)] .79054 .01131 0 1 Mshowa
.98222 .02381 m
.98222 .03006 L
s
[(1)] .98222 .01131 0 1 Mshowa
.125 Mabswid
.07173 .02381 m
.07173 .02756 L
s
.11965 .02381 m
.11965 .02756 L
s
.16757 .02381 m
.16757 .02756 L
s
.26341 .02381 m
.26341 .02756 L
s
.31133 .02381 m
.31133 .02756 L
s
.35925 .02381 m
.35925 .02756 L
s
.45509 .02381 m
.45509 .02756 L
s
.50301 .02381 m
.50301 .02756 L
s
.55093 .02381 m
.55093 .02756 L
s
.64677 .02381 m
.64677 .02756 L
s
.69469 .02381 m
.69469 .02756 L
s
.74261 .02381 m
.74261 .02756 L
s
.83846 .02381 m
.83846 .02756 L
s
.88638 .02381 m
.88638 .02756 L
s
.9343 .02381 m
.9343 .02756 L
s
.25 Mabswid
0 .02381 m
1 .02381 L
s
.02381 .21429 m
.03006 .21429 L
s
[(0.2)] .01131 .21429 1 0 Mshowa
.02381 .40476 m
.03006 .40476 L
s
[(0.4)] .01131 .40476 1 0 Mshowa
.02381 .59524 m
.03006 .59524 L
s
[(0.6)] .01131 .59524 1 0 Mshowa
.02381 .78571 m
.03006 .78571 L
s
[(0.8)] .01131 .78571 1 0 Mshowa
.02381 .97619 m
.03006 .97619 L
s
[(1)] .01131 .97619 1 0 Mshowa
.125 Mabswid
.02381 .07143 m
.02756 .07143 L
s
.02381 .11905 m
.02756 .11905 L
s
.02381 .16667 m
.02756 .16667 L
s
.02381 .2619 m
.02756 .2619 L
s
.02381 .30952 m
.02756 .30952 L
s
.02381 .35714 m
.02756 .35714 L
s
.02381 .45238 m
.02756 .45238 L
s
.02381 .5 m
.02756 .5 L
s
.02381 .54762 m
.02756 .54762 L
s
.02381 .64286 m
.02756 .64286 L
s
.02381 .69048 m
.02756 .69048 L
s
.02381 .7381 m
.02756 .7381 L
s
.02381 .83333 m
.02756 .83333 L
s
.02381 .88095 m
.02756 .88095 L
s
.02381 .92857 m
.02756 .92857 L
s
.25 Mabswid
.02381 0 m
.02381 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
7 Mabswid
.97619 .13044 Mdot
.9584 .23481 Mdot
.92843 .33836 Mdot
.88772 .43617 Mdot
.83532 .53051 Mdot
.77372 .61686 Mdot
.70151 .69724 Mdot
.62212 .76782 Mdot
.53371 .83021 Mdot
.44051 .88146 Mdot
.34035 .92275 Mdot
.23801 .9521 Mdot
.13112 .9702 Mdot
.02477 .97619 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML00?oG8ML00?oG8ML00?oG8ML00?oG
8ML00?oG8ML00?oG8ML004;G0P04e`030=OG00;G100Ue`801=L00`3Ge`04e`030=OG02CG0P04e`03
0=OG00?G0P0We`801=L00`3Ge`03e`80:mL400CG0011e`040=OG00SG00<0emL09ML0103Ge`0:e`03
0=OG02?G00@0emL02=L0103Ge`0Ue`040=OG00SG00@0emL0;=L00`3Ge`03e`00@ML0103Ge`09e`03
0=OG02CG00@0emL01mL502CG00@0emL02=L0103Ge`0Ue`040=OG00SG00@0emL0;=L00`3Ge`03e`00
@ML0103Ge`0:e`030=OG02?G00@0emL01mL0103Ge`0Ue`040=OG00SG0`0Ve`040=OG00WG0P0]e`03
0=OG00?G000Ee`030=OG02WG00@0emL02mL00`3Ge`0Re`040=OG00SG00<0e`009ML0103Ge`08e`03
0=OG02KG00@0emL02=L0103Ge`0/e`030=OG00?G000Ee`030=OG02WG00@0emL02=L0103Ge`0Te`04
0=OG00WG0P0Ue`040=OG00SG00<0emL09]L0103Ge`08e`040=OG02[G0`05e`005ML00`3Ge`0Ze`80
2]L202KG0P0;e`030=OG02CG0P0:e`<09]L200[G0P0]e`030=OG00?G000Ee`030=OG0?oG2ML001GG
00<0emL0omL9e`005ML00`3Ge`3oe`WG000>eol04`0001GG00<0emL02]L00`3Ge`0:e`030=OG00[G
00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL02]L00`3G
e`0:e`030=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL02mL00`3Ge`0:e`030=OG00[G
00<0emL02]L00`3Ge`0:e`030=OG00?G000Ee`030=OG037G00<0emL0<ML00`3Ge`0ae`030=OG03;G
00<0emL0<ML00`3Ge`03e`005ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`00
5ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`03
0=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`80omL:e`005ML00`3Ge`3oe`WG
000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG
00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3G
e`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML20?oG0ML400GG000Ee`030=OG0?kG
1P04e`005ML00`3Ge`3ne`H01=L001GG00<0emL0o]L600CG000Ee`030=OG0?kG1P04e`005ML00`3G
e`3oe`@01ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0
omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML20?oG2]L001GG
00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3G
e`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0?oG
2ML001GG00<0emL0omL9e`000]L200CG00<0emL00]L400CG00<0emL0omL9e`0000GG0=OG0008e`03
0=OG00GG00<0emL0omL9e`0000GG0=OG0009e`030=OG00CG0`3oe`WG00001ML0emL000[G00<0emL0
0mL00`3Ge`3oe`WG00001ML0emL000_G00<0emL00]L00`3Ge`3oe`WG00001ML0emL000SG00@0emL0
1=L00`3Ge`3je`@02]L000;G0P0:e`801ML00`3Ge`3ie`H02ML001GG00<0emL0nML600WG000Ee`03
0=OG0?WG1P09e`005ML00`3Ge`3ie`H02ML001GG00<0emL0n]L400[G000Ee`030=OG0?oG2ML001GG
00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG0P3oe`[G000Ee`030=OG0?oG
2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`00
5ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`03
0=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`80omL:e`005ML00`3Ge`3oe`WG
000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0?;G100Be`00
5ML00`3Ge`3ae`H04ML001GG00<0emL0lML6017G000Ee`030=OG0?7G1P0Ae`005ML00`3Ge`3ae`H0
4ML001GG00<0emL0l]L401;G000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML20?oG2]L001GG
00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3G
e`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0?oG
2ML001GG00<0emL0omL9e`000]L200CG00<0emL01=L00`3Ge`03e`030=OG0?oG2ML00005e`3Ge`00
2]L00`3Ge`03e`030=OG0?oG2ML00005e`3Ge`001mL500CG0`3oe`WG00001ML0emL000OG00@0emL0
1ML00`3Ge`3oe`WG00001ML0emL000SG00<0e`001ML00`3Ge`3oe`WG00001ML0emL000WG0P05e`03
0=OG0?oG2ML000;G0P0;e`030=OG00?G00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0>OG
100Me`005ML00`3Ge`3Ve`H07=L001GG00<0emL0i]L601cG000Ee`030=OG0>KG1P0Le`005ML00`3G
e`3Ve`H07=L001GG00<0emL0imL401gG000Ee`030=OG0?oG2ML001GG0P3oe`[G000Ee`030=OG0?oG
2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`00
5ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`03
0=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`80omL:e`005ML00`3Ge`3oe`WG
000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0=WG100[e`00
5ML00`3Ge`3He`H0:]L001GG00<0emL0f=L602[G000Ee`030=OG0=SG1P0Ze`005ML00`3Ge`3He`H0
:]L001GG00<0emL0fML402_G000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML20?oG2]L001GG
00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3G
e`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0?oG
2ML001GG00<0emL0omL9e`000]L200CG00<0emL00mL200GG00<0emL0omL9e`0000GG0=OG0008e`04
0=OG00CG00<0emL0omL9e`0000GG0=OG0008e`040=OG00CG0`3oe`WG00001ML0emL000SG0`05e`03
0=OG0?oG2ML00005e`3Ge`002=L00`3Ge`05e`030=OG0?oG2ML00005e`3Ge`002=L00`3Ge`05e`03
0=OG0<SG100le`000]L200[G0`04e`030=OG0<OG1P0ke`005ML00`3Ge`37e`H0>mL001GG00<0emL0
amL603_G000Ee`030=OG0<OG1P0ke`005ML00`3Ge`38e`@0?=L001GG00<0emL0omL9e`005ML00`3G
e`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML20?oG2]L001GG00<0emL0omL9e`00
5ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`03
0=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0
omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0;CG101@e`005ML20;CG1P1?e`005ML00`3Ge`2ce`H0
CmL001GG00<0emL0/mL604oG000Ee`030=OG0;?G1P1?e`005ML00`3Ge`2de`@0D=L001GG00<0emL0
omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG
000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`80omL:e`005ML00`3G
e`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG09oG
101Ue`005ML00`3Ge`2Ne`H0I=L001GG00<0emL0W]L606CG000Ee`030=OG09kG1P1Te`005ML00`3G
e`2Ne`H0I=L001GG00<0emL0WmL406GG0002e`801=L00`3Ge`03e`801ML00`3Ge`3oe`WG00001ML0
emL000SG00@0emL01=L00`3Ge`3oe`WG00001ML0emL000SG00@0emL01=L30?oG2ML00005e`3Ge`00
2ML200GG00<0emL0omL9e`0000GG0=OG0008e`040=OG00CG00<0emL0omL9e`0000GG0=OG0008e`04
0=OG00CG00<0emL0omL9e`000]L200[G0P05e`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3G
e`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`27e`@0OML001GG00<0emL0
Q]L607cG000Ee`030=OG08KG1P1le`005ML00`3Ge`26e`H0O=L001GG0P27e`H0O=L001GG00<0emL0
QmL407gG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0?oG
2ML001GG00<0emL0omL9e`005ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`00
5ML00`3Ge`1]e`@0UmL001GG00<0emL0K=L609KG000Ee`030=OG06cG1P2Fe`005ML206gG1P2Fe`00
5ML00`3Ge`1/e`H0U]L001GG00<0emL0KML409OG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`00
5ML00`3Ge`3oe`WG000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`1Be`@0/]L001GG
00<0emL0DML60;7G000Ee`030=OG057G1P2ae`005ML00`3Ge`1Ae`H0/ML001GG00<0emL0DML60;7G
000Ee`80DmL40;;G000Ee`030=OG0?oG2ML001GG00<0emL0omL9e`005ML00`3Ge`0fe`@0c]L001GG
00<0emL0=ML60<gG000Ee`030=OG03GG1P3=e`005ML00`3Ge`0ee`H0cML001GG00<0emL0=ML60<gG
000Ee`030=OG01WG100Ie`@0c]L001GG00<0emL06=L60>[G000De`@06=L60>[G000=e`@00]L601OG
1P3Ze`003mL0103GemL601OG1P3Ze`003mL0103GemL601SG103[e`003mL0103GemL60?oG2=L000oG
00<0emL00]L40?oG2ML000gG0`05e`030=OG0?oG2ML000oG00<0emL00mL00`3Ge`3oe`WG000Ee`03
0=OG0?oG2ML001GG00<0emL0omL9e`00omLQe`00omLQe`00omLQe`00omLQe`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0820766, -0.0652294, \
0.00383497, 0.00385924}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(* Step 2: Calculate the b.Do not modify fst *)
fst=3.00000;Clear[b] 
delta=fst/nn; b[1]=N[fst-0.00001];
Table[N[b[n+1]=b[n]-delta],{n,1,nn}];
tb=Table[b[n],{n,1,nn}]
\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2.99999`, 2.7857042857142855`, 2.571418571428571`, 
      2.3571328571428567`, 2.1428471428571423`, 1.928561428571428`, 
      1.714275714285714`, 1.4999899999999997`, 1.2857042857142855`, 
      1.0714185714285713`, 0.857132857142857`, 0.6428471428571427`, 
      0.4285614285714284`, 0.21427571428571415`}\)], "Output"]
}, Open  ]],

Cell["\<\
(* Step 3:Fill matrix for the boundary conditions *)
Clear[MM,k];(*Clear[x,y,b,A,B]*)
MM=Table[l*n,{l,1,nn},{n,1,nn}];
Table[MM[[l,n]]=Cos[Sqrt[k^2-b[n]^2]*x[l]]*
Cos[b[n]*y[l]],
{l,1,nn,2},{n,1,nn/2}];

Table[MM[[l,n]]=Cosh[Sqrt[k^2-b[n]^2]*x[l]]*
Cosh[b[n]*y[l]],
{l,1,nn,2},{n,nn/2+1,nn}];

Table[MM[[l,n]]=-x[l]*Sqrt[k^2 - b[n]^2]*
Cos[y[l]*b[n]]*Sin[x[l]*Sqrt[k^2 - b[n]^2]]-
y[l]*b[n]*Cos[x[l]*Sqrt[k^2 - b[n]^2]]*Sin[y[l]*b[n]],
{l,2,nn,2},{n,1,nn/2}];

Table[MM[[l,n]]=x[l]*Sqrt[k^2 - b[n]^2]*
Cosh[y[l]*b[n]]*Sinh[x[l]*Sqrt[k^2 - b[n]^2]]+ 
y[l]*b[n]*Cosh[x[l]*Sqrt[k^2 - b[n]^2]]*
Sinh[y[l]*b[n]],
{l,2,nn,2},{n,nn/2+1,nn}];\
\>", "Input"],

Cell["\<\
Clear[k,W];W[k_]:=Det[MM]
(*Plot[W[k],{k,fst,4.}] //Timing*)\
\>", "Input"],

Cell["FindRoot[W[k]==0,{k,2.6}] //Timing", "Input"],

Cell["(* Table[Det[MM],{k,3.1962183,3.196219,0.0000001}] *)", "Input"],

Cell[CellGroupData[{

Cell["\<\
k=3.1962183;

nf=nn-1;bbf=Table[-MM[[ifit,nn]],{ifit,1,nf}];
rdutn=Table[MM[[ifit,klfit]],
{ifit,1,nf},{klfit,1,nf}];
B=LinearSolve[rdutn,bbf];
An={1};
A=Table[B[[lk]],{lk,1,nf}];
(* Check satisfaction of boundary cond.*)
Amp=Join[A,An];
boundary = MM .  Amp\
\>", "Input"],

Cell[BoxData[
    \(LinearSolve::"luc" \(\(:\)\(\ \)\) 
      "Result for \!\(LinearSolve\) of badly conditioned matrix \!\({\(\
\[LeftSkeleton] 1 \[RightSkeleton]\)}\) may contain significant numerical \
errors."\)], "Message"],

Cell[BoxData[
    \({\(-3.552713678800501`*^-15\), 
      2.1316282072803006`*^-14, \(-3.552713678800501`*^-15\), 0.`, 
      8.881784197001252`*^-16, \(-1.7763568394002505`*^-15\), 
      0.`, \(-8.881784197001252`*^-16\), 
      5.329070518200751`*^-15, \(-3.9968028886505635`*^-15\), 
      5.773159728050814`*^-15, \(-3.375077994860476`*^-14\), 
      2.6645352591003757`*^-15, 1.1658829457417141`*^-10}\)], "Output"]
}, Open  ]],

Cell["\<\
fxy[x_,y_]:=Sum[N[Amp[[n]]*Cos[b[n]*y]*
Cos[Sqrt[k^2-b[n]^2]*x]],{n,1,nn/2}]+
Sum[N[Amp[[n]]*Cosh[b[n]*y]*
Cosh[Sqrt[k^2-b[n]^2]*x]],
{n,nn/2+1,nn}]
\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
Do[Print[fxy[x[l],y[l]]],
{l,1,nn/2,2}]\
\>", "Input"],

Cell[BoxData[
    \(\(-1.9604977363751885`*^-14\)\)], "Print"],

Cell[BoxData[
    \(\(-3.241330814862664`*^-15\)\)], "Print"],

Cell[BoxData[
    \(3.226910925968607`*^-15\)], "Print"],

Cell[BoxData[
    \(8.844921323136745`*^-16\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
pl2=ContourPlot[fxy[x,y],{x,-1.,1.},{y,-1.,1.},
ContourShading->False,ContourSmoothing-> 2,
PlotPoints->60, DisplayFunction-> Identity]\
\>", "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  ContourGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[pl1,pl2, DisplayFunction->$DisplayFunction]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[.02381 .4875 -6 -9 ]
[.02381 .4875 6 0 ]
[.2619 .4875 -12 -9 ]
[.2619 .4875 12 0 ]
[.7381 .4875 -9 -9 ]
[.7381 .4875 9 0 ]
[.97619 .4875 -3 -9 ]
[.97619 .4875 3 0 ]
[.4875 .02381 -12 -4.5 ]
[.4875 .02381 0 4.5 ]
[.4875 .2619 -24 -4.5 ]
[.4875 .2619 0 4.5 ]
[.4875 .7381 -18 -4.5 ]
[.4875 .7381 0 4.5 ]
[.4875 .97619 -6 -4.5 ]
[.4875 .97619 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .5 m
.02381 .50625 L
s
[(-1)] .02381 .4875 0 1 Mshowa
.2619 .5 m
.2619 .50625 L
s
[(-0.5)] .2619 .4875 0 1 Mshowa
.7381 .5 m
.7381 .50625 L
s
[(0.5)] .7381 .4875 0 1 Mshowa
.97619 .5 m
.97619 .50625 L
s
[(1)] .97619 .4875 0 1 Mshowa
.125 Mabswid
.07143 .5 m
.07143 .50375 L
s
.11905 .5 m
.11905 .50375 L
s
.16667 .5 m
.16667 .50375 L
s
.21429 .5 m
.21429 .50375 L
s
.30952 .5 m
.30952 .50375 L
s
.35714 .5 m
.35714 .50375 L
s
.40476 .5 m
.40476 .50375 L
s
.45238 .5 m
.45238 .50375 L
s
.54762 .5 m
.54762 .50375 L
s
.59524 .5 m
.59524 .50375 L
s
.64286 .5 m
.64286 .50375 L
s
.69048 .5 m
.69048 .50375 L
s
.78571 .5 m
.78571 .50375 L
s
.83333 .5 m
.83333 .50375 L
s
.88095 .5 m
.88095 .50375 L
s
.92857 .5 m
.92857 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .02381 m
.50625 .02381 L
s
[(-1)] .4875 .02381 1 0 Mshowa
.5 .2619 m
.50625 .2619 L
s
[(-0.5)] .4875 .2619 1 0 Mshowa
.5 .7381 m
.50625 .7381 L
s
[(0.5)] .4875 .7381 1 0 Mshowa
.5 .97619 m
.50625 .97619 L
s
[(1)] .4875 .97619 1 0 Mshowa
.125 Mabswid
.5 .07143 m
.50375 .07143 L
s
.5 .11905 m
.50375 .11905 L
s
.5 .16667 m
.50375 .16667 L
s
.5 .21429 m
.50375 .21429 L
s
.5 .30952 m
.50375 .30952 L
s
.5 .35714 m
.50375 .35714 L
s
.5 .40476 m
.50375 .40476 L
s
.5 .45238 m
.50375 .45238 L
s
.5 .54762 m
.50375 .54762 L
s
.5 .59524 m
.50375 .59524 L
s
.5 .64286 m
.50375 .64286 L
s
.5 .69048 m
.50375 .69048 L
s
.5 .78571 m
.50375 .78571 L
s
.5 .83333 m
.50375 .83333 L
s
.5 .88095 m
.50375 .88095 L
s
.5 .92857 m
.50375 .92857 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
7 Mabswid
.9732 .55332 Mdot
.96436 .6055 Mdot
.94947 .65728 Mdot
.92924 .70618 Mdot
.9032 .75335 Mdot
.8726 .79653 Mdot
.83672 .83672 Mdot
.79727 .872 Mdot
.75335 .9032 Mdot
.70704 .92883 Mdot
.65728 .94947 Mdot
.60643 .96415 Mdot
.55332 .9732 Mdot
.50048 .97619 Mdot
.5 Mabswid
.45964 .4248 m
.47579 .41814 L
.49193 .41503 L
.50807 .41503 L
.52421 .41814 L
.54036 .4248 L
.54493 .42736 L
.5565 .43597 L
.56403 .4435 L
.57264 .45507 L
.5752 .45964 L
.58186 .47579 L
.58497 .49193 L
.58497 .50807 L
.58186 .52421 L
.5752 .54036 L
.57264 .54493 L
.56403 .5565 L
.5565 .56403 L
.54493 .57264 L
.54036 .5752 L
.52421 .58186 L
.50807 .58497 L
.49193 .58497 L
.47579 .58186 L
.45964 .5752 L
.45507 .57264 L
.4435 .56403 L
.43597 .5565 L
.42736 .54493 L
.4248 .54036 L
.41814 .52421 L
.41503 .50807 L
.41503 .49193 L
.41814 .47579 L
.4248 .45964 L
.42736 .45507 L
.43597 .4435 L
.4435 .43597 L
.45507 .42736 L
.45964 .4248 L
s
.45964 .37391 m
.47579 .36984 L
.49193 .36785 L
.50807 .36785 L
.52421 .36984 L
.54036 .37391 L
.5537 .37893 L
.5565 .38027 L
.57264 .38931 L
.58077 .39508 L
.58878 .40178 L
.59822 .41122 L
.60492 .41923 L
.61069 .42736 L
.61973 .4435 L
.62107 .4463 L
.62609 .45964 L
.63016 .47579 L
.63215 .49193 L
.63215 .50807 L
.63016 .52421 L
.62609 .54036 L
.62107 .5537 L
.61973 .5565 L
.61069 .57264 L
.60492 .58077 L
.59822 .58878 L
.58878 .59822 L
.58077 .60492 L
.57264 .61069 L
.5565 .61973 L
.5537 .62107 L
.54036 .62609 L
.52421 .63016 L
.50807 .63215 L
.49193 .63215 L
.47579 .63016 L
.45964 .62609 L
.4463 .62107 L
.4435 .61973 L
.42736 .61069 L
.41923 .60492 L
.41122 .59822 L
.40178 .58878 L
.39508 .58077 L
.38931 .57264 L
.38027 .5565 L
.37893 .5537 L
.37391 .54036 L
.36984 .52421 L
Mistroke
.36785 .50807 L
.36785 .49193 L
.36984 .47579 L
.37391 .45964 L
.37893 .4463 L
.38027 .4435 L
.38931 .42736 L
.39508 .41923 L
.40178 .41122 L
.41122 .40178 L
.41923 .39508 L
.42736 .38931 L
.4435 .38027 L
.4463 .37893 L
.45964 .37391 L
Mfstroke
.4435 .34085 m
.45964 .33601 L
.47579 .33286 L
.49193 .33131 L
.50807 .33131 L
.52421 .33286 L
.54036 .33601 L
.5565 .34085 L
.57078 .34665 L
.57264 .34754 L
.58878 .35633 L
.59849 .36279 L
.60492 .36766 L
.61775 .37893 L
.62107 .38225 L
.63234 .39508 L
.63721 .40151 L
.64367 .41122 L
.65246 .42736 L
.65335 .42922 L
.65915 .4435 L
.66399 .45964 L
.66714 .47579 L
.66869 .49193 L
.66869 .50807 L
.66714 .52421 L
.66399 .54036 L
.65915 .5565 L
.65335 .57078 L
.65246 .57264 L
.64367 .58878 L
.63721 .59849 L
.63234 .60492 L
.62107 .61775 L
.61775 .62107 L
.60492 .63234 L
.59849 .63721 L
.58878 .64367 L
.57264 .65246 L
.57078 .65335 L
.5565 .65915 L
.54036 .66399 L
.52421 .66714 L
.50807 .66869 L
.49193 .66869 L
.47579 .66714 L
.45964 .66399 L
.4435 .65915 L
.42922 .65335 L
.42736 .65246 L
Mistroke
.41122 .64367 L
.40151 .63721 L
.39508 .63234 L
.38225 .62107 L
.37893 .61775 L
.36766 .60492 L
.36279 .59849 L
.35633 .58878 L
.34754 .57264 L
.34665 .57078 L
.34085 .5565 L
.33601 .54036 L
.33286 .52421 L
.33131 .50807 L
.33131 .49193 L
.33286 .47579 L
.33601 .45964 L
.34085 .4435 L
.34665 .42922 L
.34754 .42736 L
.35633 .41122 L
.36279 .40151 L
.36766 .39508 L
.37893 .38225 L
.38225 .37893 L
.39508 .36766 L
.40151 .36279 L
.41122 .35633 L
.42736 .34754 L
.42922 .34665 L
.4435 .34085 L
Mfstroke
.42736 .31253 m
.4435 .30705 L
.45964 .30304 L
.47579 .30041 L
.49193 .29911 L
.50807 .29911 L
.52421 .30041 L
.54036 .30304 L
.5565 .30705 L
.57264 .31253 L
.57724 .31437 L
.58878 .31961 L
.60492 .3285 L
.60814 .33051 L
.62107 .33949 L
.63003 .34665 L
.63721 .35304 L
.64696 .36279 L
.65335 .36997 L
.66051 .37893 L
.66949 .39186 L
.6715 .39508 L
.68039 .41122 L
.68563 .42276 L
.68747 .42736 L
.69295 .4435 L
.69696 .45964 L
.69959 .47579 L
.70089 .49193 L
.70089 .50807 L
.69959 .52421 L
.69696 .54036 L
.69295 .5565 L
.68747 .57264 L
.68563 .57724 L
.68039 .58878 L
.6715 .60492 L
.66949 .60814 L
.66051 .62107 L
.65335 .63003 L
.64696 .63721 L
.63721 .64696 L
.63003 .65335 L
.62107 .66051 L
.60814 .66949 L
.60492 .6715 L
.58878 .68039 L
.57724 .68563 L
.57264 .68747 L
.5565 .69295 L
Mistroke
.54036 .69696 L
.52421 .69959 L
.50807 .70089 L
.49193 .70089 L
.47579 .69959 L
.45964 .69696 L
.4435 .69295 L
.42736 .68747 L
.42276 .68563 L
.41122 .68039 L
.39508 .6715 L
.39186 .66949 L
.37893 .66051 L
.36997 .65335 L
.36279 .64696 L
.35304 .63721 L
.34665 .63003 L
.33949 .62107 L
.33051 .60814 L
.3285 .60492 L
.31961 .58878 L
.31437 .57724 L
.31253 .57264 L
.30705 .5565 L
.30304 .54036 L
.30041 .52421 L
.29911 .50807 L
.29911 .49193 L
.30041 .47579 L
.30304 .45964 L
.30705 .4435 L
.31253 .42736 L
.31437 .42276 L
.31961 .41122 L
.3285 .39508 L
.33051 .39186 L
.33949 .37893 L
.34665 .36997 L
.35304 .36279 L
.36279 .35304 L
.36997 .34665 L
.37893 .33949 L
.39186 .33051 L
.39508 .3285 L
.41122 .31961 L
.42276 .31437 L
.42736 .31253 L
Mfstroke
.42736 .28054 m
.4435 .27584 L
.45964 .27238 L
.47579 .2701 L
.49193 .26897 L
.50807 .26897 L
.52421 .2701 L
.54036 .27238 L
.5565 .27584 L
.57264 .28054 L
.57718 .28208 L
.58878 .28656 L
.60492 .29401 L
.61283 .29822 L
.62107 .30306 L
.63721 .31395 L
.63777 .31437 L
.65335 .32701 L
.65721 .33051 L
.66949 .34279 L
.67299 .34665 L
.68563 .36223 L
.68605 .36279 L
.69694 .37893 L
.70178 .38717 L
.70599 .39508 L
.71344 .41122 L
.71792 .42282 L
.71946 .42736 L
.72416 .4435 L
.72762 .45964 L
.7299 .47579 L
.73103 .49193 L
.73103 .50807 L
.7299 .52421 L
.72762 .54036 L
.72416 .5565 L
.71946 .57264 L
.71792 .57718 L
.71344 .58878 L
.70599 .60492 L
.70178 .61283 L
.69694 .62107 L
.68605 .63721 L
.68563 .63777 L
.67299 .65335 L
.66949 .65721 L
.65721 .66949 L
.65335 .67299 L
.63777 .68563 L
Mistroke
.63721 .68605 L
.62107 .69694 L
.61283 .70178 L
.60492 .70599 L
.58878 .71344 L
.57718 .71792 L
.57264 .71946 L
.5565 .72416 L
.54036 .72762 L
.52421 .7299 L
.50807 .73103 L
.49193 .73103 L
.47579 .7299 L
.45964 .72762 L
.4435 .72416 L
.42736 .71946 L
.42282 .71792 L
.41122 .71344 L
.39508 .70599 L
.38717 .70178 L
.37893 .69694 L
.36279 .68605 L
.36223 .68563 L
.34665 .67299 L
.34279 .66949 L
.33051 .65721 L
.32701 .65335 L
.31437 .63777 L
.31395 .63721 L
.30306 .62107 L
.29822 .61283 L
.29401 .60492 L
.28656 .58878 L
.28208 .57718 L
.28054 .57264 L
.27584 .5565 L
.27238 .54036 L
.2701 .52421 L
.26897 .50807 L
.26897 .49193 L
.2701 .47579 L
.27238 .45964 L
.27584 .4435 L
.28054 .42736 L
.28208 .42282 L
.28656 .41122 L
.29401 .39508 L
.29822 .38717 L
.30306 .37893 L
.31395 .36279 L
Mistroke
.31437 .36223 L
.32701 .34665 L
.33051 .34279 L
.34279 .33051 L
.34665 .32701 L
.36223 .31437 L
.36279 .31395 L
.37893 .30306 L
.38717 .29822 L
.39508 .29401 L
.41122 .28656 L
.42282 .28208 L
.42736 .28054 L
Mfstroke
.97619 .95649 m
.97275 .96005 L
.96005 .97274 L
.95649 .97619 L
s
.02381 .95649 m
.02725 .96005 L
.03995 .97274 L
.04351 .97619 L
s
.97619 .04351 m
.97275 .03995 L
.96005 .02726 L
.95649 .02381 L
s
.02381 .04351 m
.02725 .03995 L
.03995 .02726 L
.04351 .02381 L
s
.42736 .24977 m
.4435 .24564 L
.45964 .24258 L
.47579 .24056 L
.49193 .23956 L
.50807 .23956 L
.52421 .24056 L
.54036 .24258 L
.5565 .24564 L
.57264 .24977 L
.57275 .2498 L
.58878 .25503 L
.60492 .26149 L
.61451 .26594 L
.62107 .26927 L
.63721 .27849 L
.64285 .28208 L
.65335 .28934 L
.66487 .29822 L
.66949 .30209 L
.68285 .31437 L
.68563 .31715 L
.69791 .33051 L
.70178 .33513 L
.71066 .34665 L
.71792 .35715 L
.72151 .36279 L
.73073 .37893 L
.73406 .38549 L
.73851 .39508 L
.74497 .41122 L
.7502 .42725 L
.75023 .42736 L
.75437 .4435 L
.75742 .45964 L
.75944 .47579 L
.76044 .49193 L
.76044 .50807 L
.75944 .52421 L
.75742 .54036 L
.75437 .5565 L
.75023 .57264 L
.7502 .57275 L
.74497 .58878 L
.73851 .60492 L
.73406 .61451 L
.73073 .62107 L
.72151 .63721 L
.71792 .64285 L
.71066 .65335 L
Mistroke
.70178 .66487 L
.69791 .66949 L
.68563 .68285 L
.68285 .68563 L
.66949 .69791 L
.66487 .70178 L
.65335 .71066 L
.64285 .71792 L
.63721 .72151 L
.62107 .73073 L
.61451 .73406 L
.60492 .73851 L
.58878 .74497 L
.57275 .7502 L
.57264 .75023 L
.5565 .75436 L
.54036 .75742 L
.52421 .75944 L
.50807 .76044 L
.49193 .76044 L
.47579 .75944 L
.45964 .75742 L
.4435 .75436 L
.42736 .75023 L
.42725 .7502 L
.41122 .74497 L
.39508 .73851 L
.38549 .73406 L
.37893 .73073 L
.36279 .72151 L
.35715 .71792 L
.34665 .71066 L
.33513 .70178 L
.33051 .69791 L
.31715 .68563 L
.31437 .68285 L
.30209 .66949 L
.29822 .66487 L
.28934 .65335 L
.28208 .64285 L
.27849 .63721 L
.26927 .62107 L
.26594 .61451 L
.26149 .60492 L
.25503 .58878 L
.2498 .57275 L
.24977 .57264 L
.24563 .5565 L
.24258 .54036 L
.24056 .52421 L
Mistroke
.23956 .50807 L
.23956 .49193 L
.24056 .47579 L
.24258 .45964 L
.24563 .4435 L
.24977 .42736 L
.2498 .42725 L
.25503 .41122 L
.26149 .39508 L
.26594 .38549 L
.26927 .37893 L
.27849 .36279 L
.28208 .35715 L
.28934 .34665 L
.29822 .33513 L
.30209 .33051 L
.31437 .31715 L
.31715 .31437 L
.33051 .30209 L
.33513 .29822 L
.34665 .28934 L
.35715 .28208 L
.36279 .27849 L
.37893 .26927 L
.38549 .26594 L
.39508 .26149 L
.41122 .25503 L
.42725 .2498 L
.42736 .24977 L
Mfstroke
.97619 .93365 m
.96663 .94391 L
.96005 .95073 L
.95073 .96005 L
.94391 .96663 L
.93364 .97619 L
s
.02381 .93365 m
.03337 .94391 L
.03995 .95073 L
.04927 .96005 L
.05609 .96663 L
.06636 .97619 L
s
.97619 .06635 m
.96663 .05609 L
.96005 .04927 L
.95073 .03995 L
.94391 .03337 L
.93364 .02381 L
s
.02381 .06635 m
.03337 .05609 L
.03995 .04927 L
.04927 .03995 L
.05609 .03337 L
.06636 .02381 L
s
.4435 .21525 m
.45964 .21252 L
.47579 .21071 L
.49193 .20981 L
.50807 .20981 L
.52421 .21071 L
.54036 .21252 L
.5565 .21525 L
.56699 .21751 L
.57264 .21893 L
.58878 .22361 L
.60492 .22932 L
.61549 .23366 L
.62107 .23615 L
.63721 .24417 L
.64723 .2498 L
.65335 .25351 L
.66949 .26431 L
.67173 .26594 L
.68563 .27681 L
.6918 .28208 L
.70178 .29128 L
.70872 .29822 L
.71792 .3082 L
.72319 .31437 L
.73406 .32827 L
.73569 .33051 L
.74649 .34665 L
.7502 .35277 L
.75583 .36279 L
.76385 .37893 L
.76634 .38451 L
.77068 .39508 L
.77639 .41122 L
.78107 .42736 L
.78249 .43301 L
.78475 .4435 L
.78748 .45964 L
.78929 .47579 L
.79019 .49193 L
.79019 .50807 L
.78929 .52421 L
.78748 .54036 L
.78475 .5565 L
.78249 .56699 L
.78107 .57264 L
.77639 .58878 L
.77068 .60492 L
.76634 .61549 L
.76385 .62107 L
Mistroke
.75583 .63721 L
.7502 .64723 L
.74649 .65335 L
.73569 .66949 L
.73406 .67173 L
.72319 .68563 L
.71792 .6918 L
.70872 .70178 L
.70178 .70872 L
.6918 .71792 L
.68563 .72319 L
.67173 .73406 L
.66949 .73569 L
.65335 .74649 L
.64723 .7502 L
.63721 .75583 L
.62107 .76385 L
.61549 .76634 L
.60492 .77068 L
.58878 .77639 L
.57264 .78107 L
.56699 .78249 L
.5565 .78475 L
.54036 .78748 L
.52421 .78929 L
.50807 .79019 L
.49193 .79019 L
.47579 .78929 L
.45964 .78748 L
.4435 .78475 L
.43301 .78249 L
.42736 .78107 L
.41122 .77639 L
.39508 .77068 L
.38451 .76634 L
.37893 .76385 L
.36279 .75583 L
.35277 .7502 L
.34665 .74649 L
.33051 .73569 L
.32827 .73406 L
.31437 .72319 L
.3082 .71792 L
.29822 .70872 L
.29128 .70178 L
.28208 .6918 L
.27681 .68563 L
.26594 .67173 L
.26431 .66949 L
.25351 .65335 L
Mistroke
.2498 .64723 L
.24417 .63721 L
.23615 .62107 L
.23366 .61549 L
.22932 .60492 L
.22361 .58878 L
.21893 .57264 L
.21751 .56699 L
.21525 .5565 L
.21252 .54036 L
.21071 .52421 L
.20981 .50807 L
.20981 .49193 L
.21071 .47579 L
.21252 .45964 L
.21525 .4435 L
.21751 .43301 L
.21893 .42736 L
.22361 .41122 L
.22932 .39508 L
.23366 .38451 L
.23615 .37893 L
.24417 .36279 L
.2498 .35277 L
.25351 .34665 L
.26431 .33051 L
.26594 .32827 L
.27681 .31437 L
.28208 .3082 L
.29128 .29822 L
.29822 .29128 L
.3082 .28208 L
.31437 .27681 L
.32827 .26594 L
.33051 .26431 L
.34665 .25351 L
.35277 .2498 L
.36279 .24417 L
.37893 .23615 L
.38451 .23366 L
.39508 .22932 L
.41122 .22361 L
.42736 .21893 L
.43301 .21751 L
.4435 .21525 L
Mfstroke
.97619 .90706 m
.97223 .91162 L
.96005 .9252 L
.95767 .92776 L
.94391 .94203 L
.94203 .94391 L
.92776 .95767 L
.9252 .96005 L
.91162 .97223 L
.90705 .97619 L
s
.02381 .90706 m
.02777 .91162 L
.03995 .9252 L
.04233 .92776 L
.05609 .94203 L
.05797 .94391 L
.07224 .95767 L
.0748 .96005 L
.08838 .97223 L
.09295 .97619 L
s
.97619 .09294 m
.97223 .08838 L
.96005 .0748 L
.95767 .07224 L
.94391 .05797 L
.94203 .05609 L
.92776 .04233 L
.9252 .03995 L
.91162 .02777 L
.90705 .02381 L
s
.02381 .09294 m
.02777 .08838 L
.03995 .0748 L
.04233 .07224 L
.05609 .05797 L
.05797 .05609 L
.07224 .04233 L
.0748 .03995 L
.08838 .02777 L
.09295 .02381 L
s
.4435 .18338 m
.45964 .18092 L
.47579 .17929 L
.49193 .17848 L
.50807 .17848 L
.52421 .17929 L
.54036 .18092 L
.5565 .18338 L
.56614 .18523 L
.57264 .18669 L
.58878 .19087 L
.60492 .19597 L
.61944 .20137 L
.62107 .20203 L
.63721 .20911 L
.65335 .21729 L
.65377 .21751 L
.66949 .22666 L
.68029 .23366 L
.68563 .23735 L
.70178 .24954 L
.70209 .2498 L
.71792 .26345 L
.72059 .26594 L
.73406 .27941 L
.73655 .28208 L
.7502 .29791 L
.75046 .29822 L
.76265 .31437 L
.76634 .31971 L
.77334 .33051 L
.78249 .34623 L
.78271 .34665 L
.79089 .36279 L
.79797 .37893 L
.79863 .38056 L
.80403 .39508 L
.80913 .41122 L
.81332 .42736 L
.81477 .43386 L
.81662 .4435 L
.81908 .45964 L
.82071 .47579 L
.82152 .49193 L
.82152 .50807 L
.82071 .52421 L
.81908 .54036 L
.81662 .5565 L
.81477 .56614 L
.81332 .57264 L
Mistroke
.80913 .58878 L
.80403 .60492 L
.79863 .61944 L
.79797 .62107 L
.79089 .63721 L
.78271 .65335 L
.78249 .65377 L
.77334 .66949 L
.76634 .68029 L
.76265 .68563 L
.75046 .70178 L
.7502 .70209 L
.73655 .71792 L
.73406 .72059 L
.72059 .73406 L
.71792 .73655 L
.70209 .7502 L
.70178 .75046 L
.68563 .76265 L
.68029 .76634 L
.66949 .77334 L
.65377 .78249 L
.65335 .78271 L
.63721 .79089 L
.62107 .79797 L
.61944 .79863 L
.60492 .80403 L
.58878 .80913 L
.57264 .81331 L
.56614 .81477 L
.5565 .81662 L
.54036 .81908 L
.52421 .82071 L
.50807 .82152 L
.49193 .82152 L
.47579 .82071 L
.45964 .81908 L
.4435 .81662 L
.43386 .81477 L
.42736 .81331 L
.41122 .80913 L
.39508 .80403 L
.38056 .79863 L
.37893 .79797 L
.36279 .79089 L
.34665 .78271 L
.34623 .78249 L
.33051 .77334 L
.31971 .76634 L
.31437 .76265 L
Mistroke
.29822 .75046 L
.29791 .7502 L
.28208 .73655 L
.27941 .73406 L
.26594 .72059 L
.26345 .71792 L
.2498 .70209 L
.24954 .70178 L
.23735 .68563 L
.23366 .68029 L
.22666 .66949 L
.21751 .65377 L
.21729 .65335 L
.20911 .63721 L
.20203 .62107 L
.20137 .61944 L
.19597 .60492 L
.19087 .58878 L
.18668 .57264 L
.18523 .56614 L
.18338 .5565 L
.18092 .54036 L
.17929 .52421 L
.17848 .50807 L
.17848 .49193 L
.17929 .47579 L
.18092 .45964 L
.18338 .4435 L
.18523 .43386 L
.18668 .42736 L
.19087 .41122 L
.19597 .39508 L
.20137 .38056 L
.20203 .37893 L
.20911 .36279 L
.21729 .34665 L
.21751 .34623 L
.22666 .33051 L
.23366 .31971 L
.23735 .31437 L
.24954 .29822 L
.2498 .29791 L
.26345 .28208 L
.26594 .27941 L
.27941 .26594 L
.28208 .26345 L
.29791 .2498 L
.29822 .24954 L
.31437 .23735 L
.31971 .23366 L
Mistroke
.33051 .22666 L
.34623 .21751 L
.34665 .21729 L
.36279 .20911 L
.37893 .20203 L
.38056 .20137 L
.39508 .19597 L
.41122 .19087 L
.42736 .18669 L
.43386 .18523 L
.4435 .18338 L
Mfstroke
.97619 .87477 m
.97253 .87934 L
.96005 .89441 L
.95913 .89548 L
.94471 .91162 L
.94391 .91248 L
.9292 .92776 L
.92776 .9292 L
.91248 .94391 L
.91162 .9447 L
.89548 .95912 L
.8944 .96005 L
.87934 .97253 L
.87476 .97619 L
s
.02381 .87477 m
.02747 .87934 L
.03995 .89441 L
.04087 .89548 L
.05529 .91162 L
.05609 .91248 L
.0708 .92776 L
.07224 .9292 L
.08752 .94391 L
.08838 .9447 L
.10452 .95912 L
.1056 .96005 L
.12066 .97253 L
.12524 .97619 L
s
.97619 .12523 m
.97253 .12066 L
.96005 .10559 L
.95913 .10452 L
.94471 .08838 L
.94391 .08752 L
.9292 .07224 L
.92776 .0708 L
.91248 .05609 L
.91162 .0553 L
.89548 .04088 L
.8944 .03995 L
.87934 .02747 L
.87476 .02381 L
s
.02381 .12523 m
.02747 .12066 L
.03995 .10559 L
.04087 .10452 L
.05529 .08838 L
.05609 .08752 L
.0708 .07224 L
.07224 .0708 L
.08752 .05609 L
.08838 .0553 L
.10452 .04088 L
.1056 .03995 L
.12066 .02747 L
.12524 .02381 L
s
.42736 .15088 m
.4435 .14791 L
.45964 .14569 L
.47579 .14423 L
.49193 .14349 L
.50807 .14349 L
.52421 .14423 L
.54036 .14569 L
.5565 .14791 L
.57264 .15088 L
.58202 .15295 L
.58878 .15462 L
.60492 .15919 L
.62107 .16458 L
.63291 .16909 L
.63721 .17085 L
.65335 .17806 L
.66759 .18523 L
.66949 .18625 L
.68563 .19553 L
.69491 .20137 L
.70178 .20597 L
.71765 .21751 L
.71792 .21772 L
.73406 .23096 L
.73712 .23366 L
.7502 .2459 L
.7541 .2498 L
.76634 .26288 L
.76904 .26594 L
.78228 .28208 L
.78249 .28235 L
.79403 .29822 L
.79863 .30509 L
.80448 .31437 L
.81375 .33051 L
.81477 .33241 L
.82194 .34665 L
.82915 .36279 L
.83091 .36708 L
.83542 .37893 L
.84081 .39508 L
.84538 .41122 L
.84705 .41798 L
.84913 .42736 L
.8521 .4435 L
.85431 .45964 L
.85578 .47579 L
.85651 .49193 L
.85651 .50807 L
Mistroke
.85578 .52421 L
.85431 .54036 L
.8521 .5565 L
.84913 .57264 L
.84705 .58202 L
.84538 .58878 L
.84081 .60492 L
.83542 .62107 L
.83091 .63292 L
.82915 .63721 L
.82194 .65335 L
.81477 .66759 L
.81375 .66949 L
.80448 .68563 L
.79863 .69491 L
.79403 .70178 L
.78249 .71765 L
.78228 .71792 L
.76904 .73406 L
.76634 .73712 L
.7541 .7502 L
.7502 .7541 L
.73712 .76634 L
.73406 .76904 L
.71792 .78228 L
.71765 .78249 L
.70178 .79403 L
.69491 .79863 L
.68563 .80447 L
.66949 .81375 L
.66759 .81477 L
.65335 .82194 L
.63721 .82915 L
.63291 .83091 L
.62107 .83542 L
.60492 .84081 L
.58878 .84538 L
.58202 .84705 L
.57264 .84912 L
.5565 .85209 L
.54036 .85431 L
.52421 .85577 L
.50807 .85651 L
.49193 .85651 L
.47579 .85577 L
.45964 .85431 L
.4435 .85209 L
.42736 .84912 L
.41798 .84705 L
.41122 .84538 L
Mistroke
.39508 .84081 L
.37893 .83542 L
.36709 .83091 L
.36279 .82915 L
.34665 .82194 L
.33241 .81477 L
.33051 .81375 L
.31437 .80447 L
.30509 .79863 L
.29822 .79403 L
.28235 .78249 L
.28208 .78228 L
.26594 .76904 L
.26288 .76634 L
.2498 .7541 L
.2459 .7502 L
.23366 .73712 L
.23096 .73406 L
.21772 .71792 L
.21751 .71765 L
.20597 .70178 L
.20137 .69491 L
.19552 .68563 L
.18625 .66949 L
.18523 .66759 L
.17806 .65335 L
.17085 .63721 L
.16909 .63292 L
.16458 .62107 L
.15919 .60492 L
.15462 .58878 L
.15295 .58202 L
.15087 .57264 L
.1479 .5565 L
.14569 .54036 L
.14422 .52421 L
.14349 .50807 L
.14349 .49193 L
.14422 .47579 L
.14569 .45964 L
.1479 .4435 L
.15087 .42736 L
.15295 .41798 L
.15462 .41122 L
.15919 .39508 L
.16458 .37893 L
.16909 .36708 L
.17085 .36279 L
.17806 .34665 L
.18523 .33241 L
Mistroke
.18625 .33051 L
.19552 .31437 L
.20137 .30509 L
.20597 .29822 L
.21751 .28235 L
.21772 .28208 L
.23096 .26594 L
.23366 .26288 L
.2459 .2498 L
.2498 .2459 L
.26288 .23366 L
.26594 .23096 L
.28208 .21772 L
.28235 .21751 L
.29822 .20597 L
.30509 .20137 L
.31437 .19553 L
.33051 .18625 L
.33241 .18523 L
.34665 .17806 L
.36279 .17085 L
.36709 .16909 L
.37893 .16458 L
.39508 .15919 L
.41122 .15462 L
.41798 .15295 L
.42736 .15088 L
Mfstroke
.97619 .83249 m
.96565 .84705 L
.96005 .85449 L
.95322 .8632 L
.94391 .87451 L
.93979 .87934 L
.92776 .89284 L
.92532 .89548 L
.91162 .90972 L
.90972 .91162 L
.89548 .92532 L
.89284 .92776 L
.87934 .93978 L
.8745 .94391 L
.8632 .95321 L
.85449 .96005 L
.84705 .96565 L
.83249 .97619 L
s
.02381 .83249 m
.03435 .84705 L
.03995 .85449 L
.04678 .8632 L
.05609 .87451 L
.06021 .87934 L
.07224 .89284 L
.07468 .89548 L
.08838 .90972 L
.09028 .91162 L
.10452 .92532 L
.10716 .92776 L
.12066 .93978 L
.1255 .94391 L
.1368 .95321 L
.14551 .96005 L
.15295 .96565 L
.16751 .97619 L
s
.97619 .16751 m
.96565 .15295 L
.96005 .14551 L
.95322 .1368 L
.94391 .12549 L
.93979 .12066 L
.92776 .10716 L
.92532 .10452 L
.91162 .09028 L
.90972 .08838 L
.89548 .07468 L
.89284 .07224 L
.87934 .06022 L
.8745 .05609 L
.8632 .04679 L
.85449 .03995 L
.84705 .03435 L
.83249 .02381 L
s
.02381 .16751 m
.03435 .15295 L
.03995 .14551 L
.04678 .1368 L
.05609 .12549 L
.06021 .12066 L
.07224 .10716 L
.07468 .10452 L
.08838 .09028 L
.09028 .08838 L
.10452 .07468 L
.10716 .07224 L
.12066 .06022 L
.1255 .05609 L
.1368 .04679 L
.14551 .03995 L
.15295 .03435 L
.16751 .02381 L
s
.4435 .10322 m
.45964 .10127 L
.47579 .09997 L
.49193 .09933 L
.50807 .09933 L
.52421 .09997 L
.54036 .10127 L
.5565 .10322 L
.56517 .10452 L
.57264 .10584 L
.58878 .10918 L
.60492 .11322 L
.62107 .11795 L
.6294 .12066 L
.63721 .12343 L
.65335 .12973 L
.66949 .1368 L
.6695 .1368 L
.68563 .14481 L
.70049 .15295 L
.70178 .1537 L
.71792 .16364 L
.72613 .16909 L
.73406 .17466 L
.74811 .18523 L
.7502 .18689 L
.76634 .2005 L
.76732 .20137 L
.78249 .21568 L
.78432 .21751 L
.79863 .23268 L
.7995 .23366 L
.81311 .2498 L
.81477 .25189 L
.82534 .26594 L
.83091 .27387 L
.83636 .28208 L
.8463 .29822 L
.84705 .29951 L
.85519 .31437 L
.8632 .3305 L
.8632 .33051 L
.87027 .34665 L
.87657 .36279 L
.87934 .37059 L
.88205 .37893 L
.88678 .39508 L
.89082 .41122 L
.89416 .42736 L
.89548 .43482 L
Mistroke
.89678 .4435 L
.89873 .45964 L
.90003 .47579 L
.90068 .49193 L
.90068 .50807 L
.90003 .52421 L
.89873 .54036 L
.89678 .5565 L
.89548 .56518 L
.89416 .57264 L
.89082 .58878 L
.88678 .60492 L
.88205 .62107 L
.87934 .62941 L
.87657 .63721 L
.87027 .65335 L
.8632 .66949 L
.8632 .6695 L
.85519 .68563 L
.84705 .70049 L
.8463 .70178 L
.83636 .71792 L
.83091 .72613 L
.82534 .73406 L
.81477 .74811 L
.81311 .7502 L
.7995 .76634 L
.79863 .76732 L
.78432 .78249 L
.78249 .78432 L
.76732 .79863 L
.76634 .7995 L
.7502 .81311 L
.74811 .81477 L
.73406 .82534 L
.72613 .83091 L
.71792 .83636 L
.70178 .8463 L
.70049 .84705 L
.68563 .85519 L
.6695 .8632 L
.66949 .8632 L
.65335 .87027 L
.63721 .87657 L
.6294 .87934 L
.62107 .88205 L
.60492 .88678 L
.58878 .89082 L
.57264 .89416 L
.56517 .89548 L
Mistroke
.5565 .89678 L
.54036 .89873 L
.52421 .90003 L
.50807 .90067 L
.49193 .90067 L
.47579 .90003 L
.45964 .89873 L
.4435 .89678 L
.43483 .89548 L
.42736 .89416 L
.41122 .89082 L
.39508 .88678 L
.37893 .88205 L
.3706 .87934 L
.36279 .87657 L
.34665 .87027 L
.33051 .8632 L
.3305 .8632 L
.31437 .85519 L
.29951 .84705 L
.29822 .8463 L
.28208 .83636 L
.27387 .83091 L
.26594 .82534 L
.25189 .81477 L
.2498 .81311 L
.23366 .7995 L
.23268 .79863 L
.21751 .78432 L
.21568 .78249 L
.20137 .76732 L
.2005 .76634 L
.18689 .7502 L
.18523 .74811 L
.17466 .73406 L
.16909 .72613 L
.16364 .71792 L
.1537 .70178 L
.15295 .70049 L
.14481 .68563 L
.1368 .6695 L
.1368 .66949 L
.12973 .65335 L
.12343 .63721 L
.12066 .62941 L
.11795 .62107 L
.11322 .60492 L
.10918 .58878 L
.10584 .57264 L
.10452 .56518 L
Mistroke
.10322 .5565 L
.10127 .54036 L
.09997 .52421 L
.09932 .50807 L
.09932 .49193 L
.09997 .47579 L
.10127 .45964 L
.10322 .4435 L
.10452 .43482 L
.10584 .42736 L
.10918 .41122 L
.11322 .39508 L
.11795 .37893 L
.12066 .37059 L
.12343 .36279 L
.12973 .34665 L
.1368 .33051 L
.1368 .3305 L
.14481 .31437 L
.15295 .29951 L
.1537 .29822 L
.16364 .28208 L
.16909 .27387 L
.17466 .26594 L
.18523 .25189 L
.18689 .2498 L
.2005 .23366 L
.20137 .23268 L
.21568 .21751 L
.21751 .21568 L
.23268 .20137 L
.23366 .2005 L
.2498 .18689 L
.25189 .18523 L
.26594 .17466 L
.27387 .16909 L
.28208 .16364 L
.29822 .1537 L
.29951 .15295 L
.31437 .14481 L
.3305 .1368 L
.33051 .1368 L
.34665 .12973 L
.36279 .12343 L
.3706 .12066 L
.37893 .11795 L
.39508 .11322 L
.41122 .10918 L
.42736 .10584 L
.43483 .10452 L
Mistroke
.4435 .10322 L
Mfstroke
.97619 .76609 m
.97603 .76634 L
.96648 .78249 L
.96005 .79314 L
.95654 .79863 L
.94553 .81477 L
.94391 .81704 L
.9337 .83091 L
.92776 .83852 L
.92089 .84705 L
.91162 .85797 L
.90703 .8632 L
.89548 .87573 L
.89202 .87934 L
.87934 .89202 L
.87573 .89548 L
.8632 .90703 L
.85797 .91162 L
.84705 .92089 L
.83852 .92776 L
.83091 .93369 L
.81704 .94391 L
.81477 .94552 L
.79863 .95653 L
.79313 .96005 L
.78249 .96647 L
.76634 .97603 L
.76609 .97619 L
s
.02381 .76609 m
.02397 .76634 L
.03352 .78249 L
.03995 .79314 L
.04346 .79863 L
.05447 .81477 L
.05609 .81704 L
.0663 .83091 L
.07224 .83852 L
.07911 .84705 L
.08838 .85797 L
.09297 .8632 L
.10452 .87573 L
.10798 .87934 L
.12066 .89202 L
.12427 .89548 L
.1368 .90703 L
.14203 .91162 L
.15295 .92089 L
.16148 .92776 L
.16909 .93369 L
.18296 .94391 L
.18523 .94552 L
.20137 .95653 L
.20687 .96005 L
.21751 .96647 L
.23366 .97603 L
.23391 .97619 L
s
.97619 .23391 m
.97603 .23366 L
.96648 .21751 L
.96005 .20686 L
.95654 .20137 L
.94553 .18523 L
.94391 .18296 L
.9337 .16909 L
.92776 .16148 L
.92089 .15295 L
.91162 .14203 L
.90703 .1368 L
.89548 .12427 L
.89202 .12066 L
.87934 .10798 L
.87573 .10452 L
.8632 .09297 L
.85797 .08838 L
.84705 .07911 L
.83852 .07224 L
.83091 .06631 L
.81704 .05609 L
.81477 .05448 L
.79863 .04347 L
.79313 .03995 L
.78249 .03353 L
.76634 .02397 L
.76609 .02381 L
s
.02381 .23391 m
.02397 .23366 L
.03352 .21751 L
.03995 .20686 L
.04346 .20137 L
.05447 .18523 L
.05609 .18296 L
.0663 .16909 L
.07224 .16148 L
.07911 .15295 L
.08838 .14203 L
.09297 .1368 L
.10452 .12427 L
.10798 .12066 L
.12066 .10798 L
.12427 .10452 L
.1368 .09297 L
.14203 .08838 L
.15295 .07911 L
.16148 .07224 L
.16909 .06631 L
.18296 .05609 L
.18523 .05448 L
.20137 .04347 L
.20687 .03995 L
.21751 .03353 L
.23366 .02397 L
.23391 .02381 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooohoG00<0emL0S]L008oG00<0emL0S]L008oG
00<0emL0S]L008oG00<0emL0S]L008oG00<0emL0S]L008KG1005e`030=OG08kG0028e`030=OG00CG
00<0emL0S]L000cG00<0emL01=L00`3Ge`04e`030=OG00KG00<0emL02]L00`3Ge`0@e`030=OG04;G
00<0emL01=L304WG00<0emL04=L00`3Ge`0:e`030=OG00KG00<0emL01=L00`3Ge`04e`030=OG00_G
000;e`030=OG00CG00<0emL01=L00`3Ge`06e`030=OG00WG0P0Ae`80?ML400CG00<0emL01=L00`3G
e`1:e`804ML200_G00<0emL01]L00`3Ge`04e`030=OG00CG00<0emL02]L000[G00<0emL01=L00`3G
e`04e`030=OG00KG00<0emL02=L2017G0P17e`030=OG00CG00<0emL0C=L2017G0P0:e`030=OG00KG
00<0emL01=L00`3Ge`04e`030=OG00WG0009e`030=OG00CG00<0emL01=L00`3Ge`06e`030=OG00SG
00<0emL04=L00`3Ge`15e`<01]L00`3Ge`1>e`030=OG013G00<0emL02=L00`3Ge`06e`030=OG00CG
00<0emL01=L00`3Ge`08e`002=L00`3Ge`04e`030=OG00CG00<0emL01]L00`3Ge`08e`030=OG00oG
0P1:e`030=OG00CG00<0emL0CmL2017G00<0emL02=L00`3Ge`06e`030=OG00CG00<0emL01=L00`3G
e`07e`001mL00`3Ge`04e`030=OG00CG00<0emL01]L00`3Ge`08e`030=OG00oG00<0emL0DML00`3G
e`1Ae`030=OG00oG00<0emL02=L200OG00<0emL01=L00`3Ge`04e`030=OG00KG0006e`030=OG00CG
00<0emL01=L00`3Ge`06e`030=OG00SG00<0emL03]L205CG00<0emL0D]L2013G00<0emL02ML00`3G
e`05e`030=OG00CG00<0emL01=L00`3Ge`05e`003=L00`3Ge`04e`030=OG00GG0P0:e`030=OG00kG
00<0emL0E=L00`3Ge`1De`030=OG00kG00<0emL02ML00`3Ge`05e`030=OG00CG00<0emL02mL000_G
00<0emL01=L00`3Ge`05e`030=OG00WG00<0emL03ML205OG00<0emL0EML200oG00<0emL02ML00`3G
e`05e`030=OG00CG00<0emL02]L000[G00<0emL01=L00`3Ge`05e`030=OG00WG00<0emL03ML00`3G
e`1Ge`030=OG05OG00<0emL03ML00`3Ge`09e`030=OG00GG00<0emL01=L00`3Ge`09e`002ML00`3G
e`04e`030=OG00KG00<0emL02=L00`3Ge`0=e`030=OG05SG00<0emL0F=L00`3Ge`0=e`030=OG00SG
00<0emL01]L00`3Ge`04e`030=OG00SG0008e`030=OG00CG00<0emL01]L00`3Ge`07e`803mL00`3G
e`1Ie`030=OG05WG00<0emL03ML200WG00<0emL01]L00`3Ge`04e`030=OG00OG0007e`030=OG00CG
00<0emL01ML200WG00<0emL03ML205cG00<0emL0F]L200oG00<0emL01mL200OG00<0emL01=L00`3G
e`06e`001]L00`3Ge`04e`030=OG00GG00<0emL01mL200oG00<0emL0G=L00`3Ge`1Le`030=OG00gG
0P09e`030=OG00GG00<0emL01=L00`3Ge`05e`003=L00`3Ge`05e`030=OG00OG00<0emL03ML205oG
0P1Ne`803mL00`3Ge`07e`030=OG00GG00<0emL02mL000_G00<0emL01ML00`3Ge`08e`030=OG00_G
0P1Qe`030=OG05oG0P0>e`030=OG00OG00<0emL01ML00`3Ge`0:e`002]L00`3Ge`05e`030=OG00SG
00<0emL02mL00`3Ge`1Qe`030=OG067G00<0emL03=L00`3Ge`07e`030=OG00GG00<0emL02ML000WG
00<0emL01]L00`3Ge`06e`803ML00`3Ge`1Re`030=OG06;G00<0emL03=L00`3Ge`06e`030=OG00KG
00<0emL02=L000SG00<0emL01]L00`3Ge`06e`030=OG00cG00<0emL0HmL00`3Ge`1Se`030=OG00cG
00<0emL01]L00`3Ge`06e`030=OG00OG0007e`030=OG00GG0P08e`030=OG00cG00<0emL0I=L00`3G
e`1Te`030=OG00cG00<0emL01]L200OG00<0emL01]L000KG00<0emL01ML00`3Ge`07e`030=OG00cG
00<0emL0IML00`3Ge`1Ue`030=OG00cG00<0emL01mL00`3Ge`05e`030=OG00GG000=e`030=OG00OG
00<0emL03=L00`3Ge`1Ve`030=OG06KG00<0emL03=L00`3Ge`07e`030=OG00cG000<e`030=OG00OG
00<0emL02mL2063G4`1Pe`803ML00`3Ge`07e`030=OG00_G000;e`030=OG00OG00<0emL02mL00`3G
e`1Fe`X02ML00`3Ge`07e`X0F=L00`3Ge`0;e`030=OG00OG00<0emL02]L000_G00<0emL01]L00`3G
e`0;e`030=OG05CG0`0Ce`030=OG017G0`1Fe`030=OG00_G00<0emL01]L00`3Ge`0:e`002]L00`3G
e`06e`030=OG00_G00<0emL0D=L501KG00<0emL05=L505;G00<0emL02mL00`3Ge`06e`030=OG00WG
0009e`030=OG00KG00<0emL02mL00`3Ge`1<e`D06mL00`3Ge`0Ie`D0C]L00`3Ge`0:e`030=OG00OG
00<0emL02=L000SG00<0emL01mL00`3Ge`0:e`030=OG04[G0`0Pe`030=OG01kG0`1<e`030=OG00[G
00<0emL01mL00`3Ge`07e`001mL00`3Ge`07e`030=OG00[G00<0emL0BML202?G0P0Re`80BmL00`3G
e`0:e`030=OG00OG00<0emL01]L000KG00<0emL01mL00`3Ge`0;e`030=OG04KG0`0Ue`030=OG02?G
0`19e`030=OG00WG00<0emL02=L00`3Ge`05e`004=L00`3Ge`0:e`030=OG04GG0P0Xe`030=OG02KG
0P18e`030=OG00WG00<0emL03mL000oG00<0emL02]L00`3Ge`13e`<0:]L00`3Ge`0Xe`<0AML00`3G
e`0:e`030=OG00kG000>e`030=OG00[G00<0emL0@]L202gG00<0emL0:mL204CG00<0emL02]L00`3G
e`0=e`003ML00`3Ge`0:e`030=OG047G0P0_e`030=OG02gG0P13e`030=OG00[G00<0emL03=L000cG
00<0emL02]L00`3Ge`10e`80<ML00`3Ge`0_e`80@]L00`3Ge`0:e`030=OG00_G000;e`030=OG00[G
00<0emL0?]L302KG6`0Ve`<0@=L00`3Ge`0:e`030=OG00[G000:e`030=OG00[G00<0emL0?ML202CG
1@0=e`030=OG00_G1@0Te`80?mL00`3Ge`0:e`030=OG00WG0009e`030=OG00[G00<0emL0?=L2023G
1P0Be`030=OG013G1P0Pe`80?]L00`3Ge`0:e`030=OG00SG0008e`030=OG00[G00<0emL0?=L201kG
0`0He`030=OG01KG0`0Ne`80?]L00`3Ge`0:e`030=OG00OG0008e`030=OG00[G00<0emL0>]L201cG
100Ke`030=OG01WG100Le`80?=L00`3Ge`0:e`030=OG00OG0007e`030=OG00[G00<0emL0>ML201cG
0P0Oe`030=OG01gG0P0Le`80>mL00`3Ge`0:e`030=OG00KG0007e`030=OG00WG00<0emL0>ML00`3G
e`0Ie`<08ML2023G0`0Ke`030=OG03SG00<0emL02]L00`3Ge`06e`001]L00`3Ge`0:e`030=OG03SG
00<0emL06=L202CG00<0emL08]L201[G00<0emL0>=L00`3Ge`0:e`030=OG00GG000Be`030=OG03SG
00<0emL05mL202KG00<0emL09=L201WG00<0emL0>=L00`3Ge`0Ae`004ML00`3Ge`0he`030=OG01KG
0P0Xe`030=OG02KG0P0He`030=OG03OG00<0emL04ML0017G00<0emL0=mL00`3Ge`0Ee`807MLK01gG
0P0Ge`030=OG03OG00<0emL04=L0013G00<0emL0=]L201KG0P0Ke`@03ML00`3Ge`0;e`@06mL201KG
0P0he`030=OG00oG000?e`030=OG03GG0P0Ee`<06=L5017G00<0emL03mL501SG0`0Ee`80=mL00`3G
e`0>e`003]L00`3Ge`0ee`030=OG01CG00<0emL05ML401KG00<0emL05=L401OG00<0emL05=L00`3G
e`0ee`030=OG00gG000=e`030=OG03GG00<0emL04mL201KG0P0Je`030=OG01SG0P0Fe`805ML00`3G
e`0de`030=OG00gG000=e`030=OG03CG00<0emL04]L201GG0`0Le`030=OG01[G0`0Ee`805=L00`3G
e`0de`030=OG00cG000<e`030=OG03?G0P0Ce`804mL401oG00<0emL07ML401?G0P0Ce`80=ML00`3G
e`0;e`002mL00`3Ge`0ce`030=OG01;G00<0emL04]L00`3Ge`0Qe`030=OG027G00<0emL04]L00`3G
e`0Be`030=OG03;G00<0emL02mL000_G00<0emL0<]L00`3Ge`0Be`030=OG017G0P0Te`030=OG02;G
0P0Ce`030=OG01;G00<0emL0<]L00`3Ge`0:e`002]L00`3Ge`0be`030=OG01;G00<0emL04=L201WG
6`0Ie`804]L00`3Ge`0Be`030=OG03;G00<0emL02ML000[G00<0emL0<ML00`3Ge`0Ae`804ML201OG
100=e`803=L401OG0P0Ae`804mL00`3Ge`0ae`030=OG00WG0009e`030=OG037G00<0emL04=L2017G
0P0Ee`@04ML00`3Ge`0?e`@05ML2017G0P0Be`030=OG037G00<0emL02=L000SG00<0emL0<ML00`3G
e`0@e`030=OG00oG0P0Ee`805ML00`3Ge`0Ce`805ML2017G00<0emL04=L00`3Ge`0ae`030=OG00OG
0008e`030=OG033G00<0emL04=L00`3Ge`0>e`804mL401OG00<0emL05ML401?G0P0@e`030=OG013G
00<0emL0<=L00`3Ge`07e`001mL00`3Ge`0`e`030=OG013G00<0emL03]L00`3Ge`0@e`<06mL00`3G
e`0Ie`<04]L00`3Ge`0>e`030=OG013G00<0emL0<=L00`3Ge`06e`001mL00`3Ge`0_e`030=OG013G
00<0emL03ML2017G0P0Ne`030=OG01cG0P0Ae`803mL00`3Ge`0@e`030=OG02oG00<0emL01]L000KG
00<0emL0<=L00`3Ge`0?e`030=OG00gG00<0emL03]L3023G00<0emL07]L3013G00<0emL03ML00`3G
e`0?e`030=OG033G00<0emL01ML003SG00<0emL03mL00`3Ge`0=e`030=OG00kG00<0emL07ML901oG
00<0emL03]L00`3Ge`0=e`030=OG00oG00<0emL0=mL003OG00<0emL03]L200kG0P0?e`805mL900CG
00<0emL00]L901OG0P0?e`803]L2013G00<0emL0=]L003KG00<0emL03]L00`3Ge`0<e`803mL201CG
1@0=e`030=OG00_G1@0De`803mL200kG00<0emL03]L00`3Ge`0ee`00=ML00`3Ge`0>e`030=OG00cG
00<0emL03ML201?G0`0Be`030=OG013G0`0Ce`803mL00`3Ge`0<e`030=OG00kG00<0emL0==L003GG
00<0emL03ML00`3Ge`0<e`030=OG00cG0P0Ce`805ML00`3Ge`0Ce`804mL200kG00<0emL03=L00`3G
e`0=e`030=OG03CG000de`030=OG00gG00<0emL02mL200gG0P0Be`<00mL200CG00<0emL00]L300KG
00<0emL05ML301;G0P0=e`803=L00`3Ge`0>e`030=OG03?G000ce`030=OG00kG00<0emL02]L00`3G
e`0;e`804]L200GG00@0emL02mL00`3Ge`03e`030=OG01SG0P0Be`803ML00`3Ge`0:e`030=OG00gG
00<0emL0<mL003?G00<0emL03ML00`3Ge`0:e`030=OG00_G00<0emL03mL300OG00@0emL02mL00`3G
e`03e`<06]L3017G00<0emL02mL00`3Ge`0:e`030=OG00gG00<0emL0<]L003;G00<0emL03ML00`3G
e`0;e`030=OG00_G00<0emL03ML200CG1002e`040=OG00SG0`06e`030=OG01gG0P0?e`030=OG00_G
00<0emL02mL00`3Ge`0=e`030=OG037G000ae`030=OG00gG00<0emL02mL00`3Ge`0;e`030=OG00cG
0P0<e`040=OG00SG4`0He`803]L00`3Ge`0;e`030=OG00_G00<0emL03ML00`3Ge`0`e`00<=L00`3G
e`0=e`030=OG00_G00<0emL02]L200gG0P0>e`040=OG00CG1@08e`030=OG00OG100Fe`803ML200cG
00<0emL02mL00`3Ge`0=e`030=OG02oG000_e`030=OG00gG00<0emL02mL00`3Ge`0:e`030=OG00_G
0P0Ae`L01=L400GG00<0emL02mL501?G0P0=e`030=OG00[G00<0emL02mL00`3Ge`0=e`030=OG02kG
000^e`030=OG00gG00<0emL02]L200_G0P0<e`804ML401;G00<0emL04=L4017G0P0<e`802mL200cG
00<0emL03ML00`3Ge`0]e`00;]L00`3Ge`0=e`030=OG00WG00<0emL02]L00`3Ge`0;e`030=OG00oG
0P0Fe`030=OG01CG0P0Ae`030=OG00_G00<0emL02]L00`3Ge`09e`030=OG00gG00<0emL0;ML002gG
00<0emL03ML00`3Ge`09e`030=OG00[G00<0emL02mL00`3Ge`0>e`806=L00`3Ge`0Fe`804=L00`3G
e`0;e`030=OG00[G00<0emL02ML00`3Ge`0=e`030=OG02cG000]e`030=OG00cG00<0emL02]L00`3G
e`09e`030=OG00_G00<0emL03ML201[G00<0emL06=L200oG00<0emL02mL00`3Ge`09e`030=OG00WG
00<0emL03ML00`3Ge`0/e`00;=L00`3Ge`0=e`030=OG00WG00<0emL02ML00`3Ge`0:e`803]L201cG
00<0emL06]L200kG0P0<e`030=OG00WG00<0emL02ML00`3Ge`0=e`030=OG02_G000[e`803]L00`3G
e`09e`030=OG00WG00<0emL02]L00`3Ge`0;e`<06]L901[G0`0=e`030=OG00[G00<0emL02ML00`3G
e`09e`030=OG00cG0P0/e`00:mL00`3Ge`0<e`030=OG00WG00<0emL02ML00`3Ge`09e`803=L201GG
2004e`030=OG00;G200Ee`803=L200_G00<0emL02ML00`3Ge`09e`030=OG00cG00<0emL0:]L002[G
00<0emL03=L00`3Ge`0:e`030=OG00SG00<0emL02ML00`3Ge`0;e`030=OG01?G0P0<e`030=OG00[G
0P0Ee`030=OG00_G00<0emL02ML00`3Ge`08e`030=OG00[G00<0emL03=L00`3Ge`0Ye`00:]L00`3G
e`0<e`030=OG00WG00<0emL02=L00`3Ge`09e`030=OG00_G00<0emL04=L400kG0P0=e`@04]L00`3G
e`0:e`030=OG00[G00<0emL02=L00`3Ge`09e`030=OG00cG00<0emL0:ML002WG00<0emL03=L00`3G
e`0:e`030=OG00OG00<0emL02]L00`3Ge`0:e`030=OG00kG0`0Be`030=OG013G0`0@e`030=OG00[G
00<0emL02ML00`3Ge`08e`030=OG00[G00<0emL03=L00`3Ge`0Xe`00:ML00`3Ge`0<e`030=OG00WG
00<0emL02=L00`3Ge`09e`030=OG00WG0P0?e`805ML00`3Ge`0Ce`803mL200_G00<0emL02ML00`3G
e`08e`030=OG00WG00<0emL03=L00`3Ge`0Xe`00:=L00`3Ge`0<e`030=OG00WG00<0emL02=L00`3G
e`09e`030=OG00WG00<0emL03ML201OG00<0emL05ML200oG00<0emL02ML00`3Ge`09e`030=OG00SG
00<0emL02ML00`3Ge`0;e`030=OG02SG000Xe`030=OG00_G00<0emL02ML00`3Ge`08e`030=OG00WG
00<0emL02=L200kG0P0Ie`030=OG01OG0P0>e`802]L00`3Ge`08e`030=OG00WG00<0emL02=L00`3G
e`0<e`030=OG02OG000We`030=OG00cG00<0emL02ML00`3Ge`08e`030=OG00OG0P0:e`030=OG00cG
0P0Ke`030=OG01WG0P0>e`030=OG00SG0P09e`030=OG00SG00<0emL02ML00`3Ge`0;e`030=OG02OG
000We`030=OG00_G00<0emL02ML00`3Ge`07e`802ML00`3Ge`09e`030=OG00_G0P0Me`030=OG01_G
0P0=e`030=OG00WG00<0emL01mL200WG00<0emL02ML00`3Ge`0;e`030=OG02KG000We`030=OG00_G
00<0emL02=L00`3Ge`07e`030=OG00SG00<0emL02ML00`3Ge`0;e`030=OG01CG4`0Fe`030=OG00_G
00<0emL02=L00`3Ge`09e`030=OG00OG00<0emL02=L00`3Ge`0;e`030=OG02KG000Ve`030=OG00_G
00<0emL02ML00`3Ge`07e`030=OG00SG00<0emL02=L00`3Ge`0:e`804mL400WG00<0emL01mL401?G
0P0<e`030=OG00SG00<0emL02=L00`3Ge`07e`030=OG00SG00<0emL03=L00`3Ge`0Ue`009]L00`3G
e`0;e`030=OG00SG00<0emL01mL00`3Ge`08e`030=OG00SG00<0emL02]L00`3Ge`0@e`<03ML00`3G
e`0;e`<04]L00`3Ge`0:e`030=OG00SG00<0emL02=L00`3Ge`07e`030=OG00SG00<0emL02mL00`3G
e`0Ue`009ML00`3Ge`0;e`030=OG00WG00<0emL01mL00`3Ge`08e`030=OG00OG00<0emL02]L00`3G
e`0?e`804=L00`3Ge`0>e`804ML00`3Ge`0:e`030=OG00OG00<0emL02=L00`3Ge`07e`030=OG00SG
00<0emL03=L00`3Ge`0Te`009ML00`3Ge`0;e`030=OG00SG00<0emL01mL00`3Ge`08e`030=OG00OG
00<0emL02]L00`3Ge`0=e`<04]L00`3Ge`0@e`<03mL00`3Ge`0:e`030=OG00OG00<0emL02=L00`3G
e`07e`030=OG00SG00<0emL02mL00`3Ge`0Te`009ML00`3Ge`0;e`030=OG00SG00<0emL01]L00`3G
e`08e`030=OG00OG00<0emL02]L00`3Ge`0=e`030=OG01?G00<0emL04mL00`3Ge`0=e`030=OG00[G
00<0emL01mL00`3Ge`07e`030=OG00OG00<0emL02=L00`3Ge`0;e`030=OG02CG000Te`030=OG00_G
00<0emL02=L00`3Ge`07e`030=OG00OG00<0emL01mL00`3Ge`0:e`030=OG00cG0P0Fe`030=OG01CG
0P0>e`030=OG00WG00<0emL02=L00`3Ge`07e`030=OG00OG00<0emL02=L00`3Ge`0;e`030=OG02?G
000Te`030=OG00_G00<0emL02=L00`3Ge`07e`030=OG00KG00<0emL02=L00`3Ge`09e`030=OG00cG
00<0emL05]L201OG00<0emL03=L00`3Ge`09e`030=OG00SG00<0emL01]L00`3Ge`07e`030=OG00SG
00<0emL02mL00`3Ge`0Se`008mL00`3Ge`0;e`030=OG00SG00<0emL01mL00`3Ge`06e`030=OG00SG
00<0emL02ML00`3Ge`0;e`806ML00`3Ge`0Ge`803ML00`3Ge`09e`030=OG00OG00<0emL01mL00`3G
e`07e`030=OG00SG00<0emL02mL00`3Ge`0Re`008mL00`3Ge`0;e`030=OG00SG00<0emL01mL00`3G
e`06e`030=OG00SG00<0emL02=L00`3Ge`0;e`030=OG01WG00<0emL06ML00`3Ge`0;e`030=OG00SG
00<0emL02=L00`3Ge`06e`030=OG00OG00<0emL02=L00`3Ge`0;e`030=OG02;G000Re`030=OG00_G
00<0emL02=L00`3Ge`07e`030=OG00KG00<0emL02=L00`3Ge`08e`030=OG00[G0P0He`T06=L200cG
00<0emL02=L00`3Ge`07e`030=OG00OG00<0emL01mL00`3Ge`08e`030=OG00[G00<0emL08]L002;G
00<0emL02mL00`3Ge`07e`030=OG00OG00<0emL01mL00`3Ge`07e`030=OG00SG00<0emL02]L00`3G
e`0Ce`D01=L00`3Ge`02e`D05ML00`3Ge`0:e`030=OG00SG00<0emL01mL00`3Ge`06e`030=OG00OG
00<0emL02=L00`3Ge`0;e`030=OG027G000Qe`030=OG00_G00<0emL02=L00`3Ge`07e`030=OG00KG
00<0emL01mL00`3Ge`08e`030=OG00WG0P0Be`@02ML00`3Ge`07e`@04]L200_G00<0emL02=L00`3G
e`06e`030=OG00OG00<0emL01mL00`3Ge`08e`030=OG00[G00<0emL08ML0027G00<0emL02mL00`3G
e`07e`030=OG00OG00<0emL01mL00`3Ge`06e`030=OG00SG00<0emL02ML00`3Ge`0@e`803ML00`3G
e`0;e`804]L00`3Ge`09e`030=OG00SG00<0emL01]L00`3Ge`07e`030=OG00OG00<0emL01mL00`3G
e`0;e`030=OG023G000Qe`030=OG00_G00<0emL01mL00`3Ge`07e`030=OG00KG00<0emL01mL00`3G
e`07e`030=OG00WG00<0emL03mL200oG00<0emL03ML2017G00<0emL02ML00`3Ge`07e`030=OG00KG
00<0emL01mL00`3Ge`07e`030=OG00OG00<0emL02mL00`3Ge`0Pe`008ML00`3Ge`0:e`030=OG00SG
00<0emL01mL00`3Ge`06e`030=OG00KG00<0emL01mL00`3Ge`09e`030=OG00kG0P0Ae`030=OG00oG
0P0@e`030=OG00SG00<0emL02=L00`3Ge`06e`030=OG00KG00<0emL01mL00`3Ge`08e`030=OG00[G
00<0emL08=L0023G00<0emL02mL00`3Ge`07e`030=OG00OG00<0emL01mL00`3Ge`06e`030=OG00OG
00<0emL02=L00`3Ge`0=e`804mL00`3Ge`0Ae`803]L00`3Ge`09e`030=OG00OG00<0emL01]L00`3G
e`07e`030=OG00KG00<0emL02=L00`3Ge`0;e`030=OG01oG000Pe`030=OG00[G00<0emL02=L00`3G
e`07e`030=OG00KG00<0emL01]L00`3Ge`07e`030=OG00WG00<0emL03=L00`3Ge`0Ce`030=OG01?G
00<0emL03=L00`3Ge`09e`030=OG00KG00<0emL01mL00`3Ge`06e`030=OG00OG00<0emL02=L00`3G
e`0:e`030=OG01oG000Pe`030=OG00[G00<0emL02=L00`3Ge`06e`030=OG00OG00<0emL01]L00`3G
e`07e`030=OG00SG00<0emL03=L00`3Ge`0De`030=OG01CG00<0emL03=L00`3Ge`08e`030=OG00OG
00<0emL01]L00`3Ge`07e`030=OG00KG00<0emL02=L00`3Ge`0:e`030=OG01oG000Pe`030=OG00[G
00<0emL02=L00`3Ge`06e`030=OG00OG00<0emL01]L00`3Ge`06e`030=OG00SG00<0emL03=L00`3G
e`0Ee`030=OG01GG00<0emL02mL00`3Ge`09e`030=OG00KG00<0emL01]L00`3Ge`07e`030=OG00KG
00<0emL02=L00`3Ge`0:e`030=OG01oG000Pe`030=OG00[G00<0emL01mL00`3Ge`07e`030=OG00KG
00<0emL01]L00`3Ge`07e`030=OG00SG00<0emL02mL00`3Ge`0Fe`030=OG01KG00<0emL02mL00`3G
e`08e`030=OG00OG00<0emL01]L00`3Ge`06e`030=OG00OG00<0emL01mL00`3Ge`0:e`030=OG01oG
000Oe`030=OG00[G00<0emL02=L00`3Ge`06e`030=OG00OG00<0emL01]L00`3Ge`06e`030=OG00SG
00<0emL02mL00`3Ge`0Ge`806=L00`3Ge`0;e`030=OG00SG00<0emL01]L00`3Ge`06e`030=OG00OG
00<0emL01]L00`3Ge`08e`030=OG00[G00<0emL07]L001oG00<0emL02]L00`3Ge`07e`030=OG00OG
00<0emL01]L00`3Ge`06e`030=OG00OG00<0emL02=L00`3Ge`0:e`030=OG01SG00<0emL06=L00`3G
e`0:e`030=OG00SG00<0emL01mL00`3Ge`06e`030=OG00KG00<0emL01mL00`3Ge`07e`030=OG00[G
00<0emL07]L001oG00<0emL02]L00`3Ge`07e`030=OG00OG00<0emL01]L00`3Ge`06e`030=OG00KG
00<0emL02=L00`3Ge`0:e`030=OG01WG00<0emL06ML00`3Ge`0:e`030=OG00SG00<0emL01]L00`3G
e`06e`030=OG00KG00<0emL01mL00`3Ge`07e`030=OG00[G00<0emL07]L001oG00<0emL02ML00`3G
e`08e`030=OG00KG00<0emL01]L00`3Ge`06e`030=OG00OG00<0emL01mL00`3Ge`0:e`030=OG01KG
2@0He`030=OG00[G00<0emL01mL00`3Ge`07e`030=OG00GG00<0emL01]L00`3Ge`07e`030=OG00SG
00<0emL02ML00`3Ge`0Ne`007]L00`3Ge`0:e`030=OG00OG00<0emL01mL00`3Ge`06e`030=OG00KG
00<0emL01]L00`3Ge`07e`030=OG00[G00<0emL04]L500CG00<0emL00]L501CG00<0emL02ML00`3G
e`08e`030=OG00KG00<0emL01]L00`3Ge`06e`030=OG00KG00<0emL02=L00`3Ge`09e`030=OG01kG
000Ne`030=OG00[G00<0emL01mL00`3Ge`06e`030=OG00KG00<0emL01]L00`3Ge`07e`030=OG00OG
00<0emL02ML00`3Ge`0@e`<02ML00`3Ge`07e`<04]L00`3Ge`09e`030=OG00OG00<0emL01mL00`3G
e`05e`030=OG00KG00<0emL01mL00`3Ge`07e`030=OG00[G00<0emL07ML001kG00<0emL02]L00`3G
e`07e`030=OG00KG00<0emL01]L00`3Ge`06e`030=OG00KG00<0emL01mL00`3Ge`09e`030=OG013G
00<0emL02]L00`3Ge`0:e`030=OG013G00<0emL02ML00`3Ge`07e`030=OG00KG00<0emL01]L00`3G
e`06e`030=OG00KG00<0emL01mL00`3Ge`0:e`030=OG01gG000Ne`030=OG00[G00<0emL01mL00`3G
e`06e`030=OG00KG00<0emL01]L00`3Ge`06e`030=OG00OG00<0emL02ML00`3Ge`0?e`030=OG00_G
00<0emL02mL00`3Ge`0?e`030=OG00WG00<0emL01mL00`3Ge`06e`030=OG00KG00<0emL01]L00`3G
e`06e`030=OG00OG00<0emL02]L00`3Ge`0Me`007]L00`3Ge`0:e`030=OG00OG00<0emL01]L00`3G
e`06e`030=OG00KG00<0emL01]L00`3Ge`06e`030=OG00WG00<0emL03mL00`3Ge`0<e`030=OG00cG
00<0emL03mL00`3Ge`08e`030=OG00OG00<0emL01]L00`3Ge`06e`030=OG00KG00<0emL01]L00`3G
e`07e`030=OG00_G00<0emL07=L001kG00<0emL02ML00`3Ge`08e`030=OG00KG00<0emL01ML00`3G
e`06e`030=OG00KG00<0emL01mL00`3Ge`09e`030=OG00kG00<0emL03ML00`3Ge`0=e`030=OG00kG
00<0emL02ML00`3Ge`07e`030=OG00KG00<0emL01]L00`3Ge`05e`030=OG00KG00<0emL02=L00`3G
e`0:e`030=OG01cG000Me`030=OG00[G00<0emL01mL00`3Ge`06e`030=OG00KG00<0emL01]L00`3G
e`06e`030=OG00KG00<0emL02ML00`3Ge`0>e`030=OG00kG00<0emL03]L00`3Ge`0>e`030=OG00SG
00<0emL01mL00`3Ge`06e`030=OG00KG00<0emL01]L00`3Ge`06e`030=OG00OG00<0emL02]L00`3G
e`0Le`007ML00`3Ge`0:e`030=OG00OG00<0emL01]L00`3Ge`06e`030=OG00KG00<0emL01]L00`3G
e`06e`030=OG00WG00<0emL03ML00`3Ge`0?e`030=OG00oG00<0emL03ML00`3Ge`09e`030=OG00KG
00<0emL01]L00`3Ge`06e`030=OG00KG00<0emL01]L00`3Ge`07e`030=OG00[G00<0emL07=L001gG
00<0emL02]L00`3Ge`07e`030=OG00KG00<0emL01]L00`3Ge`06e`030=OG00GG00<0emL01mL00`3G
e`08e`030=OG00gG00<0emL04=L00`3Ge`0@e`030=OG00gG00<0emL02=L00`3Ge`06e`030=OG00KG
00<0emL01]L00`3Ge`06e`030=OG00KG00<0emL01mL00`3Ge`0:e`030=OG01cG000Me`030=OG00WG
00<0emL01mL00`3Ge`06e`030=OG00KG00<0emL01]L00`3Ge`06e`030=OG00KG00<0emL02ML00`3G
e`0<e`030=OG017G0P0Be`030=OG00cG00<0emL02=L00`3Ge`07e`030=OG00GG00<0emL01]L00`3G
e`06e`030=OG00KG00<0emL01mL00`3Ge`0:e`030=OG01cG000Me`030=OG00WG00<0emL01mL00`3G
e`06e`030=OG00KG00<0emL01]L00`3Ge`05e`030=OG00OG00<0emL02=L00`3Ge`0<e`030=OG01;G
00<0emL04]L00`3Ge`0<e`030=OG00SG00<0emL01]L00`3Ge`06e`030=OG00KG00<0emL01]L00`3G
e`06e`030=OG00OG00<0emL02ML00`3Ge`0Le`007ML00`3Ge`09e`030=OG00OG00<0emL01]L00`3G
e`06e`030=OG00KG00<0emL01ML00`3Ge`07e`030=OG00SG00<0emL02mL00`3Ge`0Ce`030=OG01?G
00<0emL02mL00`3Ge`08e`030=OG00OG00<0emL01ML00`3Ge`06e`030=OG00KG00<0emL01]L00`3G
e`07e`030=OG00WG00<0emL07=L000OG100Be`030=OG00WG00<0emL01mL00`3Ge`06e`030=OG00KG
00@0e`001=L200?G0`000mL0e`08e`030=OG00SG00<0emL02mL00`3Ge`0Ce`030=OG01?G00<0emL0
2mL00`3Ge`08e`030=OG00OG00@0emOG0P02e`030=L000CG0`08e`030=OG00KG00<0emL01mL00`3G
e`09e`030=OG01;G1006e`002ML00`3Ge`0Ae`030=OG00WG00<0emL01mL00`3Ge`06e`030=OG00KG
0P02e`030=OG00;G00<0emL01=L200WG00<0emL02=L00`3Ge`0;e`030=OG01?G00<0emL04mL00`3G
e`0;e`030=OG00SG00<0emL01mL0103Ge`02e`030=L000SG0P07e`030=OG00KG00<0emL01mL00`3G
e`09e`030=OG01CG00<0emL01ML000WG00<0emL04=L00`3Ge`0:e`030=OG00OG00<0emL01]L00`3G
e`06e`800]L01@3GemL000OG0P08e`030=OG00SG00<0emL02mL00`3Ge`0De`030=OG01CG00<0emL0
2mL00`3Ge`08e`030=OG00KG00@0emL00]L0103Ge`07e`801mL00`3Ge`06e`030=OG00OG00<0emL0
2]L00`3Ge`0Ce`030=OG00GG00000mL0000200CG00<0emL04=L00`3Ge`0:e`030=OG00OG00<0emL0
1]L0103GemL40003e`0000;G00D0emOG0004e`<000?G0=L01mL00`3Ge`08e`030=OG00_G00<0emL0
5=L00`3Ge`0De`030=OG00_G00<0emL02=L00`3Ge`06e`040=OG00;G00@0emL01ML300SG00<0emL0
1]L00`3Ge`07e`030=OG00[G00<0emL04mL00`3Ge`05e`002ML00`3Ge`0@e`030=OG00[G00<0emL0
1mL00`3Ge`06e`030=OG00KG0P02e`050=OGe`001=L01@3GemL000SG00<0emL02=L00`3Ge`0;e`03
0=OG01CG00<0emL05=L00`3Ge`0;e`030=OG00SG00<0emL01]L0103Ge`02e`040=OG00GG00<0e`00
2=L00`3Ge`06e`030=OG00OG00<0emL02]L00`3Ge`0Ce`030=OG00GG0007e`<04]L00`3Ge`0:e`03
0=OG00OG00<0emL01]L00`3Ge`06e`800]L01@3GemL000CG00D0emOG0008e`030=OG00SG00<0emL0
2mL00`3Ge`0De`030=OG01CG00<0emL02mL00`3Ge`08e`030=OG00KG00@0emL00]L0103Ge`05e`03
0=L000SG00<0emL01]L00`3Ge`07e`030=OG00[G00<0emL04ML300OG0009e`030=OG013G00<0emL0
2]L00`3Ge`07e`030=OG00KG00<0emL01]L0103G0004e`030=OG00;G1@08e`030=OG00SG00<0emL0
2mL00`3Ge`0De`030=OG01CG00<0emL02mL00`3Ge`08e`030=OG00KG00@0emOG0P03e`030=OG00?G
1007e`030=OG00KG00<0emL01mL00`3Ge`0:e`030=OG01?G00<0emL01ML001cG00<0emL02]L00`3G
e`07e`030=OG00KG00<0emL01ML00`3Ge`06e`030=OG00GG00<0emL01mL00`3Ge`07e`030=OG00_G
00<0emL05ML00`3Ge`0Ee`030=OG00_G00<0emL01mL00`3Ge`07e`030=OG00GG00<0emL01]L00`3G
e`05e`030=OG00KG00<0emL01mL00`3Ge`0:e`030=OG01_G000Le`030=OG00[G00<0emL01mL00`3G
e`06e`030=OG00GG00<0emL01]L00`3Ge`05e`030=OG00OG00<0emL01mL00`3Ge`0;e`030=OG01GG
00<0emL05ML00`3Ge`0;e`030=OG00OG00<0emL01mL00`3Ge`05e`030=OG00KG00<0emL01ML00`3G
e`06e`030=OG00OG00<0emL02]L00`3Ge`0Ke`007=L00`3Ge`0:e`030=OG00OG00<0emL01]L00`3G
e`05e`030=OG00KG00<0emL01ML00`3Ge`07e`030=OG00OG00<0emL02mL00`3Ge`0Ee`030=OG01GG
00<0emL02mL00`3Ge`07e`030=OG00OG00<0emL01ML00`3Ge`06e`030=OG00GG00<0emL01]L00`3G
e`07e`030=OG00[G00<0emL06mL001cG00<0emL02]L00`3Ge`07e`030=OG00KG00<0emL01ML00`3G
e`06e`030=OG00GG00<0emL01mL00`3Ge`07e`030=OG00_G00<0emL05ML00`3Ge`0Ee`030=OG00_G
00<0emL01mL00`3Ge`07e`030=OG00GG00<0emL01]L00`3Ge`05e`030=OG00KG00<0emL01mL00`3G
e`0:e`030=OG01_G003o02400006e`030=OG00_G00<0emL01ML00`3Ge`03e`030=OG00CG00<0emL0
0mL01@3GemL000SG0P06e`030=OG00CG00<0e`001mL0103Ge`06e`030=OG00CG00@0emL02]L0103G
e`09e`030=OG00_G00<0emL02mL00`3Ge`07e`040=OG00[G00@0emL01]L00`3Ge`04e`040=OG00OG
00<0e`001]L00`3Ge`04e`802=L01@3GemL000GG00<0emL01=L00`3Ge`03e`030=OG00GG00<0emL0
2mL00`3Ge`05e`001]L00`3Ge`0Ce`030=OG00[G00<0emL01mL00`3Ge`06e`030=OG00GG00<0emL0
1=L00`3G0007e`030=OG00OG00<0emL01mL00`3Ge`0;e`030=OG01GG00<0emL05ML00`3Ge`0;e`03
0=OG00OG00<0emL01mL00`3Ge`05e`030=L000KG00<0emL01ML00`3Ge`06e`030=OG00OG00<0emL0
2]L00`3Ge`0Ce`030=OG00GG000Le`030=OG00[G00<0emL01mL00`3Ge`06e`030=OG00GG00<0emL0
1]L00`3Ge`05e`030=OG00OG00<0emL01mL00`3Ge`0;e`030=OG01GG00<0emL05ML00`3Ge`0;e`03
0=OG00OG00<0emL01mL00`3Ge`05e`030=OG00KG00<0emL01ML00`3Ge`06e`030=OG00OG00<0emL0
2]L00`3Ge`0Ke`007=L00`3Ge`0:e`030=OG00OG00<0emL01]L00`3Ge`05e`030=OG00KG00<0emL0
1ML00`3Ge`07e`030=OG00OG00<0emL02mL00`3Ge`0Ee`030=OG01GG00<0emL02mL00`3Ge`07e`03
0=OG00OG00<0emL01ML00`3Ge`06e`030=OG00GG00<0emL01]L00`3Ge`07e`030=OG00[G00<0emL0
6mL001cG00<0emL02]L00`3Ge`07e`030=OG00KG00<0emL01]L00`3Ge`05e`030=OG00KG00<0emL0
1]L00`3Ge`08e`030=OG00_G00<0emL05=L00`3Ge`0De`030=OG00_G00<0emL02=L00`3Ge`06e`03
0=OG00KG00<0emL01ML00`3Ge`06e`030=OG00KG00<0emL01mL00`3Ge`0:e`030=OG01_G000Le`03
0=OG00[G00<0emL01mL00`3Ge`06e`030=OG00KG00<0emL01ML00`3Ge`06e`030=OG00KG00<0emL0
2=L00`3Ge`0;e`030=OG01CG00<0emL05=L00`3Ge`0;e`030=OG00SG00<0emL01]L00`3Ge`06e`03
0=OG00GG00<0emL01]L00`3Ge`06e`030=OG00OG00<0emL02]L00`3Ge`0Ke`007=L00`3Ge`0:e`03
0=OG00OG00<0emL01]L00`3Ge`06e`030=OG00GG00<0emL01]L00`3Ge`06e`030=OG00SG00<0emL0
2mL00`3Ge`0De`030=OG01CG00<0emL02mL00`3Ge`08e`030=OG00KG00<0emL01]L00`3Ge`05e`03
0=OG00KG00<0emL01]L00`3Ge`07e`030=OG00[G00<0emL06mL001cG00<0emL02]L00`3Ge`07e`03
0=OG00KG00<0emL01]L00`3Ge`05e`030=OG00KG00<0emL01]L00`3Ge`08e`030=OG00_G00<0emL0
5=L00`3Ge`0De`030=OG00_G00<0emL02=L00`3Ge`06e`030=OG00KG00<0emL01ML00`3Ge`06e`03
0=OG00KG00<0emL01mL00`3Ge`0:e`030=OG01_G000Le`030=OG00[G00<0emL01mL00`3Ge`06e`03
0=OG00KG00<0emL01ML00`3Ge`06e`030=OG00KG00<0emL02=L00`3Ge`0;e`030=OG01CG00<0emL0
5=L00`3Ge`0;e`030=OG00SG00<0emL01]L00`3Ge`06e`030=OG00GG00<0emL01]L00`3Ge`06e`03
0=OG00OG00<0emL02]L00`3Ge`0Ke`007ML00`3Ge`09e`030=OG00OG00<0emL01]L00`3Ge`06e`03
0=OG00KG00<0emL01ML00`3Ge`07e`030=OG00SG00<0emL02mL00`3Ge`0Ce`030=OG01?G00<0emL0
2mL00`3Ge`08e`030=OG00OG00<0emL01ML00`3Ge`06e`030=OG00KG00<0emL01]L00`3Ge`07e`03
0=OG00WG00<0emL07=L001gG00<0emL02ML00`3Ge`07e`030=OG00KG00<0emL01]L00`3Ge`06e`03
0=OG00GG00<0emL01mL00`3Ge`08e`030=OG00_G00<0emL04mL00`3Ge`0Ce`030=OG00_G00<0emL0
2=L00`3Ge`07e`030=OG00GG00<0emL01]L00`3Ge`06e`030=OG00KG00<0emL01mL00`3Ge`09e`03
0=OG01cG000Me`030=OG00WG00<0emL01mL00`3Ge`06e`030=OG00KG00<0emL01]L00`3Ge`05e`03
0=OG00OG00<0emL02=L00`3Ge`0;e`030=OG01?G00<0emL04mL00`3Ge`0;e`030=OG00SG00<0emL0
1mL00`3Ge`05e`030=OG00KG00<0emL01]L00`3Ge`06e`030=OG00OG00<0emL02ML00`3Ge`0Be`@0
1]L001gG00<0emL02ML00`3Ge`07e`030=OG00KG00<0emL01]L00`3Ge`06e`030=OG00GG00<0emL0
1mL00`3Ge`08e`030=OG00cG00<0emL04]L00`3Ge`0Be`030=OG00cG00<0emL02=L00`3Ge`06e`03
0=OG00KG00<0emL01]L00`3Ge`06e`030=OG00KG00<0emL01mL00`3Ge`09e`030=OG017G1P05e`00
7ML00`3Ge`09e`030=OG00OG00<0emL01]L00`3Ge`06e`030=OG00KG00<0emL01]L00`3Ge`06e`03
0=OG00WG00<0emL03=L00`3Ge`0Ae`804]L00`3Ge`0<e`030=OG00SG00<0emL01mL00`3Ge`05e`03
0=OG00KG00<0emL01]L00`3Ge`06e`030=OG00OG00<0emL02]L00`3Ge`0Ae`H01ML001gG00<0emL0
2]L00`3Ge`07e`030=OG00KG00<0emL01]L00`3Ge`06e`030=OG00GG00<0emL01mL00`3Ge`08e`03
0=OG00gG00<0emL04=L00`3Ge`0@e`030=OG00gG00<0emL02=L00`3Ge`06e`030=OG00KG00<0emL0
1]L00`3Ge`06e`030=OG00KG00<0emL01mL00`3Ge`0:e`030=OG017G1P05e`007ML00`3Ge`0:e`03
0=OG00OG00<0emL01]L00`3Ge`06e`030=OG00KG00<0emL01]L00`3Ge`06e`030=OG00WG00<0emL0
3ML00`3Ge`0?e`030=OG00oG00<0emL03ML00`3Ge`09e`030=OG00KG00<0emL01]L00`3Ge`06e`03
0=OG00KG00<0emL01]L00`3Ge`07e`030=OG00[G00<0emL04ML600GG000Me`030=OG00[G00<0emL0
1mL00`3Ge`06e`030=OG00KG00<0emL01]L00`3Ge`06e`030=OG00KG00<0emL02ML00`3Ge`0>e`03
0=OG00kG00<0emL03]L00`3Ge`0>e`030=OG00SG00<0emL01mL00`3Ge`06e`030=OG00KG00<0emL0
1]L00`3Ge`06e`030=OG00OG00<0emL02]L00`3Ge`0Be`@01]L001kG00<0emL02ML00`3Ge`08e`03
0=OG00KG00<0emL01ML00`3Ge`06e`030=OG00KG00<0emL01mL00`3Ge`09e`030=OG00kG00<0emL0
3ML00`3Ge`0=e`030=OG00kG00<0emL02ML00`3Ge`07e`030=OG00KG00<0emL01]L00`3Ge`05e`03
0=OG00KG00<0emL02=L00`3Ge`0:e`030=OG01cG000Ne`030=OG00[G00<0emL01mL00`3Ge`06e`03
0=OG00KG00<0emL01]L00`3Ge`06e`030=OG00KG00<0emL02ML00`3Ge`0?e`030=OG00cG00<0emL0
3=L00`3Ge`0?e`030=OG00SG00<0emL01mL00`3Ge`06e`030=OG00KG00<0emL01]L00`3Ge`06e`03
0=OG00OG00<0emL02mL00`3Ge`0Le`007]L00`3Ge`0:e`030=OG00OG00<0emL01]L00`3Ge`06e`03
0=OG00KG00<0emL01]L00`3Ge`07e`030=OG00WG00<0emL03mL00`3Ge`0;e`030=OG00_G00<0emL0
3mL00`3Ge`09e`030=OG00OG00<0emL01]L00`3Ge`06e`030=OG00KG00<0emL01]L00`3Ge`07e`03
0=OG00[G00<0emL07ML001kG00<0emL02]L00`3Ge`07e`030=OG00KG00<0emL01]L00`3Ge`06e`03
0=OG00KG00<0emL01mL00`3Ge`09e`030=OG013G00<0emL02]L00`3Ge`0:e`030=OG013G00<0emL0
2ML00`3Ge`07e`030=OG00KG00<0emL01]L00`3Ge`06e`030=OG00KG00<0emL01mL00`3Ge`0:e`03
0=OG01gG000Ne`030=OG00[G00<0emL01mL00`3Ge`06e`030=OG00KG00<0emL01]L00`3Ge`07e`03
0=OG00OG00<0emL02ML00`3Ge`0@e`<02ML00`3Ge`07e`<04]L00`3Ge`09e`030=OG00OG00<0emL0
1mL00`3Ge`05e`030=OG00KG00<0emL01mL00`3Ge`07e`030=OG00[G00<0emL07ML001kG00<0emL0
2]L00`3Ge`07e`030=OG00OG00<0emL01]L00`3Ge`06e`030=OG00KG00<0emL01mL00`3Ge`0:e`03
0=OG01;G1@04e`030=OG00;G1@0De`030=OG00WG00<0emL02=L00`3Ge`06e`030=OG00KG00<0emL0
1]L00`3Ge`06e`030=OG00SG00<0emL02ML00`3Ge`0Ne`007mL00`3Ge`09e`030=OG00SG00<0emL0
1]L00`3Ge`06e`030=OG00KG00<0emL01mL00`3Ge`07e`030=OG00[G00<0emL05]L901SG00<0emL0
2]L00`3Ge`07e`030=OG00OG00<0emL01ML00`3Ge`06e`030=OG00OG00<0emL02=L00`3Ge`09e`03
0=OG01kG000Oe`030=OG00[G00<0emL01mL00`3Ge`07e`030=OG00KG00<0emL01]L00`3Ge`06e`03
0=OG00SG00<0emL02]L00`3Ge`0Ie`030=OG01WG00<0emL02]L00`3Ge`08e`030=OG00KG00<0emL0
1]L00`3Ge`06e`030=OG00OG00<0emL01mL00`3Ge`0:e`030=OG01kG000Oe`030=OG00[G00<0emL0
1mL00`3Ge`07e`030=OG00KG00<0emL01]L00`3Ge`07e`030=OG00SG00<0emL02]L00`3Ge`0He`03
0=OG01SG00<0emL02]L00`3Ge`08e`030=OG00OG00<0emL01]L00`3Ge`06e`030=OG00OG00<0emL0
1mL00`3Ge`0:e`030=OG01kG000Oe`030=OG00[G00<0emL02=L00`3Ge`06e`030=OG00OG00<0emL0
1]L00`3Ge`06e`030=OG00SG00<0emL02mL00`3Ge`0Ge`806=L00`3Ge`0;e`030=OG00SG00<0emL0
1]L00`3Ge`06e`030=OG00OG00<0emL01]L00`3Ge`08e`030=OG00[G00<0emL04ML400WG000Pe`03
0=OG00[G00<0emL01mL00`3Ge`07e`030=OG00KG00<0emL01]L00`3Ge`07e`030=OG00SG00<0emL0
2mL00`3Ge`0Fe`030=OG01KG00<0emL02mL00`3Ge`08e`030=OG00OG00<0emL01]L00`3Ge`06e`03
0=OG00OG00<0emL01mL00`3Ge`0:e`030=OG017G1P08e`008=L00`3Ge`0:e`030=OG00SG00<0emL0
1]L00`3Ge`07e`030=OG00KG00<0emL01]L00`3Ge`08e`030=OG00cG00<0emL05ML00`3Ge`0Ee`03
0=OG00_G00<0emL02ML00`3Ge`06e`030=OG00KG00<0emL01mL00`3Ge`06e`030=OG00SG00<0emL0
2]L00`3Ge`0Ae`H02=L0023G00<0emL02]L00`3Ge`08e`030=OG00KG00<0emL01mL00`3Ge`06e`03
0=OG00OG00<0emL02=L00`3Ge`0<e`030=OG01CG00<0emL05=L00`3Ge`0<e`030=OG00SG00<0emL0
1mL00`3Ge`06e`030=OG00OG00<0emL01]L00`3Ge`08e`030=OG00[G00<0emL04ML600SG000Pe`03
0=OG00[G00<0emL02=L00`3Ge`07e`030=OG00KG00<0emL01]L00`3Ge`07e`030=OG00WG00<0emL0
3=L00`3Ge`0Ce`030=OG01?G00<0emL03=L00`3Ge`09e`030=OG00KG00<0emL01mL00`3Ge`06e`03
0=OG00OG00<0emL02=L00`3Ge`0:e`030=OG017G1P08e`008=L00`3Ge`0;e`030=OG00OG00<0emL0
1mL00`3Ge`07e`030=OG00KG00<0emL01mL00`3Ge`08e`030=OG00gG0P0Ce`030=OG017G0P0>e`03
0=OG00WG00<0emL01mL00`3Ge`06e`030=OG00OG00<0emL01]L00`3Ge`08e`030=OG00_G00<0emL0
4]L400WG000Qe`030=OG00[G00<0emL02=L00`3Ge`07e`030=OG00KG00<0emL01]L00`3Ge`07e`03
0=OG00WG00<0emL03]L2017G00<0emL03mL2013G00<0emL02=L00`3Ge`08e`030=OG00KG00<0emL0
1]L00`3Ge`07e`030=OG00SG00<0emL02]L00`3Ge`0Pe`008ML00`3Ge`0;e`030=OG00OG00<0emL0
1mL00`3Ge`06e`030=OG00OG00<0emL01mL00`3Ge`09e`030=OG00oG0P0?e`030=OG00gG0P0Ae`03
0=OG00WG00<0emL01mL00`3Ge`06e`030=OG00OG00<0emL01mL00`3Ge`07e`030=OG00_G00<0emL0
8=L0027G00<0emL02mL00`3Ge`07e`030=OG00OG00<0emL01mL00`3Ge`06e`030=OG00SG00<0emL0
2ML00`3Ge`0@e`803ML00`3Ge`0;e`804]L00`3Ge`09e`030=OG00SG00<0emL01]L00`3Ge`07e`03
0=OG00OG00<0emL01mL00`3Ge`0;e`030=OG023G000Qe`030=OG00_G00<0emL02=L00`3Ge`07e`03
0=OG00KG00<0emL01mL00`3Ge`08e`030=OG00WG00<0emL04ML400WG00<0emL01mL401?G00<0emL0
2ML00`3Ge`08e`030=OG00KG00<0emL01mL00`3Ge`07e`030=OG00SG00<0emL02]L00`3Ge`0Qe`00
8]L00`3Ge`0;e`030=OG00OG00<0emL01mL00`3Ge`07e`030=OG00OG00<0emL02=L00`3Ge`09e`80
5ML500CG00<0emL00]L501GG0P0;e`030=OG00SG00<0emL01mL00`3Ge`06e`030=OG00OG00<0emL0
2=L00`3Ge`0;e`030=OG027G000Re`030=OG00_G00<0emL02=L00`3Ge`07e`030=OG00KG00<0emL0
2=L00`3Ge`08e`030=OG00[G00<0emL05mL901WG00<0emL02]L00`3Ge`08e`030=OG00OG00<0emL0
1mL00`3Ge`07e`030=OG00SG00<0emL02]L00`3Ge`0Re`008mL00`3Ge`0;e`030=OG00SG00<0emL0
1mL00`3Ge`06e`030=OG00SG00<0emL02=L00`3Ge`0:e`806mL00`3Ge`0Ie`803=L00`3Ge`08e`03
0=OG00SG00<0emL01]L00`3Ge`07e`030=OG00SG00<0emL02mL00`3Ge`0Re`008mL00`3Ge`0;e`03
0=OG00SG00<0emL01mL00`3Ge`06e`030=OG00SG00<0emL02ML00`3Ge`0;e`806ML00`3Ge`0Ge`80
3ML00`3Ge`09e`030=OG00OG00<0emL01mL00`3Ge`07e`030=OG00SG00<0emL02mL00`3Ge`0Re`00
9=L00`3Ge`0;e`030=OG00SG00<0emL01mL00`3Ge`06e`030=OG00SG00<0emL02ML00`3Ge`0<e`03
0=OG01KG0P0Ge`030=OG00cG00<0emL02ML00`3Ge`08e`030=OG00KG00<0emL01mL00`3Ge`08e`03
0=OG00_G00<0emL08mL002CG00<0emL02mL00`3Ge`08e`030=OG00OG00<0emL01mL00`3Ge`07e`03
0=OG00[G00<0emL03=L00`3Ge`0Ee`030=OG01GG00<0emL03=L00`3Ge`09e`030=OG00SG00<0emL0
1mL00`3Ge`07e`030=OG00SG00<0emL02mL00`3Ge`0Be`@03ML002GG00<0emL02mL00`3Ge`08e`03
0=OG00KG00<0emL02=L00`3Ge`07e`030=OG00[G00<0emL03=L201GG00<0emL04mL200kG00<0emL0
2]L00`3Ge`07e`030=OG00OG00<0emL01mL00`3Ge`08e`030=OG00_G00<0emL04]L600cG000Ue`03
0=OG00_G00<0emL02=L00`3Ge`07e`030=OG00SG00<0emL01mL00`3Ge`0:e`030=OG00gG0P0Ce`03
0=OG017G0P0?e`030=OG00[G00<0emL01mL00`3Ge`08e`030=OG00OG00<0emL02=L00`3Ge`0;e`03
0=OG01;G1P0<e`009ML00`3Ge`0;e`030=OG00WG00<0emL01mL00`3Ge`08e`030=OG00OG00<0emL0
2]L00`3Ge`0>e`804ML00`3Ge`0?e`804=L00`3Ge`0:e`030=OG00OG00<0emL02=L00`3Ge`07e`03
0=OG00SG00<0emL03=L00`3Ge`0Be`H03=L002KG00<0emL02mL00`3Ge`08e`030=OG00OG00<0emL0
2=L00`3Ge`08e`030=OG00[G00<0emL03mL300kG00<0emL03=L3017G00<0emL02]L00`3Ge`08e`03
0=OG00SG00<0emL01mL00`3Ge`08e`030=OG00_G00<0emL04mL600cG000Ve`030=OG00_G00<0emL0
2ML00`3Ge`07e`030=OG00SG00<0emL02=L00`3Ge`0:e`030=OG017G1@09e`030=OG00OG1@0Ce`03
0=OG00[G00<0emL02=L00`3Ge`08e`030=OG00OG00<0emL02=L00`3Ge`0<e`030=OG01CG100=e`00
9mL00`3Ge`0;e`030=OG00SG00<0emL01mL00`3Ge`08e`030=OG00WG00<0emL02]L201KG4`0Fe`80
3=L00`3Ge`08e`030=OG00WG00<0emL01mL00`3Ge`08e`030=OG00_G00<0emL09]L002OG00<0emL0
2mL00`3Ge`09e`030=OG00OG0P09e`030=OG00WG00<0emL02mL201gG00<0emL06mL200gG00<0emL0
2ML00`3Ge`07e`802ML00`3Ge`09e`030=OG00_G00<0emL09]L002OG00<0emL03=L00`3Ge`09e`03
0=OG00SG00<0emL01mL00`3Ge`09e`030=OG00cG0P0Ke`030=OG01WG0P0>e`030=OG00WG00<0emL0
1mL00`3Ge`08e`030=OG00WG00<0emL02mL00`3Ge`0We`00:=L00`3Ge`0;e`030=OG00WG00<0emL0
2=L00`3Ge`08e`802]L00`3Ge`0=e`806ML00`3Ge`0Ge`803mL00`3Ge`08e`802ML00`3Ge`09e`03
0=OG00SG00<0emL03=L00`3Ge`0We`00:=L00`3Ge`0<e`030=OG00WG00<0emL02=L00`3Ge`09e`03
0=OG00SG0P0?e`805mL00`3Ge`0Ee`803mL200[G00<0emL02ML00`3Ge`08e`030=OG00WG00<0emL0
2mL00`3Ge`0Xe`00:ML00`3Ge`0<e`030=OG00WG00<0emL02=L00`3Ge`09e`030=OG00WG0P0?e`80
5ML00`3Ge`0Ce`803mL200_G00<0emL02ML00`3Ge`08e`030=OG00WG00<0emL03=L00`3Ge`0Xe`00
:ML00`3Ge`0<e`030=OG00[G00<0emL01mL00`3Ge`0:e`030=OG00[G00<0emL03]L301;G00<0emL0
4=L3013G00<0emL02]L00`3Ge`09e`030=OG00SG00<0emL02]L00`3Ge`0<e`030=OG02SG000Ze`03
0=OG00cG00<0emL02ML00`3Ge`08e`030=OG00WG00<0emL02mL00`3Ge`0@e`<03mL200kG0`0Be`03
0=OG00[G00<0emL02]L00`3Ge`08e`030=OG00WG00<0emL03=L00`3Ge`0Ye`00:]L00`3Ge`0<e`03
0=OG00[G00<0emL02=L00`3Ge`09e`030=OG00_G00<0emL04]L200gG00<0emL02mL201CG00<0emL0
2mL00`3Ge`09e`030=OG00SG00<0emL02]L00`3Ge`0<e`030=OG01;G100Ce`00:mL00`3Ge`0<e`03
0=OG00WG00<0emL02ML00`3Ge`09e`030=OG00_G0P0De`T01=L00`3Ge`02e`T05=L200gG00<0emL0
2ML00`3Ge`09e`030=OG00WG00<0emL03=L00`3Ge`0Be`H04]L002_G0P0>e`030=OG00WG00<0emL0
2ML00`3Ge`09e`803ML201_G2@0Ke`803ML200_G00<0emL02ML00`3Ge`09e`030=OG00cG0P0De`H0
4]L002cG00<0emL03ML00`3Ge`09e`030=OG00WG00<0emL02]L200gG0`0Le`030=OG01[G0`0=e`80
3=L00`3Ge`09e`030=OG00WG00<0emL03ML00`3Ge`0Ce`H04]L002gG00<0emL03=L00`3Ge`0:e`03
0=OG00WG00<0emL02mL00`3Ge`0=e`806]L00`3Ge`0He`803mL00`3Ge`0;e`030=OG00WG00<0emL0
2ML00`3Ge`0=e`030=OG01CG1P0Be`00;ML00`3Ge`0=e`030=OG00WG00<0emL02]L00`3Ge`0;e`03
0=OG00kG0P0He`030=OG01KG0P0@e`030=OG00_G00<0emL02]L00`3Ge`09e`030=OG00gG00<0emL0
5ML401?G000^e`030=OG00gG00<0emL02ML00`3Ge`0:e`030=OG00_G00<0emL03mL201KG00<0emL0
5=L2017G00<0emL02mL00`3Ge`0:e`030=OG00WG00<0emL03ML00`3Ge`0]e`00;]L00`3Ge`0=e`03
0=OG00[G0P0;e`030=OG00_G00<0emL04=L401;G00<0emL04=L401;G00<0emL02mL00`3Ge`09e`80
3=L00`3Ge`0=e`030=OG02gG000_e`030=OG00gG00<0emL02mL00`3Ge`09e`803=L201CG100>e`03
0=OG00cG100De`803=L200_G00<0emL02mL00`3Ge`0=e`030=OG02kG000`e`030=OG00gG00<0emL0
2mL00`3Ge`0:e`030=OG00_G0P0Fe`D02ML00`3Ge`07e`D05]L200gG00<0emL02]L00`3Ge`0;e`03
0=OG00gG00<0emL0;mL0037G00<0emL03ML00`3Ge`0;e`030=OG00[G0P0=e`803]L200CG00<0emL0
0]LC01WG0P0=e`803=L00`3Ge`0;e`030=OG00gG00<0emL0<=L003;G00<0emL03ML00`3Ge`0;e`03
0=OG00_G00<0emL03=L300[G00@0emL02mL00`3Ge`03e`030=OG01gG0`0>e`030=OG00_G00<0emL0
2mL00`3Ge`0=e`030=OG037G000ce`030=OG00gG00<0emL02]L00`3Ge`0;e`030=OG00oG0`07e`04
0=OG00_G00<0emL00mL301[G0`0Ae`030=OG00_G00<0emL02]L00`3Ge`0=e`030=OG03;G000ce`03
0=OG00kG00<0emL02]L00`3Ge`0;e`804]L200GG00@0emL02=L300KG00<0emL06=L201;G0P0=e`03
0=OG00[G00<0emL03ML00`3Ge`0ce`00==L00`3Ge`0=e`030=OG00_G0P0=e`804]L200?G00@0emL0
2=L00`3Ge`06e`030=OG01KG0P0Be`803ML200cG00<0emL03]L00`3Ge`0Ee`@06]L003GG00<0emL0
3ML00`3Ge`0<e`030=OG00cG00<0emL04ML20005e`3Ge`002=L00`3Ge`06e`030=OG01CG0P0Ce`03
0=OG00cG00<0emL03=L00`3Ge`0=e`030=OG01GG1P0Ie`00=ML00`3Ge`0>e`030=OG00cG00<0emL0
3=L301;G1009e`@01ML00`3Ge`0@e`@04]L300kG00<0emL03=L00`3Ge`0>e`030=OG01GG1P0Ie`00
=]L00`3Ge`0>e`030=OG00cG0P0?e`805=L400kG00<0emL03=L401CG0P0?e`803]L00`3Ge`0>e`03
0=OG01KG1P0Ie`00=mL00`3Ge`0>e`030=OG00gG0P0?e`030=OG01GG2P04e`030=OG00;G2P0Ge`03
0=OG00gG0P0?e`030=OG00kG00<0emL05mL601WG000he`030=OG00kG0P0?e`030=OG00gG0P0Oe`T0
7mL200oG00<0emL03ML2013G00<0emL06ML401[G0006e`030=OG033G00<0emL03mL00`3Ge`0=e`03
0=OG00kG0`0Pe`030=OG01kG0`0@e`030=OG00gG00<0emL03mL00`3Ge`0`e`030=OG00GG0007e`03
0=OG02oG00<0emL04=L00`3Ge`0=e`804ML201kG00<0emL07=L2017G0P0?e`030=OG013G00<0emL0
;mL00`3Ge`06e`001mL00`3Ge`0`e`030=OG013G00<0emL03]L00`3Ge`0@e`<06mL00`3Ge`0Ie`<0
4]L00`3Ge`0>e`030=OG013G00<0emL0<=L00`3Ge`06e`002=L00`3Ge`0`e`030=OG013G00<0emL0
3]L201?G0`0He`030=OG01KG0`0Ce`804=L00`3Ge`0@e`030=OG033G00<0emL01mL000SG00<0emL0
<ML00`3Ge`0@e`030=OG00oG0P0De`805]L00`3Ge`0De`805=L2017G00<0emL04=L00`3Ge`0ae`03
0=OG00OG0009e`030=OG037G00<0emL04=L2017G0P0De`D04ML00`3Ge`0?e`D05=L2017G0P0Be`03
0=OG037G00<0emL02=L000[G00<0emL0<ML00`3Ge`0Ae`030=OG013G0P0Ge`<03]L200gG0`0Ge`80
4]L00`3Ge`0Ae`030=OG01KG100Ge`030=OG00WG000:e`030=OG03;G00<0emL04ML201;G0P0Head0
6=L201;G0P0Ce`030=OG01KG1P0Fe`030=OG00WG000;e`030=OG03;G00<0emL04]L00`3Ge`0Ae`03
0=OG02?G00<0emL08mL00`3Ge`0Ae`030=OG01;G00<0emL05mL601GG00<0emL02]L000_G00<0emL0
<mL00`3Ge`0Be`030=OG017G0P0Se`030=OG027G0P0Ce`030=OG01;G00<0emL06=L601CG00<0emL0
2mL000cG00<0emL0<mL201?G0P0Ce`<08=L00`3Ge`0Ne`<04mL201?G0P0Ke`H05=L00`3Ge`0;e`00
3ML00`3Ge`0de`030=OG01;G0P0De`@07=L00`3Ge`0Je`@05=L201CG00<0emL07=L401CG00<0emL0
3=L000gG00<0emL0=ML00`3Ge`0Ce`030=OG01GG0P0Je`030=OG01SG0P0Ge`030=OG01?G00<0emL0
==L00`3Ge`0=e`003]L00`3Ge`0ee`030=OG01?G0P0Ge`<05mL00`3Ge`0Ee`<05mL201GG00<0emL0
=ML00`3Ge`0=e`003mL00`3Ge`0ee`805ML201SG1P0Ae`030=OG00oG1P0He`805ML203OG00<0emL0
3]L0013G00<0emL0=]L00`3Ge`0De`807=L300kG00<0emL03=L301cG0P0Fe`030=OG03KG00<0emL0
3mL0017G00<0emL0=]L201KG0`0Lead07=L301KG0P0he`030=OG013G000Ae`030=OG03SG00<0emL0
5]L202SG00<0emL09]L201SG00<0emL0=mL00`3Ge`0Ae`004]L00`3Ge`0he`030=OG01OG0P0Ve`03
0=OG02CG0P0Ie`030=OG01_G100Ie`030=OG017G0006e`030=OG00[G00<0emL0>=L00`3Ge`0He`80
9=L00`3Ge`0Re`806]L00`3Ge`0Ke`H05mL00`3Ge`0:e`030=OG00GG0007e`030=OG00WG00<0emL0
>ML00`3Ge`0Ie`<08ML2023G0`0Ke`030=OG01cG1P0Fe`030=OG00[G00<0emL01]L000OG00<0emL0
2]L00`3Ge`0ie`807=L201oG00<0emL07ML201cG0P0Oe`H05]L00`3Ge`0:e`030=OG00KG0008e`03
0=OG00[G00<0emL0>]L201cG100Ke`030=OG01WG100Le`808ML601GG00<0emL02]L00`3Ge`07e`00
2=L00`3Ge`0:e`030=OG03cG0P0Ne`<06=L00`3Ge`0Fe`<07]L202CG100Fe`030=OG00[G00<0emL0
1mL000WG00<0emL02]L00`3Ge`0le`808=L601;G00<0emL04=L6023G0P0ne`030=OG00[G00<0emL0
2=L000[G00<0emL02]L00`3Ge`0me`809=L400kG00<0emL03=L402CG0P0oe`030=OG00[G00<0emL0
2ML000_G00<0emL02]L00`3Ge`0ne`809]LM02KG0P10e`030=OG00[G00<0emL02]L000cG00<0emL0
2]L00`3Ge`0oe`80<]L00`3Ge`0`e`80@ML00`3Ge`0:e`030=OG00_G000=e`030=OG00[G00<0emL0
@=L302oG00<0emL0;ML3027G100Me`030=OG00[G00<0emL03=L000kG00<0emL02]L00`3Ge`12e`80
;ML00`3Ge`0[e`808mL601_G00<0emL02]L00`3Ge`0=e`003mL00`3Ge`0:e`030=OG04?G0`0Ze`03
0=OG02SG0`0Ue`H06]L00`3Ge`0:e`030=OG00kG000@e`030=OG00[G00<0emL0AML202SG00<0emL0
9]L202SG1P0Je`030=OG00WG00<0emL03mL000KG00<0emL01mL00`3Ge`0;e`030=OG04KG0P0Ve`03
0=OG02CG0P0Ze`H06ML00`3Ge`09e`030=OG00SG00<0emL01ML000OG00<0emL01mL00`3Ge`0:e`03
0=OG04SG0P0Te`808mL202gG100Ie`030=OG00[G00<0emL01mL00`3Ge`06e`002=L00`3Ge`07e`03
0=OG00[G00<0emL0BML4023G00<0emL07]L404_G00<0emL02]L00`3Ge`07e`030=OG00OG0009e`03
0=OG00KG00<0emL02mL00`3Ge`1<e`D06mL00`3Ge`0Ie`D0C]L00`3Ge`0:e`030=OG00OG00<0emL0
2=L000[G00<0emL01]L00`3Ge`0;e`030=OG053G100Ge`030=OG01GG101Be`030=OG00_G00<0emL0
1]L00`3Ge`09e`002mL00`3Ge`06e`803=L205CG1P0Ae`030=OG00oG1P0`e`@08=L200cG0P08e`03
0=OG00[G000<e`030=OG00OG00<0emL02mL00`3Ge`1Ge`P02ML00`3Ge`07e`P0=ML601kG00<0emL0
2mL00`3Ge`07e`030=OG00_G000=e`030=OG00OG00<0emL02mL00`3Ge`1Nea<0?ML601gG00<0emL0
2mL00`3Ge`07e`030=OG00cG000=e`030=OG00OG00<0emL03=L00`3Ge`1Ve`030=OG04CG1P0Le`03
0=OG00cG00<0emL01mL00`3Ge`0<e`001]L00`3Ge`05e`030=OG00OG00<0emL03=L00`3Ge`1Ue`03
0=OG04CG1P0Ke`030=OG00cG00<0emL01mL00`3Ge`05e`030=OG00GG0007e`030=OG00GG0P08e`03
0=OG00cG00<0emL0I=L00`3Ge`15e`@06mL00`3Ge`0<e`030=OG00KG0P07e`030=OG00KG0008e`03
0=OG00KG00<0emL01]L00`3Ge`0<e`030=OG06?G00<0emL0HmL00`3Ge`0<e`030=OG00KG00<0emL0
1]L00`3Ge`07e`002ML00`3Ge`06e`030=OG00KG0P0=e`030=OG06;G00<0emL0=mL402OG00<0emL0
3=L00`3Ge`06e`030=OG00KG00<0emL02=L000[G00<0emL01ML00`3Ge`08e`030=OG00_G00<0emL0
HML00`3Ge`0fe`H09ML00`3Ge`0<e`030=OG00OG00<0emL01ML00`3Ge`09e`002mL00`3Ge`05e`03
0=OG00SG00<0emL02mL2067G00<0emL0=]L602?G0P0>e`030=OG00OG00<0emL01ML00`3Ge`0:e`00
3=L00`3Ge`05e`030=OG00OG00<0emL03ML00`3Ge`1Ne`80=mL602;G00<0emL03ML00`3Ge`07e`03
0=OG00GG00<0emL02mL000KG00<0emL01=L00`3Ge`05e`030=OG00OG00<0emL03ML205kG00<0emL0
=]L6023G0P0?e`030=OG00OG00<0emL01ML00`3Ge`04e`030=OG00GG0007e`030=OG00CG00<0emL0
1ML200SG0P0?e`030=OG05_G00<0emL0=mL4023G00<0emL03ML200SG0P07e`030=OG00CG00<0emL0
1]L000SG00<0emL01=L00`3Ge`06e`030=OG00OG00<0emL03ML205_G00<0emL0:ML402cG0P0?e`03
0=OG00OG00<0emL01]L00`3Ge`04e`030=OG00OG0009e`030=OG00CG00<0emL01]L00`3Ge`07e`80
3mL00`3Ge`1He`030=OG02SG1P0Ze`030=OG00gG0P09e`030=OG00KG00<0emL01=L00`3Ge`08e`00
2]L00`3Ge`04e`030=OG00GG00<0emL02ML00`3Ge`0=e`030=OG05OG00<0emL0:=L602WG00<0emL0
3ML00`3Ge`09e`030=OG00GG00<0emL01=L00`3Ge`09e`002mL00`3Ge`04e`030=OG00GG00<0emL0
2ML00`3Ge`0=e`030=OG05KG00<0emL0:=L602SG00<0emL03ML00`3Ge`09e`030=OG00GG00<0emL0
1=L00`3Ge`0:e`003=L00`3Ge`04e`030=OG00GG0P0:e`030=OG00gG0P1Fe`030=OG01_G1009e`H0
9]L200oG00<0emL02ML00`3Ge`05e`030=OG00CG00<0emL02mL000KG00<0emL01=L00`3Ge`04e`03
0=OG00KG00<0emL02=L00`3Ge`0>e`030=OG05?G00<0emL06]L600WG100Ve`030=OG00kG00<0emL0
2ML00`3Ge`05e`030=OG00CG00<0emL01=L00`3Ge`05e`001mL00`3Ge`04e`030=OG00CG00<0emL0
1]L00`3Ge`08e`030=OG00kG0P1Ce`030=OG01[G1P0ae`804=L00`3Ge`08e`801mL00`3Ge`04e`03
0=OG00CG00<0emL01]L000SG00<0emL01=L00`3Ge`04e`030=OG00KG00<0emL02=L00`3Ge`0?e`80
DML00`3Ge`0;e`@02mL602oG0P0Ae`030=OG00SG00<0emL01]L00`3Ge`04e`030=OG00CG00<0emL0
1mL000WG00<0emL01=L00`3Ge`04e`030=OG00KG00<0emL02=L00`3Ge`0@e`030=OG04gG100:e`H0
2]L602kG00<0emL04=L00`3Ge`08e`030=OG00KG00<0emL01=L00`3Ge`04e`030=OG00SG000:e`03
0=OG00CG00<0emL01=L00`3Ge`06e`030=OG00SG0P0Ae`80AML400?G1P09e`H02mL402gG0P0Ae`80
2]L00`3Ge`06e`030=OG00CG00<0emL01=L00`3Ge`09e`002mL00`3Ge`04e`030=OG00CG00<0emL0
1]L00`3Ge`09e`804ML204GG00<0emL00]L600WG1P0je`804ML200_G00<0emL01]L00`3Ge`04e`03
0=OG00CG00<0emL02]L000cG00<0emL01=L00`3Ge`04e`030=OG00KG00<0emL02]L00`3Ge`0@e`03
0=OG04;G00<0emL00]L600WG1P0ie`030=OG013G00<0emL02]L00`3Ge`06e`030=OG00CG00<0emL0
1=L00`3Ge`0;e`00R=L00`3Ge`02e`H02]L407oG0028e`030=OG00?G102>e`00Q]L300KG00<0emL0
S]L008SG00<0emL01=L00`3Ge`2>e`00SmL00`3Ge`2>e`00SmL00`3Ge`2>e`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.05001, -1.05001, 0.00731715, \
0.00731715}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
gxy[x_,y_]:=fxy[x,y]/; x^2+y^2<=R^2
Off[Plot3D::plnc];Off[Plot3D::gval];
Plot3D[-gxy[x,y],{x,-1.,1.},{y,-1.,1.},PlotPoints->50]\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -12 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -15.8219 -9 ]
[.50253 .05935 2.17811 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 12 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 24 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 18 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.01802 .30332 -48 -2.77461 ]
[.01802 .30332 0 6.22539 ]
[.00371 .39298 -48 -2.85069 ]
[.00371 .39298 0 6.14931 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-1)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(-0.5)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(0.5)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03027 .29862 m
.0364 .29627 L
s
[(-0.00004)] .01802 .30332 1 -0.38342 Mshowa
.01603 .38846 m
.02219 .38621 L
s
[(-0.00002)] .00371 .39298 1 -0.36651 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(0)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02679 .32061 m
.03047 .31921 L
s
.02325 .3429 m
.02694 .34152 L
s
.01967 .36552 m
.02336 .36415 L
s
.01234 .41174 m
.01604 .4104 L
s
.0086 .43535 m
.01231 .43403 L
s
.0048 .45931 m
.00852 .458 L
s
.03371 .27694 m
.03738 .27552 L
s
.03709 .25556 m
.04076 .25412 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.671 .73 .894 r
.5921 .73866 .59823 .74577 .61019 .74248 .60407 .7348 Metetra
.67 .715 .882 r
.60407 .7348 .61019 .74248 .62219 .73909 .61609 .73092 Metetra
.667 .702 .873 r
.61609 .73092 .62219 .73909 .63424 .73566 .62815 .72709 Metetra
.664 .692 .866 r
.62815 .72709 .63424 .73566 .64634 .73224 .64027 .72336 Metetra
.659 .684 .862 r
.64027 .72336 .64634 .73224 .6585 .72885 .65245 .71975 Metetra
.655 .678 .86 r
.65245 .71975 .6585 .72885 .67071 .72553 .66468 .71631 Metetra
.65 .674 .86 r
.66468 .71631 .67071 .72553 .68297 .72229 .67697 .71304 Metetra
.645 .672 .861 r
.67697 .71304 .68297 .72229 .6953 .71913 .68933 .70994 Metetra
.641 .672 .864 r
.68933 .70994 .6953 .71913 .70768 .71603 .70174 .707 Metetra
.637 .675 .869 r
.70174 .707 .70768 .71603 .72012 .71297 .71423 .70419 Metetra
.634 .68 .876 r
.71423 .70419 .72012 .71297 .73262 .70992 .72678 .70148 Metetra
.632 .689 .885 r
.72678 .70148 .73262 .70992 .74517 .70682 .73939 .69883 Metetra
.631 .7 .896 r
.73939 .69883 .74517 .70682 .75778 .70363 .75206 .69616 Metetra
.68 .738 .895 r
.55018 .74251 .55645 .74941 .56829 .74605 .56204 .73834 Metetra
.682 .718 .876 r
.56204 .73834 .56829 .74605 .58017 .74243 .57394 .734 Metetra
.682 .7 .861 r
.57394 .734 .58017 .74243 .5921 .73866 .58588 .72956 Metetra
.679 .685 .849 r
.58588 .72956 .5921 .73866 .60407 .7348 .59787 .72512 Metetra
.675 .672 .84 r
.59787 .72512 .60407 .7348 .61609 .73092 .6099 .72075 Metetra
.67 .661 .833 r
.6099 .72075 .61609 .73092 .62815 .72709 .62198 .71652 Metetra
.665 .652 .828 r
.62198 .71652 .62815 .72709 .64027 .72336 .63411 .71247 Metetra
.659 .645 .825 r
.63411 .71247 .64027 .72336 .65245 .71975 .6463 .70864 Metetra
.652 .639 .824 r
.6463 .70864 .65245 .71975 .66468 .71631 .65854 .70507 Metetra
.646 .635 .824 r
.65854 .70507 .66468 .71631 .67697 .71304 .67085 .70177 Metetra
.64 .632 .826 r
.67085 .70177 .67697 .71304 .68933 .70994 .68323 .69873 Metetra
.634 .631 .829 r
.68323 .69873 .68933 .70994 .70174 .707 .69567 .69595 Metetra
.629 .632 .834 r
.69567 .69595 .70174 .707 .71423 .70419 .70819 .69339 Metetra
.624 .635 .84 r
.70819 .69339 .71423 .70419 .72678 .70148 .72078 .69103 Metetra
.621 .64 .848 r
.72078 .69103 .72678 .70148 .73939 .69883 .73344 .68881 Metetra
.618 .648 .858 r
.73344 .68881 .73939 .69883 .75206 .69616 .74617 .68667 Metetra
.617 .66 .869 r
.74617 .68667 .75206 .69616 .76479 .6934 .75897 .68452 Metetra
.618 .675 .882 r
.75897 .68452 .76479 .6934 .77757 .69049 .77183 .68229 Metetra
.621 .695 .897 r
.77183 .68229 .77757 .69049 .79039 .68731 .78474 .67988 Metetra
.687 .74 .891 r
.52022 .74299 .5266 .74988 .53837 .74639 .53202 .73857 Metetra
.692 .717 .868 r
.53202 .73857 .53837 .74639 .55018 .74251 .54386 .73381 Metetra
.693 .698 .85 r
.54386 .73381 .55018 .74251 .56204 .73834 .55573 .72883 Metetra
.691 .681 .835 r
.55573 .72883 .56204 .73834 .57394 .734 .56765 .72375 Metetra
.687 .666 .824 r
.56765 .72375 .57394 .734 .58588 .72956 .5796 .71865 Metetra
.682 .653 .815 r
.5796 .71865 .58588 .72956 .59787 .72512 .5916 .71363 Metetra
.677 .642 .808 r
.5916 .71363 .59787 .72512 .6099 .72075 .60364 .70876 Metetra
.67 .632 .803 r
.60364 .70876 .6099 .72075 .62198 .71652 .61572 .70412 Metetra
.663 .624 .8 r
.61572 .70412 .62198 .71652 .63411 .71247 .62786 .69975 Metetra
.656 .617 .798 r
.62786 .69975 .63411 .71247 .6463 .70864 .64005 .6957 Metetra
.649 .611 .797 r
.64005 .6957 .6463 .70864 .65854 .70507 .65231 .692 Metetra
.642 .606 .798 r
.65231 .692 .65854 .70507 .67085 .70177 .66463 .68866 Metetra
.635 .602 .8 r
.66463 .68866 .67085 .70177 .68323 .69873 .67702 .68568 Metetra
.628 .6 .803 r
.67702 .68568 .68323 .69873 .69567 .69595 .68949 .68305 Metetra
.621 .599 .807 r
.68949 .68305 .69567 .69595 .70819 .69339 .70203 .68075 Metetra
.615 .601 .813 r
.70203 .68075 .70819 .69339 .72078 .69103 .71465 .67873 Metetra
.61 .604 .82 r
.71465 .67873 .72078 .69103 .73344 .68881 .72736 .67695 Metetra
.606 .609 .828 r
.72736 .67695 .73344 .68881 .74617 .68667 .74014 .67532 Metetra
.603 .617 .839 r
.74014 .67532 .74617 .68667 .75897 .68452 .753 .67379 Metetra
.602 .629 .85 r
.753 .67379 .75897 .68452 .77183 .68229 .76593 .67225 Metetra
.603 .644 .864 r
.76593 .67225 .77183 .68229 .78474 .67988 .77892 .6706 Metetra
.606 .663 .879 r
.77892 .6706 .78474 .67988 .7977 .67718 .79197 .66874 Metetra
.613 .688 .896 r
.79197 .66874 .7977 .67718 .81069 .67409 .80507 .66655 Metetra
.699 .726 .872 r
.50202 .73945 .50847 .74697 .52022 .74299 .5138 .73447 Metetra
.702 .704 .849 r
.5138 .73447 .52022 .74299 .53202 .73857 .52563 .72911 Metetra
.702 .685 .831 r
.52563 .72911 .53202 .73857 .54386 .73381 .53749 .72347 Metetra
.7 .669 .817 r
.53749 .72347 .54386 .73381 .55573 .72883 .54938 .71768 Metetra
.695 .655 .805 r
.54938 .71768 .55573 .72883 .56765 .72375 .56131 .71186 Metetra
.69 .642 .796 r
.56131 .71186 .56765 .72375 .5796 .71865 .57327 .7061 Metetra
.684 .63 .79 r
.57327 .7061 .5796 .71865 .5916 .71363 .58527 .70049 Metetra
.677 .62 .784 r
.58527 .70049 .5916 .71363 .60364 .70876 .59731 .69513 Metetra
.67 .611 .781 r
.59731 .69513 .60364 .70876 .61572 .70412 .6094 .69008 Metetra
.662 .603 .778 r
.6094 .69008 .61572 .70412 .62786 .69975 .62154 .68539 Metetra
.654 .596 .777 r
.62154 .68539 .62786 .69975 .64005 .6957 .63374 .68112 Metetra
.646 .59 .777 r
.63374 .68112 .64005 .6957 .65231 .692 .64599 .67728 Metetra
.638 .584 .778 r
.64599 .67728 .65231 .692 .66463 .68866 .65832 .67391 Metetra
.63 .58 .78 r
.65832 .67391 .66463 .68866 .67702 .68568 .67072 .67098 Metetra
.622 .577 .783 r
.67072 .67098 .67702 .68568 .68949 .68305 .6832 .66851 Metetra
.614 .575 .787 r
.6832 .66851 .68949 .68305 .70203 .68075 .69577 .66645 Metetra
.607 .575 .792 r
.69577 .66645 .70203 .68075 .71465 .67873 .70842 .66477 Metetra
.6 .576 .798 r
.70842 .66477 .71465 .67873 .72736 .67695 .72115 .66342 Metetra
.594 .579 .806 r
.72115 .66342 .72736 .67695 .74014 .67532 .73398 .66231 Metetra
.59 .585 .815 r
.73398 .66231 .74014 .67532 .753 .67379 .74689 .66138 Metetra
.587 .593 .826 r
.74689 .66138 .753 .67379 .76593 .67225 .75988 .66052 Metetra
.586 .605 .838 r
.75988 .66052 .76593 .67225 .77892 .6706 .77295 .65964 Metetra
.587 .62 .852 r
.77295 .65964 .77892 .6706 .79197 .66874 .78609 .65862 Metetra
.591 .639 .867 r
.78609 .65862 .79197 .66874 .80507 .66655 .79928 .65733 Metetra
.599 .664 .885 r
.79928 .65733 .80507 .66655 .8182 .6639 .81252 .65564 Metetra
.699 .744 .886 r
.47202 .7408 .47859 .74768 .49028 .74389 .48376 .73594 Metetra
.708 .719 .858 r
.48376 .73594 .49028 .74389 .50202 .73945 .49553 .73045 Metetra
.711 .697 .835 r
.49553 .73045 .50202 .73945 .5138 .73447 .50735 .72448 Metetra
.711 .679 .817 r
.50735 .72448 .5138 .73447 .52563 .72911 .5192 .71818 Metetra
.708 .663 .803 r
.5192 .71818 .52563 .72911 .53749 .72347 .53108 .71167 Metetra
.704 .649 .792 r
.53108 .71167 .53749 .72347 .54938 .71768 .54299 .70507 Metetra
.698 .636 .783 r
.54299 .70507 .54938 .71768 .56131 .71186 .55492 .69851 Metetra
.692 .624 .776 r
.55492 .69851 .56131 .71186 .57327 .7061 .56689 .69209 Metetra
.685 .614 .771 r
.56689 .69209 .57327 .7061 .58527 .70049 .57889 .68591 Metetra
.678 .605 .767 r
.57889 .68591 .58527 .70049 .59731 .69513 .59094 .68006 Metetra
.67 .596 .764 r
.59094 .68006 .59731 .69513 .6094 .69008 .60302 .6746 Metetra
.661 .588 .762 r
.60302 .6746 .6094 .69008 .62154 .68539 .61516 .6696 Metetra
.653 .581 .761 r
.61516 .6696 .62154 .68539 .63374 .68112 .62736 .6651 Metetra
.644 .574 .762 r
.62736 .6651 .63374 .68112 .64599 .67728 .63961 .66113 Metetra
.634 .568 .763 r
.63961 .66113 .64599 .67728 .65832 .67391 .65194 .65771 Metetra
.625 .563 .765 r
.65194 .65771 .65832 .67391 .67072 .67098 .66435 .65484 Metetra
.616 .559 .768 r
.66435 .65484 .67072 .67098 .6832 .66851 .67684 .65252 Metetra
.607 .556 .772 r
.67684 .65252 .6832 .66851 .69577 .66645 .68941 .6507 Metetra
.599 .555 .776 r
.68941 .6507 .69577 .66645 .70842 .66477 .70208 .64935 Metetra
.591 .554 .782 r
.70208 .64935 .70842 .66477 .72115 .66342 .71484 .64842 Metetra
.584 .556 .789 r
.71484 .64842 .72115 .66342 .73398 .66231 .7277 .64782 Metetra
.578 .559 .797 r
.7277 .64782 .73398 .66231 .74689 .66138 .74066 .64749 Metetra
.573 .565 .806 r
.74066 .64749 .74689 .66138 .75988 .66052 .75371 .64731 Metetra
.57 .573 .817 r
.75371 .64731 .75988 .66052 .77295 .65964 .76684 .64718 Metetra
.569 .585 .83 r
.76684 .64718 .77295 .65964 .78609 .65862 .78006 .64698 Metetra
.571 .601 .844 r
.78006 .64698 .78609 .65862 .79928 .65733 .79334 .64659 Metetra
.577 .621 .86 r
.79334 .64659 .79928 .65733 .81252 .65564 .80669 .64585 Metetra
.586 .647 .878 r
.80669 .64585 .81252 .65564 .82579 .65341 .82007 .64464 Metetra
.6 .679 .897 r
.82007 .64464 .82579 .65341 .83907 .65051 .83348 .6428 Metetra
.706 .74 .878 r
.45371 .73782 .46034 .74491 .47202 .7408 .46543 .7326 Metetra
.716 .716 .849 r
.46543 .7326 .47202 .7408 .48376 .73594 .47721 .72666 Metetra
.719 .695 .826 r
.47721 .72666 .48376 .73594 .49553 .73045 .48902 .72014 Metetra
.719 .677 .808 r
.48902 .72014 .49553 .73045 .50735 .72448 .50087 .7132 Metetra
.717 .661 .794 r
.50087 .7132 .50735 .72448 .5192 .71818 .51274 .70596 Metetra
.713 .647 .782 r
.51274 .70596 .5192 .71818 .53108 .71167 .52464 .69859 Metetra
.707 .634 .773 r
.52464 .69859 .53108 .71167 .54299 .70507 .53656 .6912 Metetra
.701 .623 .766 r
.53656 .6912 .54299 .70507 .55492 .69851 .54851 .68391 Metetra
.694 .612 .76 r
.54851 .68391 .55492 .69851 .56689 .69209 .56048 .67684 Metetra
.687 .602 .756 r
.56048 .67684 .56689 .69209 .57889 .68591 .57248 .67009 Metetra
.679 .593 .753 r
.57248 .67009 .57889 .68591 .59094 .68006 .58452 .66375 Metetra
.67 .585 .751 r
.58452 .66375 .59094 .68006 .60302 .6746 .59661 .65789 Metetra
.661 .577 .75 r
.59661 .65789 .60302 .6746 .61516 .6696 .60874 .65257 Metetra
.651 .569 .75 r
.60874 .65257 .61516 .6696 .62736 .6651 .62093 .64785 Metetra
.642 .562 .75 r
.62093 .64785 .62736 .6651 .63961 .66113 .63318 .64375 Metetra
.632 .556 .751 r
.63318 .64375 .63961 .66113 .65194 .65771 .64551 .64029 Metetra
.622 .551 .753 r
.64551 .64029 .65194 .65771 .66435 .65484 .65791 .63747 Metetra
.612 .546 .756 r
.65791 .63747 .66435 .65484 .67684 .65252 .6704 .63529 Metetra
.602 .542 .76 r
.6704 .63529 .67684 .65252 .68941 .6507 .68299 .63371 Metetra
.592 .539 .764 r
.68299 .63371 .68941 .6507 .70208 .64935 .69567 .63268 Metetra
.583 .537 .77 r
.69567 .63268 .70208 .64935 .71484 .64842 .70845 .63216 Metetra
.574 .537 .776 r
.70845 .63216 .71484 .64842 .7277 .64782 .72134 .63206 Metetra
.567 .539 .783 r
.72134 .63206 .7277 .64782 .74066 .64749 .73433 .63231 Metetra
.56 .542 .792 r
.73433 .63231 .74066 .64749 .75371 .64731 .74743 .63279 Metetra
.556 .549 .802 r
.74743 .63279 .75371 .64731 .76684 .64718 .76062 .6334 Metetra
.553 .558 .813 r
.76062 .6334 .76684 .64718 .78006 .64698 .7739 .63402 Metetra
.553 .57 .826 r
.7739 .63402 .78006 .64698 .79334 .64659 .78727 .6345 Metetra
.556 .587 .84 r
.78727 .6345 .79334 .64659 .80669 .64585 .80071 .63471 Metetra
.562 .608 .857 r
.80071 .63471 .80669 .64585 .82007 .64464 .8142 .6345 Metetra
.574 .635 .874 r
.8142 .6345 .82007 .64464 .83348 .6428 .82773 .6337 Metetra
.59 .669 .894 r
.82773 .6337 .83348 .6428 .8469 .64017 .84128 .63216 Metetra
.712 .74 .874 r
.43532 .73502 .44203 .74216 .45371 .73782 .44705 .72955 Metetra
.722 .717 .844 r
.44705 .72955 .45371 .73782 .46543 .7326 .45882 .72324 Metetra
.727 .696 .821 r
.45882 .72324 .46543 .7326 .47721 .72666 .47064 .71624 Metetra
.727 .678 .802 r
.47064 .71624 .47721 .72666 .48902 .72014 .48249 .7087 Metetra
.725 .662 .787 r
.48249 .7087 .48902 .72014 .50087 .7132 .49436 .70079 Metetra
.722 .648 .776 r
.49436 .70079 .50087 .7132 .51274 .70596 .50626 .69265 Metetra
.717 .636 .766 r
.50626 .69265 .51274 .70596 .52464 .69859 .51818 .68442 Metetra
.711 .624 .759 r
.51818 .68442 .52464 .69859 .53656 .6912 .53011 .67624 Metetra
.704 .614 .753 r
.53011 .67624 .53656 .6912 .54851 .68391 .54206 .66825 Metetra
.697 .604 .748 r
.54206 .66825 .54851 .68391 .56048 .67684 .55404 .66054 Metetra
.688 .594 .745 r
.55404 .66054 .56048 .67684 .57248 .67009 .56604 .65323 Metetra
.68 .585 .743 r
.56604 .65323 .57248 .67009 .58452 .66375 .57808 .64641 Metetra
.671 .577 .741 r
.57808 .64641 .58452 .66375 .59661 .65789 .59016 .64016 Metetra
.661 .569 .741 r
.59016 .64016 .59661 .65789 .60874 .65257 .60228 .63454 Metetra
.651 .561 .741 r
.60228 .63454 .60874 .65257 .62093 .64785 .61446 .62959 Metetra
.64 .554 .741 r
.61446 .62959 .62093 .64785 .63318 .64375 .62671 .62536 Metetra
.629 .547 .743 r
.62671 .62536 .63318 .64375 .64551 .64029 .63902 .62186 Metetra
.618 .541 .745 r
.63902 .62186 .64551 .64029 .65791 .63747 .65142 .61909 Metetra
.607 .535 .748 r
.65142 .61909 .65791 .63747 .6704 .63529 .66391 .61704 Metetra
.596 .531 .751 r
.66391 .61704 .6704 .63529 .68299 .63371 .6765 .61568 Metetra
.586 .527 .755 r
.6765 .61568 .68299 .63371 .69567 .63268 .68919 .61497 Metetra
.575 .524 .76 r
.68919 .61497 .69567 .63268 .70845 .63216 .70199 .61485 Metetra
.565 .522 .766 r
.70199 .61485 .70845 .63216 .72134 .63206 .7149 .61524 Metetra
.556 .522 .773 r
.7149 .61524 .72134 .63206 .73433 .63231 .72792 .61605 Metetra
.548 .524 .781 r
.72792 .61605 .73433 .63231 .74743 .63279 .74106 .61718 Metetra
.542 .528 .79 r
.74106 .61718 .74743 .63279 .76062 .6334 .7543 .61851 Metetra
.537 .535 .8 r
.7543 .61851 .76062 .6334 .7739 .63402 .76765 .61992 Metetra
.535 .545 .812 r
.76765 .61992 .7739 .63402 .78727 .6345 .78109 .62127 Metetra
.536 .558 .825 r
.78109 .62127 .78727 .6345 .80071 .63471 .79461 .6224 Metetra
.54 .576 .84 r
.79461 .6224 .80071 .63471 .8142 .6345 .8082 .62316 Metetra
.549 .6 .857 r
.8082 .62316 .8142 .6345 .82773 .6337 .82185 .6234 Metetra
.563 .629 .875 r
.82185 .6234 .82773 .6337 .84128 .63216 .83552 .62293 Metetra
.583 .664 .894 r
.83552 .62293 .84128 .63216 .85483 .62972 .8492 .62159 Metetra
.715 .744 .875 r
.41686 .73242 .42366 .73948 .43532 .73502 .42858 .72683 Metetra
.728 .72 .843 r
.42858 .72683 .43532 .73502 .44705 .72955 .44036 .72026 Metetra
.733 .7 .819 r
.44036 .72026 .44705 .72955 .45882 .72324 .45219 .71288 Metetra
.735 .682 .799 r
.45219 .71288 .45882 .72324 .47064 .71624 .46405 .70484 Metetra
.734 .666 .784 r
.46405 .70484 .47064 .71624 .48249 .7087 .47593 .69631 Metetra
.731 .653 .772 r
.47593 .69631 .48249 .7087 .49436 .70079 .48784 .68745 Metetra
.726 .64 .762 r
.48784 .68745 .49436 .70079 .50626 .69265 .49976 .67842 Metetra
.721 .628 .754 r
.49976 .67842 .50626 .69265 .51818 .68442 .51169 .66936 Metetra
.715 .618 .748 r
.51169 .66936 .51818 .68442 .53011 .67624 .52364 .66042 Metetra
.707 .608 .743 r
.52364 .66042 .53011 .67624 .54206 .66825 .5356 .65173 Metetra
.699 .598 .739 r
.5356 .65173 .54206 .66825 .55404 .66054 .54758 .6434 Metetra
.691 .589 .737 r
.54758 .6434 .55404 .66054 .56604 .65323 .55958 .63555 Metetra
.682 .58 .735 r
.55958 .63555 .56604 .65323 .57808 .64641 .57162 .62827 Metetra
.672 .572 .734 r
.57162 .62827 .57808 .64641 .59016 .64016 .58369 .62163 Metetra
.661 .563 .734 r
.58369 .62163 .59016 .64016 .60228 .63454 .5958 .61571 Metetra
.651 .555 .734 r
.5958 .61571 .60228 .63454 .61446 .62959 .60797 .61055 Metetra
.639 .548 .735 r
.60797 .61055 .61446 .62959 .62671 .62536 .6202 .60619 Metetra
.628 .541 .737 r
.6202 .60619 .62671 .62536 .63902 .62186 .63251 .60264 Metetra
.616 .534 .739 r
.63251 .60264 .63902 .62186 .65142 .61909 .6449 .59992 Metetra
.604 .527 .741 r
.6449 .59992 .65142 .61909 .66391 .61704 .65739 .598 Metetra
.592 .522 .745 r
.65739 .598 .66391 .61704 .6765 .61568 .66997 .59685 Metetra
.58 .517 .749 r
.66997 .59685 .6765 .61568 .68919 .61497 .68267 .59644 Metetra
.568 .513 .754 r
.68267 .59644 .68919 .61497 .70199 .61485 .69548 .5967 Metetra
.556 .51 .759 r
.69548 .5967 .70199 .61485 .7149 .61524 .7084 .59756 Metetra
.546 .509 .765 r
.7084 .59756 .7149 .61524 .72792 .61605 .72145 .59892 Metetra
.536 .509 .772 r
.72145 .59892 .72792 .61605 .74106 .61718 .73461 .60067 Metetra
.528 .511 .781 r
.73461 .60067 .74106 .61718 .7543 .61851 .7479 .6027 Metetra
.522 .516 .79 r
.7479 .6027 .7543 .61851 .76765 .61992 .7613 .60488 Metetra
.518 .524 .801 r
.7613 .60488 .76765 .61992 .78109 .62127 .77481 .60706 Metetra
.517 .535 .813 r
.77481 .60706 .78109 .62127 .79461 .6224 .78841 .60909 Metetra
.519 .55 .827 r
.78841 .60909 .79461 .6224 .8082 .62316 .80209 .61081 Metetra
.526 .57 .842 r
.80209 .61081 .8082 .62316 .82185 .6234 .81584 .61204 Metetra
.538 .595 .86 r
.81584 .61204 .82185 .6234 .83552 .62293 .82963 .61262 Metetra
.555 .627 .878 r
.82963 .61262 .83552 .62293 .8492 .62159 .84344 .61237 Metetra
.579 .665 .897 r
.84344 .61237 .8492 .62159 .86287 .61921 .85725 .6111 Metetra
.715 .75 .879 r
.39833 .73 .40521 .73686 .41686 .73242 .41004 .72444 Metetra
.731 .726 .846 r
.41004 .72444 .41686 .73242 .42858 .72683 .42183 .71776 Metetra
.739 .706 .82 r
.42183 .71776 .42858 .72683 .44036 .72026 .43366 .71011 Metetra
.742 .688 .799 r
.43366 .71011 .44036 .72026 .45219 .71288 .44554 .70168 Metetra
.742 .673 .783 r
.44554 .70168 .45219 .71288 .46405 .70484 .45744 .69263 Metetra
.74 .659 .77 r
.45744 .69263 .46405 .70484 .47593 .69631 .46936 .68314 Metetra
.736 .646 .759 r
.46936 .68314 .47593 .69631 .48784 .68745 .4813 .67336 Metetra
.731 .635 .751 r
.4813 .67336 .48784 .68745 .49976 .67842 .49325 .66347 Metetra
.725 .624 .745 r
.49325 .66347 .49976 .67842 .51169 .66936 .5052 .65361 Metetra
.719 .614 .739 r
.5052 .65361 .51169 .66936 .52364 .66042 .51716 .64393 Metetra
.711 .604 .736 r
.51716 .64393 .52364 .66042 .5356 .65173 .52913 .63457 Metetra
.703 .595 .733 r
.52913 .63457 .5356 .65173 .54758 .6434 .54111 .62564 Metetra
.694 .586 .731 r
.54111 .62564 .54758 .6434 .55958 .63555 .55311 .61726 Metetra
.684 .577 .729 r
.55311 .61726 .55958 .63555 .57162 .62827 .56514 .60953 Metetra
.674 .568 .729 r
.56514 .60953 .57162 .62827 .58369 .62163 .5772 .60252 Metetra
.663 .56 .729 r
.5772 .60252 .58369 .62163 .5958 .61571 .5893 .59631 Metetra
.651 .552 .729 r
.5893 .59631 .5958 .61571 .60797 .61055 .60146 .59094 Metetra
.639 .544 .731 r
.60146 .59094 .60797 .61055 .6202 .60619 .61368 .58645 Metetra
.627 .536 .732 r
.61368 .58645 .6202 .60619 .63251 .60264 .62598 .58286 Metetra
.614 .529 .735 r
.62598 .58286 .63251 .60264 .6449 .59992 .63836 .58018 Metetra
.601 .522 .737 r
.63836 .58018 .6449 .59992 .65739 .598 .65084 .57838 Metetra
.587 .515 .741 r
.65084 .57838 .65739 .598 .66997 .59685 .66342 .57744 Metetra
.574 .509 .745 r
.66342 .57744 .66997 .59685 .68267 .59644 .67611 .57732 Metetra
.561 .504 .749 r
.67611 .57732 .68267 .59644 .69548 .5967 .68892 .57795 Metetra
.548 .5 .754 r
.68892 .57795 .69548 .5967 .7084 .59756 .70186 .57925 Metetra
.536 .497 .76 r
.70186 .57925 .7084 .59756 .72145 .59892 .71492 .58113 Metetra
.525 .496 .767 r
.71492 .58113 .72145 .59892 .73461 .60067 .72812 .58348 Metetra
.515 .497 .774 r
.72812 .58348 .73461 .60067 .7479 .6027 .74144 .58618 Metetra
.507 .5 .783 r
.74144 .58618 .7479 .6027 .7613 .60488 .75489 .5891 Metetra
.501 .506 .793 r
.75489 .5891 .7613 .60488 .77481 .60706 .76845 .59209 Metetra
.498 .515 .804 r
.76845 .59209 .77481 .60706 .78841 .60909 .78212 .59498 Metetra
.499 .527 .817 r
.78212 .59498 .78841 .60909 .80209 .61081 .79588 .59762 Metetra
.503 .545 .832 r
.79588 .59762 .80209 .61081 .81584 .61204 .80973 .59982 Metetra
.513 .567 .848 r
.80973 .59982 .81584 .61204 .82963 .61262 .82363 .60141 Metetra
.528 .595 .865 r
.82363 .60141 .82963 .61262 .84344 .61237 .83756 .60221 Metetra
.55 .63 .884 r
.83756 .60221 .84344 .61237 .85725 .6111 .8515 .60202 Metetra
.579 .671 .902 r
.8515 .60202 .85725 .6111 .87103 .60865 .86543 .60067 Metetra
.711 .757 .889 r
.37972 .72769 .3867 .73426 .39833 .73 .39142 .72234 Metetra
.732 .734 .852 r
.39142 .72234 .39833 .73 .41004 .72444 .4032 .7157 Metetra
.743 .714 .824 r
.4032 .7157 .41004 .72444 .42183 .71776 .41505 .70795 Metetra
.748 .696 .802 r
.41505 .70795 .42183 .71776 .43366 .71011 .42694 .69927 Metetra
.75 .68 .784 r
.42694 .69927 .43366 .71011 .44554 .70168 .43886 .68982 Metetra
.749 .667 .77 r
.43886 .68982 .44554 .70168 .45744 .69263 .45081 .6798 Metetra
.746 .654 .759 r
.45081 .6798 .45744 .69263 .46936 .68314 .46277 .66937 Metetra
.742 .643 .75 r
.46277 .66937 .46936 .68314 .4813 .67336 .47474 .65872 Metetra
.736 .632 .743 r
.47474 .65872 .4813 .67336 .49325 .66347 .48672 .64799 Metetra
.73 .622 .738 r
.48672 .64799 .49325 .66347 .5052 .65361 .49869 .63736 Metetra
.723 .612 .733 r
.49869 .63736 .5052 .65361 .51716 .64393 .51066 .62697 Metetra
.715 .603 .73 r
.51066 .62697 .51716 .64393 .52913 .63457 .52264 .61697 Metetra
.706 .594 .728 r
.52264 .61697 .52913 .63457 .54111 .62564 .53463 .60746 Metetra
.697 .585 .726 r
.53463 .60746 .54111 .62564 .55311 .61726 .54663 .59858 Metetra
.687 .576 .725 r
.54663 .59858 .55311 .61726 .56514 .60953 .55865 .59042 Metetra
.676 .567 .725 r
.55865 .59042 .56514 .60953 .5772 .60252 .5707 .58305 Metetra
.664 .559 .726 r
.5707 .58305 .5772 .60252 .5893 .59631 .5828 .57656 Metetra
.652 .55 .726 r
.5828 .57656 .5893 .59631 .60146 .59094 .59494 .57099 Metetra
.639 .542 .728 r
.59494 .57099 .60146 .59094 .61368 .58645 .60715 .56638 Metetra
.626 .533 .73 r
.60715 .56638 .61368 .58645 .62598 .58286 .61944 .56274 Metetra
.612 .525 .732 r
.61944 .56274 .62598 .58286 .63836 .58018 .6318 .56009 Metetra
.598 .517 .735 r
.6318 .56009 .63836 .58018 .65084 .57838 .64427 .55841 Metetra
.583 .51 .738 r
.64427 .55841 .65084 .57838 .66342 .57744 .65684 .55766 Metetra
.569 .503 .742 r
.65684 .55766 .66342 .57744 .67611 .57732 .66953 .55781 Metetra
.554 .497 .746 r
.66953 .55781 .67611 .57732 .68892 .57795 .68234 .55878 Metetra
.54 .492 .751 r
.68234 .55878 .68892 .57795 .70186 .57925 .69529 .56051 Metetra
.526 .488 .757 r
.69529 .56051 .70186 .57925 .71492 .58113 .70837 .56289 Metetra
.513 .485 .763 r
.70837 .56289 .71492 .58113 .72812 .58348 .72158 .56581 Metetra
.502 .485 .77 r
.72158 .56581 .72812 .58348 .74144 .58618 .73493 .56915 Metetra
.492 .486 .778 r
.73493 .56915 .74144 .58618 .75489 .5891 .74842 .57278 Metetra
.484 .49 .788 r
.74842 .57278 .75489 .5891 .76845 .59209 .76203 .57653 Metetra
.48 .497 .798 r
.76203 .57653 .76845 .59209 .78212 .59498 .77577 .58025 Metetra
.478 .508 .81 r
.77577 .58025 .78212 .59498 .79588 .59762 .7896 .58377 Metetra
.481 .523 .823 r
.7896 .58377 .79588 .59762 .80973 .59982 .80353 .58691 Metetra
.489 .543 .838 r
.80353 .58691 .80973 .59982 .82363 .60141 .81753 .58947 Metetra
.502 .568 .855 r
.81753 .58947 .82363 .60141 .83756 .60221 .83158 .59128 Metetra
.522 .6 .873 r
.83158 .59128 .83756 .60221 .8515 .60202 .84565 .59213 Metetra
.549 .638 .891 r
.84565 .59213 .8515 .60202 .86543 .60067 .85971 .59184 Metetra
.584 .683 .909 r
.85971 .59184 .86543 .60067 .8793 .59797 .87373 .59022 Metetra
.73 .744 .862 r
.37271 .72041 .37972 .72769 .39142 .72234 .38449 .71401 Metetra
.745 .723 .831 r
.38449 .71401 .39142 .72234 .4032 .7157 .39634 .70634 Metetra
.753 .705 .807 r
.39634 .70634 .4032 .7157 .41505 .70795 .40824 .69757 Metetra
.756 .69 .788 r
.40824 .69757 .41505 .70795 .42694 .69927 .42019 .68788 Metetra
.757 .676 .772 r
.42019 .68788 .42694 .69927 .43886 .68982 .43217 .67747 Metetra
.755 .663 .76 r
.43217 .67747 .43886 .68982 .45081 .6798 .44417 .66652 Metetra
.752 .652 .751 r
.44417 .66652 .45081 .6798 .46277 .66937 .45617 .6552 Metetra
.747 .641 .743 r
.45617 .6552 .46277 .66937 .47474 .65872 .46817 .64369 Metetra
.742 .631 .737 r
.46817 .64369 .47474 .65872 .48672 .64799 .48017 .63218 Metetra
.735 .622 .732 r
.48017 .63218 .48672 .64799 .49869 .63736 .49217 .62081 Metetra
.728 .613 .729 r
.49217 .62081 .49869 .63736 .51066 .62697 .50416 .60975 Metetra
.72 .603 .726 r
.50416 .60975 .51066 .62697 .52264 .61697 .51614 .59913 Metetra
.711 .594 .724 r
.51614 .59913 .52264 .61697 .53463 .60746 .52814 .58908 Metetra
.701 .586 .723 r
.52814 .58908 .53463 .60746 .54663 .59858 .54014 .57971 Metetra
.69 .577 .723 r
.54014 .57971 .54663 .59858 .55865 .59042 .55216 .57114 Metetra
.679 .568 .723 r
.55216 .57114 .55865 .59042 .5707 .58305 .5642 .56343 Metetra
.667 .559 .724 r
.5642 .56343 .5707 .58305 .5828 .57656 .57629 .55667 Metetra
.654 .55 .725 r
.57629 .55667 .5828 .57656 .59494 .57099 .58842 .55091 Metetra
.64 .541 .727 r
.58842 .55091 .59494 .57099 .60715 .56638 .60062 .54618 Metetra
.626 .532 .729 r
.60062 .54618 .60715 .56638 .61944 .56274 .61289 .5425 Metetra
.611 .524 .731 r
.61289 .5425 .61944 .56274 .6318 .56009 .62524 .53988 Metetra
.595 .515 .734 r
.62524 .53988 .6318 .56009 .64427 .55841 .6377 .5383 Metetra
.579 .507 .738 r
.6377 .5383 .64427 .55841 .65684 .55766 .65026 .53773 Metetra
.563 .499 .741 r
.65026 .53773 .65684 .55766 .66953 .55781 .66294 .53813 Metetra
.547 .492 .746 r
.66294 .53813 .66953 .55781 .68234 .55878 .67575 .53943 Metetra
.531 .486 .75 r
.67575 .53943 .68234 .55878 .69529 .56051 .6887 .54156 Metetra
.516 .48 .756 r
.6887 .54156 .69529 .56051 .70837 .56289 .70179 .5444 Metetra
.501 .476 .761 r
.70179 .5444 .70837 .56289 .72158 .56581 .71502 .54786 Metetra
.488 .474 .768 r
.71502 .54786 .72158 .56581 .73493 .56915 .7284 .55181 Metetra
.476 .474 .776 r
.7284 .55181 .73493 .56915 .74842 .57278 .74192 .5561 Metetra
.467 .476 .784 r
.74192 .5561 .74842 .57278 .76203 .57653 .75557 .56058 Metetra
.461 .482 .794 r
.75557 .56058 .76203 .57653 .77577 .58025 .76936 .56509 Metetra
.457 .491 .805 r
.76936 .56509 .77577 .58025 .7896 .58377 .78326 .56945 Metetra
.458 .504 .818 r
.78326 .56945 .7896 .58377 .80353 .58691 .79727 .57347 Metetra
.464 .521 .832 r
.79727 .57347 .80353 .58691 .81753 .58947 .81136 .57697 Metetra
.476 .545 .847 r
.81136 .57697 .81753 .58947 .83158 .59128 .82551 .57974 Metetra
.495 .574 .864 r
.82551 .57974 .83158 .59128 .84565 .59213 .83969 .58159 Metetra
.52 .609 .882 r
.83969 .58159 .84565 .59213 .85971 .59184 .85388 .58231 Metetra
.554 .652 .9 r
.85388 .58231 .85971 .59184 .87373 .59022 .86804 .58173 Metetra
.723 .754 .877 r
.35392 .71853 .36103 .72537 .37271 .72041 .36568 .71257 Metetra
.745 .734 .842 r
.36568 .71257 .37271 .72041 .38449 .71401 .37752 .70517 Metetra
.756 .716 .815 r
.37752 .70517 .38449 .71401 .39634 .70634 .38944 .69651 Metetra
.762 .7 .794 r
.38944 .69651 .39634 .70634 .40824 .69757 .40142 .68676 Metetra
.764 .686 .777 r
.40142 .68676 .40824 .69757 .42019 .68788 .41343 .67613 Metetra
.764 .674 .764 r
.41343 .67613 .42019 .68788 .43217 .67747 .42546 .66479 Metetra
.761 .663 .753 r
.42546 .66479 .43217 .67747 .44417 .66652 .4375 .65295 Metetra
.758 .652 .745 r
.4375 .65295 .44417 .66652 .45617 .6552 .44954 .64079 Metetra
.753 .642 .738 r
.44954 .64079 .45617 .6552 .46817 .64369 .46158 .62848 Metetra
.748 .633 .733 r
.46158 .62848 .46817 .64369 .48017 .63218 .47361 .61621 Metetra
.741 .624 .729 r
.47361 .61621 .48017 .63218 .49217 .62081 .48563 .60415 Metetra
.733 .615 .726 r
.48563 .60415 .49217 .62081 .50416 .60975 .49764 .59245 Metetra
.725 .606 .724 r
.49764 .59245 .50416 .60975 .51614 .59913 .50964 .58124 Metetra
.716 .597 .722 r
.50964 .58124 .51614 .59913 .52814 .58908 .52164 .57068 Metetra
.705 .588 .722 r
.52164 .57068 .52814 .58908 .54014 .57971 .53364 .56086 Metetra
.694 .579 .722 r
.53364 .56086 .54014 .57971 .55216 .57114 .54566 .55189 Metetra
.682 .57 .722 r
.54566 .55189 .55216 .57114 .5642 .56343 .5577 .54387 Metetra
.669 .561 .724 r
.5577 .54387 .5642 .56343 .57629 .55667 .56977 .53686 Metetra
.656 .552 .725 r
.56977 .53686 .57629 .55667 .58842 .55091 .5819 .53091 Metetra
.641 .542 .727 r
.5819 .53091 .58842 .55091 .60062 .54618 .59408 .52606 Metetra
.626 .533 .73 r
.59408 .52606 .60062 .54618 .61289 .5425 .60634 .52234 Metetra
.61 .524 .732 r
.60634 .52234 .61289 .5425 .62524 .53988 .61868 .51974 Metetra
.593 .514 .735 r
.61868 .51974 .62524 .53988 .6377 .5383 .63112 .51826 Metetra
.576 .505 .739 r
.63112 .51826 .6377 .5383 .65026 .53773 .64367 .51786 Metetra
.558 .496 .742 r
.64367 .51786 .65026 .53773 .66294 .53813 .65635 .51849 Metetra
.54 .488 .747 r
.65635 .51849 .66294 .53813 .67575 .53943 .66916 .5201 Metetra
.522 .481 .751 r
.66916 .5201 .67575 .53943 .6887 .54156 .6821 .52259 Metetra
.505 .474 .756 r
.6821 .52259 .6887 .54156 .70179 .5444 .6952 .52588 Metetra
.489 .469 .762 r
.6952 .52588 .70179 .5444 .71502 .54786 .70844 .52984 Metetra
.473 .465 .768 r
.70844 .52984 .71502 .54786 .7284 .55181 .72184 .53435 Metetra
.46 .463 .775 r
.72184 .53435 .7284 .55181 .74192 .5561 .73539 .53927 Metetra
.449 .464 .783 r
.73539 .53927 .74192 .5561 .75557 .56058 .74908 .54444 Metetra
.44 .468 .792 r
.74908 .54444 .75557 .56058 .76936 .56509 .76291 .54969 Metetra
.436 .475 .802 r
.76291 .54969 .76936 .56509 .78326 .56945 .77688 .55483 Metetra
.435 .487 .814 r
.77688 .55483 .78326 .56945 .79727 .57347 .79095 .55969 Metetra
.44 .503 .827 r
.79095 .55969 .79727 .57347 .81136 .57697 .80512 .56406 Metetra
.45 .524 .842 r
.80512 .56406 .81136 .57697 .82551 .57974 .81937 .56775 Metetra
.467 .551 .858 r
.81937 .56775 .82551 .57974 .83969 .58159 .83366 .57054 Metetra
.492 .585 .876 r
.83366 .57054 .83969 .58159 .85388 .58231 .84796 .57223 Metetra
.524 .625 .893 r
.84796 .57223 .85388 .58231 .86804 .58173 .86226 .57262 Metetra
.565 .671 .91 r
.86226 .57262 .86804 .58173 .88214 .57963 .8765 .57151 Metetra
.709 .765 .896 r
.33507 .7165 .34229 .72288 .35392 .71853 .34678 .7112 Metetra
.739 .746 .857 r
.34678 .7112 .35392 .71853 .36568 .71257 .35861 .70429 Metetra
.756 .728 .826 r
.35861 .70429 .36568 .71257 .37752 .70517 .37053 .69595 Metetra
.765 .712 .802 r
.37053 .69595 .37752 .70517 .38944 .69651 .38252 .68634 Metetra
.77 .698 .784 r
.38252 .68634 .38944 .69651 .40142 .68676 .39456 .67568 Metetra
.771 .685 .769 r
.39456 .67568 .40142 .68676 .41343 .67613 .40663 .66415 Metetra
.77 .674 .757 r
.40663 .66415 .41343 .67613 .42546 .66479 .41872 .65194 Metetra
.768 .664 .747 r
.41872 .65194 .42546 .66479 .4375 .65295 .43081 .63927 Metetra
.764 .654 .74 r
.43081 .63927 .4375 .65295 .44954 .64079 .4429 .62631 Metetra
.76 .645 .734 r
.4429 .62631 .44954 .64079 .46158 .62848 .45497 .61325 Metetra
.754 .636 .73 r
.45497 .61325 .46158 .62848 .47361 .61621 .46703 .60028 Metetra
.747 .627 .726 r
.46703 .60028 .47361 .61621 .48563 .60415 .47908 .58756 Metetra
.739 .618 .724 r
.47908 .58756 .48563 .60415 .49764 .59245 .49111 .57525 Metetra
.731 .61 .722 r
.49111 .57525 .49764 .59245 .50964 .58124 .50312 .56351 Metetra
.721 .601 .722 r
.50312 .56351 .50964 .58124 .52164 .57068 .51513 .55245 Metetra
.711 .592 .722 r
.51513 .55245 .52164 .57068 .53364 .56086 .52714 .54221 Metetra
.699 .583 .722 r
.52714 .54221 .53364 .56086 .54566 .55189 .53916 .53288 Metetra
.687 .574 .723 r
.53916 .53288 .54566 .55189 .5577 .54387 .55119 .52456 Metetra
.673 .565 .725 r
.55119 .52456 .5577 .54387 .56977 .53686 .56326 .51731 Metetra
.658 .555 .727 r
.56326 .51731 .56977 .53686 .5819 .53091 .57538 .51118 Metetra
.643 .545 .729 r
.57538 .51118 .5819 .53091 .59408 .52606 .58755 .50623 Metetra
.626 .535 .732 r
.58755 .50623 .59408 .52606 .60634 .52234 .5998 .50246 Metetra
.609 .525 .735 r
.5998 .50246 .60634 .52234 .61868 .51974 .61213 .49989 Metetra
.591 .515 .738 r
.61213 .49989 .61868 .51974 .63112 .51826 .62455 .49849 Metetra
.572 .505 .741 r
.62455 .49849 .63112 .51826 .64367 .51786 .6371 .49824 Metetra
.552 .495 .745 r
.6371 .49824 .64367 .51786 .65635 .51849 .64976 .49909 Metetra
.533 .486 .749 r
.64976 .49909 .65635 .51849 .66916 .5201 .66256 .50097 Metetra
.513 .477 .754 r
.66256 .50097 .66916 .5201 .6821 .52259 .67551 .50381 Metetra
.494 .469 .758 r
.67551 .50381 .6821 .52259 .6952 .52588 .68861 .5075 Metetra
.475 .462 .764 r
.68861 .5075 .6952 .52588 .70844 .52984 .70186 .51193 Metetra
.458 .457 .769 r
.70186 .51193 .70844 .52984 .72184 .53435 .71527 .51696 Metetra
.442 .454 .776 r
.71527 .51696 .72184 .53435 .73539 .53927 .72884 .52247 Metetra
.429 .453 .783 r
.72884 .52247 .73539 .53927 .74908 .54444 .74257 .52827 Metetra
.419 .455 .791 r
.74257 .52827 .74908 .54444 .76291 .54969 .75645 .53421 Metetra
.413 .461 .801 r
.75645 .53421 .76291 .54969 .77688 .55483 .77046 .54009 Metetra
.411 .471 .812 r
.77046 .54009 .77688 .55483 .79095 .55969 .7846 .54573 Metetra
.414 .486 .825 r
.7846 .54573 .79095 .55969 .80512 .56406 .79884 .55092 Metetra
.423 .505 .839 r
.79884 .55092 .80512 .56406 .81937 .56775 .81317 .55546 Metetra
.44 .531 .854 r
.81317 .55546 .81937 .56775 .83366 .57054 .82756 .55913 Metetra
.464 .563 .871 r
.82756 .55913 .83366 .57054 .84796 .57223 .84197 .56173 Metetra
.496 .601 .888 r
.84197 .56173 .84796 .57223 .86226 .57262 .85639 .56305 Metetra
.536 .646 .905 r
.85639 .56305 .86226 .57262 .8765 .57151 .87077 .56287 Metetra
.584 .695 .919 r
.87077 .56287 .8765 .57151 .89065 .56871 .88506 .56101 Metetra
.728 .758 .876 r
.32781 .70969 .33507 .7165 .34678 .7112 .33961 .7035 Metetra
.752 .74 .841 r
.33961 .7035 .34678 .7112 .35861 .70429 .35151 .6957 Metetra
.766 .724 .814 r
.35151 .6957 .35861 .70429 .37053 .69595 .36351 .68647 Metetra
.773 .71 .793 r
.36351 .68647 .37053 .69595 .38252 .68634 .37557 .67599 Metetra
.777 .698 .776 r
.37557 .67599 .38252 .68634 .39456 .67568 .38767 .66446 Metetra
.778 .687 .763 r
.38767 .66446 .39456 .67568 .40663 .66415 .3998 .65209 Metetra
.777 .676 .752 r
.3998 .65209 .40663 .66415 .41872 .65194 .41195 .63908 Metetra
.775 .667 .744 r
.41195 .63908 .41872 .65194 .43081 .63927 .42409 .62563 Metetra
.771 .658 .737 r
.42409 .62563 .43081 .63927 .4429 .62631 .43622 .61193 Metetra
.767 .649 .732 r
.43622 .61193 .4429 .62631 .45497 .61325 .44834 .59817 Metetra
.761 .64 .728 r
.44834 .59817 .45497 .61325 .46703 .60028 .46044 .58454 Metetra
.754 .632 .725 r
.46044 .58454 .46703 .60028 .47908 .58756 .47251 .57121 Metetra
.746 .624 .723 r
.47251 .57121 .47908 .58756 .49111 .57525 .48456 .55835 Metetra
.737 .615 .723 r
.48456 .55835 .49111 .57525 .50312 .56351 .49659 .5461 Metetra
.727 .607 .722 r
.49659 .5461 .50312 .56351 .51513 .55245 .50861 .53459 Metetra
.717 .598 .723 r
.50861 .53459 .51513 .55245 .52714 .54221 .52063 .52395 Metetra
.705 .589 .724 r
.52063 .52395 .52714 .54221 .53916 .53288 .53265 .51429 Metetra
.691 .58 .725 r
.53265 .51429 .53916 .53288 .55119 .52456 .54469 .50568 Metetra
.677 .57 .727 r
.54469 .50568 .55119 .52456 .56326 .51731 .55675 .49821 Metetra
.662 .56 .73 r
.55675 .49821 .56326 .51731 .57538 .51118 .56886 .49192 Metetra
.645 .55 .732 r
.56886 .49192 .57538 .51118 .58755 .50623 .58103 .48686 Metetra
.628 .539 .735 r
.58103 .48686 .58755 .50623 .5998 .50246 .59326 .48305 Metetra
.609 .529 .739 r
.59326 .48305 .5998 .50246 .61213 .49989 .60558 .48049 Metetra
.589 .518 .742 r
.60558 .48049 .61213 .49989 .62455 .49849 .618 .47917 Metetra
.568 .506 .746 r
.618 .47917 .62455 .49849 .6371 .49824 .63053 .47906 Metetra
.547 .495 .75 r
.63053 .47906 .6371 .49824 .64976 .49909 .64319 .4801 Metetra
.525 .485 .754 r
.64319 .4801 .64976 .49909 .66256 .50097 .65598 .48224 Metetra
.503 .474 .758 r
.65598 .48224 .66256 .50097 .67551 .50381 .66892 .48539 Metetra
.481 .465 .763 r
.66892 .48539 .67551 .50381 .68861 .5075 .68202 .48945 Metetra
.461 .457 .767 r
.68202 .48945 .68861 .5075 .70186 .51193 .69528 .4943 Metetra
.441 .45 .773 r
.69528 .4943 .70186 .51193 .71527 .51696 .70871 .49982 Metetra
.423 .445 .778 r
.70871 .49982 .71527 .51696 .72884 .52247 .7223 .50586 Metetra
.408 .443 .785 r
.7223 .50586 .72884 .52247 .74257 .52827 .73605 .51225 Metetra
.396 .444 .793 r
.73605 .51225 .74257 .52827 .75645 .53421 .74996 .51882 Metetra
.388 .448 .801 r
.74996 .51882 .75645 .53421 .77046 .54009 .76402 .52539 Metetra
.385 .457 .812 r
.76402 .52539 .77046 .54009 .7846 .54573 .77822 .53175 Metetra
.387 .47 .824 r
.77822 .53175 .7846 .54573 .79884 .55092 .79253 .5377 Metetra
.395 .489 .837 r
.79253 .5377 .79884 .55092 .81317 .55546 .80693 .54303 Metetra
.411 .513 .852 r
.80693 .54303 .81317 .55546 .82756 .55913 .82141 .54752 Metetra
.435 .544 .868 r
.82141 .54752 .82756 .55913 .84197 .56173 .83593 .55096 Metetra
.467 .581 .885 r
.83593 .55096 .84197 .56173 .85639 .56305 .85045 .55313 Metetra
.508 .624 .901 r
.85045 .55313 .85639 .56305 .87077 .56287 .86495 .55382 Metetra
.556 .673 .916 r
.86495 .55382 .87077 .56287 .88506 .56101 .87938 .55283 Metetra
.707 .768 .9 r
.30878 .70777 .31615 .71409 .32781 .70969 .32051 .70255 Metetra
.742 .753 .861 r
.32051 .70255 .32781 .70969 .33961 .7035 .33239 .69554 Metetra
.763 .737 .829 r
.33239 .69554 .33961 .7035 .35151 .6957 .34437 .68692 Metetra
.775 .723 .805 r
.34437 .68692 .35151 .6957 .36351 .68647 .35644 .67686 Metetra
.781 .711 .785 r
.35644 .67686 .36351 .68647 .37557 .67599 .36857 .66557 Metetra
.785 .7 .77 r
.36857 .66557 .37557 .67599 .38767 .66446 .38074 .65325 Metetra
.785 .689 .758 r
.38074 .65325 .38767 .66446 .3998 .65209 .39294 .64011 Metetra
.785 .68 .749 r
.39294 .64011 .3998 .65209 .41195 .63908 .40514 .62635 Metetra
.782 .671 .741 r
.40514 .62635 .41195 .63908 .42409 .62563 .41734 .61218 Metetra
.779 .663 .735 r
.41734 .61218 .42409 .62563 .43622 .61193 .42952 .59779 Metetra
.774 .654 .731 r
.42952 .59779 .43622 .61193 .44834 .59817 .44168 .58339 Metetra
.768 .646 .728 r
.44168 .58339 .44834 .59817 .46044 .58454 .45381 .56916 Metetra
.761 .639 .725 r
.45381 .56916 .46044 .58454 .47251 .57121 .46592 .55528 Metetra
.753 .631 .724 r
.46592 .55528 .47251 .57121 .48456 .55835 .47799 .5419 Metetra
.744 .622 .724 r
.47799 .5419 .48456 .55835 .49659 .5461 .49005 .52918 Metetra
.734 .614 .724 r
.49005 .52918 .49659 .5461 .50861 .53459 .50208 .51726 Metetra
.723 .605 .725 r
.50208 .51726 .50861 .53459 .52063 .52395 .51411 .50626 Metetra
.711 .596 .727 r
.51411 .50626 .52063 .52395 .53265 .51429 .52614 .49628 Metetra
.697 .587 .729 r
.52614 .49628 .53265 .51429 .54469 .50568 .53818 .48741 Metetra
.682 .577 .731 r
.53818 .48741 .54469 .50568 .55675 .49821 .55025 .47973 Metetra
.666 .567 .734 r
.55025 .47973 .55675 .49821 .56886 .49192 .56235 .4733 Metetra
.648 .556 .737 r
.56235 .4733 .56886 .49192 .58103 .48686 .57451 .46814 Metetra
.629 .545 .741 r
.57451 .46814 .58103 .48686 .59326 .48305 .58673 .46428 Metetra
.609 .534 .745 r
.58673 .46428 .59326 .48305 .60558 .48049 .59904 .46174 Metetra
.587 .522 .748 r
.59904 .46174 .60558 .48049 .618 .47917 .61145 .46048 Metetra
.564 .51 .752 r
.61145 .46048 .618 .47917 .63053 .47906 .62397 .46049 Metetra
.541 .497 .756 r
.62397 .46049 .63053 .47906 .64319 .4801 .63662 .4617 Metetra
.517 .485 .76 r
.63662 .4617 .64319 .4801 .65598 .48224 .64941 .46407 Metetra
.492 .473 .764 r
.64941 .46407 .65598 .48224 .66892 .48539 .66235 .4675 Metetra
.468 .462 .769 r
.66235 .4675 .66892 .48539 .68202 .48945 .67545 .4719 Metetra
.444 .452 .773 r
.67545 .4719 .68202 .48945 .69528 .4943 .68871 .47714 Metetra
.422 .444 .778 r
.68871 .47714 .69528 .4943 .70871 .49982 .70215 .48309 Metetra
.402 .437 .783 r
.70215 .48309 .70871 .49982 .7223 .50586 .71576 .48962 Metetra
.384 .434 .789 r
.71576 .48962 .7223 .50586 .73605 .51225 .72954 .49654 Metetra
.37 .433 .795 r
.72954 .49654 .73605 .51225 .74996 .51882 .74348 .50369 Metetra
.361 .436 .803 r
.74348 .50369 .74996 .51882 .76402 .52539 .75758 .51087 Metetra
.356 .443 .813 r
.75758 .51087 .76402 .52539 .77822 .53175 .77182 .51789 Metetra
.357 .455 .824 r
.77182 .51789 .77822 .53175 .79253 .5377 .78619 .52454 Metetra
.366 .473 .837 r
.78619 .52454 .79253 .5377 .80693 .54303 .80066 .53059 Metetra
.381 .497 .851 r
.80066 .53059 .80693 .54303 .82141 .54752 .81522 .53583 Metetra
.405 .527 .867 r
.81522 .53583 .82141 .54752 .83593 .55096 .82983 .54004 Metetra
.438 .563 .883 r
.82983 .54004 .83593 .55096 .85045 .55313 .84446 .543 Metetra
.48 .606 .9 r
.84446 .543 .85045 .55313 .86495 .55382 .85907 .54449 Metetra
.53 .653 .914 r
.85907 .54449 .86495 .55382 .87938 .55283 .87362 .54429 Metetra
.587 .704 .924 r
.87362 .54429 .87938 .55283 .89371 .54996 .88808 .54222 Metetra
.723 .764 .885 r
.30136 .70116 .30878 .70777 .32051 .70255 .31317 .6952 Metetra
.754 .75 .849 r
.31317 .6952 .32051 .70255 .33239 .69554 .32512 .68743 Metetra
.772 .736 .82 r
.32512 .68743 .33239 .69554 .34437 .68692 .33718 .67805 Metetra
.783 .724 .798 r
.33718 .67805 .34437 .68692 .35644 .67686 .34932 .66725 Metetra
.789 .713 .78 r
.34932 .66725 .35644 .67686 .36857 .66557 .36153 .65522 Metetra
.792 .703 .766 r
.36153 .65522 .36857 .66557 .38074 .65325 .37377 .64218 Metetra
.793 .694 .755 r
.37377 .64218 .38074 .65325 .39294 .64011 .38603 .62833 Metetra
.792 .685 .746 r
.38603 .62833 .39294 .64011 .40514 .62635 .39829 .61389 Metetra
.79 .677 .74 r
.39829 .61389 .40514 .62635 .41734 .61218 .41054 .59906 Metetra
.786 .669 .734 r
.41054 .59906 .41734 .61218 .42952 .59779 .42277 .58406 Metetra
.782 .662 .731 r
.42277 .58406 .42952 .59779 .44168 .58339 .43498 .56907 Metetra
.776 .654 .728 r
.43498 .56907 .44168 .58339 .45381 .56916 .44715 .55429 Metetra
.769 .647 .726 r
.44715 .55429 .45381 .56916 .46592 .55528 .45929 .53989 Metetra
.761 .639 .726 r
.45929 .53989 .46592 .55528 .47799 .5419 .4714 .52605 Metetra
.752 .631 .726 r
.4714 .52605 .47799 .5419 .49005 .52918 .48348 .51291 Metetra
.742 .623 .727 r
.48348 .51291 .49005 .52918 .50208 .51726 .49554 .50061 Metetra
.731 .615 .728 r
.49554 .50061 .50208 .51726 .51411 .50626 .50758 .48928 Metetra
.718 .606 .731 r
.50758 .48928 .51411 .50626 .52614 .49628 .51962 .47901 Metetra
.704 .596 .733 r
.51962 .47901 .52614 .49628 .53818 .48741 .53166 .46991 Metetra
.688 .587 .737 r
.53166 .46991 .53818 .48741 .55025 .47973 .54373 .46204 Metetra
.671 .576 .74 r
.54373 .46204 .55025 .47973 .56235 .4733 .55584 .45547 Metetra
.652 .565 .744 r
.55584 .45547 .56235 .4733 .57451 .46814 .56799 .45022 Metetra
.631 .553 .748 r
.56799 .45022 .57451 .46814 .58673 .46428 .58021 .44632 Metetra
.609 .541 .752 r
.58021 .44632 .58673 .46428 .59904 .46174 .59252 .44378 Metetra
.586 .528 .757 r
.59252 .44378 .59904 .46174 .61145 .46048 .60492 .44258 Metetra
.561 .515 .761 r
.60492 .44258 .61145 .46048 .62397 .46049 .61743 .44269 Metetra
.534 .501 .765 r
.61743 .44269 .62397 .46049 .63662 .4617 .63007 .44406 Metetra
.507 .487 .769 r
.63007 .44406 .63662 .4617 .64941 .46407 .64286 .44663 Metetra
.48 .474 .773 r
.64286 .44663 .64941 .46407 .66235 .4675 .6558 .45031 Metetra
.453 .461 .777 r
.6558 .45031 .66235 .4675 .67545 .4719 .66889 .455 Metetra
.426 .449 .781 r
.66889 .455 .67545 .4719 .68871 .47714 .68216 .46059 Metetra
.401 .438 .784 r
.68216 .46059 .68871 .47714 .70215 .48309 .69561 .46693 Metetra
.378 .43 .789 r
.69561 .46693 .70215 .48309 .71576 .48962 .70923 .47389 Metetra
.358 .425 .794 r
.70923 .47389 .71576 .48962 .72954 .49654 .72303 .48129 Metetra
.342 .422 .8 r
.72303 .48129 .72954 .49654 .74348 .50369 .737 .48895 Metetra
.33 .424 .807 r
.737 .48895 .74348 .50369 .75758 .51087 .75113 .49669 Metetra
.325 .43 .815 r
.75113 .49669 .75758 .51087 .77182 .51789 .76542 .5043 Metetra
.326 .441 .825 r
.76542 .5043 .77182 .51789 .78619 .52454 .77984 .51157 Metetra
.334 .458 .838 r
.77984 .51157 .78619 .52454 .80066 .53059 .79438 .51828 Metetra
.35 .482 .852 r
.79438 .51828 .80066 .53059 .81522 .53583 .809 .5242 Metetra
.375 .511 .867 r
.809 .5242 .81522 .53583 .82983 .54004 .8237 .52911 Metetra
.409 .548 .883 r
.8237 .52911 .82983 .54004 .84446 .543 .83842 .53277 Metetra
.452 .59 .899 r
.83842 .53277 .84446 .543 .85907 .54449 .85313 .53498 Metetra
.503 .637 .914 r
.85313 .53498 .85907 .54449 .87362 .54429 .8678 .53551 Metetra
.562 .688 .924 r
.8678 .53551 .87362 .54429 .88808 .54222 .88238 .53416 Metetra
.737 .762 .873 r
.29389 .69434 .30136 .70116 .31317 .6952 .30578 .68771 Metetra
.764 .75 .84 r
.30578 .68771 .31317 .6952 .32512 .68743 .31781 .67927 Metetra
.78 .738 .814 r
.31781 .67927 .32512 .68743 .33718 .67805 .32994 .66921 Metetra
.79 .727 .793 r
.32994 .66921 .33718 .67805 .34932 .66725 .34216 .65773 Metetra
.796 .717 .777 r
.34216 .65773 .34932 .66725 .36153 .65522 .35443 .64504 Metetra
.799 .708 .764 r
.35443 .64504 .36153 .65522 .37377 .64218 .36674 .63135 Metetra
.8 .699 .754 r
.36674 .63135 .37377 .64218 .38603 .62833 .37906 .61687 Metetra
.8 .692 .746 r
.37906 .61687 .38603 .62833 .39829 .61389 .39139 .60182 Metetra
.798 .684 .739 r
.39139 .60182 .39829 .61389 .41054 .59906 .4037 .5864 Metetra
.794 .677 .735 r
.4037 .5864 .41054 .59906 .42277 .58406 .41599 .57084 Metetra
.79 .67 .732 r
.41599 .57084 .42277 .58406 .43498 .56907 .42824 .55533 Metetra
.785 .663 .73 r
.42824 .55533 .43498 .56907 .44715 .55429 .44046 .54006 Metetra
.778 .656 .729 r
.44046 .54006 .44715 .55429 .45929 .53989 .45264 .5252 Metetra
.77 .649 .728 r
.45264 .5252 .45929 .53989 .4714 .52605 .46478 .51094 Metetra
.761 .642 .729 r
.46478 .51094 .4714 .52605 .48348 .51291 .47689 .49742 Metetra
.751 .634 .731 r
.47689 .49742 .48348 .51291 .49554 .50061 .48897 .48479 Metetra
.739 .626 .733 r
.48897 .48479 .49554 .50061 .50758 .48928 .50103 .47315 Metetra
.726 .617 .736 r
.50103 .47315 .50758 .48928 .51962 .47901 .51308 .46263 Metetra
.711 .608 .74 r
.51308 .46263 .51962 .47901 .53166 .46991 .52514 .45332 Metetra
.695 .598 .744 r
.52514 .45332 .53166 .46991 .54373 .46204 .53721 .44528 Metetra
.676 .587 .748 r
.53721 .44528 .54373 .46204 .55584 .45547 .54932 .43857 Metetra
.656 .576 .753 r
.54932 .43857 .55584 .45547 .56799 .45022 .56148 .43324 Metetra
.634 .563 .758 r
.56148 .43324 .56799 .45022 .58021 .44632 .5737 .4293 Metetra
.61 .55 .762 r
.5737 .4293 .58021 .44632 .59252 .44378 .586 .42676 Metetra
.584 .536 .767 r
.586 .42676 .59252 .44378 .60492 .44258 .59839 .42561 Metetra
.556 .521 .772 r
.59839 .42561 .60492 .44258 .61743 .44269 .6109 .42581 Metetra
.527 .506 .776 r
.6109 .42581 .61743 .44269 .63007 .44406 .62354 .42731 Metetra
.497 .491 .78 r
.62354 .42731 .63007 .44406 .64286 .44663 .63632 .43005 Metetra
.466 .475 .784 r
.63632 .43005 .64286 .44663 .6558 .45031 .64926 .43395 Metetra
.435 .46 .787 r
.64926 .43395 .6558 .45031 .66889 .455 .66236 .4389 Metetra
.405 .446 .79 r
.66236 .4389 .66889 .455 .68216 .46059 .67563 .44479 Metetra
.376 .434 .793 r
.67563 .44479 .68216 .46059 .69561 .46693 .68908 .45147 Metetra
.35 .423 .796 r
.68908 .45147 .69561 .46693 .70923 .47389 .70272 .45881 Metetra
.327 .416 .8 r
.70272 .45881 .70923 .47389 .72303 .48129 .71653 .46663 Metetra
.309 .412 .805 r
.71653 .46663 .72303 .48129 .737 .48895 .73053 .47475 Metetra
.296 .412 .811 r
.73053 .47475 .737 .48895 .75113 .49669 .74469 .48298 Metetra
.29 .417 .818 r
.74469 .48298 .75113 .49669 .76542 .5043 .75902 .49112 Metetra
.29 .428 .828 r
.75902 .49112 .76542 .5043 .77984 .51157 .77348 .49894 Metetra
.299 .444 .839 r
.77348 .49894 .77984 .51157 .79438 .51828 .78808 .50622 Metetra
.316 .468 .853 r
.78808 .50622 .79438 .51828 .809 .5242 .80277 .51274 Metetra
.343 .497 .868 r
.80277 .51274 .809 .5242 .8237 .52911 .81753 .51826 Metetra
.378 .534 .884 r
.81753 .51826 .8237 .52911 .83842 .53277 .83234 .52256 Metetra
.424 .576 .9 r
.83234 .52256 .83842 .53277 .85313 .53498 .84715 .52541 Metetra
.478 .623 .915 r
.84715 .52541 .85313 .53498 .8678 .53551 .86192 .52658 Metetra
.539 .674 .925 r
.86192 .52658 .8678 .53551 .88238 .53416 .87661 .52586 Metetra
.705 .77 .903 r
.27458 .69265 .28217 .699 .29389 .69434 .28637 .68741 Metetra
.747 .761 .864 r
.28637 .68741 .29389 .69434 .30578 .68771 .29834 .68018 Metetra
.772 .751 .833 r
.29834 .68018 .30578 .68771 .31781 .67927 .31043 .67114 Metetra
.788 .74 .809 r
.31043 .67114 .31781 .67927 .32994 .66921 .32264 .66049 Metetra
.798 .731 .79 r
.32264 .66049 .32994 .66921 .34216 .65773 .33493 .64842 Metetra
.803 .722 .775 r
.33493 .64842 .34216 .65773 .35443 .64504 .34727 .63514 Metetra
.807 .714 .763 r
.34727 .63514 .35443 .64504 .36674 .63135 .35965 .62088 Metetra
.808 .707 .753 r
.35965 .62088 .36674 .63135 .37906 .61687 .37204 .60584 Metetra
.808 .7 .746 r
.37204 .60584 .37906 .61687 .39139 .60182 .38443 .59025 Metetra
.806 .693 .74 r
.38443 .59025 .39139 .60182 .4037 .5864 .3968 .57432 Metetra
.803 .687 .736 r
.3968 .57432 .4037 .5864 .41599 .57084 .40915 .55827 Metetra
.799 .68 .733 r
.40915 .55827 .41599 .57084 .42824 .55533 .42145 .54229 Metetra
.794 .674 .732 r
.42145 .54229 .42824 .55533 .44046 .54006 .43371 .52659 Metetra
.787 .668 .732 r
.43371 .52659 .44046 .54006 .45264 .5252 .44594 .51133 Metetra
.78 .661 .732 r
.44594 .51133 .45264 .5252 .46478 .51094 .45811 .4967 Metetra
.771 .654 .734 r
.45811 .4967 .46478 .51094 .47689 .49742 .47025 .48285 Metetra
.76 .647 .736 r
.47025 .48285 .47689 .49742 .48897 .48479 .48236 .46991 Metetra
.748 .639 .739 r
.48236 .46991 .48897 .48479 .50103 .47315 .49445 .45802 Metetra
.735 .631 .743 r
.49445 .45802 .50103 .47315 .51308 .46263 .50652 .44727 Metetra
.72 .622 .747 r
.50652 .44727 .51308 .46263 .52514 .45332 .51859 .43777 Metetra
.702 .612 .752 r
.51859 .43777 .52514 .45332 .53721 .44528 .53068 .42957 Metetra
.683 .601 .758 r
.53068 .42957 .53721 .44528 .54932 .43857 .5428 .42275 Metetra
.661 .589 .763 r
.5428 .42275 .54932 .43857 .56148 .43324 .55496 .41734 Metetra
.637 .576 .769 r
.55496 .41734 .56148 .43324 .5737 .4293 .56718 .41336 Metetra
.611 .562 .775 r
.56718 .41336 .5737 .4293 .586 .42676 .57948 .41082 Metetra
.582 .547 .78 r
.57948 .41082 .586 .42676 .59839 .42561 .59188 .4097 Metetra
.552 .531 .786 r
.59188 .4097 .59839 .42561 .6109 .42581 .60439 .40997 Metetra
.519 .514 .79 r
.60439 .40997 .6109 .42581 .62354 .42731 .61703 .41158 Metetra
.484 .496 .794 r
.61703 .41158 .62354 .42731 .63632 .43005 .6298 .41447 Metetra
.449 .478 .797 r
.6298 .41447 .63632 .43005 .64926 .43395 .64274 .41855 Metetra
.414 .461 .8 r
.64274 .41855 .64926 .43395 .66236 .4389 .65584 .42372 Metetra
.38 .444 .802 r
.65584 .42372 .66236 .4389 .67563 .44479 .66912 .42986 Metetra
.347 .429 .803 r
.66912 .42986 .67563 .44479 .68908 .45147 .68258 .43684 Metetra
.318 .416 .805 r
.68258 .43684 .68908 .45147 .70272 .45881 .69622 .44451 Metetra
.292 .407 .807 r
.69622 .44451 .70272 .45881 .71653 .46663 .71005 .45269 Metetra
.272 .401 .811 r
.71005 .45269 .71653 .46663 .73053 .47475 .72407 .4612 Metetra
.258 .4 .815 r
.72407 .4612 .73053 .47475 .74469 .48298 .73826 .46986 Metetra
.251 .404 .822 r
.73826 .46986 .74469 .48298 .75902 .49112 .75262 .47844 Metetra
.251 .414 .83 r
.75262 .47844 .75902 .49112 .77348 .49894 .76713 .48674 Metetra
.261 .431 .841 r
.76713 .48674 .77348 .49894 .78808 .50622 .78177 .49452 Metetra
.28 .454 .855 r
.78177 .49452 .78808 .50622 .80277 .51274 .79652 .50156 Metetra
.309 .484 .87 r
.79652 .50156 .80277 .51274 .81753 .51826 .81135 .50761 Metetra
.347 .521 .886 r
.81135 .50761 .81753 .51826 .83234 .52256 .82623 .51246 Metetra
.396 .564 .902 r
.82623 .51246 .83234 .52256 .84715 .52541 .84112 .51585 Metetra
.453 .612 .917 r
.84112 .51585 .84715 .52541 .86192 .52658 .85599 .51758 Metetra
.517 .663 .927 r
.85599 .51758 .86192 .52658 .87661 .52586 .87078 .51742 Metetra
.586 .714 .932 r
.87078 .51742 .87661 .52586 .89118 .52307 .88546 .51518 Metetra
.717 .77 .894 r
.26693 .68616 .27458 .69265 .28637 .68741 .27879 .68041 Metetra
.756 .762 .858 r
.27879 .68041 .28637 .68741 .29834 .68018 .29083 .67268 Metetra
.779 .753 .829 r
.29083 .67268 .29834 .68018 .31043 .67114 .303 .66313 Metetra
.795 .744 .806 r
.303 .66313 .31043 .67114 .32264 .66049 .31527 .65197 Metetra
.804 .736 .788 r
.31527 .65197 .32264 .66049 .33493 .64842 .32763 .63939 Metetra
.811 .728 .774 r
.32763 .63939 .33493 .64842 .34727 .63514 .34005 .62561 Metetra
.814 .721 .762 r
.34005 .62561 .34727 .63514 .35965 .62088 .3525 .61085 Metetra
.816 .715 .754 r
.3525 .61085 .35965 .62088 .37204 .60584 .36496 .59533 Metetra
.816 .709 .747 r
.36496 .59533 .37204 .60584 .38443 .59025 .37741 .57928 Metetra
.815 .703 .742 r
.37741 .57928 .38443 .59025 .3968 .57432 .38984 .56291 Metetra
.812 .697 .738 r
.38984 .56291 .3968 .57432 .40915 .55827 .40224 .54644 Metetra
.808 .692 .736 r
.40224 .54644 .40915 .55827 .42145 .54229 .4146 .53006 Metetra
.803 .686 .735 r
.4146 .53006 .42145 .54229 .43371 .52659 .42692 .51398 Metetra
.797 .681 .736 r
.42692 .51398 .43371 .52659 .44594 .51133 .43918 .49839 Metetra
.79 .675 .737 r
.43918 .49839 .44594 .51133 .45811 .4967 .4514 .48344 Metetra
.781 .668 .739 r
.4514 .48344 .45811 .4967 .47025 .48285 .46358 .46929 Metetra
.771 .662 .742 r
.46358 .46929 .47025 .48285 .48236 .46991 .47572 .4561 Metetra
.759 .655 .746 r
.47572 .4561 .48236 .46991 .49445 .45802 .48784 .44398 Metetra
.745 .647 .751 r
.48784 .44398 .49445 .45802 .50652 .44727 .49993 .43303 Metetra
.729 .638 .757 r
.49993 .43303 .50652 .44727 .51859 .43777 .51203 .42336 Metetra
.711 .628 .763 r
.51203 .42336 .51859 .43777 .53068 .42957 .52413 .41503 Metetra
.691 .618 .77 r
.52413 .41503 .53068 .42957 .5428 .42275 .53626 .40811 Metetra
.668 .606 .777 r
.53626 .40811 .5428 .42275 .55496 .41734 .54843 .40263 Metetra
.641 .592 .784 r
.54843 .40263 .55496 .41734 .56718 .41336 .56066 .39861 Metetra
.612 .577 .79 r
.56066 .39861 .56718 .41336 .57948 .41082 .57297 .39606 Metetra
.581 .561 .797 r
.57297 .39606 .57948 .41082 .59188 .4097 .58537 .39496 Metetra
.546 .543 .803 r
.58537 .39496 .59188 .4097 .60439 .40997 .59788 .39528 Metetra
.509 .524 .807 r
.59788 .39528 .60439 .40997 .61703 .41158 .61052 .39698 Metetra
.47 .504 .811 r
.61052 .39698 .61703 .41158 .6298 .41447 .6233 .39999 Metetra
.43 .483 .814 r
.6233 .39999 .6298 .41447 .64274 .41855 .63624 .40422 Metetra
.389 .462 .815 r
.63624 .40422 .64274 .41855 .65584 .42372 .64934 .40957 Metetra
.35 .443 .815 r
.64934 .40957 .65584 .42372 .66912 .42986 .66262 .41593 Metetra
.313 .425 .815 r
.66262 .41593 .66912 .42986 .68258 .43684 .67609 .42315 Metetra
.28 .409 .815 r
.67609 .42315 .68258 .43684 .69622 .44451 .68975 .43109 Metetra
.251 .397 .815 r
.68975 .43109 .69622 .44451 .71005 .45269 .70359 .43957 Metetra
.229 .389 .817 r
.70359 .43957 .71005 .45269 .72407 .4612 .71763 .44841 Metetra
.214 .387 .82 r
.71763 .44841 .72407 .4612 .73826 .46986 .73185 .45742 Metetra
.206 .39 .825 r
.73185 .45742 .73826 .46986 .75262 .47844 .74624 .46638 Metetra
.208 .4 .833 r
.74624 .46638 .75262 .47844 .76713 .48674 .76078 .47507 Metetra
.219 .417 .843 r
.76078 .47507 .76713 .48674 .78177 .49452 .77547 .48327 Metetra
.241 .441 .857 r
.77547 .48327 .78177 .49452 .79652 .50156 .79027 .49074 Metetra
.273 .472 .872 r
.79027 .49074 .79652 .50156 .81135 .50761 .80516 .49725 Metetra
.315 .51 .889 r
.80516 .49725 .81135 .50761 .82623 .51246 .82011 .50255 Metetra
.367 .555 .905 r
.82011 .50255 .82623 .51246 .84112 .51585 .83507 .50641 Metetra
.428 .603 .92 r
.83507 .50641 .84112 .51585 .85599 .51758 .85002 .5086 Metetra
.496 .655 .93 r
.85002 .5086 .85599 .51758 .87078 .51742 .8649 .50891 Metetra
.568 .705 .934 r
.8649 .50891 .87078 .51742 .88546 .51518 .87968 .50712 Metetra
.726 .77 .888 r
.25923 .67958 .26693 .68616 .27879 .68041 .27115 .67343 Metetra
.763 .764 .854 r
.27115 .67343 .27879 .68041 .29083 .67268 .28325 .66528 Metetra
.786 .757 .827 r
.28325 .66528 .29083 .67268 .303 .66313 .29549 .6553 Metetra
.801 .749 .805 r
.29549 .6553 .303 .66313 .31527 .65197 .30784 .64371 Metetra
.811 .742 .788 r
.30784 .64371 .31527 .65197 .32763 .63939 .32027 .63071 Metetra
.818 .736 .774 r
.32027 .63071 .32763 .63939 .34005 .62561 .33275 .61652 Metetra
.822 .73 .763 r
.33275 .61652 .34005 .62561 .3525 .61085 .34527 .60135 Metetra
.824 .724 .755 r
.34527 .60135 .3525 .61085 .36496 .59533 .35779 .58544 Metetra
.824 .719 .749 r
.35779 .58544 .36496 .59533 .37741 .57928 .37031 .569 Metetra
.824 .714 .744 r
.37031 .569 .37741 .57928 .38984 .56291 .38281 .55226 Metetra
.821 .71 .741 r
.38281 .55226 .38984 .56291 .40224 .54644 .39527 .53544 Metetra
.818 .705 .74 r
.39527 .53544 .40224 .54644 .4146 .53006 .40769 .51873 Metetra
.814 .7 .74 r
.40769 .51873 .4146 .53006 .42692 .51398 .42005 .50234 Metetra
.808 .695 .741 r
.42005 .50234 .42692 .51398 .43918 .49839 .43237 .48645 Metetra
.801 .69 .743 r
.43237 .48645 .43918 .49839 .4514 .48344 .44463 .47124 Metetra
.792 .685 .746 r
.44463 .47124 .4514 .48344 .46358 .46929 .45685 .45685 Metetra
.782 .679 .75 r
.45685 .45685 .46358 .46929 .47572 .4561 .46903 .44344 Metetra
.77 .673 .755 r
.46903 .44344 .47572 .4561 .48784 .44398 .48118 .43112 Metetra
.756 .665 .761 r
.48118 .43112 .48784 .44398 .49993 .43303 .49331 .42001 Metetra
.74 .657 .768 r
.49331 .42001 .49993 .43303 .51203 .42336 .50543 .4102 Metetra
.721 .648 .776 r
.50543 .4102 .51203 .42336 .52413 .41503 .51755 .40176 Metetra
.699 .638 .784 r
.51755 .40176 .52413 .41503 .53626 .40811 .5297 .39474 Metetra
.674 .626 .792 r
.5297 .39474 .53626 .40811 .54843 .40263 .54189 .38919 Metetra
.646 .612 .801 r
.54189 .38919 .54843 .40263 .56066 .39861 .55413 .38514 Metetra
.614 .596 .809 r
.55413 .38514 .56066 .39861 .57297 .39606 .56645 .38257 Metetra
.578 .578 .817 r
.56645 .38257 .57297 .39606 .58537 .39496 .57886 .38149 Metetra
.539 .559 .823 r
.57886 .38149 .58537 .39496 .59788 .39528 .59137 .38185 Metetra
.496 .537 .828 r
.59137 .38185 .59788 .39528 .61052 .39698 .60402 .38362 Metetra
.452 .514 .831 r
.60402 .38362 .61052 .39698 .6233 .39999 .6168 .38671 Metetra
.405 .489 .833 r
.6168 .38671 .6233 .39999 .63624 .40422 .62975 .39106 Metetra
.359 .465 .832 r
.62975 .39106 .63624 .40422 .64934 .40957 .64286 .39655 Metetra
.314 .441 .83 r
.64286 .39655 .64934 .40957 .66262 .41593 .65614 .40308 Metetra
.272 .42 .828 r
.65614 .40308 .66262 .41593 .67609 .42315 .66962 .41049 Metetra
.234 .401 .825 r
.66962 .41049 .67609 .42315 .68975 .43109 .68329 .41864 Metetra
.203 .386 .822 r
.68329 .41864 .68975 .43109 .70359 .43957 .69715 .42736 Metetra
.179 .377 .821 r
.69715 .42736 .70359 .43957 .71763 .44841 .7112 .43646 Metetra
.163 .373 .823 r
.7112 .43646 .71763 .44841 .73185 .45742 .72544 .44575 Metetra
.156 .376 .827 r
.72544 .44575 .73185 .45742 .74624 .46638 .73986 .45502 Metetra
.16 .386 .834 r
.73986 .45502 .74624 .46638 .76078 .47507 .75444 .46403 Metetra
.174 .403 .844 r
.75444 .46403 .76078 .47507 .77547 .48327 .76917 .47256 Metetra
.198 .428 .858 r
.76917 .47256 .77547 .48327 .79027 .49074 .78401 .48038 Metetra
.235 .461 .874 r
.78401 .48038 .79027 .49074 .80516 .49725 .79896 .48725 Metetra
.282 .501 .891 r
.79896 .48725 .80516 .49725 .82011 .50255 .81396 .49291 Metetra
.339 .547 .908 r
.81396 .49291 .82011 .50255 .83507 .50641 .82899 .49715 Metetra
.405 .597 .923 r
.82899 .49715 .83507 .50641 .85002 .5086 .84401 .49971 Metetra
.477 .649 .934 r
.84401 .49971 .85002 .5086 .8649 .50891 .85898 .50039 Metetra
.553 .7 .937 r
.85898 .50039 .8649 .50891 .87968 .50712 .87384 .49897 Metetra
.733 .772 .884 r
.25145 .67298 .25923 .67958 .27115 .67343 .26344 .6665 Metetra
.768 .768 .852 r
.26344 .6665 .27115 .67343 .28325 .66528 .2756 .65802 Metetra
.791 .762 .826 r
.2756 .65802 .28325 .66528 .29549 .6553 .2879 .64772 Metetra
.807 .756 .805 r
.2879 .64772 .29549 .6553 .30784 .64371 .30032 .63579 Metetra
.817 .75 .789 r
.30032 .63579 .30784 .64371 .32027 .63071 .31282 .62246 Metetra
.824 .744 .776 r
.31282 .62246 .32027 .63071 .33275 .61652 .32537 .60794 Metetra
.829 .74 .765 r
.32537 .60794 .33275 .61652 .34527 .60135 .33795 .59245 Metetra
.832 .735 .758 r
.33795 .59245 .34527 .60135 .35779 .58544 .35055 .57622 Metetra
.833 .731 .752 r
.35055 .57622 .35779 .58544 .37031 .569 .36313 .55948 Metetra
.833 .727 .748 r
.36313 .55948 .37031 .569 .38281 .55226 .37569 .54244 Metetra
.831 .723 .745 r
.37569 .54244 .38281 .55226 .39527 .53544 .38822 .52534 Metetra
.828 .719 .744 r
.38822 .52534 .39527 .53544 .40769 .51873 .40069 .50837 Metetra
.824 .716 .745 r
.40069 .50837 .40769 .51873 .42005 .50234 .41312 .49173 Metetra
.819 .712 .746 r
.41312 .49173 .42005 .50234 .43237 .48645 .42548 .47561 Metetra
.813 .708 .749 r
.42548 .47561 .43237 .48645 .44463 .47124 .4378 .46018 Metetra
.805 .703 .754 r
.4378 .46018 .44463 .47124 .45685 .45685 .45007 .4456 Metetra
.795 .699 .759 r
.45007 .4456 .45685 .45685 .46903 .44344 .46229 .43201 Metetra
.783 .693 .765 r
.46229 .43201 .46903 .44344 .48118 .43112 .47447 .41954 Metetra
.769 .687 .773 r
.47447 .41954 .48118 .43112 .49331 .42001 .48663 .40829 Metetra
.752 .68 .782 r
.48663 .40829 .49331 .42001 .50543 .4102 .49878 .39836 Metetra
.732 .672 .791 r
.49878 .39836 .50543 .4102 .51755 .40176 .51094 .38982 Metetra
.709 .662 .801 r
.51094 .38982 .51755 .40176 .5297 .39474 .52311 .38272 Metetra
.682 .65 .811 r
.52311 .38272 .5297 .39474 .54189 .38919 .53532 .37712 Metetra
.651 .636 .822 r
.53532 .37712 .54189 .38919 .55413 .38514 .54758 .37302 Metetra
.615 .619 .832 r
.54758 .37302 .55413 .38514 .56645 .38257 .55991 .37044 Metetra
.575 .6 .841 r
.55991 .37044 .56645 .38257 .57886 .38149 .57233 .36936 Metetra
.53 .578 .848 r
.57233 .36936 .57886 .38149 .59137 .38185 .58486 .36975 Metetra
.481 .553 .853 r
.58486 .36975 .59137 .38185 .60402 .38362 .59752 .37155 Metetra
.429 .526 .855 r
.59752 .37155 .60402 .38362 .6168 .38671 .61031 .37471 Metetra
.375 .497 .855 r
.61031 .37471 .6168 .38671 .62975 .39106 .62326 .37914 Metetra
.321 .468 .851 r
.62326 .37914 .62975 .39106 .64286 .39655 .63638 .38474 Metetra
.269 .44 .846 r
.63638 .38474 .64286 .39655 .65614 .40308 .64968 .39138 Metetra
.222 .413 .84 r
.64968 .39138 .65614 .40308 .66962 .41049 .66317 .39894 Metetra
.18 .391 .833 r
.66317 .39894 .66962 .41049 .68329 .41864 .67685 .40725 Metetra
.146 .373 .827 r
.67685 .40725 .68329 .41864 .69715 .42736 .69072 .41614 Metetra
.12 .362 .824 r
.69072 .41614 .69715 .42736 .7112 .43646 .7048 .42544 Metetra
.105 .357 .823 r
.7048 .42544 .7112 .43646 .72544 .44575 .71906 .43494 Metetra
.1 .359 .826 r
.71906 .43494 .72544 .44575 .73986 .45502 .7335 .44442 Metetra
.106 .37 .833 r
.7335 .44442 .73986 .45502 .75444 .46403 .74811 .45368 Metetra
.124 .389 .843 r
.74811 .45368 .75444 .46403 .76917 .47256 .76287 .46246 Metetra
.153 .416 .858 r
.76287 .46246 .76917 .47256 .78401 .48038 .77776 .47054 Metetra
.195 .451 .875 r
.77776 .47054 .78401 .48038 .79896 .48725 .79275 .47767 Metetra
.248 .493 .894 r
.79275 .47767 .79896 .48725 .81396 .49291 .8078 .48361 Metetra
.311 .541 .912 r
.8078 .48361 .81396 .49291 .82899 .49715 .82289 .48812 Metetra
.383 .593 .928 r
.82289 .48812 .82899 .49715 .84401 .49971 .83798 .49096 Metetra
.46 .646 .938 r
.83798 .49096 .84401 .49971 .85898 .50039 .85302 .49191 Metetra
.54 .697 .941 r
.85302 .49191 .85898 .50039 .87384 .49897 .86796 .49076 Metetra
.737 .774 .882 r
.24361 .66637 .25145 .67298 .26344 .6665 .25565 .65967 Metetra
.773 .771 .852 r
.25565 .65967 .26344 .6665 .2756 .65802 .26787 .65095 Metetra
.796 .767 .827 r
.26787 .65095 .2756 .65802 .2879 .64772 .28023 .64041 Metetra
.812 .763 .807 r
.28023 .64041 .2879 .64772 .30032 .63579 .29271 .62825 Metetra
.823 .758 .791 r
.29271 .62825 .30032 .63579 .31282 .62246 .30528 .61468 Metetra
.831 .754 .778 r
.30528 .61468 .31282 .62246 .32537 .60794 .3179 .59991 Metetra
.836 .75 .768 r
.3179 .59991 .32537 .60794 .33795 .59245 .33055 .58419 Metetra
.84 .747 .761 r
.33055 .58419 .33795 .59245 .35055 .57622 .34321 .56773 Metetra
.841 .744 .756 r
.34321 .56773 .35055 .57622 .36313 .55948 .35586 .55076 Metetra
.842 .741 .752 r
.35586 .55076 .36313 .55948 .37569 .54244 .36849 .53351 Metetra
.841 .738 .75 r
.36849 .53351 .37569 .54244 .38822 .52534 .38107 .5162 Metetra
.839 .735 .75 r
.38107 .5162 .38822 .52534 .40069 .50837 .39361 .49903 Metetra
.836 .733 .751 r
.39361 .49903 .40069 .50837 .41312 .49173 .40609 .48221 Metetra
.831 .73 .753 r
.40609 .48221 .41312 .49173 .42548 .47561 .41852 .46591 Metetra
.825 .727 .757 r
.41852 .46591 .42548 .47561 .4378 .46018 .43089 .45032 Metetra
.817 .724 .762 r
.43089 .45032 .4378 .46018 .45007 .4456 .44321 .4356 Metetra
.808 .721 .769 r
.44321 .4356 .45007 .4456 .46229 .43201 .45547 .42187 Metetra
.796 .717 .777 r
.45547 .42187 .46229 .43201 .47447 .41954 .4677 .40928 Metetra
.782 .712 .786 r
.4677 .40928 .47447 .41954 .48663 .40829 .4799 .39792 Metetra
.765 .707 .797 r
.4799 .39792 .48663 .40829 .49878 .39836 .49209 .3879 Metetra
.745 .699 .809 r
.49209 .3879 .49878 .39836 .51094 .38982 .50428 .37928 Metetra
.72 .69 .821 r
.50428 .37928 .51094 .38982 .52311 .38272 .51648 .37212 Metetra
.691 .679 .834 r
.51648 .37212 .52311 .38272 .53532 .37712 .52871 .36646 Metetra
.656 .665 .847 r
.52871 .36646 .53532 .37712 .54758 .37302 .541 .36233 Metetra
.616 .648 .859 r
.541 .36233 .54758 .37302 .55991 .37044 .55335 .35973 Metetra
.57 .627 .869 r
.55335 .35973 .55991 .37044 .57233 .36936 .5658 .35863 Metetra
.517 .602 .877 r
.5658 .35863 .57233 .36936 .58486 .36975 .57834 .35903 Metetra
.46 .573 .881 r
.57834 .35903 .58486 .36975 .59752 .37155 .59101 .36085 Metetra
.399 .54 .882 r
.59101 .36085 .59752 .37155 .61031 .37471 .60382 .36405 Metetra
.335 .506 .878 r
.60382 .36405 .61031 .37471 .62326 .37914 .61678 .36853 Metetra
.273 .471 .87 r
.61678 .36853 .62326 .37914 .63638 .38474 .62991 .37418 Metetra
.214 .436 .86 r
.62991 .37418 .63638 .38474 .64968 .39138 .64323 .3809 Metetra
.16 .405 .849 r
.64323 .3809 .64968 .39138 .66317 .39894 .65673 .38854 Metetra
.115 .378 .837 r
.65673 .38854 .66317 .39894 .67685 .40725 .67042 .39696 Metetra
.079 .357 .827 r
.67042 .39696 .67685 .40725 .69072 .41614 .68431 .40597 Metetra
.053 .344 .821 r
.68431 .40597 .69072 .41614 .7048 .42544 .6984 .41539 Metetra
.04 .338 .818 r
.6984 .41539 .7048 .42544 .71906 .43494 .71268 .42503 Metetra
.037 .341 .82 r
.71268 .42503 .71906 .43494 .7335 .44442 .72715 .43466 Metetra
.048 .353 .827 r
.72715 .43466 .7335 .44442 .74811 .45368 .74179 .44407 Metetra
.07 .374 .84 r
.74179 .44407 .74811 .45368 .76287 .46246 .75658 .45302 Metetra
.106 .404 .856 r
.75658 .45302 .76287 .46246 .77776 .47054 .7715 .46126 Metetra
.154 .441 .875 r
.7715 .46126 .77776 .47054 .79275 .47767 .78653 .46857 Metetra
.213 .487 .896 r
.78653 .46857 .79275 .47767 .8078 .48361 .80163 .47469 Metetra
.284 .537 .916 r
.80163 .47469 .8078 .48361 .82289 .48812 .81677 .47937 Metetra
.362 .591 .933 r
.81677 .47937 .82289 .48812 .83798 .49096 .83192 .48239 Metetra
.446 .645 .943 r
.83192 .48239 .83798 .49096 .85302 .49191 .84702 .48352 Metetra
.53 .697 .945 r
.84702 .48352 .85302 .49191 .86796 .49076 .86202 .48254 Metetra
.74 .776 .882 r
.2357 .6598 .24361 .66637 .25565 .65967 .24779 .65296 Metetra
.776 .776 .853 r
.24779 .65296 .25565 .65967 .26787 .65095 .26006 .6441 Metetra
.8 .773 .829 r
.26006 .6441 .26787 .65095 .28023 .64041 .27248 .63342 Metetra
.817 .77 .809 r
.27248 .63342 .28023 .64041 .29271 .62825 .28502 .62111 Metetra
.829 .767 .794 r
.28502 .62111 .29271 .62825 .30528 .61468 .29764 .60739 Metetra
.837 .764 .782 r
.29764 .60739 .30528 .61468 .3179 .59991 .31033 .59248 Metetra
.843 .762 .772 r
.31033 .59248 .3179 .59991 .33055 .58419 .32304 .57661 Metetra
.847 .759 .765 r
.32304 .57661 .33055 .58419 .34321 .56773 .33577 .56 Metetra
.85 .757 .76 r
.33577 .56 .34321 .56773 .35586 .55076 .34849 .54289 Metetra
.851 .756 .757 r
.34849 .54289 .35586 .55076 .36849 .53351 .36118 .52551 Metetra
.851 .754 .755 r
.36118 .52551 .36849 .53351 .38107 .5162 .37383 .50806 Metetra
.85 .753 .756 r
.37383 .50806 .38107 .5162 .39361 .49903 .38644 .49076 Metetra
.847 .752 .757 r
.38644 .49076 .39361 .49903 .40609 .48221 .39898 .47382 Metetra
.843 .75 .761 r
.39898 .47382 .40609 .48221 .41852 .46591 .41147 .45741 Metetra
.838 .749 .766 r
.41147 .45741 .41852 .46591 .43089 .45032 .42389 .44171 Metetra
.831 .748 .772 r
.42389 .44171 .43089 .45032 .44321 .4356 .43626 .42688 Metetra
.822 .746 .78 r
.43626 .42688 .44321 .4356 .45547 .42187 .44858 .41306 Metetra
.811 .744 .79 r
.44858 .41306 .45547 .42187 .4677 .40928 .46086 .40038 Metetra
.797 .741 .801 r
.46086 .40038 .4677 .40928 .4799 .39792 .47311 .38895 Metetra
.779 .737 .814 r
.47311 .38895 .4799 .39792 .49209 .3879 .48534 .37886 Metetra
.758 .732 .829 r
.48534 .37886 .49209 .3879 .50428 .37928 .49756 .37018 Metetra
.731 .724 .844 r
.49756 .37018 .50428 .37928 .51648 .37212 .5098 .36297 Metetra
.699 .714 .86 r
.5098 .36297 .51648 .37212 .52871 .36646 .52207 .35727 Metetra
.661 .7 .876 r
.52207 .35727 .52871 .36646 .541 .36233 .53438 .3531 Metetra
.615 .682 .89 r
.53438 .3531 .541 .36233 .55335 .35973 .54677 .35047 Metetra
.561 .659 .902 r
.54677 .35047 .55335 .35973 .5658 .35863 .55923 .34936 Metetra
.499 .63 .91 r
.55923 .34936 .5658 .35863 .57834 .35903 .5718 .34974 Metetra
.431 .595 .912 r
.5718 .34974 .57834 .35903 .59101 .36085 .58449 .35156 Metetra
.358 .556 .909 r
.58449 .35156 .59101 .36085 .60382 .36405 .59732 .35476 Metetra
.284 .514 .9 r
.59732 .35476 .60382 .36405 .61678 .36853 .6103 .35925 Metetra
.212 .471 .886 r
.6103 .35925 .61678 .36853 .62991 .37418 .62345 .36493 Metetra
.145 .429 .868 r
.62345 .36493 .62991 .37418 .64323 .3809 .63677 .37168 Metetra
.086 .392 .85 r
.63677 .37168 .64323 .3809 .65673 .38854 .65029 .37936 Metetra
.038 .361 .833 r
.65029 .37936 .65673 .38854 .67042 .39696 .664 .38782 Metetra
.002 .337 .819 r
.664 .38782 .67042 .39696 .68431 .40597 .67791 .39688 Metetra
0 .323 .81 r
.67791 .39688 .68431 .40597 .6984 .41539 .69201 .40636 Metetra
0 .317 .806 r
.69201 .40636 .6984 .41539 .71268 .42503 .70632 .41606 Metetra
0 .321 .808 r
.70632 .41606 .71268 .42503 .72715 .43466 .7208 .42576 Metetra
0 .335 .817 r
.7208 .42576 .72715 .43466 .74179 .44407 .73547 .43524 Metetra
.014 .359 .832 r
.73547 .43524 .74179 .44407 .75658 .45302 .75029 .44426 Metetra
.057 .391 .851 r
.75029 .44426 .75658 .45302 .7715 .46126 .76524 .45259 Metetra
.112 .433 .874 r
.76524 .45259 .7715 .46126 .78653 .46857 .78031 .45998 Metetra
.18 .482 .897 r
.78031 .45998 .78653 .46857 .80163 .47469 .79545 .46617 Metetra
.258 .536 .92 r
.79545 .46617 .80163 .47469 .81677 .47937 .81063 .47094 Metetra
.345 .592 .938 r
.81063 .47094 .81677 .47937 .83192 .48239 .82583 .47404 Metetra
.434 .648 .948 r
.82583 .47404 .83192 .48239 .84702 .48352 .84098 .47524 Metetra
.523 .699 .949 r
.84098 .47524 .84702 .48352 .86202 .48254 .85605 .47432 Metetra
.74 .779 .884 r
.22772 .65326 .2357 .6598 .24779 .65296 .23984 .64638 Metetra
.777 .781 .855 r
.23984 .64638 .24779 .65296 .26006 .6441 .25216 .63749 Metetra
.803 .78 .832 r
.25216 .63749 .26006 .6441 .27248 .63342 .26463 .62676 Metetra
.82 .779 .813 r
.26463 .62676 .27248 .63342 .28502 .62111 .27722 .6144 Metetra
.833 .777 .798 r
.27722 .6144 .28502 .62111 .29764 .60739 .28991 .60062 Metetra
.843 .775 .786 r
.28991 .60062 .29764 .60739 .31033 .59248 .30265 .58566 Metetra
.85 .774 .777 r
.30265 .58566 .31033 .59248 .32304 .57661 .31543 .56973 Metetra
.855 .773 .77 r
.31543 .56973 .32304 .57661 .33577 .56 .32823 .55306 Metetra
.858 .772 .765 r
.32823 .55306 .33577 .56 .34849 .54289 .34101 .5359 Metetra
.86 .772 .763 r
.34101 .5359 .34849 .54289 .36118 .52551 .35377 .51845 Metetra
.861 .771 .762 r
.35377 .51845 .36118 .52551 .37383 .50806 .36649 .50094 Metetra
.86 .772 .762 r
.36649 .50094 .37383 .50806 .38644 .49076 .37915 .48359 Metetra
.859 .772 .765 r
.37915 .48359 .38644 .49076 .39898 .47382 .39176 .46658 Metetra
.856 .772 .769 r
.39176 .46658 .39898 .47382 .41147 .45741 .40431 .45012 Metetra
.851 .773 .775 r
.40431 .45012 .41147 .45741 .42389 .44171 .4168 .43436 Metetra
.845 .774 .783 r
.4168 .43436 .42389 .44171 .43626 .42688 .42923 .41948 Metetra
.836 .774 .792 r
.42923 .41948 .43626 .42688 .44858 .41306 .44161 .40561 Metetra
.825 .774 .804 r
.44161 .40561 .44858 .41306 .46086 .40038 .45394 .39288 Metetra
.811 .774 .818 r
.45394 .39288 .46086 .40038 .47311 .38895 .46624 .3814 Metetra
.794 .772 .833 r
.46624 .3814 .47311 .38895 .48534 .37886 .47851 .37127 Metetra
.771 .769 .851 r
.47851 .37127 .48534 .37886 .49756 .37018 .49078 .36254 Metetra
.743 .763 .87 r
.49078 .36254 .49756 .37018 .5098 .36297 .50306 .35529 Metetra
.707 .755 .889 r
.50306 .35529 .5098 .36297 .52207 .35727 .51537 .34956 Metetra
.664 .741 .908 r
.51537 .34956 .52207 .35727 .53438 .3531 .52772 .34535 Metetra
.61 .722 .925 r
.52772 .34535 .53438 .3531 .54677 .35047 .54014 .34269 Metetra
.546 .696 .938 r
.54014 .34269 .54677 .35047 .55923 .34936 .55263 .34155 Metetra
.473 .662 .944 r
.55263 .34155 .55923 .34936 .5718 .34974 .56523 .34191 Metetra
.391 .619 .943 r
.56523 .34191 .5718 .34974 .58449 .35156 .57795 .3437 Metetra
.304 .571 .933 r
.57795 .3437 .58449 .35156 .59732 .35476 .5908 .34688 Metetra
.217 .519 .915 r
.5908 .34688 .59732 .35476 .6103 .35925 .6038 .35135 Metetra
.135 .466 .891 r
.6038 .35135 .6103 .35925 .62345 .36493 .61697 .35701 Metetra
.061 .416 .864 r
.61697 .35701 .62345 .36493 .63677 .37168 .63031 .36374 Metetra
0 .373 .838 r
.63031 .36374 .63677 .37168 .65029 .37936 .64385 .37141 Metetra
0 .338 .815 r
.64385 .37141 .65029 .37936 .664 .38782 .65758 .37985 Metetra
0 .312 .798 r
.65758 .37985 .664 .38782 .67791 .39688 .67151 .3889 Metetra
0 .297 .787 r
.67151 .3889 .67791 .39688 .69201 .40636 .68563 .39837 Metetra
0 .292 .784 r
.68563 .39837 .69201 .40636 .70632 .41606 .69995 .40805 Metetra
0 .299 .788 r
.69995 .40805 .70632 .41606 .7208 .42576 .71446 .41774 Metetra
0 .316 .8 r
.71446 .41774 .7208 .42576 .73547 .43524 .72915 .42721 Metetra
0 .343 .819 r
.72915 .42721 .73547 .43524 .75029 .44426 .74399 .43623 Metetra
.008 .38 .843 r
.74399 .43623 .75029 .44426 .76524 .45259 .75898 .44454 Metetra
.072 .426 .87 r
.75898 .44454 .76524 .45259 .78031 .45998 .77407 .45191 Metetra
.149 .479 .898 r
.77407 .45191 .78031 .45998 .79545 .46617 .78925 .45809 Metetra
.236 .537 .923 r
.78925 .45809 .79545 .46617 .81063 .47094 .80447 .46284 Metetra
.33 .596 .943 r
.80447 .46284 .81063 .47094 .82583 .47404 .81971 .46591 Metetra
.427 .653 .953 r
.81971 .46591 .82583 .47404 .84098 .47524 .8349 .46708 Metetra
.52 .703 .953 r
.8349 .46708 .84098 .47524 .85605 .47432 .85002 .46613 Metetra
.739 .781 .887 r
.21966 .64676 .22772 .65326 .23984 .64638 .23181 .63995 Metetra
.777 .786 .86 r
.23181 .63995 .23984 .64638 .25216 .63749 .24417 .6311 Metetra
.804 .787 .837 r
.24417 .6311 .25216 .63749 .26463 .62676 .25668 .62042 Metetra
.823 .787 .818 r
.25668 .62042 .26463 .62676 .27722 .6144 .26933 .60811 Metetra
.837 .787 .803 r
.26933 .60811 .27722 .6144 .28991 .60062 .28206 .59438 Metetra
.848 .787 .792 r
.28206 .59438 .28991 .60062 .30265 .58566 .29487 .57945 Metetra
.856 .787 .783 r
.29487 .57945 .30265 .58566 .31543 .56973 .30771 .56355 Metetra
.862 .787 .776 r
.30771 .56355 .31543 .56973 .32823 .55306 .32057 .54692 Metetra
.866 .788 .772 r
.32057 .54692 .32823 .55306 .34101 .5359 .33341 .52977 Metetra
.869 .789 .769 r
.33341 .52977 .34101 .5359 .35377 .51845 .34624 .51234 Metetra
.871 .79 .768 r
.34624 .51234 .35377 .51845 .36649 .50094 .35902 .49485 Metetra
.871 .792 .77 r
.35902 .49485 .36649 .50094 .37915 .48359 .37176 .47751 Metetra
.87 .794 .773 r
.37176 .47751 .37915 .48359 .39176 .46658 .38443 .46051 Metetra
.868 .796 .778 r
.38443 .46051 .39176 .46658 .40431 .45012 .39705 .44405 Metetra
.864 .799 .785 r
.39705 .44405 .40431 .45012 .4168 .43436 .4096 .42829 Metetra
.858 .802 .794 r
.4096 .42829 .4168 .43436 .42923 .41948 .42209 .4134 Metetra
.85 .805 .805 r
.42209 .4134 .42923 .41948 .44161 .40561 .43453 .39953 Metetra
.84 .807 .819 r
.43453 .39953 .44161 .40561 .45394 .39288 .44692 .38678 Metetra
.826 .81 .835 r
.44692 .38678 .45394 .39288 .46624 .3814 .45928 .37529 Metetra
.807 .811 .854 r
.45928 .37529 .46624 .3814 .47851 .37127 .47161 .36513 Metetra
.783 .811 .874 r
.47161 .36513 .47851 .37127 .49078 .36254 .48393 .35638 Metetra
.752 .808 .897 r
.48393 .35638 .49078 .36254 .50306 .35529 .49626 .34911 Metetra
.712 .801 .92 r
.49626 .34911 .50306 .35529 .51537 .34956 .50861 .34334 Metetra
.662 .788 .942 r
.50861 .34334 .51537 .34956 .52772 .34535 .521 .3391 Metetra
.598 .767 .96 r
.521 .3391 .52772 .34535 .54014 .34269 .53346 .3364 Metetra
.521 .736 .972 r
.53346 .3364 .54014 .34269 .55263 .34155 .54599 .33522 Metetra
.432 .693 .974 r
.54599 .33522 .55263 .34155 .56523 .34191 .55862 .33553 Metetra
.333 .64 .965 r
.55862 .33553 .56523 .34191 .57795 .3437 .57137 .33728 Metetra
.231 .579 .943 r
.57137 .33728 .57795 .3437 .5908 .34688 .58425 .34041 Metetra
.131 .514 .913 r
.58425 .34041 .5908 .34688 .6038 .35135 .59728 .34482 Metetra
.041 .451 .877 r
.59728 .34482 .6038 .35135 .61697 .35701 .61047 .35042 Metetra
0 .393 .84 r
.61047 .35042 .61697 .35701 .63031 .36374 .62384 .35709 Metetra
0 .345 .806 r
.62384 .35709 .63031 .36374 .64385 .37141 .6374 .36469 Metetra
0 .307 .78 r
.6374 .36469 .64385 .37141 .65758 .37985 .65115 .37306 Metetra
0 .281 .761 r
.65115 .37306 .65758 .37985 .67151 .3889 .6651 .38203 Metetra
0 .267 .751 r
.6651 .38203 .67151 .3889 .68563 .39837 .67925 .39142 Metetra
0 .265 .751 r
.67925 .39142 .68563 .39837 .69995 .40805 .69359 .40102 Metetra
0 .275 .759 r
.69359 .40102 .69995 .40805 .71446 .41774 .70812 .41062 Metetra
0 .296 .776 r
.70812 .41062 .71446 .41774 .72915 .42721 .72283 .42 Metetra
0 .328 .801 r
.72283 .42 .72915 .42721 .74399 .43623 .7377 .42891 Metetra
0 .37 .831 r
.7377 .42891 .74399 .43623 .75898 .44454 .75271 .43712 Metetra
.034 .421 .864 r
.75271 .43712 .75898 .44454 .77407 .45191 .76783 .44438 Metetra
.121 .48 .898 r
.76783 .44438 .77407 .45191 .78925 .45809 .78303 .45044 Metetra
.218 .542 .927 r
.78303 .45044 .78925 .45809 .80447 .46284 .79829 .45506 Metetra
.32 .603 .948 r
.79829 .45506 .80447 .46284 .81971 .46591 .81356 .45801 Metetra
.423 .66 .959 r
.81356 .45801 .81971 .46591 .8349 .46708 .82879 .45905 Metetra
.521 .71 .957 r
.82879 .45905 .8349 .46708 .85002 .46613 .84395 .45796 Metetra
.735 .783 .891 r
.21152 .64029 .21966 .64676 .23181 .63995 .2237 .63363 Metetra
.776 .79 .865 r
.2237 .63363 .23181 .63995 .24417 .6311 .23609 .62494 Metetra
.804 .794 .843 r
.23609 .62494 .24417 .6311 .25668 .62042 .24864 .61441 Metetra
.825 .796 .824 r
.24864 .61441 .25668 .62042 .26933 .60811 .26132 .60224 Metetra
.84 .797 .81 r
.26132 .60224 .26933 .60811 .28206 .59438 .27411 .58864 Metetra
.852 .799 .798 r
.27411 .58864 .28206 .59438 .29487 .57945 .28697 .57384 Metetra
.861 .8 .789 r
.28697 .57384 .29487 .57945 .30771 .56355 .29987 .55807 Metetra
.868 .802 .783 r
.29987 .55807 .30771 .56355 .32057 .54692 .31278 .54155 Metetra
.873 .804 .778 r
.31278 .54155 .32057 .54692 .33341 .52977 .3257 .52451 Metetra
.877 .806 .776 r
.3257 .52451 .33341 .52977 .34624 .51234 .33858 .50718 Metetra
.88 .809 .776 r
.33858 .50718 .34624 .51234 .35902 .49485 .35144 .48978 Metetra
.881 .813 .777 r
.35144 .48978 .35902 .49485 .37176 .47751 .36424 .47251 Metetra
.881 .817 .781 r
.36424 .47251 .37176 .47751 .38443 .46051 .37698 .45558 Metetra
.879 .821 .787 r
.37698 .45558 .38443 .46051 .39705 .44405 .38967 .43918 Metetra
.876 .826 .795 r
.38967 .43918 .39705 .44405 .4096 .42829 .40229 .42348 Metetra
.871 .832 .805 r
.40229 .42348 .4096 .42829 .42209 .4134 .41484 .40863 Metetra
.863 .837 .818 r
.41484 .40863 .42209 .4134 .43453 .39953 .42735 .39479 Metetra
.853 .843 .834 r
.42735 .39479 .43453 .39953 .44692 .38678 .4398 .38207 Metetra
.839 .849 .853 r
.4398 .38207 .44692 .38678 .45928 .37529 .45222 .37059 Metetra
.819 .853 .874 r
.45222 .37059 .45928 .37529 .47161 .36513 .46461 .36044 Metetra
.793 .856 .898 r
.46461 .36044 .47161 .36513 .48393 .35638 .47699 .35169 Metetra
.758 .856 .923 r
.47699 .35169 .48393 .35638 .49626 .34911 .48937 .3444 Metetra
.711 .85 .949 r
.48937 .3444 .49626 .34911 .50861 .34334 .50177 .33861 Metetra
.65 .837 .972 r
.50177 .33861 .50861 .34334 .521 .3391 .51421 .33434 Metetra
.573 .811 .989 r
.51421 .33434 .521 .3391 .53346 .3364 .52671 .33159 Metetra
.479 .772 .996 r
.52671 .33159 .53346 .3364 .54599 .33522 .53929 .33036 Metetra
.37 .717 .988 r
.53929 .33036 .54599 .33522 .55862 .33553 .55196 .33061 Metetra
.253 .649 .964 r
.55196 .33061 .55862 .33553 .57137 .33728 .56475 .33229 Metetra
.137 .572 .926 r
.56475 .33229 .57137 .33728 .58425 .34041 .57766 .33534 Metetra
.029 .494 .88 r
.57766 .33534 .58425 .34041 .59728 .34482 .59072 .33966 Metetra
0 .422 .832 r
.59072 .33966 .59728 .34482 .61047 .35042 .60395 .34516 Metetra
0 .359 .788 r
.60395 .34516 .61047 .35042 .62384 .35709 .61735 .35172 Metetra
0 .308 .751 r
.61735 .35172 .62384 .35709 .6374 .36469 .63093 .3592 Metetra
0 .271 .724 r
.63093 .3592 .6374 .36469 .65115 .37306 .64471 .36744 Metetra
0 .247 .707 r
.64471 .36744 .65115 .37306 .6651 .38203 .65868 .37627 Metetra
0 .236 .701 r
.65868 .37627 .6651 .38203 .67925 .39142 .67285 .38551 Metetra
0 .237 .706 r
.67285 .38551 .67925 .39142 .69359 .40102 .68722 .39495 Metetra
0 .251 .722 r
.68722 .39495 .69359 .40102 .70812 .41062 .70177 .40438 Metetra
0 .277 .746 r
.70177 .40438 .70812 .41062 .72283 .42 .7165 .41357 Metetra
0 .314 .778 r
.7165 .41357 .72283 .42 .7377 .42891 .73139 .42229 Metetra
0 .362 .817 r
.73139 .42229 .7377 .42891 .75271 .43712 .74642 .4303 Metetra
.002 .419 .858 r
.74642 .4303 .75271 .43712 .76783 .44438 .76157 .43736 Metetra
.099 .483 .897 r
.76157 .43736 .76783 .44438 .78303 .45044 .7768 .44321 Metetra
.205 .549 .931 r
.7768 .44321 .78303 .45044 .79829 .45506 .79208 .44761 Metetra
.316 .613 .954 r
.79208 .44761 .79829 .45506 .81356 .45801 .80737 .45032 Metetra
.426 .671 .964 r
.80737 .45032 .81356 .45801 .82879 .45905 .82264 .45113 Metetra
.527 .718 .96 r
.82264 .45113 .82879 .45905 .84395 .45796 .83782 .4498 Metetra
.729 .784 .897 r
.20331 .63382 .21152 .64029 .2237 .63363 .2155 .62741 Metetra
.772 .794 .871 r
.2155 .62741 .2237 .63363 .23609 .62494 .22791 .61897 Metetra
.802 .8 .85 r
.22791 .61897 .23609 .62494 .24864 .61441 .24049 .60869 Metetra
.825 .804 .832 r
.24049 .60869 .24864 .61441 .26132 .60224 .25322 .59675 Metetra
.842 .808 .817 r
.25322 .59675 .26132 .60224 .27411 .58864 .26604 .58339 Metetra
.855 .811 .806 r
.26604 .58339 .27411 .58864 .28697 .57384 .27895 .56881 Metetra
.865 .814 .797 r
.27895 .56881 .28697 .57384 .29987 .55807 .2919 .55325 Metetra
.873 .817 .79 r
.2919 .55325 .29987 .55807 .31278 .54155 .30487 .53693 Metetra
.88 .82 .786 r
.30487 .53693 .31278 .54155 .3257 .52451 .31785 .52008 Metetra
.884 .825 .784 r
.31785 .52008 .3257 .52451 .33858 .50718 .3308 .50293 Metetra
.888 .829 .784 r
.3308 .50293 .33858 .50718 .35144 .48978 .34372 .48569 Metetra
.89 .835 .786 r
.34372 .48569 .35144 .48978 .36424 .47251 .35659 .46857 Metetra
.89 .84 .79 r
.35659 .46857 .36424 .47251 .37698 .45558 .3694 .45178 Metetra
.889 .847 .796 r
.3694 .45178 .37698 .45558 .38967 .43918 .38216 .4355 Metetra
.887 .855 .805 r
.38216 .4355 .38967 .43918 .40229 .42348 .39485 .4199 Metetra
.882 .863 .816 r
.39485 .4199 .40229 .42348 .41484 .40863 .40747 .40515 Metetra
.874 .871 .831 r
.40747 .40515 .41484 .40863 .42735 .39479 .42005 .39138 Metetra
.863 .88 .848 r
.42005 .39138 .42735 .39479 .4398 .38207 .43257 .37872 Metetra
.848 .889 .868 r
.43257 .37872 .4398 .38207 .45222 .37059 .44505 .36728 Metetra
.826 .897 .891 r
.44505 .36728 .45222 .37059 .46461 .36044 .45751 .35716 Metetra
.796 .903 .917 r
.45751 .35716 .46461 .36044 .47699 .35169 .46995 .34842 Metetra
.754 .904 .944 r
.46995 .34842 .47699 .35169 .48937 .3444 .48239 .34113 Metetra
.697 .898 .969 r
.48239 .34113 .48937 .3444 .50177 .33861 .49485 .33533 Metetra
.622 .88 .989 r
.49485 .33533 .50177 .33861 .51421 .33434 .50735 .33103 Metetra
.527 .846 .998 r
.50735 .33103 .51421 .33434 .52671 .33159 .5199 .32824 Metetra
.412 .792 .992 r
.5199 .32824 .52671 .33159 .53929 .33036 .53252 .32694 Metetra
.284 .72 .966 r
.53252 .32694 .53929 .33036 .55196 .33061 .54524 .32711 Metetra
.152 .634 .923 r
.54524 .32711 .55196 .33061 .56475 .33229 .55807 .3287 Metetra
.028 .543 .868 r
.55807 .3287 .56475 .33229 .57766 .33534 .57103 .33163 Metetra
0 .455 .81 r
.57103 .33163 .57766 .33534 .59072 .33966 .58413 .33583 Metetra
0 .378 .755 r
.58413 .33583 .59072 .33966 .60395 .34516 .59739 .34119 Metetra
0 .315 .709 r
.59739 .34119 .60395 .34516 .61735 .35172 .61082 .34759 Metetra
0 .266 .674 r
.61082 .34759 .61735 .35172 .63093 .3592 .62444 .3549 Metetra
0 .232 .651 r
.62444 .3549 .63093 .3592 .64471 .36744 .63824 .36295 Metetra
0 .211 .64 r
.63824 .36295 .64471 .36744 .65868 .37627 .65224 .37158 Metetra
0 .204 .642 r
.65224 .37158 .65868 .37627 .67285 .38551 .66644 .3806 Metetra
0 .21 .655 r
.66644 .3806 .67285 .38551 .68722 .39495 .68082 .3898 Metetra
0 .229 .678 r
.68082 .3898 .68722 .39495 .70177 .40438 .6954 .39898 Metetra
0 .26 .712 r
.6954 .39898 .70177 .40438 .7165 .41357 .71015 .40791 Metetra
0 .303 .753 r
.71015 .40791 .7165 .41357 .73139 .42229 .72506 .41636 Metetra
0 .358 .801 r
.72506 .41636 .73139 .42229 .74642 .4303 .74011 .42408 Metetra
0 .421 .851 r
.74011 .42408 .74642 .4303 .76157 .43736 .75528 .43083 Metetra
.083 .491 .897 r
.75528 .43083 .76157 .43736 .7768 .44321 .77053 .43636 Metetra
.2 .561 .936 r
.77053 .43636 .7768 .44321 .79208 .44761 .78583 .44044 Metetra
.319 .627 .96 r
.78583 .44044 .79208 .44761 .80737 .45032 .80115 .44283 Metetra
.434 .684 .969 r
.80115 .44283 .80737 .45032 .82264 .45113 .81644 .44329 Metetra
.537 .728 .962 r
.81644 .44329 .82264 .45113 .83782 .4498 .83165 .44162 Metetra
.719 .783 .903 r
.19502 .62731 .20331 .63382 .2155 .62741 .20722 .62125 Metetra
.765 .797 .879 r
.20722 .62125 .2155 .62741 .22791 .61897 .21964 .61316 Metetra
.799 .806 .858 r
.21964 .61316 .22791 .61897 .24049 .60869 .23225 .60321 Metetra
.823 .813 .84 r
.23225 .60321 .24049 .60869 .25322 .59675 .245 .59161 Metetra
.842 .818 .825 r
.245 .59161 .25322 .59675 .26604 .58339 .25786 .57857 Metetra
.857 .823 .814 r
.25786 .57857 .26604 .58339 .27895 .56881 .27081 .56431 Metetra
.868 .827 .805 r
.27081 .56431 .27895 .56881 .2919 .55325 .28381 .54905 Metetra
.877 .832 .798 r
.28381 .54905 .2919 .55325 .30487 .53693 .29684 .53302 Metetra
.885 .837 .794 r
.29684 .53302 .30487 .53693 .31785 .52008 .30987 .51644 Metetra
.89 .843 .792 r
.30987 .51644 .31785 .52008 .3308 .50293 .32288 .49955 Metetra
.894 .849 .792 r
.32288 .49955 .3308 .50293 .34372 .48569 .33586 .48254 Metetra
.897 .857 .794 r
.33586 .48254 .34372 .48569 .35659 .46857 .3488 .46565 Metetra
.898 .865 .798 r
.3488 .46565 .35659 .46857 .3694 .45178 .36169 .44906 Metetra
.897 .874 .805 r
.36169 .44906 .3694 .45178 .38216 .4355 .37451 .43295 Metetra
.895 .883 .814 r
.37451 .43295 .38216 .4355 .39485 .4199 .38727 .41752 Metetra
.89 .894 .826 r
.38727 .41752 .39485 .4199 .40747 .40515 .39997 .4029 Metetra
.882 .905 .841 r
.39997 .4029 .40747 .40515 .42005 .39138 .41262 .38925 Metetra
.869 .917 .859 r
.41262 .38925 .42005 .39138 .43257 .37872 .42521 .37669 Metetra
.851 .928 .879 r
.42521 .37669 .43257 .37872 .44505 .36728 .43777 .36532 Metetra
.824 .938 .902 r
.43777 .36532 .44505 .36728 .45751 .35716 .45029 .35525 Metetra
.787 .944 .927 r
.45029 .35525 .45751 .35716 .46995 .34842 .4628 .34655 Metetra
.735 .944 .951 r
.4628 .34655 .46995 .34842 .48239 .34113 .47531 .33927 Metetra
.664 .932 .97 r
.47531 .33927 .48239 .34113 .49485 .33533 .48783 .33345 Metetra
.57 .904 .979 r
.48783 .33345 .49485 .33533 .50735 .33103 .50039 .32912 Metetra
.454 .854 .972 r
.50039 .32912 .50735 .33103 .5199 .32824 .513 .32628 Metetra
.32 .781 .944 r
.513 .32628 .5199 .32824 .53252 .32694 .52568 .32491 Metetra
.178 .69 .896 r
.52568 .32491 .53252 .32694 .54524 .32711 .53845 .32499 Metetra
.041 .589 .835 r
.53845 .32499 .54524 .32711 .55807 .3287 .55133 .32646 Metetra
0 .49 .769 r
.55133 .32646 .55807 .3287 .57103 .33163 .56433 .32926 Metetra
0 .401 .707 r
.56433 .32926 .57103 .33163 .58413 .33583 .57748 .33329 Metetra
.26 0 0 r
.57748 .33329 .58413 .33583 .59739 .34119 .59078 .33847 Metetra
.319 0 0 r
.59078 .33847 .59739 .34119 .61082 .34759 .60425 .34467 Metetra
.36 0 0 r
.60425 .34467 .61082 .34759 .62444 .3549 .6179 .35175 Metetra
.384 0 0 r
.6179 .35175 .62444 .3549 .63824 .36295 .63174 .35955 Metetra
.394 0 0 r
.63174 .35955 .63824 .36295 .65224 .37158 .64577 .36791 Metetra
.391 0 0 r
.64577 .36791 .65224 .37158 .66644 .3806 .65999 .37664 Metetra
.373 0 0 r
.65999 .37664 .66644 .3806 .68082 .3898 .67441 .38554 Metetra
0 .211 .633 r
.67441 .38554 .68082 .3898 .6954 .39898 .68901 .39439 Metetra
0 .247 .676 r
.68901 .39439 .6954 .39898 .71015 .40791 .70378 .40297 Metetra
0 .297 .728 r
.70378 .40297 .71015 .40791 .72506 .41636 .71871 .41105 Metetra
0 .358 .786 r
.71871 .41105 .72506 .41636 .74011 .42408 .73378 .41839 Metetra
0 .428 .845 r
.73378 .41839 .74011 .42408 .75528 .43083 .74896 .42474 Metetra
.078 .504 .899 r
.74896 .42474 .75528 .43083 .77053 .43636 .76423 .42986 Metetra
.204 .578 .941 r
.76423 .42986 .77053 .43636 .78583 .44044 .77955 .43352 Metetra
.33 .644 .967 r
.77955 .43352 .78583 .44044 .80115 .44283 .79488 .43547 Metetra
.448 .699 .973 r
.79488 .43547 .80115 .44283 .81644 .44329 .81019 .4355 Metetra
.552 .739 .963 r
.81019 .4355 .81644 .44329 .83165 .44162 .82541 .43339 Metetra
.707 .781 .91 r
.18667 .62072 .19502 .62731 .20722 .62125 .19886 .6151 Metetra
.756 .799 .887 r
.19886 .6151 .20722 .62125 .21964 .61316 .21129 .60745 Metetra
.793 .811 .867 r
.21129 .60745 .21964 .61316 .23225 .60321 .2239 .59794 Metetra
.82 .82 .849 r
.2239 .59794 .23225 .60321 .245 .59161 .23667 .58677 Metetra
.841 .827 .835 r
.23667 .58677 .245 .59161 .25786 .57857 .24956 .57414 Metetra
.857 .834 .823 r
.24956 .57414 .25786 .57857 .27081 .56431 .26255 .56028 Metetra
.87 .84 .814 r
.26255 .56028 .27081 .56431 .28381 .54905 .27559 .54541 Metetra
.88 .847 .807 r
.27559 .54541 .28381 .54905 .29684 .53302 .28866 .52975 Metetra
.888 .854 .803 r
.28866 .52975 .29684 .53302 .30987 .51644 .30175 .51353 Metetra
.894 .861 .801 r
.30175 .51353 .30987 .51644 .32288 .49955 .31482 .49697 Metetra
.899 .87 .8 r
.31482 .49697 .32288 .49955 .33586 .48254 .32787 .48028 Metetra
.902 .879 .802 r
.32787 .48028 .33586 .48254 .3488 .46565 .34087 .46367 Metetra
.903 .889 .807 r
.34087 .46367 .3488 .46565 .36169 .44906 .35383 .44734 Metetra
.903 .899 .813 r
.35383 .44734 .36169 .44906 .37451 .43295 .36672 .43148 Metetra
.899 .911 .822 r
.36672 .43148 .37451 .43295 .38727 .41752 .37956 .41625 Metetra
.893 .924 .834 r
.37956 .41625 .38727 .41752 .39997 .4029 .39234 .40182 Metetra
.883 .937 .848 r
.39234 .40182 .39997 .4029 .41262 .38925 .40506 .38833 Metetra
.867 .95 .864 r
.40506 .38833 .41262 .38925 .42521 .37669 .41773 .3759 Metetra
.844 .962 .883 r
.41773 .3759 .42521 .37669 .43777 .36532 .43035 .36464 Metetra
.81 .971 .903 r
.43035 .36464 .43777 .36532 .45029 .35525 .44295 .35465 Metetra
.762 .974 .922 r
.44295 .35465 .45029 .35525 .4628 .34655 .45553 .346 Metetra
.695 .966 .936 r
.45553 .346 .4628 .34655 .47531 .33927 .46811 .33875 Metetra
.605 .942 .941 r
.46811 .33875 .47531 .33927 .48783 .33345 .48071 .33293 Metetra
.491 .896 .93 r
.48071 .33293 .48783 .33345 .50039 .32912 .49333 .32856 Metetra
.357 .825 .899 r
.49333 .32856 .50039 .32912 .513 .32628 .50601 .32566 Metetra
.211 .733 .849 r
.50601 .32566 .513 .32628 .52568 .32491 .51875 .32421 Metetra
.067 .628 .784 r
.51875 .32421 .52568 .32491 .53845 .32499 .53158 .32418 Metetra
0 .522 .715 r
.53158 .32418 .53845 .32499 .55133 .32646 .54452 .32551 Metetra
.173 0 0 r
.54452 .32551 .55133 .32646 .56433 .32926 .55757 .32814 Metetra
.262 0 0 r
.55757 .32814 .56433 .32926 .57748 .33329 .57077 .33198 Metetra
.329 0 0 r
.57077 .33198 .57748 .33329 .59078 .33847 .58411 .33694 Metetra
.378 0 0 r
.58411 .33694 .59078 .33847 .60425 .34467 .59763 .34288 Metetra
.412 0 0 r
.59763 .34288 .60425 .34467 .6179 .35175 .61132 .34968 Metetra
.431 0 0 r
.61132 .34968 .6179 .35175 .63174 .35955 .62519 .35718 Metetra
.437 0 0 r
.62519 .35718 .63174 .35955 .64577 .36791 .63926 .36521 Metetra
.429 0 0 r
.63926 .36521 .64577 .36791 .65999 .37664 .65351 .37358 Metetra
.408 0 0 r
.65351 .37358 .65999 .37664 .67441 .38554 .66795 .3821 Metetra
.372 0 0 r
.66795 .3821 .67441 .38554 .68901 .39439 .68258 .39054 Metetra
0 .241 .643 r
.68258 .39054 .68901 .39439 .70378 .40297 .69737 .39869 Metetra
0 .297 .706 r
.69737 .39869 .70378 .40297 .71871 .41105 .71232 .40631 Metetra
0 .365 .774 r
.71232 .40631 .71871 .41105 .73378 .41839 .72741 .41318 Metetra
0 .442 .843 r
.72741 .41318 .73378 .41839 .74896 .42474 .74261 .41904 Metetra
.083 .522 .904 r
.74261 .41904 .74896 .42474 .76423 .42986 .75789 .42365 Metetra
.217 .599 .949 r
.75789 .42365 .76423 .42986 .77955 .43352 .77322 .42679 Metetra
.349 .664 .973 r
.77322 .42679 .77955 .43352 .79488 .43547 .78857 .42821 Metetra
.469 .715 .976 r
.78857 .42821 .79488 .43547 .81019 .4355 .80388 .4277 Metetra
.571 .751 .962 r
.80388 .4277 .81019 .4355 .82541 .43339 .81912 .42504 Metetra
.69 .776 .917 r
.17825 .61398 .18667 .62072 .19886 .6151 .19043 .6089 Metetra
.744 .798 .896 r
.19043 .6089 .19886 .6151 .21129 .60745 .20284 .60177 Metetra
.784 .814 .876 r
.20284 .60177 .21129 .60745 .2239 .59794 .21546 .59279 Metetra
.814 .826 .859 r
.21546 .59279 .2239 .59794 .23667 .58677 .22824 .58214 Metetra
.837 .836 .845 r
.22824 .58214 .23667 .58677 .24956 .57414 .24115 .57002 Metetra
.855 .844 .833 r
.24115 .57002 .24956 .57414 .26255 .56028 .25416 .55666 Metetra
.869 .853 .824 r
.25416 .55666 .26255 .56028 .27559 .54541 .26724 .54226 Metetra
.88 .861 .817 r
.26724 .54226 .27559 .54541 .28866 .52975 .28036 .52706 Metetra
.89 .87 .812 r
.28036 .52706 .28866 .52975 .30175 .51353 .29349 .51127 Metetra
.897 .879 .81 r
.29349 .51127 .30175 .51353 .31482 .49697 .30662 .49512 Metetra
.902 .889 .809 r
.30662 .49512 .31482 .49697 .32787 .48028 .31973 .47881 Metetra
.905 .9 .811 r
.31973 .47881 .32787 .48028 .34087 .46367 .3328 .46256 Metetra
.906 .911 .814 r
.3328 .46256 .34087 .46367 .35383 .44734 .34582 .44656 Metetra
.904 .924 .82 r
.34582 .44656 .35383 .44734 .36672 .43148 .35879 .43099 Metetra
.9 .937 .828 r
.35879 .43099 .36672 .43148 .37956 .41625 .3717 .41603 Metetra
.891 .951 .838 r
.3717 .41603 .37956 .41625 .39234 .40182 .38455 .40183 Metetra
.877 .964 .85 r
.38455 .40183 .39234 .40182 .40506 .38833 .39735 .38854 Metetra
.856 .977 .863 r
.39735 .38854 .40506 .38833 .41773 .3759 .4101 .37628 Metetra
.824 .986 .877 r
.4101 .37628 .41773 .3759 .43035 .36464 .42281 .36516 Metetra
.779 .99 .889 r
.42281 .36516 .43035 .36464 .44295 .35465 .43548 .35527 Metetra
.716 .984 .896 r
.43548 .35527 .44295 .35465 .45553 .346 .44814 .34669 Metetra
.632 .962 .894 r
.44814 .34669 .45553 .346 .46811 .33875 .4608 .33947 Metetra
.523 .919 .878 r
.4608 .33947 .46811 .33875 .48071 .33293 .47347 .33366 Metetra
.393 .852 .843 r
.47347 .33366 .48071 .33293 .49333 .32856 .48617 .32927 Metetra
.249 .762 .791 r
.48617 .32927 .49333 .32856 .50601 .32566 .49891 .3263 Metetra
.104 .659 .726 r
.49891 .3263 .50601 .32566 .51875 .32421 .51172 .32476 Metetra
.03 0 0 r
.51172 .32476 .51875 .32421 .53158 .32418 .52462 .32459 Metetra
.146 0 0 r
.52462 .32459 .53158 .32418 .54452 .32551 .53761 .32576 Metetra
.242 0 0 r
.53761 .32576 .54452 .32551 .55757 .32814 .55073 .32819 Metetra
.317 0 0 r
.55073 .32819 .55757 .32814 .57077 .33198 .56398 .33181 Metetra
.375 0 0 r
.56398 .33181 .57077 .33198 .58411 .33694 .57738 .3365 Metetra
.416 0 0 r
.57738 .3365 .58411 .33694 .59763 .34288 .59094 .34215 Metetra
.444 0 0 r
.59094 .34215 .59763 .34288 .61132 .34968 .60468 .34862 Metetra
.459 0 0 r
.60468 .34862 .61132 .34968 .62519 .35718 .61859 .35576 Metetra
.462 0 0 r
.61859 .35576 .62519 .35718 .63926 .36521 .63269 .36339 Metetra
.452 0 0 r
.63269 .36339 .63926 .36521 .65351 .37358 .64698 .37133 Metetra
.429 0 0 r
.64698 .37133 .65351 .37358 .66795 .3821 .66145 .37939 Metetra
.39 0 0 r
.66145 .37939 .66795 .3821 .68258 .39054 .6761 .38734 Metetra
.333 0 0 r
.6761 .38734 .68258 .39054 .69737 .39869 .69092 .39498 Metetra
0 .305 .69 r
.69092 .39498 .69737 .39869 .71232 .40631 .70589 .40206 Metetra
0 .379 .769 r
.70589 .40206 .71232 .40631 .72741 .41318 .721 .40836 Metetra
0 .462 .846 r
.721 .40836 .72741 .41318 .74261 .41904 .73621 .41364 Metetra
.1 .547 .912 r
.73621 .41364 .74261 .41904 .75789 .42365 .7515 .41765 Metetra
.242 .624 .958 r
.7515 .41765 .75789 .42365 .77322 .42679 .76684 .42017 Metetra
.377 .687 .979 r
.76684 .42017 .77322 .42679 .78857 .42821 .78219 .42096 Metetra
.496 .732 .978 r
.78219 .42096 .78857 .42821 .80388 .4277 .79751 .41982 Metetra
.594 .761 .959 r
.79751 .41982 .80388 .4277 .81912 .42504 .81275 .41652 Metetra
.729 .795 .905 r
.18192 .60256 .19043 .6089 .20284 .60177 .19432 .59606 Metetra
.772 .815 .886 r
.19432 .59606 .20284 .60177 .21546 .59279 .20693 .58769 Metetra
.805 .83 .87 r
.20693 .58769 .21546 .59279 .22824 .58214 .21971 .57764 Metetra
.83 .843 .856 r
.21971 .57764 .22824 .58214 .24115 .57002 .23263 .56612 Metetra
.85 .854 .844 r
.23263 .56612 .24115 .57002 .25416 .55666 .24566 .55334 Metetra
.866 .864 .835 r
.24566 .55334 .25416 .55666 .26724 .54226 .25876 .53951 Metetra
.879 .874 .828 r
.25876 .53951 .26724 .54226 .28036 .52706 .27192 .52484 Metetra
.889 .885 .822 r
.27192 .52484 .28036 .52706 .29349 .51127 .28509 .50957 Metetra
.896 .896 .819 r
.28509 .50957 .29349 .51127 .30662 .49512 .29827 .4939 Metetra
.901 .907 .818 r
.29827 .4939 .30662 .49512 .31973 .47881 .31144 .47805 Metetra
.904 .919 .819 r
.31144 .47805 .31973 .47881 .3328 .46256 .32457 .46222 Metetra
.904 .932 .821 r
.32457 .46222 .3328 .46256 .34582 .44656 .33766 .44661 Metetra
.901 .946 .826 r
.33766 .44661 .34582 .44656 .35879 .43099 .3507 .43139 Metetra
.894 .959 .831 r
.3507 .43139 .35879 .43099 .3717 .41603 .36369 .41675 Metetra
.882 .973 .839 r
.36369 .41675 .3717 .41603 .38455 .40183 .37662 .40283 Metetra
.862 .985 .846 r
.37662 .40283 .38455 .40183 .39735 .38854 .3895 .38979 Metetra
.833 .994 .853 r
.3895 .38979 .39735 .38854 .4101 .37628 .40233 .37773 Metetra
.791 .997 .858 r
.40233 .37773 .4101 .37628 .42281 .36516 .41512 .36678 Metetra
.732 .991 .858 r
.41512 .36678 .42281 .36516 .43548 .35527 .42787 .35702 Metetra
.653 .97 .849 r
.42787 .35702 .43548 .35527 .44814 .34669 .44062 .34853 Metetra
.551 .93 .828 r
.44062 .34853 .44814 .34669 .4608 .33947 .45335 .34136 Metetra
.428 .867 .79 r
.45335 .34136 .4608 .33947 .47347 .33366 .4661 .33555 Metetra
.291 .783 .737 r
.4661 .33555 .47347 .33366 .48617 .32927 .47888 .33113 Metetra
.47888 .33113 .48617 .32927 .49891 .3263 .4917 .3281 Metetra
.4917 .3281 .49891 .3263 .51172 .32476 .50459 .32645 Metetra
.104 0 0 r
.50459 .32645 .51172 .32476 .52462 .32459 .51755 .32613 Metetra
.205 0 0 r
.51755 .32613 .52462 .32459 .53761 .32576 .53062 .32712 Metetra
.287 0 0 r
.53062 .32712 .53761 .32576 .55073 .32819 .5438 .32932 Metetra
.352 0 0 r
.5438 .32932 .55073 .32819 .56398 .33181 .55711 .33267 Metetra
.401 0 0 r
.55711 .33267 .56398 .33181 .57738 .3365 .57056 .33706 Metetra
.437 0 0 r
.57056 .33706 .57738 .3365 .59094 .34215 .58418 .34237 Metetra
.461 0 0 r
.58418 .34237 .59094 .34215 .60468 .34862 .59796 .34846 Metetra
.473 0 0 r
.59796 .34846 .60468 .34862 .61859 .35576 .61192 .35517 Metetra
.473 0 0 r
.61192 .35517 .61859 .35576 .63269 .36339 .62607 .36235 Metetra
.461 0 0 r
.62607 .36235 .63269 .36339 .64698 .37133 .64039 .36979 Metetra
.436 0 0 r
.64039 .36979 .64698 .37133 .66145 .37939 .6549 .37732 Metetra
.394 0 0 r
.6549 .37732 .66145 .37939 .6761 .38734 .66957 .38471 Metetra
.333 0 0 r
.66957 .38471 .6761 .38734 .69092 .39498 .68442 .39175 Metetra
0 .321 .683 r
.68442 .39175 .69092 .39498 .70589 .40206 .69941 .39821 Metetra
0 .403 .771 r
.69941 .39821 .70589 .40206 .721 .40836 .71453 .40386 Metetra
0 .491 .855 r
.71453 .40386 .721 .40836 .73621 .41364 .72975 .40846 Metetra
.131 .578 .924 r
.72975 .40846 .73621 .41364 .7515 .41765 .74505 .41178 Metetra
.278 .653 .968 r
.74505 .41178 .7515 .41765 .76684 .42017 .7604 .41359 Metetra
.412 .71 .984 r
.7604 .41359 .76684 .42017 .78219 .42096 .77575 .41366 Metetra
.527 .748 .977 r
.77575 .41366 .78219 .42096 .79751 .41982 .79107 .41178 Metetra
.709 .788 .913 r
.17335 .59602 .18192 .60256 .19432 .59606 .18572 .59021 Metetra
.757 .813 .897 r
.18572 .59021 .19432 .59606 .20693 .58769 .19831 .58254 Metetra
.793 .832 .882 r
.19831 .58254 .20693 .58769 .21971 .57764 .21108 .57319 Metetra
.821 .847 .868 r
.21108 .57319 .21971 .57764 .23263 .56612 .224 .56235 Metetra
.843 .861 .856 r
.224 .56235 .23263 .56612 .24566 .55334 .23704 .55023 Metetra
.861 .874 .847 r
.23704 .55023 .24566 .55334 .25876 .53951 .25016 .53704 Metetra
.875 .886 .839 r
.25016 .53704 .25876 .53951 .27192 .52484 .26335 .52299 Metetra
.885 .898 .833 r
.26335 .52299 .27192 .52484 .28509 .50957 .27656 .50831 Metetra
.893 .911 .83 r
.27656 .50831 .28509 .50957 .29827 .4939 .28979 .4932 Metetra
.898 .924 .827 r
.28979 .4932 .29827 .4939 .31144 .47805 .303 .47788 Metetra
.9 .937 .827 r
.303 .47788 .31144 .47805 .32457 .46222 .31619 .46254 Metetra
.899 .95 .828 r
.31619 .46254 .32457 .46222 .33766 .44661 .32935 .44737 Metetra
.894 .964 .83 r
.32935 .44737 .33766 .44661 .3507 .43139 .34246 .43257 Metetra
.883 .977 .832 r
.34246 .43257 .3507 .43139 .36369 .41675 .35552 .4183 Metetra
.865 .988 .835 r
.35552 .4183 .36369 .41675 .37662 .40283 .36853 .40471 Metetra
.838 .997 .837 r
.36853 .40471 .37662 .40283 .3895 .38979 .38149 .39195 Metetra
.799 .999 .835 r
.38149 .39195 .3895 .38979 .40233 .37773 .3944 .38013 Metetra
.745 .993 .829 r
.3944 .38013 .40233 .37773 .41512 .36678 .40728 .36938 Metetra
.672 .973 .814 r
.40728 .36938 .41512 .36678 .42787 .35702 .42012 .35977 Metetra
.578 .936 .788 r
.42012 .35977 .42787 .35702 .44062 .34853 .43295 .35138 Metetra
.464 .878 .748 r
.43295 .35138 .44062 .34853 .45335 .34136 .44577 .34428 Metetra
.336 .801 .695 r
.44577 .34428 .45335 .34136 .4661 .33555 .4586 .33849 Metetra
.4586 .33849 .4661 .33555 .47888 .33113 .47146 .33404 Metetra
.47146 .33404 .47888 .33113 .4917 .3281 .48437 .33094 Metetra
.051 0 0 r
.48437 .33094 .4917 .3281 .50459 .32645 .49733 .32916 Metetra
.156 0 0 r
.49733 .32916 .50459 .32645 .51755 .32613 .51037 .32869 Metetra
.243 0 0 r
.51037 .32869 .51755 .32613 .53062 .32712 .52351 .32946 Metetra
.314 0 0 r
.52351 .32946 .53062 .32712 .5438 .32932 .53676 .33141 Metetra
.37 0 0 r
.53676 .33141 .5438 .32932 .55711 .33267 .55014 .33446 Metetra
.413 0 0 r
.55014 .33446 .55711 .33267 .57056 .33706 .56366 .33851 Metetra
.444 0 0 r
.56366 .33851 .57056 .33706 .58418 .34237 .57733 .34342 Metetra
.465 0 0 r
.57733 .34342 .58418 .34237 .59796 .34846 .59117 .34908 Metetra
.474 0 0 r
.59117 .34908 .59796 .34846 .61192 .35517 .60518 .35531 Metetra
.472 0 0 r
.60518 .35531 .61192 .35517 .62607 .36235 .61937 .36197 Metetra
.459 0 0 r
.61937 .36197 .62607 .36235 .64039 .36979 .63373 .36885 Metetra
.431 0 0 r
.63373 .36885 .64039 .36979 .6549 .37732 .64827 .37578 Metetra
.386 0 0 r
.64827 .37578 .6549 .37732 .66957 .38471 .66298 .38253 Metetra
.32 0 0 r
.66298 .38253 .66957 .38471 .68442 .39175 .67785 .38889 Metetra
0 .349 .688 r
.67785 .38889 .68442 .39175 .69941 .39821 .69286 .39464 Metetra
0 .436 .784 r
.69286 .39464 .69941 .39821 .71453 .40386 .708 .39956 Metetra
.026 .529 .872 r
.708 .39956 .71453 .40386 .72975 .40846 .72323 .40339 Metetra
.176 .615 .94 r
.72323 .40339 .72975 .40846 .74505 .41178 .73854 .40593 Metetra
.324 .685 .979 r
.73854 .40593 .74505 .41178 .7604 .41359 .75388 .40693 Metetra
.455 .734 .987 r
.75388 .40693 .7604 .41359 .77575 .41366 .76923 .40619 Metetra
.562 .763 .972 r
.76923 .40619 .77575 .41366 .79107 .41178 .78454 .40349 Metetra
.684 .777 .921 r
.16474 .58916 .17335 .59602 .18572 .59021 .17706 .58414 Metetra
.737 .807 .907 r
.17706 .58414 .18572 .59021 .19831 .58254 .18961 .57725 Metetra
.777 .83 .893 r
.18961 .57725 .19831 .58254 .21108 .57319 .20236 .56867 Metetra
.809 .849 .88 r
.20236 .56867 .21108 .57319 .224 .56235 .21527 .55859 Metetra
.833 .866 .869 r
.21527 .55859 .224 .56235 .23704 .55023 .22831 .54721 Metetra
.853 .881 .859 r
.22831 .54721 .23704 .55023 .25016 .53704 .24145 .53475 Metetra
.868 .896 .851 r
.24145 .53475 .25016 .53704 .26335 .52299 .25465 .5214 Metetra
.879 .91 .845 r
.25465 .5214 .26335 .52299 .27656 .50831 .2679 .50738 Metetra
.887 .924 .841 r
.2679 .50738 .27656 .50831 .28979 .4932 .28116 .4929 Metetra
.892 .938 .837 r
.28116 .4929 .28979 .4932 .303 .47788 .29442 .47817 Metetra
.893 .952 .835 r
.29442 .47817 .303 .47788 .31619 .46254 .30767 .46338 Metetra
.89 .965 .834 r
.30767 .46338 .31619 .46254 .32935 .44737 .32089 .44873 Metetra
.881 .978 .833 r
.32089 .44873 .32935 .44737 .34246 .43257 .33407 .43439 Metetra
.866 .989 .831 r
.33407 .43439 .34246 .43257 .35552 .4183 .3472 .42054 Metetra
.842 .997 .828 r
.3472 .42054 .35552 .4183 .36853 .40471 .36029 .40733 Metetra
.807 1 .822 r
.36029 .40733 .36853 .40471 .38149 .39195 .37333 .39489 Metetra
.757 .994 .811 r
.37333 .39489 .38149 .39195 .3944 .38013 .38632 .38335 Metetra
.691 .976 .793 r
.38632 .38335 .3944 .38013 .40728 .36938 .39928 .37282 Metetra
.606 .942 .763 r
.39928 .37282 .40728 .36938 .42012 .35977 .41222 .36339 Metetra
.502 .89 .723 r
.41222 .36339 .42012 .35977 .43295 .35138 .42513 .35513 Metetra
.383 .82 .67 r
.42513 .35513 .43295 .35138 .44577 .34428 .43805 .34809 Metetra
.43805 .34809 .44577 .34428 .4586 .33849 .45097 .34233 Metetra
.45097 .34233 .4586 .33849 .47146 .33404 .46392 .33786 Metetra
.46392 .33786 .47146 .33404 .48437 .33094 .4769 .33467 Metetra
.097 0 0 r
.4769 .33467 .48437 .33094 .49733 .32916 .48995 .33277 Metetra
.189 0 0 r
.48995 .33277 .49733 .32916 .51037 .32869 .50308 .33211 Metetra
.265 0 0 r
.50308 .33211 .51037 .32869 .52351 .32946 .51629 .33265 Metetra
.327 0 0 r
.51629 .33265 .52351 .32946 .53676 .33141 .52962 .33432 Metetra
.377 0 0 r
.52962 .33432 .53676 .33141 .55014 .33446 .54307 .33704 Metetra
.415 0 0 r
.54307 .33704 .55014 .33446 .56366 .33851 .55666 .34069 Metetra
.442 0 0 r
.55666 .34069 .56366 .33851 .57733 .34342 .57039 .34517 Metetra
.459 0 0 r
.57039 .34517 .57733 .34342 .59117 .34908 .58429 .35034 Metetra
.466 0 0 r
.58429 .35034 .59117 .34908 .60518 .35531 .59836 .35605 Metetra
.462 0 0 r
.59836 .35605 .60518 .35531 .61937 .36197 .61259 .36212 Metetra
.446 0 0 r
.61259 .36212 .61937 .36197 .63373 .36885 .627 .36838 Metetra
.414 0 0 r
.627 .36838 .63373 .36885 .64827 .37578 .64158 .37463 Metetra
.364 0 0 r
.64158 .37463 .64827 .37578 .66298 .38253 .65632 .38066 Metetra
.291 0 0 r
.65632 .38066 .66298 .38253 .67785 .38889 .67121 .38628 Metetra
0 .387 .706 r
.67121 .38628 .67785 .38889 .69286 .39464 .68624 .39124 Metetra
0 .48 .808 r
.68624 .39124 .69286 .39464 .708 .39956 .70139 .39533 Metetra
.081 .574 .897 r
.70139 .39533 .708 .39956 .72323 .40339 .71663 .39832 Metetra
.235 .656 .959 r
.71663 .39832 .72323 .40339 .73854 .40593 .73195 .39999 Metetra
.379 .716 .988 r
.73195 .39999 .73854 .40593 .75388 .40693 .74729 .40011 Metetra
.501 .754 .986 r
.74729 .40011 .75388 .40693 .76923 .40619 .76264 .39846 Metetra
.599 .774 .964 r
.76264 .39846 .76923 .40619 .78454 .40349 .77794 .39486 Metetra
.713 .797 .917 r
.16834 .57772 .17706 .58414 .18961 .57725 .18085 .57169 Metetra
.758 .825 .904 r
.18085 .57169 .18961 .57725 .20236 .56867 .19357 .56396 Metetra
.792 .848 .893 r
.19357 .56396 .20236 .56867 .21527 .55859 .20646 .55472 Metetra
.82 .868 .882 r
.20646 .55472 .21527 .55859 .22831 .54721 .21948 .54416 Metetra
.841 .886 .873 r
.21948 .54416 .22831 .54721 .24145 .53475 .23262 .53249 Metetra
.858 .903 .865 r
.23262 .53249 .24145 .53475 .25465 .5214 .24584 .51991 Metetra
.87 .919 .858 r
.24584 .51991 .25465 .5214 .2679 .50738 .2591 .50663 Metetra
.879 .934 .852 r
.2591 .50663 .2679 .50738 .28116 .4929 .2724 .49285 Metetra
.883 .949 .848 r
.2724 .49285 .28116 .4929 .29442 .47817 .2857 .47878 Metetra
.883 .964 .844 r
.2857 .47878 .29442 .47817 .30767 .46338 .299 .46461 Metetra
.877 .977 .84 r
.299 .46461 .30767 .46338 .32089 .44873 .31228 .45053 Metetra
.865 .988 .835 r
.31228 .45053 .32089 .44873 .33407 .43439 .32552 .43671 Metetra
.845 .997 .829 r
.32552 .43671 .33407 .43439 .3472 .42054 .33872 .42333 Metetra
.814 1 .82 r
.33872 .42333 .3472 .42054 .36029 .40733 .35189 .41053 Metetra
.77 .996 .806 r
.35189 .41053 .36029 .40733 .37333 .39489 .36501 .39846 Metetra
.711 .981 .785 r
.36501 .39846 .37333 .39489 .38632 .38335 .37809 .38723 Metetra
.635 .951 .754 r
.37809 .38723 .38632 .38335 .39928 .37282 .39114 .37696 Metetra
.541 .906 .714 r
.39114 .37696 .39928 .37282 .41222 .36339 .40416 .36772 Metetra
.432 .843 .662 r
.40416 .36772 .41222 .36339 .42513 .35513 .41717 .35961 Metetra
.41717 .35961 .42513 .35513 .43805 .34809 .43017 .35266 Metetra
.43017 .35266 .43805 .34809 .45097 .34233 .44319 .34693 Metetra
.44319 .34693 .45097 .34233 .46392 .33786 .45623 .34242 Metetra
.031 0 0 r
.45623 .34242 .46392 .33786 .4769 .33467 .46931 .33916 Metetra
.126 0 0 r
.46931 .33916 .4769 .33467 .48995 .33277 .48244 .33711 Metetra
.207 0 0 r
.48244 .33711 .48995 .33277 .50308 .33211 .49565 .33626 Metetra
.275 0 0 r
.49565 .33626 .50308 .33211 .51629 .33265 .50895 .33654 Metetra
.33 0 0 r
.50895 .33654 .51629 .33265 .52962 .33432 .52236 .3379 Metetra
.374 0 0 r
.52236 .3379 .52962 .33432 .54307 .33704 .53589 .34024 Metetra
.407 0 0 r
.53589 .34024 .54307 .33704 .55666 .34069 .54955 .34348 Metetra
.431 0 0 r
.54955 .34348 .55666 .34069 .57039 .34517 .56335 .34748 Metetra
.445 0 0 r
.56335 .34748 .57039 .34517 .58429 .35034 .57731 .35211 Metetra
.449 0 0 r
.57731 .35211 .58429 .35034 .59836 .35605 .59143 .35722 Metetra
.442 0 0 r
.59143 .35722 .59836 .35605 .61259 .36212 .60572 .36265 Metetra
.422 0 0 r
.60572 .36265 .61259 .36212 .627 .36838 .62017 .36822 Metetra
.386 0 0 r
.62017 .36822 .627 .36838 .64158 .37463 .63479 .37373 Metetra
.329 0 0 r
.63479 .37373 .64158 .37463 .65632 .38066 .64957 .37898 Metetra
.247 0 0 r
.64957 .37898 .65632 .38066 .67121 .38628 .66449 .38376 Metetra
0 .438 .739 r
.66449 .38376 .67121 .38628 .68624 .39124 .67954 .38786 Metetra
0 .534 .842 r
.67954 .38786 .68624 .39124 .70139 .39533 .6947 .39105 Metetra
.151 .624 .926 r
.6947 .39105 .70139 .39533 .71663 .39832 .70996 .39312 Metetra
.303 .697 .977 r
.70996 .39312 .71663 .39832 .73195 .39999 .72527 .39383 Metetra
.439 .745 .993 r
.72527 .39383 .73195 .39999 .74729 .40011 .74061 .39298 Metetra
.549 .771 .98 r
.74061 .39298 .74729 .40011 .76264 .39846 .75595 .39035 Metetra
.684 .781 .924 r
.15959 .57084 .16834 .57772 .18085 .57169 .17204 .56574 Metetra
.733 .814 .915 r
.17204 .56574 .18085 .57169 .19357 .56396 .18471 .55893 Metetra
.772 .842 .905 r
.18471 .55893 .19357 .56396 .20646 .55472 .19756 .5506 Metetra
.802 .866 .895 r
.19756 .5506 .20646 .55472 .21948 .54416 .21057 .54094 Metetra
.826 .887 .886 r
.21057 .54094 .21948 .54416 .23262 .53249 .2237 .53013 Metetra
.845 .906 .878 r
.2237 .53013 .23262 .53249 .24584 .51991 .23691 .51839 Metetra
.858 .924 .871 r
.23691 .51839 .24584 .51991 .2591 .50663 .25019 .50591 Metetra
.867 .941 .865 r
.25019 .50591 .2591 .50663 .2724 .49285 .26351 .4929 Metetra
.871 .957 .859 r
.26351 .4929 .2724 .49285 .2857 .47878 .27685 .47955 Metetra
.869 .972 .853 r
.27685 .47955 .2857 .47878 .299 .46461 .29019 .46606 Metetra
.861 .985 .847 r
.29019 .46606 .299 .46461 .31228 .45053 .30352 .4526 Metetra
.846 .995 .839 r
.30352 .4526 .31228 .45053 .32552 .43671 .31682 .43936 Metetra
.82 1 .828 r
.31682 .43936 .32552 .43671 .33872 .42333 .33009 .4265 Metetra
.784 .998 .812 r
.33009 .4265 .33872 .42333 .35189 .41053 .34333 .41416 Metetra
.733 .987 .79 r
.34333 .41416 .35189 .41053 .36501 .39846 .35653 .40249 Metetra
.666 .963 .76 r
.35653 .40249 .36501 .39846 .37809 .38723 .3697 .39161 Metetra
.583 .924 .721 r
.3697 .39161 .37809 .38723 .39114 .37696 .38283 .38162 Metetra
.485 .87 .672 r
.38283 .38162 .39114 .37696 .40416 .36772 .39595 .3726 Metetra
.376 .801 .614 r
.39595 .3726 .40416 .36772 .41717 .35961 .40905 .36465 Metetra
.40905 .36465 .41717 .35961 .43017 .35266 .42215 .3578 Metetra
.42215 .3578 .43017 .35266 .44319 .34693 .43526 .3521 Metetra
.43526 .3521 .44319 .34693 .45623 .34242 .44839 .34757 Metetra
.056 0 0 r
.44839 .34757 .45623 .34242 .46931 .33916 .46157 .34422 Metetra
.141 0 0 r
.46157 .34422 .46931 .33916 .48244 .33711 .4748 .34202 Metetra
.213 0 0 r
.4748 .34202 .48244 .33711 .49565 .33626 .4881 .34095 Metetra
.274 0 0 r
.4881 .34095 .49565 .33626 .50895 .33654 .50149 .34095 Metetra
.324 0 0 r
.50149 .34095 .50895 .33654 .52236 .3379 .51498 .34197 Metetra
.363 0 0 r
.51498 .34197 .52236 .3379 .53589 .34024 .52858 .34391 Metetra
.392 0 0 r
.52858 .34391 .53589 .34024 .54955 .34348 .54232 .34668 Metetra
.413 0 0 r
.54232 .34668 .54955 .34348 .56335 .34748 .5562 .35016 Metetra
.424 0 0 r
.5562 .35016 .56335 .34748 .57731 .35211 .57023 .3542 Metetra
.424 0 0 r
.57023 .3542 .57731 .35211 .59143 .35722 .58441 .35867 Metetra
.413 0 0 r
.58441 .35867 .59143 .35722 .60572 .36265 .59875 .3634 Metetra
.388 0 0 r
.59875 .3634 .60572 .36265 .62017 .36822 .61325 .36821 Metetra
.344 0 0 r
.61325 .36821 .62017 .36822 .63479 .37373 .62791 .37292 Metetra
.278 0 0 r
.62791 .37292 .63479 .37373 .64957 .37898 .64272 .37732 Metetra
.186 0 0 r
.64272 .37732 .64957 .37898 .66449 .38376 .65767 .3812 Metetra
0 .501 .785 r
.65767 .3812 .66449 .38376 .67954 .38786 .67275 .38436 Metetra
.081 .595 .884 r
.67275 .38436 .67954 .38786 .6947 .39105 .68792 .38658 Metetra
.235 .677 .956 r
.68792 .38658 .6947 .39105 .70996 .39312 .70318 .38764 Metetra
.379 .735 .99 r
.70318 .38764 .70996 .39312 .72527 .39383 .7185 .38732 Metetra
.501 .768 .991 r
.7185 .38732 .72527 .39383 .74061 .39298 .73384 .38542 Metetra
.596 .781 .969 r
.73384 .38542 .74061 .39298 .75595 .39035 .74916 .38174 Metetra
.704 .798 .923 r
.16319 .55927 .17204 .56574 .18471 .55893 .1758 .55345 Metetra
.747 .831 .916 r
.1758 .55345 .18471 .55893 .19756 .5506 .18861 .54609 Metetra
.781 .859 .908 r
.18861 .54609 .19756 .5506 .21057 .54094 .20158 .53739 Metetra
.808 .883 .9 r
.20158 .53739 .21057 .54094 .2237 .53013 .21468 .52752 Metetra
.828 .906 .893 r
.21468 .52752 .2237 .53013 .23691 .51839 .22789 .51668 Metetra
.843 .926 .886 r
.22789 .51668 .23691 .51839 .25019 .50591 .24117 .50507 Metetra
.852 .945 .879 r
.24117 .50507 .25019 .50591 .26351 .4929 .25451 .49288 Metetra
.856 .962 .872 r
.25451 .49288 .26351 .4929 .27685 .47955 .26787 .48032 Metetra
.854 .977 .865 r
.26787 .48032 .27685 .47955 .29019 .46606 .28125 .46756 Metetra
.844 .989 .856 r
.28125 .46756 .29019 .46606 .30352 .4526 .29462 .45478 Metetra
.825 .997 .844 r
.29462 .45478 .30352 .4526 .31682 .43936 .30798 .44216 Metetra
.796 .999 .829 r
.30798 .44216 .31682 .43936 .33009 .4265 .32132 .42987 Metetra
.754 .993 .808 r
.32132 .42987 .33009 .4265 .34333 .41416 .33463 .41804 Metetra
.698 .976 .779 r
.33463 .41804 .34333 .41416 .35653 .40249 .34791 .40681 Metetra
.626 .945 .742 r
.34791 .40681 .35653 .40249 .3697 .39161 .36115 .3963 Metetra
.539 .9 .696 r
.36115 .3963 .3697 .39161 .38283 .38162 .37438 .38662 Metetra
.441 .841 .642 r
.37438 .38662 .38283 .38162 .39595 .3726 .38758 .37785 Metetra
.38758 .37785 .39595 .3726 .40905 .36465 .40078 .37007 Metetra
.40078 .37007 .40905 .36465 .42215 .3578 .41397 .36333 Metetra
.41397 .36333 .42215 .3578 .43526 .3521 .42718 .35767 Metetra
.42718 .35767 .43526 .3521 .44839 .34757 .44041 .35312 Metetra
.067 0 0 r
.44041 .35312 .44839 .34757 .46157 .34422 .45368 .34967 Metetra
.144 0 0 r
.45368 .34967 .46157 .34422 .4748 .34202 .46701 .3473 Metetra
.21 0 0 r
.46701 .3473 .4748 .34202 .4881 .34095 .4804 .346 Metetra
.265 0 0 r
.4804 .346 .4881 .34095 .50149 .34095 .49389 .34571 Metetra
.309 0 0 r
.49389 .34571 .50149 .34095 .51498 .34197 .50746 .34636 Metetra
.344 0 0 r
.50746 .34636 .51498 .34197 .52858 .34391 .52116 .34786 Metetra
.37 0 0 r
.52116 .34786 .52858 .34391 .54232 .34668 .53497 .35013 Metetra
.387 0 0 r
.53497 .35013 .54232 .34668 .5562 .35016 .54893 .35303 Metetra
.394 0 0 r
.54893 .35303 .5562 .35016 .57023 .3542 .56303 .35645 Metetra
.39 0 0 r
.56303 .35645 .57023 .3542 .58441 .35867 .57727 .36022 Metetra
.373 0 0 r
.57727 .36022 .58441 .35867 .59875 .3634 .59167 .36419 Metetra
.34 0 0 r
.59167 .36419 .59875 .3634 .61325 .36821 .60623 .36819 Metetra
.287 0 0 r
.60623 .36819 .61325 .36821 .62791 .37292 .62093 .37203 Metetra
.21 0 0 r
.62093 .37203 .62791 .37292 .64272 .37732 .63578 .37551 Metetra
0 .479 .733 r
.63578 .37551 .64272 .37732 .65767 .3812 .65076 .37843 Metetra
.029 .573 .841 r
.65076 .37843 .65767 .3812 .67275 .38436 .66585 .38058 Metetra
.179 .66 .928 r
.66585 .38058 .67275 .38436 .68792 .38658 .68105 .38175 Metetra
.326 .726 .981 r
.68105 .38175 .68792 .38658 .70318 .38764 .69631 .38173 Metetra
.456 .766 .996 r
.69631 .38173 .70318 .38764 .7185 .38732 .71163 .38032 Metetra
.56 .783 .982 r
.71163 .38032 .7185 .38732 .73384 .38542 .72696 .3773 Metetra
.718 .814 .925 r
.16686 .54736 .1758 .55345 .18861 .54609 .17961 .54104 Metetra
.755 .846 .919 r
.17961 .54104 .18861 .54609 .20158 .53739 .19253 .53336 Metetra
.785 .874 .913 r
.19253 .53336 .20158 .53739 .21468 .52752 .2056 .52448 Metetra
.808 .9 .907 r
.2056 .52448 .21468 .52752 .22789 .51668 .21879 .51461 Metetra
.824 .923 .901 r
.21879 .51461 .22789 .51668 .24117 .50507 .23206 .50393 Metetra
.835 .944 .894 r
.23206 .50393 .24117 .50507 .25451 .49288 .2454 .49263 Metetra
.839 .963 .887 r
.2454 .49263 .25451 .49288 .26787 .48032 .25879 .4809 Metetra
.836 .979 .878 r
.25879 .4809 .26787 .48032 .28125 .46756 .27219 .46892 Metetra
.825 .991 .867 r
.27219 .46892 .28125 .46756 .29462 .45478 .2856 .45688 Metetra
.805 .998 .853 r
.2856 .45688 .29462 .45478 .30798 .44216 .29901 .44493 Metetra
.773 .997 .834 r
.29901 .44493 .30798 .44216 .32132 .42987 .31241 .43324 Metetra
.728 .988 .809 r
.31241 .43324 .32132 .42987 .33463 .41804 .32578 .42195 Metetra
.668 .967 .776 r
.32578 .42195 .33463 .41804 .34791 .40681 .33913 .4112 Metetra
.594 .932 .734 r
.33913 .4112 .34791 .40681 .36115 .3963 .35246 .4011 Metetra
.507 .883 .684 r
.35246 .4011 .36115 .3963 .37438 .38662 .36577 .39175 Metetra
.41 .821 .627 r
.36577 .39175 .37438 .38662 .38758 .37785 .37907 .38325 Metetra
.37907 .38325 .38758 .37785 .40078 .37007 .39236 .37566 Metetra
.39236 .37566 .40078 .37007 .41397 .36333 .40565 .36905 Metetra
.40565 .36905 .41397 .36333 .42718 .35767 .41895 .36344 Metetra
.41895 .36344 .42718 .35767 .44041 .35312 .43228 .35885 Metetra
.066 0 0 r
.43228 .35885 .44041 .35312 .45368 .34967 .44565 .3553 Metetra
.136 0 0 r
.44565 .3553 .45368 .34967 .46701 .3473 .45908 .35277 Metetra
.196 0 0 r
.45908 .35277 .46701 .3473 .4804 .346 .47257 .35121 Metetra
.246 0 0 r
.47257 .35121 .4804 .346 .49389 .34571 .48615 .3506 Metetra
.287 0 0 r
.48615 .3506 .49389 .34571 .50746 .34636 .49982 .35085 Metetra
.318 0 0 r
.49982 .35085 .50746 .34636 .52116 .34786 .5136 .35189 Metetra
.34 0 0 r
.5136 .35189 .52116 .34786 .53497 .35013 .5275 .35361 Metetra
.352 0 0 r
.5275 .35361 .53497 .35013 .54893 .35303 .54154 .35591 Metetra
.354 0 0 r
.54154 .35591 .54893 .35303 .56303 .35645 .55571 .35865 Metetra
.344 0 0 r
.55571 .35865 .56303 .35645 .57727 .36022 .57002 .36168 Metetra
.32 0 0 r
.57002 .36168 .57727 .36022 .59167 .36419 .58448 .36484 Metetra
.277 0 0 r
.58448 .36484 .59167 .36419 .60623 .36819 .59909 .36797 Metetra
.211 0 0 r
.59909 .36797 .60623 .36819 .62093 .37203 .61384 .37087 Metetra
.119 0 0 r
.61384 .37087 .62093 .37203 .63578 .37551 .62873 .37337 Metetra
0 .562 .804 r
.62873 .37337 .63578 .37551 .65076 .37843 .64374 .37526 Metetra
.14 .649 .901 r
.64374 .37526 .65076 .37843 .66585 .38058 .65885 .37634 Metetra
.286 .719 .967 r
.65885 .37634 .66585 .38058 .68105 .38175 .67406 .3764 Metetra
.419 .765 .996 r
.67406 .3764 .68105 .38175 .69631 .38173 .68933 .37524 Metetra
.529 .786 .991 r
.68933 .37524 .69631 .38173 .71163 .38032 .70465 .37266 Metetra
.683 .789 .93 r
.15791 .54053 .16686 .54736 .17961 .54104 .17058 .5353 Metetra
.725 .826 .928 r
.17058 .5353 .17961 .54104 .19253 .53336 .18344 .52868 Metetra
.758 .859 .924 r
.18344 .52868 .19253 .53336 .2056 .52448 .19647 .52085 Metetra
.784 .888 .92 r
.19647 .52085 .2056 .52448 .21879 .51461 .20962 .512 Metetra
.803 .915 .915 r
.20962 .512 .21879 .51461 .23206 .50393 .22288 .5023 Metetra
.815 .938 .909 r
.22288 .5023 .23206 .50393 .2454 .49263 .23621 .49194 Metetra
.82 .959 .902 r
.23621 .49194 .2454 .49263 .25879 .4809 .2496 .4811 Metetra
.818 .976 .893 r
.2496 .4811 .25879 .4809 .27219 .46892 .26303 .46996 Metetra
.807 .989 .882 r
.26303 .46996 .27219 .46892 .2856 .45688 .27647 .45869 Metetra
.786 .996 .866 r
.27647 .45869 .2856 .45688 .29901 .44493 .28992 .44746 Metetra
.753 .995 .845 r
.28992 .44746 .29901 .44493 .31241 .43324 .30337 .43642 Metetra
.707 .984 .818 r
.30337 .43642 .31241 .43324 .32578 .42195 .3168 .42571 Metetra
.647 .961 .782 r
.3168 .42571 .32578 .42195 .33913 .4112 .33022 .41547 Metetra
.573 .925 .738 r
.33022 .41547 .33913 .4112 .35246 .4011 .34363 .4058 Metetra
.488 .875 .686 r
.34363 .4058 .35246 .4011 .36577 .39175 .35702 .39682 Metetra
.394 .814 .629 r
.35702 .39682 .36577 .39175 .37907 .38325 .37041 .3886 Metetra
.37041 .3886 .37907 .38325 .39236 .37566 .38379 .38122 Metetra
.38379 .38122 .39236 .37566 .40565 .36905 .39718 .37473 Metetra
.39718 .37473 .40565 .36905 .41895 .36344 .41058 .36918 Metetra
.41058 .36918 .41895 .36344 .43228 .35885 .42401 .36457 Metetra
.052 0 0 r
.42401 .36457 .43228 .35885 .44565 .3553 .43748 .36091 Metetra
.117 0 0 r
.43748 .36091 .44565 .3553 .45908 .35277 .45101 .35818 Metetra
.173 0 0 r
.45101 .35818 .45908 .35277 .47257 .35121 .4646 .35637 Metetra
.218 0 0 r
.4646 .35637 .47257 .35121 .48615 .3506 .47828 .35541 Metetra
.254 0 0 r
.47828 .35541 .48615 .3506 .49982 .35085 .49204 .35524 Metetra
.281 0 0 r
.49204 .35524 .49982 .35085 .5136 .35189 .50591 .35578 Metetra
.299 0 0 r
.50591 .35578 .5136 .35189 .5275 .35361 .5199 .35693 Metetra
.306 0 0 r
.5199 .35693 .5275 .35361 .54154 .35591 .53402 .35858 Metetra
.301 0 0 r
.53402 .35858 .54154 .35591 .55571 .35865 .54826 .36059 Metetra
.283 0 0 r
.54826 .36059 .55571 .35865 .57002 .36168 .56265 .36283 Metetra
.248 0 0 r
.56265 .36283 .57002 .36168 .58448 .36484 .57717 .36513 Metetra
.193 0 0 r
.57717 .36513 .58448 .36484 .59909 .36797 .59184 .36734 Metetra
.112 0 0 r
.59184 .36734 .59909 .36797 .61384 .37087 .60664 .36926 Metetra
0 .564 .78 r
.60664 .36926 .61384 .37087 .62873 .37337 .62156 .37072 Metetra
.124 .648 .879 r
.62156 .37072 .62873 .37337 .64374 .37526 .6366 .37152 Metetra
.263 .719 .954 r
.6366 .37152 .64374 .37526 .65885 .37634 .65174 .37147 Metetra
.394 .766 .992 r
.65174 .37147 .65885 .37634 .67406 .3764 .66696 .37036 Metetra
.506 .789 .996 r
.66696 .37036 .67406 .3764 .68933 .37524 .68224 .368 Metetra
.593 .793 .976 r
.68224 .368 .68933 .37524 .70465 .37266 .69755 .36419 Metetra
.69 .8 .933 r
.16155 .52869 .17058 .5353 .18344 .52868 .17434 .52319 Metetra
.726 .837 .933 r
.17434 .52319 .18344 .52868 .19647 .52085 .1873 .51646 Metetra
.755 .87 .931 r
.1873 .51646 .19647 .52085 .20962 .512 .20041 .50867 Metetra
.777 .9 .928 r
.20041 .50867 .20962 .512 .22288 .5023 .21363 .5 Metetra
.792 .926 .924 r
.21363 .5 .22288 .5023 .23621 .49194 .22695 .49062 Metetra
.8 .949 .919 r
.22695 .49062 .23621 .49194 .2496 .4811 .24034 .48072 Metetra
.799 .969 .911 r
.24034 .48072 .2496 .4811 .26303 .46996 .25377 .47046 Metetra
.79 .983 .9 r
.25377 .47046 .26303 .46996 .27647 .45869 .26724 .46001 Metetra
.77 .992 .884 r
.26724 .46001 .27647 .45869 .28992 .44746 .28072 .44953 Metetra
.738 .992 .863 r
.28072 .44953 .28992 .44746 .30337 .43642 .29421 .43918 Metetra
.693 .981 .835 r
.29421 .43918 .30337 .43642 .3168 .42571 .30771 .42909 Metetra
.635 .959 .799 r
.30771 .42909 .3168 .42571 .33022 .41547 .32119 .41938 Metetra
.564 .924 .755 r
.32119 .41938 .33022 .41547 .34363 .4058 .33467 .41018 Metetra
.482 .877 .704 r
.33467 .41018 .34363 .4058 .35702 .39682 .34814 .40158 Metetra
.393 .819 .648 r
.34814 .40158 .35702 .39682 .37041 .3886 .36161 .39367 Metetra
.36161 .39367 .37041 .3886 .38379 .38122 .37508 .38651 Metetra
.37508 .38651 .38379 .38122 .39718 .37473 .38857 .38016 Metetra
.38857 .38016 .39718 .37473 .41058 .36918 .40207 .37466 Metetra
.40207 .37466 .41058 .36918 .42401 .36457 .4156 .37002 Metetra
.025 0 0 r
.4156 .37002 .42401 .36457 .43748 .36091 .42917 .36625 Metetra
.086 0 0 r
.42917 .36625 .43748 .36091 .45101 .35818 .4428 .36333 Metetra
.137 0 0 r
.4428 .36333 .45101 .35818 .4646 .35637 .45649 .36124 Metetra
.178 0 0 r
.45649 .36124 .4646 .35637 .47828 .35541 .47027 .35991 Metetra
.21 0 0 r
.47027 .35991 .47828 .35541 .49204 .35524 .48413 .3593 Metetra
.232 0 0 r
.48413 .3593 .49204 .35524 .50591 .35578 .4981 .35931 Metetra
.244 0 0 r
.4981 .35931 .50591 .35578 .5199 .35693 .51217 .35986 Metetra
.244 0 0 r
.51217 .35986 .5199 .35693 .53402 .35858 .52637 .36082 Metetra
.231 0 0 r
.52637 .36082 .53402 .35858 .54826 .36059 .5407 .36207 Metetra
.202 0 0 r
.5407 .36207 .54826 .36059 .56265 .36283 .55515 .36347 Metetra
.154 0 0 r
.55515 .36347 .56265 .36283 .57717 .36513 .56974 .36487 Metetra
.083 0 0 r
.56974 .36487 .57717 .36513 .59184 .36734 .58446 .3661 Metetra
.013 .583 .773 r
.58446 .3661 .59184 .36734 .60664 .36926 .59931 .36699 Metetra
.13 .66 .87 r
.59931 .36699 .60664 .36926 .62156 .37072 .61428 .36736 Metetra
.259 .726 .945 r
.61428 .36736 .62156 .37072 .6366 .37152 .62935 .36702 Metetra
.384 .772 .989 r
.62935 .36702 .6366 .37152 .65174 .37147 .64451 .36578 Metetra
.493 .795 .999 r
.64451 .36578 .65174 .37147 .66696 .37036 .65975 .36345 Metetra
.579 .799 .983 r
.65975 .36345 .66696 .37036 .68224 .368 .67503 .35984 Metetra
.691 .806 .937 r
.16523 .51672 .17434 .52319 .1873 .51646 .17812 .51112 Metetra
.723 .843 .938 r
.17812 .51112 .1873 .51646 .20041 .50867 .19117 .50444 Metetra
.748 .877 .938 r
.19117 .50444 .20041 .50867 .21363 .5 .20435 .49684 Metetra
.766 .907 .937 r
.20435 .49684 .21363 .5 .22695 .49062 .21764 .48848 Metetra
.777 .933 .934 r
.21764 .48848 .22695 .49062 .24034 .48072 .23101 .47956 Metetra
.779 .956 .928 r
.23101 .47956 .24034 .48072 .25377 .47046 .24445 .47021 Metetra
.772 .973 .919 r
.24445 .47021 .25377 .47046 .26724 .46001 .25793 .46062 Metetra
.755 .984 .906 r
.25793 .46062 .26724 .46001 .28072 .44953 .27144 .45094 Metetra
.727 .987 .887 r
.27144 .45094 .28072 .44953 .29421 .43918 .28496 .4413 Metetra
.686 .98 .861 r
.28496 .4413 .29421 .43918 .30771 .42909 .2985 .43186 Metetra
.632 .962 .827 r
.2985 .43186 .30771 .42909 .32119 .41938 .31205 .42272 Metetra
.566 .931 .786 r
.31205 .42272 .32119 .41938 .33467 .41018 .32559 .41401 Metetra
.49 .889 .738 r
.32559 .41401 .33467 .41018 .34814 .40158 .33914 .40581 Metetra
.407 .836 .685 r
.33914 .40581 .34814 .40158 .36161 .39367 .35269 .39822 Metetra
.322 .777 .63 r
.35269 .39822 .36161 .39367 .37508 .38651 .36625 .3913 Metetra
.36625 .3913 .37508 .38651 .38857 .38016 .37983 .3851 Metetra
.37983 .3851 .38857 .38016 .40207 .37466 .39343 .37965 Metetra
.39343 .37965 .40207 .37466 .4156 .37002 .40706 .37499 Metetra
.40706 .37499 .4156 .37002 .42917 .36625 .42073 .3711 Metetra
.039 0 0 r
.42073 .3711 .42917 .36625 .4428 .36333 .43446 .36797 Metetra
.086 0 0 r
.43446 .36797 .4428 .36333 .45649 .36124 .44826 .36558 Metetra
.123 0 0 r
.44826 .36558 .45649 .36124 .47027 .35991 .46213 .36388 Metetra
.149 0 0 r
.46213 .36388 .47027 .35991 .48413 .3593 .47609 .36279 Metetra
.165 0 0 r
.47609 .36279 .48413 .3593 .4981 .35931 .49015 .36225 Metetra
.17 0 0 r
.49015 .36225 .4981 .35931 .51217 .35986 .50432 .36216 Metetra
.161 0 0 r
.50432 .36216 .51217 .35986 .52637 .36082 .5186 .3624 Metetra
.137 0 0 r
.5186 .3624 .52637 .36082 .5407 .36207 .533 .36285 Metetra
.095 0 0 r
.533 .36285 .5407 .36207 .55515 .36347 .54753 .36338 Metetra
.031 0 0 r
.54753 .36338 .55515 .36347 .56974 .36487 .56219 .36383 Metetra
.054 .617 .786 r
.56219 .36383 .56974 .36487 .58446 .3661 .57697 .36405 Metetra
.159 .684 .874 r
.57697 .36405 .58446 .3661 .59931 .36699 .59187 .36386 Metetra
.276 .743 .945 r
.59187 .36386 .59931 .36699 .61428 .36736 .60687 .36309 Metetra
.391 .783 .988 r
.60687 .36309 .61428 .36736 .62935 .36702 .62198 .36157 Metetra
.492 .803 1 r
.62198 .36157 .62935 .36702 .64451 .36578 .63716 .3591 Metetra
.574 .804 .986 r
.63716 .3591 .64451 .36578 .65975 .36345 .65241 .3555 Metetra
.687 .809 .94 r
.16896 .50466 .17812 .51112 .19117 .50444 .18194 .49911 Metetra
.715 .846 .944 r
.18194 .49911 .19117 .50444 .20435 .49684 .19506 .49261 Metetra
.737 .879 .946 r
.19506 .49261 .20435 .49684 .21764 .48848 .20831 .48532 Metetra
.751 .909 .946 r
.20831 .48532 .21764 .48848 .23101 .47956 .22165 .4774 Metetra
.757 .935 .944 r
.22165 .4774 .23101 .47956 .24445 .47021 .23508 .46901 Metetra
.755 .956 .938 r
.23508 .46901 .24445 .47021 .25793 .46062 .24856 .46031 Metetra
.742 .972 .929 r
.24856 .46031 .25793 .46062 .27144 .45094 .26208 .45145 Metetra
.719 .979 .913 r
.26208 .45145 .27144 .45094 .28496 .4413 .27564 .44256 Metetra
.685 .978 .892 r
.27564 .44256 .28496 .4413 .2985 .43186 .28922 .43379 Metetra
.638 .965 .863 r
.28922 .43379 .2985 .43186 .31205 .42272 .30281 .42525 Metetra
.579 .942 .827 r
.30281 .42525 .31205 .42272 .32559 .41401 .31642 .41704 Metetra
.511 .907 .785 r
.31642 .41704 .32559 .41401 .33914 .40581 .33003 .40927 Metetra
.436 .863 .738 r
.33003 .40927 .33914 .40581 .35269 .39822 .34366 .40201 Metetra
.358 .811 .689 r
.34366 .40201 .35269 .39822 .36625 .3913 .35731 .39533 Metetra
.35731 .39533 .36625 .3913 .37983 .3851 .37097 .38929 Metetra
.37097 .38929 .37983 .3851 .39343 .37965 .38466 .38391 Metetra
.38466 .38391 .39343 .37965 .40706 .37499 .39839 .37921 Metetra
.39839 .37921 .40706 .37499 .42073 .3711 .41217 .3752 Metetra
.41217 .3752 .42073 .3711 .43446 .36797 .426 .37186 Metetra
.016 0 0 r
.426 .37186 .43446 .36797 .44826 .36558 .43989 .36916 Metetra
.047 0 0 r
.43989 .36916 .44826 .36558 .46213 .36388 .45386 .36705 Metetra
.068 0 0 r
.45386 .36705 .46213 .36388 .47609 .36279 .46792 .36548 Metetra
.076 0 0 r
.46792 .36548 .47609 .36279 .49015 .36225 .48208 .36436 Metetra
.071 0 0 r
.48208 .36436 .49015 .36225 .50432 .36216 .49634 .3636 Metetra
.051 0 0 r
.49634 .3636 .50432 .36216 .5186 .3624 .5107 .36309 Metetra
.014 0 0 r
.5107 .36309 .5186 .3624 .533 .36285 .52519 .36271 Metetra
.042 .611 .737 r
.52519 .36271 .533 .36285 .54753 .36338 .53979 .36233 Metetra
.118 .666 .817 r
.53979 .36233 .54753 .36338 .56219 .36383 .55451 .3618 Metetra
.211 .72 .893 r
.55451 .3618 .56219 .36383 .57697 .36405 .56935 .36096 Metetra
.313 .767 .954 r
.56935 .36096 .57697 .36405 .59187 .36386 .5843 .35966 Metetra
.414 .798 .99 r
.5843 .35966 .59187 .36386 .60687 .36309 .59935 .35771 Metetra
.504 .811 1 r
.59935 .35771 .60687 .36309 .62198 .36157 .61448 .35496 Metetra
.578 .809 .987 r
.61448 .35496 .62198 .36157 .63716 .3591 .62969 .35122 Metetra
.679 .806 .943 r
.17274 .4925 .18194 .49911 .19506 .49261 .18579 .48714 Metetra
.704 .843 .949 r
.18579 .48714 .19506 .49261 .20831 .48532 .19898 .48093 Metetra
.722 .876 .953 r
.19898 .48093 .20831 .48532 .22165 .4774 .21229 .47405 Metetra
.732 .906 .955 r
.21229 .47405 .22165 .4774 .23508 .46901 .22568 .46664 Metetra
.735 .931 .954 r
.22568 .46664 .23508 .46901 .24856 .46031 .23915 .45886 Metetra
.729 .951 .949 r
.23915 .45886 .24856 .46031 .26208 .45145 .25268 .45084 Metetra
.713 .965 .94 r
.25268 .45084 .26208 .45145 .27564 .44256 .26626 .44273 Metetra
.686 .97 .925 r
.26626 .44273 .27564 .44256 .28922 .43379 .27987 .43465 Metetra
.649 .966 .904 r
.27987 .43465 .28922 .43379 .30281 .42525 .2935 .42671 Metetra
.6 .952 .876 r
.2935 .42671 .30281 .42525 .31642 .41704 .30716 .41904 Metetra
.543 .927 .842 r
.30716 .41904 .31642 .41704 .33003 .40927 .32084 .4117 Metetra
.478 .894 .803 r
.32084 .4117 .33003 .40927 .34366 .40201 .33454 .40479 Metetra
.41 .853 .762 r
.33454 .40479 .34366 .40201 .35731 .39533 .34827 .39837 Metetra
.34 .809 .721 r
.34827 .39837 .35731 .39533 .37097 .38929 .36202 .39248 Metetra
.274 .763 .682 r
.36202 .39248 .37097 .38929 .38466 .38391 .3758 .38716 Metetra
.3758 .38716 .38466 .38391 .39839 .37921 .38962 .38244 Metetra
.38962 .38244 .39839 .37921 .41217 .3752 .40349 .3783 Metetra
.40349 .3783 .41217 .3752 .426 .37186 .41742 .37473 Metetra
.41742 .37473 .426 .37186 .43989 .36916 .43141 .37171 Metetra
.43141 .37171 .43989 .36916 .45386 .36705 .44548 .3692 Metetra
.44548 .3692 .45386 .36705 .46792 .36548 .45964 .36711 Metetra
.45964 .36711 .46792 .36548 .48208 .36436 .47389 .36539 Metetra
.47389 .36539 .48208 .36436 .49634 .3636 .48824 .36394 Metetra
.089 .647 .737 r
.48824 .36394 .49634 .3636 .5107 .36309 .50269 .36266 Metetra
.138 .683 .798 r
.50269 .36266 .5107 .36309 .52519 .36271 .51726 .36142 Metetra
.203 .724 .863 r
.51726 .36142 .52519 .36271 .53979 .36233 .53193 .36009 Metetra
.282 .764 .923 r
.53193 .36009 .53979 .36233 .55451 .3618 .54672 .35854 Metetra
.367 .796 .969 r
.54672 .35854 .55451 .3618 .56935 .36096 .56162 .35662 Metetra
.451 .815 .995 r
.56162 .35662 .56935 .36096 .5843 .35966 .57661 .35417 Metetra
.526 .82 .999 r
.57661 .35417 .5843 .35966 .59935 .35771 .5917 .35102 Metetra
.589 .812 .985 r
.5917 .35102 .59935 .35771 .61448 .35496 .60687 .34701 Metetra
.668 .798 .945 r
.17656 .48021 .18579 .48714 .19898 .48093 .18968 .47511 Metetra
.69 .834 .952 r
.18968 .47511 .19898 .48093 .21229 .47405 .20294 .46929 Metetra
.705 .867 .959 r
.20294 .46929 .21229 .47405 .22568 .46664 .2163 .46288 Metetra
.713 .896 .962 r
.2163 .46288 .22568 .46664 .23915 .45886 .22975 .45603 Metetra
.713 .92 .963 r
.22975 .45603 .23915 .45886 .25268 .45084 .24327 .44888 Metetra
.705 .94 .961 r
.24327 .44888 .25268 .45084 .26626 .44273 .25685 .44156 Metetra
.687 .952 .954 r
.25685 .44156 .26626 .44273 .27987 .43465 .27048 .43419 Metetra
.66 .957 .941 r
.27048 .43419 .27987 .43465 .2935 .42671 .28415 .42689 Metetra
.624 .954 .924 r
.28415 .42689 .2935 .42671 .30716 .41904 .29785 .41975 Metetra
.579 .942 .901 r
.29785 .41975 .30716 .41904 .32084 .4117 .31159 .41287 Metetra
.528 .921 .873 r
.31159 .41287 .32084 .4117 .33454 .40479 .32535 .40631 Metetra
.471 .894 .843 r
.32535 .40631 .33454 .40479 .34827 .39837 .33915 .40015 Metetra
.414 .862 .812 r
.33915 .40015 .34827 .39837 .36202 .39248 .35298 .39443 Metetra
.357 .828 .783 r
.35298 .39443 .36202 .39248 .3758 .38716 .36684 .38918 Metetra
.305 .794 .758 r
.36684 .38918 .3758 .38716 .38962 .38244 .38075 .38442 Metetra
.26 .764 .739 r
.38075 .38442 .38962 .38244 .40349 .3783 .39472 .38014 Metetra
.223 .739 .728 r
.39472 .38014 .40349 .3783 .41742 .37473 .40874 .37635 Metetra
.195 .722 .727 r
.40874 .37635 .41742 .37473 .43141 .37171 .42283 .373 Metetra
.18 .712 .736 r
.42283 .373 .43141 .37171 .44548 .3692 .437 .37005 Metetra
.176 .711 .756 r
.437 .37005 .44548 .3692 .45964 .36711 .45125 .36744 Metetra
.187 .72 .786 r
.45125 .36744 .45964 .36711 .47389 .36539 .46559 .3651 Metetra
.211 .736 .825 r
.46559 .3651 .47389 .36539 .48824 .36394 .48003 .36294 Metetra
.251 .758 .87 r
.48003 .36294 .48824 .36394 .50269 .36266 .49457 .36086 Metetra
.303 .783 .916 r
.49457 .36086 .50269 .36266 .51726 .36142 .50921 .35873 Metetra
.365 .806 .957 r
.50921 .35873 .51726 .36142 .53193 .36009 .52396 .35644 Metetra
.432 .822 .986 r
.52396 .35644 .53193 .36009 .54672 .35854 .53881 .35385 Metetra
.498 .829 .999 r
.53881 .35385 .54672 .35854 .56162 .35662 .55377 .35082 Metetra
.557 .824 .996 r
.55377 .35082 .56162 .35662 .57661 .35417 .56881 .34719 Metetra
.607 .812 .979 r
.56881 .34719 .57661 .35417 .5917 .35102 .58394 .34281 Metetra
.674 .819 .953 r
.19364 .46291 .20294 .46929 .2163 .46288 .20695 .45752 Metetra
.687 .85 .961 r
.20695 .45752 .2163 .46288 .22975 .45603 .22036 .45162 Metetra
.693 .878 .967 r
.22036 .45162 .22975 .45603 .24327 .44888 .23386 .44535 Metetra
.692 .902 .971 r
.23386 .44535 .24327 .44888 .25685 .44156 .24744 .43883 Metetra
.684 .921 .972 r
.24744 .43883 .25685 .44156 .27048 .43419 .26108 .43219 Metetra
.668 .935 .968 r
.26108 .43219 .27048 .43419 .28415 .42689 .27477 .42553 Metetra
.645 .941 .961 r
.27477 .42553 .28415 .42689 .29785 .41975 .28851 .41894 Metetra
.614 .941 .95 r
.28851 .41894 .29785 .41975 .31159 .41287 .30229 .41252 Metetra
.577 .933 .935 r
.30229 .41252 .31159 .41287 .32535 .40631 .31611 .40633 Metetra
.535 .92 .917 r
.31611 .40633 .32535 .40631 .33915 .40015 .32997 .40043 Metetra
.492 .902 .899 r
.32997 .40043 .33915 .40015 .35298 .39443 .34387 .39487 Metetra
.449 .882 .881 r
.34387 .39487 .35298 .39443 .36684 .38918 .35782 .38969 Metetra
.409 .86 .866 r
.35782 .38969 .36684 .38918 .38075 .38442 .37182 .38489 Metetra
.374 .841 .856 r
.37182 .38489 .38075 .38442 .39472 .38014 .38587 .38048 Metetra
.347 .825 .852 r
.38587 .38048 .39472 .38014 .40874 .37635 .39998 .37645 Metetra
.33 .814 .855 r
.39998 .37645 .40874 .37635 .42283 .373 .41417 .37276 Metetra
.322 .808 .867 r
.41417 .37276 .42283 .373 .437 .37005 .42843 .36937 Metetra
.327 .808 .885 r
.42843 .36937 .437 .37005 .45125 .36744 .44277 .36622 Metetra
.343 .814 .909 r
.44277 .36622 .45125 .36744 .46559 .3651 .4572 .36325 Metetra
.371 .822 .937 r
.4572 .36325 .46559 .3651 .48003 .36294 .47172 .36036 Metetra
.408 .831 .964 r
.47172 .36036 .48003 .36294 .49457 .36086 .48635 .35746 Metetra
.453 .838 .985 r
.48635 .35746 .49457 .36086 .50921 .35873 .50107 .35443 Metetra
.5 .84 .997 r
.50107 .35443 .50921 .35873 .52396 .35644 .51589 .35116 Metetra
.547 .835 .998 r
.51589 .35116 .52396 .35644 .53881 .35385 .5308 .34751 Metetra
.59 .823 .988 r
.5308 .34751 .53881 .35385 .55377 .35082 .54581 .34334 Metetra
.657 .797 .949 r
.19766 .45035 .20695 .45752 .22036 .45162 .21103 .44541 Metetra
.669 .826 .959 r
.21103 .44541 .22036 .45162 .23386 .44535 .2245 .44003 Metetra
.675 .853 .968 r
.2245 .44003 .23386 .44535 .24744 .43883 .23806 .43433 Metetra
.675 .876 .974 r
.23806 .43433 .24744 .43883 .26108 .43219 .2517 .42842 Metetra
.669 .895 .978 r
.2517 .42842 .26108 .43219 .27477 .42553 .26541 .4224 Metetra
.657 .909 .98 r
.26541 .4224 .27477 .42553 .28851 .41894 .27917 .41637 Metetra
.639 .918 .978 r
.27917 .41637 .28851 .41894 .30229 .41252 .29299 .41041 Metetra
.616 .922 .974 r
.29299 .41041 .30229 .41252 .31611 .40633 .30685 .40459 Metetra
.59 .921 .969 r
.30685 .40459 .31611 .40633 .32997 .40043 .32077 .39896 Metetra
.562 .915 .962 r
.32077 .39896 .32997 .40043 .34387 .39487 .33474 .39357 Metetra
.533 .907 .955 r
.33474 .39357 .34387 .39487 .35782 .38969 .34875 .38845 Metetra
.507 .897 .949 r
.34875 .38845 .35782 .38969 .37182 .38489 .36283 .38362 Metetra
.484 .886 .946 r
.36283 .38362 .37182 .38489 .38587 .38048 .37696 .37906 Metetra
.468 .877 .947 r
.37696 .37906 .38587 .38048 .39998 .37645 .39116 .37478 Metetra
.459 .87 .952 r
.39116 .37478 .39998 .37645 .41417 .37276 .40543 .37075 Metetra
.458 .865 .96 r
.40543 .37075 .41417 .37276 .42843 .36937 .41978 .36691 Metetra
.465 .861 .971 r
.41978 .36691 .42843 .36937 .44277 .36622 .43421 .36322 Metetra
.481 .859 .982 r
.43421 .36322 .44277 .36622 .4572 .36325 .44873 .3596 Metetra
.504 .856 .992 r
.44873 .3596 .4572 .36325 .47172 .36036 .46334 .35597 Metetra
.532 .851 .998 r
.46334 .35597 .47172 .36036 .48635 .35746 .47804 .35223 Metetra
.562 .842 .997 r
.47804 .35223 .48635 .35746 .50107 .35443 .49283 .34829 Metetra
.593 .83 .989 r
.49283 .34829 .50107 .35443 .51589 .35116 .50772 .34402 Metetra
.622 .813 .974 r
.50772 .34402 .51589 .35116 .5308 .34751 .5227 .3393 Metetra
.652 .795 .951 r
.21522 .43272 .2245 .44003 .23806 .43433 .22875 .42783 Metetra
.658 .82 .961 r
.22875 .42783 .23806 .43433 .2517 .42842 .24237 .42265 Metetra
.66 .842 .97 r
.24237 .42265 .2517 .42842 .26541 .4224 .25608 .41728 Metetra
.657 .86 .977 r
.25608 .41728 .26541 .4224 .27917 .41637 .26985 .41181 Metetra
.65 .874 .982 r
.26985 .41181 .27917 .41637 .29299 .41041 .2837 .40632 Metetra
.64 .885 .985 r
.2837 .40632 .29299 .41041 .30685 .40459 .2976 .40086 Metetra
.626 .891 .987 r
.2976 .40086 .30685 .40459 .32077 .39896 .31156 .3955 Metetra
.611 .894 .988 r
.31156 .3955 .32077 .39896 .33474 .39357 .32559 .39028 Metetra
.595 .894 .989 r
.32559 .39028 .33474 .39357 .34875 .38845 .33967 .38522 Metetra
.581 .891 .989 r
.33967 .38522 .34875 .38845 .36283 .38362 .35381 .38035 Metetra
.569 .887 .99 r
.35381 .38035 .36283 .38362 .37696 .37906 .36802 .37565 Metetra
.561 .882 .991 r
.36802 .37565 .37696 .37906 .39116 .37478 .3823 .37112 Metetra
.558 .876 .993 r
.3823 .37112 .39116 .37478 .40543 .37075 .39665 .36673 Metetra
.559 .869 .995 r
.39665 .36673 .40543 .37075 .41978 .36691 .41109 .36244 Metetra
.566 .861 .996 r
.41109 .36244 .41978 .36691 .43421 .36322 .4256 .35819 Metetra
.578 .852 .996 r
.4256 .35819 .43421 .36322 .44873 .3596 .4402 .35391 Metetra
.593 .841 .991 r
.4402 .35391 .44873 .3596 .46334 .35597 .45488 .34954 Metetra
.611 .827 .983 r
.45488 .34954 .46334 .35597 .47804 .35223 .46966 .34496 Metetra
.629 .812 .97 r
.46966 .34496 .47804 .35223 .49283 .34829 .48452 .3401 Metetra
.648 .8 .956 r
.24682 .40996 .25608 .41728 .26985 .41181 .2606 .40505 Metetra
.649 .816 .964 r
.2606 .40505 .26985 .41181 .2837 .40632 .27446 .40001 Metetra
.647 .829 .971 r
.27446 .40001 .2837 .40632 .2976 .40086 .28839 .39493 Metetra
.642 .839 .976 r
.28839 .39493 .2976 .40086 .31156 .3955 .30239 .38983 Metetra
.637 .846 .98 r
.30239 .38983 .31156 .3955 .32559 .39028 .31646 .38477 Metetra
.631 .85 .983 r
.31646 .38477 .32559 .39028 .33967 .38522 .33059 .37978 Metetra
.625 .851 .985 r
.33059 .37978 .33967 .38522 .35381 .38035 .3448 .37486 Metetra
.62 .85 .986 r
.3448 .37486 .35381 .38035 .36802 .37565 .35908 .37001 Metetra
.618 .846 .986 r
.35908 .37001 .36802 .37565 .3823 .37112 .37343 .36523 Metetra
.618 .84 .985 r
.37343 .36523 .3823 .37112 .39665 .36673 .38785 .36048 Metetra
.62 .833 .982 r
.38785 .36048 .39665 .36673 .41109 .36244 .40236 .35573 Metetra
.626 .823 .976 r
.40236 .35573 .41109 .36244 .4256 .35819 .41695 .35092 Metetra
.633 .812 .968 r
.41695 .35092 .4256 .35819 .4402 .35391 .43162 .34598 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000j@P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML00?oG8ML00?oG8ML00?oG8ML00?oG
8ML00?oG8ML00?oG8ML00?oG8ML00?oG8ML00?oG8ML00?oG8ML00?oG8ML00?oG8ML00?oG8ML00?oG
8ML00?oG8ML00<gG101?e`00cmL00`3Ge`1>e`00cmL00`3Ge`1>e`00cmL00`3Ge`1>e`00cmL00`3G
e`0;e`@0?mL00<gG0`0?e`030=OG03kG003?e`030=OG00gG00<0emL0?]L00=OG1004e`030=OG03kG
003Oe`030=OG03kG003Be`802ML3043G003@e`D02]L00`3Ge`0ne`00cML300?G0P1;e`00bmL200KG
00<0e`00B]L00<SG0`08e`040=OG04WG0035e`<00]L00`3Ge`06e`040=OG04WG0033e`803]L01@3G
emL004SG0030e`<04=L00`3Ge`0304OG002He`801=L00`3Ge`02e`<06=L200;G00<0emL03]L00`3G
e`02e`030=OG04GG002Ge`040=OG00_G00<0emL04]L301GG00<0emL00mL00`3Ge`14e`00UmL0103G
e`0;e`030=OG013G0P0Ie`030=OG00?G00<0emL0@mL009OG00@0emL02=L3013G100Je`030=OG00?G
00<0emL0@mL009OG00@0emL02=L00`3Ge`0>e`807]L00`3Ge`04e`030=OG04;G002Ge`040=OG00SG
00<0emL02mL3023G00<0emL00mL204CG002He`802ML400OG0`0Se`030=OG00GG00<0emL0@ML00:cG
0P03e`030=OG023G00<0emL01]L00`3Ge`10e`00ZML302SG00<0emL01]L00`3Ge`10e`00YmL202_G
00<0emL01mL00`3Ge`0oe`00Y=L300;G00<0emL0:=L00`3Ge`08e`030=OG03kG002Re`80<=L00`3G
e`07e`80@=L009oG0`0be`030=OG00WG00<0emL0?ML009gG0P02e`030=OG033G00<0emL02]L00`3G
e`0le`00V]L303OG00<0emL02]L00`3Ge`0le`00NmL201[G0`0je`030=OG00_G00<0emL0>mL007[G
00@0emL05mL200;G00<0emL0>=L00`3Ge`0<e`030=OG03[G001je`040=OG01CG0`0oe`030=OG00_G
0P0=e`801=L00`3Ge`02e`<08ML007[G00@0emL04]L204;G00<0emL03ML00`3Ge`09e`040=OG00_G
00<0emL07]L007[G00@0emL03mL504;G00<0emL03]L00`3Ge`08e`040=OG00_G00<0emL07]L007[G
00@0emL03ML204OG00<0emL03]L00`3Ge`02e`@00]L0103Ge`08e`<08ML007_G0P0;e`<0BML00`3G
e`0?e`030=OG00OG00@0emL02=L00`3Ge`0Qe`00Q]L404_G00<0emL03]L200SG00@0emL02=L00`3G
e`0Qe`00PmL304oG00<0emL03ML00`3G0009e`802ML4023G0020e`<0D]L00`3Ge`0@e`030=OG03GG
001ne`<0E=L00`3Ge`0@e`030=OG03GG001ke`<00mL00`3Ge`1Ae`030=OG017G00<0emL0==L007WG
0P1Je`030=OG01;G00<0emL0<mL007KG101Ke`030=OG017G0P0ee`00M=L205oG00<0emL04mL00`3G
e`0be`00BML200CG00<0emL00]L301[G0`1Qe`030=OG01CG00<0emL0<ML004SG00@0emL02mL00`3G
e`0De`D0H]L00`3Ge`0De`030=OG037G0018e`040=OG00_G00<0emL04]L206OG00<0emL05ML00`3G
e`0`e`00@]L400;G00@0emL02=L301;G0`1Ye`030=OG01GG0P0ae`00B=L0103Ge`08e`030=OG013G
0P000mL0e`1Ye`030=OG01GG0P0ae`00B=L0103Ge`08e`030=OG00gG0`1^e`030=OG01OG00<0emL0
;]L004WG0P09e`@02]L2077G00<0emL06=L00`3Ge`0]e`00GmL30003e`3G073G00<0emL06=L00`3G
e`0]e`00GML207KG00<0emL06ML00`3Ge`0/e`00F]L307SG00<0emL06=L302gG001Ge`<00]L00`3G
e`1fe`030=OG01[G00<0emL0:mL005GG0P1ne`030=OG01_G00<0emL0:]L005;G0`21e`030=OG01_G
00<0emL0:ML0053G0P02e`030=OG07oG00<0emL06mL00`3Ge`0Ye`00<=L401WG0`26e`030=OG01[G
0`07e`808ML003;G00<0emL05]L208WG00<0emL07=L00`3Ge`04e`040=OG023G000be`030=OG01?G
0`02e`030=OG08KG00<0emL07ML00`3Ge`03e`040=OG023G000Ze`@01=L00`3Ge`0Ae`80S]L00`3G
e`0Ne`030=OG00;G00@0emL08=L003;G00<0emL03]L408oG00<0emL07]L00`3Ge`02e`040=OG023G
000`e`<03ML309?G00<0emL07mL01@3GemL000;G00<0emL07]L003;G00<0emL02ML209KG00<0emL0
7ML20003e`3G00;G0P0Qe`00>mL30003e`3G09CG0P0Re`030=OG02CG000ie`80UmL300;G00<0emL0
8=L00`3Ge`0Se`00=mL209KG0`05e`030=OG027G00<0emL08]L003OG0`2Be`<02ML00`3Ge`0Oe`80
9=L003OG00<0e`00T=L200gG00<0emL08=L00`3Ge`0Qe`00=mL0103Ge`2<e`<04=L00`3Ge`0Pe`03
0=OG023G000fe`030=OG00;G00<0emL0Q]L301?G00<0emL08=L00`3Ge`0Pe`00=]L300?G00<0emL0
P]L301OG00<0emL08=L00`3Ge`0Oe`00=]L00`3Ge`04e`030=OG07kG0`0Ke`030=OG01kG0`0Pe`00
=]L00`3Ge`05e`80NmL301oG00<0emL07mL00`3Ge`0Ne`00=]L00`3Ge`07e`030=OG07GG0`0Re`03
0=OG023G00<0emL07ML003KG00<0emL02=L00`3Ge`1ae`<09]L00`3Ge`0Pe`030=OG01cG000fe`80
2]L00`3Ge`1^e`80:]L00`3Ge`0Oe`030=OG01cG000ee`803=L00`3Ge`1Ze`<0;ML00`3Ge`0Me`<0
7ML000_G0P04e`030=OG00?G0P04e`801=L200CG0P05e`030=OG00;G00<0emL03=L00`3Ge`1Ve`<0
<=L00`3Ge`0Oe`030=OG01_G000:e`040=OG00SG00@0emL00]L0103Ge`02e`040=OG00;G00@0emL0
1=L00`3Ge`02e`030=OG00gG00<0emL0H]L303CG00<0emL07mL00`3Ge`0Je`002]L0103Ge`08e`04
0=OG00;G00@0emL00]L0103Ge`02e`050=OG0=L01@03e`030=OG00kG00<0emL0G]L303SG00<0emL0
7mL00`3Ge`0Ie`001=L400;G00@0emL02=L0103Ge`02e`040=OG00;G00@0emL00]L01P3Ge`3G00;G
00<0emL00]L2013G00<0emL0F]L303_G00<0emL07mL00`3Ge`05e`801=L00`3Ge`02e`<01]L000[G
00@0emL02=L0103Ge`02e`040=OG00;G00@0emL00]L0103Ge`02e`030=L000CG00<0emL04=L00`3G
e`1Fe`<0?mL00`3Ge`0Me`030=L000GG00@0emL02mL00`3Ge`03e`002]L0103Ge`08e`040=OG00;G
00@0emL00]L0103Ge`02e`040=OG00?G0P04e`030=OG017G00<0emL0D]L300?G400`e`030=OG01oG
00<0emL00]L0103Ge`0;e`030=OG00?G000;e`802]L200CG0P04e`801=L200GG00D0emOG000Ee`03
0=OG04kG0`02eaT0;=L00`3Ge`0Ne`030=OG00;G00@0emL02=L300KG000de`030=OG01CG00<0emL0
BmL200?G4@000dP000030003B00000<0:]L00`3Ge`0Oe`050=OGe`000]L00`3Ge`06e`030=OG00KG
000de`030=OG01GG00<0emL0AmL300;G5`02B0T0:ML00`3Ge`0Me`<00]L0103Ge`08e`030=OG00KG
000de`805mL204CG0`03e`T000>900001@02R@<000=800000`02B0P0:=L00`3Ge`0Ne`040=OGe`80
2ML400GG000de`030=OG01SG00<0emL0?]L30004e`00e`T000>cRK<010001HT0RK>900@000B?R@18
1@000hV?000502OG00<0emL07]L00`3Ge`0De`00==L00`3Ge`0Ie`030=OG03[G0`001=L00002R@L0
0XT40003RFD000:910000fF90003R@<000>9I@000hT300:90`000mL0000Re`030=OG01oG00<0emL0
4mL003CG00<0emL06]L00`3Ge`0fe`L000F9/`2cR@040003ShT0008000J9S`2?RHl30003SfD000L0
00>?00001P001HT0RHn900@000>90=L00]L201kG00<0emL07]L00`3Ge`0Ce`00<mL00`3Ge`0Le`03
0=OG03;G1P02R@800XT300>90`000fF9000;0003@FD000H000=U@@002P000fF90002R@@00XT00`3G
e`0201[G00<0emL07=L301CG000ce`807]L00`3Ge`0^e`<000WG002?R@29/hT00`000hV?00030003
IHl002T000=UR@000hT300:900@0emOG0P0De`030=OG01oG00<0emL04ML003?G00<0emL07]L00`3G
e`0[e`800]L20004R@29R@@000=US`0030000j`0[@030007[@00PP22[@030007PP23PP1NP`0E0003
R@2900:910000hT0e`0De`030=OG01kG00<0emL04ML003?G00<0emL07mL00`3Ge`0We`<000OG0000
ShV?00<000>?R@002P004J`0[=L0/jbc0:f/[@2][:f/008000B]0:f21P001X<0Ph80GQ@000>9I@00
0XT201GG00<0emL07]L00`3Ge`0@e`00<mL00`3Ge`0Pe`030=OG02?G0`001=L00002R@@000>?I@00
2@000k>/00020003[00000:/0`001Z`00:`0[0<000>/PZ`00P02PP0408:200:200L0PUh0F01H00<0
00<d03@040000hUU0003e`804=L00`3Ge`0Le`<04ML003?G00<0emL08ML00`3Ge`0Oe`L000>cR@00
0P000hV?000:0003e`3G00<000GG[=L0e`02000<[:f/0:b][:d0[JJ]0`002Zd0[H80PX<0Ph850004
GP1NP`D000<k00004P000hT0e`02e`802mL00`3Ge`0Ne`030=OG00oG000ce`808mL00`3Ge`0Ke`H0
0hT30003RHl000X000Jc0=L0ej`20004[02/00:/0P001Z`00:H0PP<000R2[000PZJ200:21P001H80
F01H00<000AH03AN0`000cD000080004>fDk00=U00<0IHT01002R@030=OG00WG00<0emL07]L00`3G
e`0>e`00<]L202GG00<0emL05mL60003RK<000<000>9S`0040005]Nb003G[=L0ej`0[=40[Jb][02V
[:H20005[880PZd00`003JH0PX80PX<0Ph80GX<01P000cAO00020003=@0A00l000>9I@000hT200_G
00<0emL07ML00`3Ge`0>e`002=L200CG00<0emL00mL200CG0P04e`801=L200?G1003e`030=OG02GG
00<0emL04mL600:900D0R@00R@0>0007eP3F0=H0eP0300>/00@0[0000Z`0102/0:`30008[000PP22
YX820003YP2200:200D0PX80PP040007PUP0F5h0GP040004=000=1H000=U0=L00]L200OG00<0emL0
7ML00`3Ge`0=e`001mL0103Ge`08e`040=OG00;G00@0emL00]L0103Ge`02e`040=OG00;G00<0emL0
1=L00`3Ge`0Ve`804=L30004e`00R@8000>cR@001002S`/000SG0=L0e`3G/P8000KG0=L0dJ`20003
d@2/00:/00X0[:J/0:bV[02/0`001Jb2[02V00H000>208801P001H<0G`1O00P000<@00002@001S/0
IHUU00:910000hT0e`06e`030=OG01cG00<0e`003]L000OG00@0emL02=L0103Ge`02e`040=OG00;G
00@0emL00]L0103Ge`03e`030=OG00?G00<0emL0:=L00`3Ge`0;e`800]L200B90`0018T008lC0008
eZ`00=2/d002[00H0:b/0:bV[02/0:`0[02/PZ`0YX80PZJ20P000h80PP02PP09089l05R2089H00@0
00EN05P0F0020003=00000X000<G00001`000hUO0003R@030=OG00GG00<0emL07ML00`3Ge`0<e`00
00?G00000P02e`040=OG00SG00@0emL00]L0103Ge`02e`040=OG00;G00@0emL01=L00`3Ge`02e`03
0=OG02WG00<0emL01mL30006e`0008Vc10000hVc000@0007e`3G0=L0e`020006[02/e`3@0P003jc@
0=00[02/YP2V0:H0YP030003PZb200@000BVPZH00X801022PP02PP0605j208=H10000el0G`040003
=00001P02=L00`3Ge`0Me`030=OG00_G0007e`040=OG00SG00@0emL00]L0103Ge`02e`040=OG00;G
00@0emL01ML01@3GemL002cG00<0emL00mL30004e`0000:900D0R@00R@040003S`0000X0016b003F
0=H0eP3F[02/0:c@0002[08001B/0:bV[02/YZbV08:/PP22YX80PP8000BVPZH00X800`22PP0=0003
GUP000<000EH03@0=00600032@0000D000dF03]U>`1OI@29IHT000SG00<0emL07ML00`3Ge`04e`@0
0]L000OG00@0emL02=L0103Ge`02e`040=OG00;G00@0emL00]L0103Ge`02e`040=OG00?G00<0emL0
:mL00`3G000200GG0P001Zf9002cR@8000>cS`0030003k80/P2b0;80/P2/0:`0[002000=d:`0[=00
d:c@0:`0[0030007[000YP2V[0020008PZH0YX80PZH30005PP22PP000X801@22F01H00@000=OF000
0P000cAI00040003=@0001D01mL00`3Ge`0Le`802=L00`3Ge`01e`002=L200[G0P04e`801=L200CG
0P04e`800mL00`3Ge`0[e`<02ML30003RHl0010000>b00002P001Z`0[=00d0800Z`04P2/0:`0[:J/
0:bV[02VPZH0YP8000J2YX80PZH3000BPP22O01lPP22F01HPP22F01H10000eP000020005=00:00X0
40001fEOI@29GhT01@03e`030=OG01gG00<0emL01ML00`3Ge`01e`00<ML00`3Ge`0Xe`<00mL00`3G
e`02e`@000>9/`000P001;<008l?000I/P2b0;80/P2/0:`0[=H0d:`0[02/0:c@0003[08000nV[000
YZbV[02/PP22YX800P001JH0YX8000>200@0PX800X802P1HPP22089H05P20003G`1I008000<d0000
3@000a0000080003R@2900:900D0emOG000Oe`030=OG00CG00<0emL00ML0037G00<0emL09ML300OG
1003R@<000>cR@003`004;800;80/P2/0:`0[02/0:`20003d:`000>/00X0YZ`0[02/0:bV0P001JJ1
08:V008000B2YP2V0`02PP0608:2PP1l30001880GP02F0<000<dF0000P002C@0000@010040070003
5`0000d00]L00`3Ge`0Me`030=OG00CG00<0emL00ML0037G00<0emL08]L300WG0P001Jf908Vc0080
00F90000S`020003/`0000T000?G00001P001;;G0=L20009[=H0d03@0=2/008000?@0:`00Z`06@2/
YZ`0[:J/0:`0[02/PZ`0YX80PZJ208800`003880PX80PW`0O880PP<000J205h0GUP20005F@1I03D0
2P000a0040060008IEmU08UUR@02R@050=OGe`007ML300?G0`03e`00<ML2023G0`0=e`0308R900<0
00FcR@00/`0B0007/P2/0:`0[0040008d03@0=2/d002[0070:J/0:bV[002000<YZ`0[02VPJH0YX6V
0`001ZH0YX40PP<0019k07b2O01lPP22F01HPP2205P30004F01H=0<000<d00000P000c@0000:0003
400000d00mL00`3Ge`0Ge`@000?G0=L01=L00`3Ge`01e`00<ML00`3Ge`0Me`804ML20003/hVc0080
00>?/`000`000hl00008000Re`00/P2b0;80[=L0eP3F0=J/0:c@0=00d03@0=00[02/YP8000B/YP2V
0`002ZJ/YP22YX80PZH20006PP22YX800X804022PP1lPP22O01HPP2208830003GP1N00@000@d03@e
3@000c/000040004GhUO00>900D0emOG000Ee`<01ML00`3Ge`07e`00<ML00`3Ge`0Je`<04ML20003
R@00008000>cR@003`004MH0eP3F0=H0eP3F0=H0d03@008000>/d0000j`04`2/0:bV0:H0YJ`0[:F/
Y@21YX400`001H40PJJ100<000V1PX40Nh80PW`03@02F00405P0F0<000AH05P00S@500072P0:00X0
2P080003G`0000P00]L00`3Ge`0@e`<02=L00`3Ge`07e`00<=L00`3Ge`0He`<04]L20006/hT00;>9
0`000hl000080004/`00/P`000gF[000eZ`0[02/0:c@008000f/0:c@[02V[02/0:bV008000V/YZ`0
[:J/0:H00`002:J208:V0:J20`003880PX80PW`0O880PP@000EHPP1NF0030003=000008000He0000
=A0;000:>`0003/0GhUO00:900D0emOG000=e`@03=L00`3Ge`06e`00<=L00`3Ge`0Ee`<04mL20007
R8T008VcR@020003/`0000D000Fc/P00/P05000;eP3F0=H0eP3F0=H00P002:`0[02/d:`00Z`01`2/
YP2V[:H00P002j`0[:D0Y@21086V008000f1YX6V0:J1086V08:100<0019k07^2089k05N2089H05R2
07`4009H00L0F3@0=00d008000<d00000`000c@0000600044000>`/00mL00`3Ge`07e`<04=L00`3G
e`06e`00<=L00`3Ge`0Be`<05mL30003/hT0008000>?/`001P000k<00004000I/P00e`3G0=L0e`3F
0=J/0:`0[=H0d:`0[002000Bd:`0[02/0:J/0:bV[:H0YZbV0P001JbV0:J/008000F2YX80PP030005
PP22YP000h804022PP1lPP22O01H05R208830003GP1N00<000=H=0000`001CD0000e00l000AUGfD0
0hT01@3GemL000GG0`0Ce`030=OG00KG000`e`804=L301WG0P000hT0R@020003/hT000/001Jc002b
0;80/P2/0:`0[02/0:`0[02/0P000m2/0002[08001jV0:F/Y@2U[02/0:bU0:D0PJH0YX6V0:H0YP2V
PJH2000:P@1kPP22Nh80PP`000AH05P00UP02`1H000d03AH05P0008d00<0=0001`000c@0=@060003
>P0000P00]L00`3G000301KG00<0emL01]L0033G00<0emL03=L301_G00@0/hVc0P000hVcR@0<0003
e`0000h002Z/eP00[=H0d03@0=00d:`0[=2/0:H0YP2V0:H0YZ`0[02/0:bV[02VPZH40008PZJ208:V
0:H3000<PP22O01lPP22O01H0`001UP0F880GP@00UP30003F@0000@000<d01000P000cD0000<0003
GhUO00D06]L00`3Ge`06e`00<=L00`3Ge`09e`<07mL30003/hT0010000nb0;80[02/0:`0[02/0:`0
0P002=00d03@[=000Z`02@2U0:D0Y@2U[002000=YJbU0:FVYJH0YX40P@03000=PJJ1086VP@21YP22
N`02000BPP22Nh80PW/0Eh80PUL0E`1H0`001UP0F5P0F08000@d03@00S@01`0d03@0=1002@002100
000jG`1O10000en90002e`030=OG01OG00<0emL01]L0033G00<0emL01mL2027G0P0018T00002/`80
00Zc0;<0/`2b0;;G0P006[80/P2b0;80/P3@0:`0[=H0eP3F[02/d03@0P004Z`0[=00d03@Y]00[:H0
YP2V[08000BV[:H00ZH00`2VPP020007YX:V0:J2YP030004YX:V00:20100O880PW`0O880PUP0F01H
1@000eQN00030006=00003AI1@0013D003@30003=00000L000EO05n9G`0200;G00<0emL05]L00`3G
e`06e`00;mL00`3Ge`05e`<08ML20005[HP00;<00`002[>80;80/P2b0;820003/`0000P000Z/eP3F
0=00d03@0P001Jc@0=2/008000V/0:bU[02/YJ`00P002jD0YJ`0YP2V0:J1008000>VPJH00P001X6V
0:J1YP@001QkPP22N`1kPW/0Nh80PUL0Eh80PP1lF002F00305P000<000<dF0000P000eP000020003
=000008000<d00000P0013@0=3/30003GcYO00H000EN0=OG000He`030=OG00KG000_e`800mL302;G
0P001XV]002]/`800[<>0009/P2b0;80/P2/00@001[F0=H0eZ`0[02/0:`0[=00d:c@0=00d02/YP80
00N/YZ`0[:J/008000>V[0000ZH04@22YX80PZJ208:V0:J208:V01<000N2F01HPP1N008000QH05QH
05P0F@8000<d0000100013D003@20003>`1O00L000>9GhT00P02e`030=OG01KG00<0emL01ML002SG
0P05e`030=L000809]L30007[HP00;>8/`040008[02b0;80/[<2000/[02/0:`0[02/eP3F0=00d:`0
[02/d:`0[=00[02/0:`0[:F/0:bU[02/YJ`20009PJJ1086VP@21008000BVPJJ110001X9kPP22N`80
01:2089k07^2089G05N2089G05L30004F01H009H10000c@000020003F000008000<d03@00P000cD0
00050006>`1O>P1N10000hT0e`02e`030=OG01GG00<0emL01ML002OG00@0emL01=L202SG0P000hT0
R@020003/`0000<00[<01P2b0;80/P80017G0=L0e`3G0=L0eP3F0=H0eP020007[=H0d:`0[0020009
d03@[02/0:K@008000^V[02/0:`0[02/YP020005[:J/YP000ZH02`2VPZH0YX80PZJ200@000>VPP00
0X804@22O01lPP22O01lPP22F01H00<000UH05P0F5h0F0000UP0200dF@1I05Td1P001C/0001O00L0
00B908V30P02e`030=OG01GG00<0emL01ML002OG00@0emL01ML00`3Ge`0Ue`040:f8[@8000R8/`00
[;<0/a<000CF[02/0P001=2/0:`20005d:`0[=000P002jD0YJbU0:F/0:bU008000N/Y@2U0:FV0080
00F1YP2VP@020004YX40P@<000F1YX40N`02000LPW^2089k07^2089k05N2089G05N207aG05P0F0<0
00=H05P010000ePd00020003=000008000@d000d100023/003@0GUmN1@000ej90002e`030=OG01CG
00<0emL01ML002OG00@0emL01]L202KG0`000k>]000200:c00<0/`000`004;80/P2be`3G0=L0e`3G
0=L4000/[02/0:c@0=00d03@0=2/0:c@[02/0:H0YZ`0[:J/YP2V[:H0YZbV0:H0YP03YP0708:V0:J2
YP02000:PP22YX80PZH0PP`000]l05R2089H05P0F0020004GUP0F08000=H05P00P000c@0=0020003
G`00008000@d001O2P000h>9P`0200;G00<0emL04mL00`3Ge`05e`009mL0103Ge`08e`030=OG02;G
0P000hP0R0020003/hP000D000Jc[02/0:`6000XeP3F0=J/0:`0[02/d03@0=2/d03@[02U0:D0Y@2U
[:D0YJ`0[02/Y@8000bVY@00YX6VP@21YX440003YX6V00@000UkPW/0Nh9k07/00P003880PW/0Nh80
PUL0E`P00UP00`1H0003009H10001UP0001H=0@000@d000d1@001S@0GUl0P`@000=N0=L00]L00`3G
e`0Be`030=OG00GG000We`040=OG00WG00<0emL08=L0102]RJd20003[K>]00@000>c0=L02`003=Nb
0:`0[02/0:`0[08000O@[02/d03@008000V/0:c@0=00d:`00P002J`0[:H0YP2V[0020005YZ`0[:H0
0P03YP0A0:J208:VPP22YX80PZH0YX801003PP0A089l07b2089l07`0F89H05P01000189H05P40003
GUP000<000UO000d03@0=5l01P000el000020007G`29G`23R@0200;G00<0emL04]L00`3Ge`05e`00
:=L200_G00<0emL08=L30003[HP000@000B//`2c0P002Z`0[02/0:`0[=H4000:[02/0:`0[=00d080
00F/d03@[002000;[02/YJ`0[:D0YJ`00P004ZF/Y@2UYZD0PJJ10840P@21YP8000>1YX4010001jIk
YP22Nh800P006g/0Nh80PW/0Nh80PW/0Eh80PUL0Eh80O5L0F0020006F01HF01H0P0025P0F3@0=00d
0P000ePd00020004=5l0G`<000=O05l01`000hUN0002e`030=OG01;G00<0emL01=L003KG00<0emL0
7ML20003[HT0008000F]/`00[@04000@ek80/P2b0;80[=N/0:`0[0<001n/eP3F0=2/0:`0[02/d03@
0=2/d03@0=00d:H0YZbV008000b/YP00[:J/YP2V[:H200:V00/0PZH0YX:V0:J2YP040006PZH0YX80
0h80501lPP22O01lPP22089HPP22089H100015h0GUP40003GP00008000<dG`000P0025l0001O05mH
1@0025l0GhT0RH>90P02e`030=OG017G00<0emL01=L003OG0P0Ne`0508P00:d00`001k>/002c0;<0
10001ZcG0=H0eP8000N/0:`0[02/008002K@[02/d03@[02/d02/0:`0[02/YJ`0[:D0Y@2U0:D0Y@2U
YP2VP@8000VVPJH0YX6V0:H00P001X6VP@1kYP8000]kPP22Nh80PW/0N`0?0007E`1GO01H0002F080
00AH05P00UP01@0dF01H008000<d03@010002Ul0001O05mH05h80003R@3G00;G00<0emL04=L00`3G
e`04e`00>ML00`3Ge`0Ke`8000J]/`00[K<20009[K<0ek80/P2/00H000_G[02/0:`0[=H0eP020009
[=00d:`0[02/008000O@[02/0:c@008000VV0:J/0:`0[:H00P001jbV0:H0YZ`01004YP070:J208:V
PP02000:YP2VPZH0YX80PP<000n207b2089l07b2089l05P00`0025P0F880PP220`000eh0GP040003
F5l000<000=H05P00`000eP00003000;GP1OP`29G`23RH<00P02e`030=OG013G00<0emL01=L003[G
00<0emL06=L20007[HP00;>8/`02000@[000/j`0[02/e`3F0=H0eP8001n/eP3@0=00d:`0[02/0:`0
[=2/0:D0YJbU0:F/0:bU008001N/YJ`0[:F/0:JUYZD0PJJ1086VP@21YP020004PJH0YP<000RVN`1k
PW/0N`<001Ek07^2N`1kPP22N`1GPP22E`1G05L00`0025P0F5P0F01H0P02F00305P000<000<dF000
0`000cAN00050003GP0000T01ML00`3Ge`0?e`030=OG00CG000ke`030=OG01SG00D0R@00/`030005
/jd00;<010002jcG0=L0e`3G[02/00@002SF[02/0:c@[02/d03@[02/0:c@[02/0:`0Y]00[:J/0:`0
[02/0:bV0P001:bV0003YP0A0:H0YP2VPZH0YX80PZJ208800`001X80PZJ200:201<0PW`0O880PW`0
O880PUP0F01H00<000IH05R208840004F5h0G`<000=O05l00P001UP0F5l0G`<000UO08UO08>9P`00
1mL00`3Ge`0>e`030=OG00CG000le`806=L20006R:d008R]0P001jbc002/0:`010002mJ/0:`0[=H0
d03@008000N/d03@[02/008001o@[02U0:D0Y@2U[:D0YJ`0[02/0:bU0:D0Y@2U086V008000b1YP2V
PJH0YX6V0:H20006PJJ107^V0P008G/0Nh9k07^2089kPP22N`1kPP22E`1GPP2207aG05P0F005009H
00<0F0000P0015P0F5P30003=5P000@000AO05mH2`07e`030=OG00gG00<0emL01=L003kG00<0emL0
4mL20003[HT0008000F]/`00[@020009ej`0[=L0e`3G008000^/e`3G0=H0eZ`0[002000Bd:`0[=00
d03@0=00d03@0=2/0P006=00[:H0YP2V[:H0YZbV0:J/YP2V[:H0YP<00jH20005YX80PZH0100038:V
PP22YP2VPZH0PQ<000N2F01HPP2200@000AHGP1N0`000el0G`040004F5l0G`<000aO08=N05n9G`23
R@07e`030=OG00gG00<0emL01=L003oG00<0emL04mL01P28002]R08000Fc[;<0/`020009[;<0/`3F
[02/00@001g@[02/0:c@0=00d03@0=2/d02/0:bU[02/Y@2U[0020007YJbU0:F/Y@020006YZD00:J1
0P007jJ1YX40PJH0YX6V0:J1YP2VP@1kYW/0Nh80PW^208800`004X80PW/0Nh80PUL0Eh80PUL0E`@0
0UP01@1HF01H00<000EH05P0F0030003F01N00<000AN05mH3P07e`030=OG00gG00<0emL00mL0043G
00<0emL04mL0102]/jd20008/`2c0;>/0:`40009ej`0[=L0e`3G008000j/eP3F0=2/d03@[02/d080
01J/0:c@0=00d03@YP2V[:H0YP2V0:J/0P002JJ/0:`0[02/YP0200>V100018:VPZH30009YX:V0:J2
YP2V00<001RV08:207b2089l07b2089l07b2089H05P30008F01H05R208820005F5h0GeP00`0015QO
05l3000>G`23GP1NPeh0PhT0RH<200OG00<0emL03=L00`3Ge`03e`00@ML00`3Ge`0Ce`<000V8[HR]
0;>/0:`00P000k<0/P020009[=H0d03@[02/008000O@[02/d03@008001n/d02/Y@2U[02/YJ`0[:D0
Y@2U0:F/0:`0YZD0YJJU008001^VP@210840PJJ1086VP@21YX40NjH0YW^V08800`007X80PW/0Nh9k
07^2089k05N2089G05N20880O5L0F0<000IH05QH05P4009H00<0GUP00P0015h0GUP?00WG00<0emL0
3=L00`3Ge`03e`00@]L201;G0P001:d00:d20003/`00008000N/e`3G[02/008000WG[02/0:cF0=H0
0P004Zc@0=2/0:`0[02/0:`0[02/d08000fV0:K@YP2V[:J/0:bV008000V/YZbV0:J/YP000jH02@2V
002VPZH0YP030006YX80PZJ20P002JH0YX80PZJ20002PP03088000P000j2089l05R20880PUP0F0<0
00IH05R208830005G`1O05l00`003el0Peh0GX=N05j908V3000;e`030=OG00_G00<0emL00mL004CG
00<0emL03]L20003[HR]008000N/[@00[02/008000>b[0000Z`04P2/002/d03@0=2/0:`0[02/00>/
00`0Y@2U[:D0YJ`0[:D20007[:D0Y@2U[0020007Y@2UYP2VY@020007YX400:J1YP02000=PJH0YX6V
0:J107^VN`040008PW/0Nh9k07/60009PP22N`1GPP2200T000Ql07aH05P0F0D00UP00`1N00020004
GP1NF0P000AO08=N1@0;e`030=OG00[G00<0emL00mL004GG00<0emL03mL3000;/jd00;>/0:bc0=L0
0P001jcG0=N/0:`00P003]J/0:`0[=2/0:c@0=2/0P005]00d:`0[02/0:K@0=2V0:J/0:`0[:H20007
[:H0YP2V[0020003YZ`000:V00H0YZJV08830005PZJ208800P002:J208:VPP220`006880PX80PWb2
089l07b20880PW`0O880PP<000V2089H05R208800`001880PeP40008G`23GP1NPeh50006P`23RH<0
2mL00`3Ge`09e`030=OG00?G0016e`030=OG00cG0P001:f808P2000:[@00[:d0[J`0[0800Z`01@2/
[02/008000N/d03@[02/00800Z`0:02V[02/Y@2U[:D0YJ`0[02/0:bU[02/YJ`0YZFVY@21YX40PJJ1
0842000;YX6VP@21YP2VPJH00P0027/0NjIk07^20P007W/0Nh9k07^2089k07^2089G05N2089G05N2
0880PPD00UP01@1HGP1N00<000AN05iH20002el0Peh0GX=N08:900802]L00`3Ge`09e`030=OG00?G
0017e`803ML00`29[@020005[;<00:`00P001mN/0:cG0=L00P001jcG0=N/0:`00P007M2/0:c@0=00
d03@0=00d03@[02/0:H0Y]00[:J/008000NV[02/0:bV008000V/YP00[:J/YP000ZH00`2VYP020005
YX:V0:H00P001X:VPP22YP@000N2YX80PZH000:201X0O89l07b2089l07`0O880PW`0F880PUP0F0<0
00MH05P0F89H00H000J3GP1NPeh<00gG00<0emL02=L00`3Ge`03e`00BML00`3Ge`0;e`8000J]R000
[J`20003[@0000:/00D0[:`0[00200:/00D0[:`0[00200:/02/0[:b/0:`0[:F/0:bU0:F/Y@2U[02/
0:`0[02/0:JU0:D0Y@21086V0:J1008000ZVP@210840PJJ10P006:J107^V0:Ik07^2N`1kPP22Nh80
PW/0N`l000]G05P0F880PUP0F0030009F01HGP1NF01H00<000iH05QO08=N05j308UNR@803]L00`3G
e`08e`030=OG00;G001:e`030=OG00_G00D0R@00[@020005[;<00:`00P001mN/0:cG0=L00P003:cF
0=2/0:`0[02/d08000^/0:c@0=00d03@[0020009d02/YP2V0:J/008000NV[:H0YZbV008000N/YP2V
0:H000>V00l0YZJV08:V0:J2YP2VPZH00`002JJ2YP2VPZH0YP06000?O01lPP22O01lPP22O01l00H0
00N20880PUR200P000EH05P0GP0>017G00<0emL01mL00`3Ge`02e`00BmL00`3Ge`0:e`8000F8[@00
R0020005[Jb]0:d00P02[00:0:b/0:`0[02/00>/00@0[:`00Z`03@2U[02/YJ`0[:D0YJ`00P002jF/
Y@2U[:D0YJJU008000jVYJH0YX6VP@21YX40P@8000>VPJH01000186VPJH40008Nh80PW^20883000K
PP22N`1kPP22N`1kPP22E`1GPP22E`1HPP2200<000b2089H05R2089H05P3000?F01HGP23GP1NP`23
GX<001;G00<0emL01mL00`3Ge`02e`00C=L00`3Ge`07e`8000J]R@00/j`20008/`2c0=N/0:`2000T
ej`0[=6/0:c@0=2/0:`0[02/0:`0[02/d03@0=00d:H0YZbV0P004:bV0:H0YP2V0:J/0:`0[:H200>V
0P02YP0D0:JV08:VPP22YX80PZH0YX80PZH30005YP2VPP000X806P22O880PW`0O880PW`0O880PP22
O880PP2220001eR308=H05h0400Be`030=OG00KG00<0emL00]L004gG0P08e`<000b8[@00[:f/[@2]
[002[0050:`0[0000Z`0102/0002[00K0:b/[02/0:J/YP2U[02/YJ`0[:D0Y@2U0:F/008000NU[02V
0:JU0080012VP@210840PJJ1086VP@210P001JJ1YP2V00<000JVNjH0PW/2000CPP22N`1kPW/0Nh80
PW/0Nh80PP03000EPP22E`1GPP22F01HPP22F01HPP2200<001F2089H05R2089H05j308=NP`29PP00
4mL00`3Ge`05e`030=OG00;G001?e`030=OG00OG00L0[@00[@2/0080016c002/e`3G[=L0dJ`0[=40
d002000@[=2/0:`0[=2/0:`0[02/d08001^V0:J/0:`0[:H0YZbV[02/YZ`0[:J/YP2V[:H01004YP0>
08:V0:J2YP2VPP22YX84000;YX80PZJ208:V08802@000h80PP0>000:F880PUP0F880P`H000]N05j3
GP1NP`29PP0501;G00<0emL01ML00`3Ge`02e`00D=L00`3Ge`07e`040:f8[@8000F/[@00[00200:/
0P000j`00002[00G0:b/0:`0[02/0:H0YP2V[:H0YJ`0[:D00P005:bU[02/Y@2U0:F/0:H0YP2V0:J1
0P002ZJ1YP2VPJH0YX420004YX40P@<001:1YX40NjH0PW^2089k07^20883000IPP22N`1kPP22Nh80
PP22E`1HPP22F880PP06000:F01H05R2F01HPP`000>20=L05ML00`3Ge`04e`030=OG00;G001Ae`03
0=OG00OG0`001Zf/002c[08000R]002/dJ`0[08001_@[02/d:`0[02/d:`0[=2/0:`0[02/d02/YZ`0
0P005:H0YZ`0[02/YP2V0:H0YP2V0:J/0P03YP0?0:H0YP22YX80PZH0YX:V00@000R2YX80PZH0YP<0
00>V08800X807@22PP1lPP22O01lPP22O01lPP22O01lPP22F01N00<001AH05j308=N05j308>2P`29
PP22R@805]L00`3Ge`04e`030=OG007G001Be`801]L20003R028008000^]002/[J`0[02/0002[005
0:`0[0000Z`2000F[02/YP2V0:H0YZbV0:F/0:`0[02/Y@80012/YJ`0YZFVY@2UYZD0PJJ10P002ZJ1
086VP@21YX440005YX6V0:H00P002G^VN`1kPW/0N`02000WPP22Nh80PW/0Nh80PW/0Nh9k05L0Eh80
PUP0F89H05P0F880PUR201D06ML00`3Ge`03e`030=OG007G001De`030=OG00;G00@0[HV]0P008jb]
002/0:`0[:f/0:cA0=6/d@3@[02/d03@[02/d:`0[=2/008001;@0:bV[02/YZ`0[:J/0:`0[:H2000=
[:H00:bV[02/YZ`0YP0300>V00L0YX:V0:J2008000RV0:J2YP2VPP@000NVPZH0YX8000>200<0PP00
50006g`0F880PUh0GX<0Peh0PX<0Ph:308V208:9000Je`030=OG00?G00<0emL00ML005GG00<0emL0
0]L30009[HP00:f/[J`000:/0P000j`00003[0040:`000:/02P0[02/0:bV0:H0YP2V[02/YJ`0[02/
0:`0[02/Y@2U0:D0Y@21YP2V0P002X6VPJH0YX40PJH20005PJJ108400P001jJ1YP2VNjH00P003G/0
Nh80PW/0Nh9k07/00`005G/0Nh80PW/0Nh80PUP0F880PUP0F00;000<F89H05R208=N05j31@0Je`03
0=OG00;G00<0emL00ML005KG00<0emL00mL01`29002]0:d00P003J`00:f/[@2]0=40dJ`00P009=00
d:c@0=2/0:c@[02/d02/0:`0[:H0YP2V0:H0YZbV0:J/YP8000V/YP2V0:H0YZ`00P03YP800ZH03022
YX80PZH0YX80PP<000R2YP2VPP22YPH000F208:20002PP0408:200:200P0O880PWb200:200@0PX80
0X801@22P`2300d000>90=L07ML01@3GemL000?G001Ge`030=OG00?G00@0R:f80P002:f/002]0:`0
0j`0102/[002[00;0:bV[02/0:`0[:H00P004Z`0[:H0Y@2U[:D0YJbU0:F/Y@8001ZVYJH0YX6VP@21
YP2V0:H0YX6V0:J1YP2VP@80012VP@21YX40PJH0PW^2089k0P00=X80PW/0Nh80PW^2089k07^2089k
05R2089H05R2089H05R2089H05R2089NPP22GP1NP`23PP807]L0103Ge`03e`00F=L200CG0`002jb]
002/[Jb]0:f/008001>]002/d03@0=00d:c@0=2/0:c@008000NV[:H0YZbV0080012/YP2V0:H0YP2V
[02/0:bV0P001jbV[02/YZ`01004YP8000F208:VPP040006YX:V0:J210001ZJ208:V00>200D0PX80
PP0I000:PP22P`23PP22P`H08=L0103Ge`03e`00F]L00`3Ge`03e`070:d008P0[0020003[@0000>/
0P000j`0[002[00F0:bV[02/0:`0[:H0YZbV0:H0Y@2U[08000NU[02/0:bU008000VVY@210840PJH0
0P006h6VP@21YX40PJJ1086VP@21YP2VP@21YX40N`02000;PW^2089k07^208801P006G/0O880PW`0
O880PUR2089H05R2089H05P02P001H<0RH8002;G00<0e`000mL005_G00<0emL00mL0102][:d2000g
[:d00:`0[02/[@3@[=00[03@0=2/d03@[02/0:H0YZbV0:J/YP2V[:J/0:bV[02/YZbV0:J/YP020004
[:H0YP800jH00`2V00020003YX:V00@000F2YX80PP03000:PP22YX80PZH0YP<000FV08:20003PP04
08:200:200@0PX800X801022PP02PP0C08:308>2P`23PP22P`29PXT0R@0202;G00<0e`000]L005cG
00<0emL00mL30004[HP000B/00l0[000[02/0:bV[02/YZ`00P002JH0YZbV0:J/YP020007[:D0Y@2U
[0020007YJ`0YP2VY@02000MYX6V0:J1YP2V0:H0YX6V0:J1086VP@21YP2VPJH00P002h40Nh9k07^2
N`1k008002B2089kPP22N`1kPP22O01lPP22O01HPUP0F880PUP0F880PUP<02GG0P02e`00GML00`3G
e`04e`070:`00:d0[@020007[02/[Jb]0003[0050:`0d0000Z`02`2/[:`0[02V0:J/008000NV[02/
0:bV008000N/YP2V0:J/00<000Z/0:bV[02/YP2V0`000h:VPP040003YX:V00@000V2YX80PZH0YX80
10001jJ2YP2VPP000X800`22PP0I000:PP22R@29PP22R@809ML200;G001Ne`801ML01P28[HR]00:/
00@0[02/0P00;Z`0[02/YZ`0[:H0YP2V0:J/YP2V[:H0YJbU[02/YJ`0YZFVY@21YX40PJJ10843000K
PJJ1086V0:J1YP2VPJH0YX40PJJ1086V089k00<000Yk07^2089k07^21P0087`0O880PW`0O880PWb2
089l05j2089N05j2GP22P`230`0We`800]L0063G00<0emL00mL0402/002]0:d0[J`0[:f/[@02[0<0
00>/0:`00Z`0102/[:`20007[:H0YP2V[0020007YZ`0[02/YP02000<[:H00:bV[:H0YZbV1003YP@0
00F2YX80PP020007YX:V0:J2YP02000:PP22YP2VPP22YP<000FV08:20002PP0408:200>200@0PX80
0X802@22PP23PP22P`0902KG1004e`00HML00`3Ge`03e`0408R]R08000J/002/0:`2000A[000YZbV
0:J/YP2V0:H0YZ`00P001jJ/0:`0[:H00P001jbU0:D0PJH00P001H6V0:J1008001VVPJH0YX40PJJ1
086VP@21YX40PJH0YX6V00@000R1PP22Nh80PP<00122089l07b2089lPP22O01l40002H80Ph80PX>2
000Re`@02=L006;G00<0emL00mL3000D[:d0[Jb][02/[J`0[02/0:`0[003[00Q0:J/YP2V[:J/0:bV
[02/YZbV0:J/YP2V[:H0YP2V0:J/008000>V[:H00`001ZH0PZH0YP<000FVPP22YP020008PZH0YX:V
0:H30009YP2VPP22YX8000:200<0PP001@000h80PP02PP0?08:308>208:308V2R@2900H07ML400cG
001Se`801ML01P2]0:d0[08001N/0:H0YZbV0:J/YP2V[:H0YP2V0:H0YP020007[02/0:`0[002000=
YP210840PJJ1086VP@02000<YX40PJH0YX6V0:J10P001ZJ1086VP@8000NV0:J1YP2200<000Z208:2
07b2O01l1P000h80PP02PP0408:200:200D0PX:20002PP03088000D000>9PP007=L4013G001Ue`03
0=OG00?G00<0[J`00P000jf/[@020003[:d0008000N/002/0:`000:/01P0[02/YP2V[:J/0:bV[02/
YZ`0[02/0:`3000<[:J/0:bV[02/0:`00jH20005PP22YX8010001JJ2YP2V00<000ZV0:J2YP2VPP22
0`001X80PZJ200:200@0PX800X800`22PP090008PXT0RH80PXT201SG0`0De`00I]L00`3Ge`03e`80
00>8[@000P006Jf8002/YZ`0[:J/YP2V[:J/0:bV0:H0YZ`00P004:J/0:`0[:J/0:J1YP2VPJH3000:
YP2VPJH0YX40P@<000F1YX40P@020006YX6V0:J10P000jH0PP02PP0408:100:20P02PP0408:200:2
00@0PX800X860005PP22PP000X801022Ph8601KG100Ge`00ImL00`3Ge`03e`070:d00:`0[0030006
[000[@2]0P000j`0[0030009YP2V[02/0:bV008000B/YP2V0`003JJ/0:`0[:H0YZbV0:H00`002ZJ/
YP22[02VPZH20007PZH0YX80PP020009YX:V0:J208:V00<000ZV0:J208:V0:J21P002X<0Ph80PX>2
08870003PP3G01GG100Ke`00J=L00`3Ge`03e`040:f8[@8002>2[H80YZbV[02/YZbV0:J/YP2V[:J/
0:bV[02/YZbV08:/PP02000>[880P@22086VP@22YX840003YX6V00@000J1YX40PJH20006PZH0YX80
0X830005PP22PP000X860005PP22PP000h800`2200050008PX<0RH80PXT2017G100Oe`00JML200CG
0`002:f80:`0[02/0P000jd0[@030006[000[02V0`001jH00:`0[:H00P003JbV[02/YZbV0:J/0:`0
0`004ZbV[02/YZ`0[880PZb208:VPP8000NV0:J208:V00<000NV0:J2YP2V00<000fV0:J208:VPP22
YP2300<000^]PP22R@29PP22R@03013G0`0Se`00JmL00`3Ge`03e`0308R]008001j8[@00PZb2[02/
YZ`0[:J/YP2V[:H0YZbV0:H0PZ`30004[02/PP8000NVPZH0YX:V00@000b2YX80P@2208:V0:H30005
YX:V0:H00`000jH0PP02PP030880008000F208:20003PP03088000D00X801P22PP23PPH03mL402KG
001/e`030=OG00?G0P02e`8000B][02/0P001jd0[@2]0:d00P005Z`0YP2/0:J/YP2V[:H0YZbV0:H0
YZ`3000B[02/YP2V[:H0YZbV08:/0:b20P001Zb208:VPP8000N/0:J2YP2V00<000ZVPP22YP2VPP22
0`002h:]0:f208:]0:f200<000>20=L03]L402[G001]e`030=OG00OG00<0R:d00P000h:]PP02000=
[8:/0:b2[880PZ`0[003000I[000PP22[880PZb208:VPP220880PZH0YP030003YX:V008000F208:V
PP030006PP22YP2V0`02PP0408:200:21@02PP0408:200:21P001880PXT200[G100^e`00K]L200SG
0P000jf800020003[02/008000>]0:d00`003Jf/002/YZ`0[:J/0:`00`003Z`00:H0YZbV0:J/0:bV
0P000jb2[0040005PZb208800P001Zb2[02/PP8000R/PP22[02VPP<000Z208:]0:f208:]0`001jd0
[H80PZd00`08e`@0<]L0073G00<0emL01]L00`280002000<PZd008:/PZ`0[8:/0P002H:/0:`0[02/
PP020009[8:/0:b2[02V00<000>VPZH00P001880PZH20005PZJ208800`001X:V0:J2YP8000F208:V
0002PP<000F208:20002PPH000B908V21P08e`<0=]L0077G00<0emL01]L0103GemL20004[HP0[0<0
00N/002]0:f/008000>]YZd00P003ZJ]0:`0[@2/YZ`0[:J/10000jJ/YP020005[880PZ`00P001h:/
0:b208800`001H:/0:b200<000N208:]PP2200<000N208:]0:f200<02]L403WG001be`030=OG00[G
00<0R:d00P0028:]PP22[H:]0P000h80PP02000:[02/PZ`0[880PP<000N2[880PZb200<000j208:V
0:H0[02VPP22YP8000F2YX80PP030003PP2200:200<0PP000P001880PXT600WG100me`00LmL00`3G
e`0:e`800]L30003e`2/00<000V/[@00[:f/0:H00`001jJ]002V[JH00`002jH0YZ`0[H:]0:b20080
00F]PP22[0030004[@2]PP<000N208:]PP2200<000B208:]0`0;e`@0@ML007CG0P0Ce`0408:]PP80
00F]PP22[0020003PZ`0008000B/0:b20P001:b2[8820004[02/PP<000B208:/0`001:`0YX830007
PZ`0[880PP030005PXT0RH800P0:e`@0AML007KG00<0emL04ML30004e`2/[@<000V][000[HP0[:d0
0P001:b]0:d30003[H:]008000B208:]0`001:d0[H830005PZd0[H801@001H:]0:f200<02ML304WG
001ge`030=OG01CG0`02e`070880e`22[@030004[@2/PP8000>]PZd00`001:d0[8820005[H80PZ`0
0P001H:]0:f200<000B208:]1P08e`@0C=L007SG00<0emL04mL00`3Ge`03e`040=OGe`8000CG0:f8
0`0018P0R:d20003R:f800<000B808R]0`001:d0[HP30004e`28[@<02]L4053G001ie`804mL00`3G
e`0;e`800]L00`2]PP0200;G0`001=L0PZd30004e`2]PP<01ML200WG101De`00NmL00`3Ge`0@e`03
0=OG013G0P09e`801ML200oG101He`00O=L00`3Ge`0?e`030=OG033G0`1Le`00OML00`3Ge`0>e`03
0=OG02cG101Oe`00O]L00`3Ge`0<e`030=OG02WG101Se`00OmL200cG00<0emL09ML406OG0021e`03
0=OG00WG00<0emL08]L306_G0022e`030=OG00SG00<0emL07]L406kG0023e`030=OG00OG00<0emL0
6]L407;G0024e`801mL00`3Ge`0Fe`@0M]L008KG00<0emL01=L00`3Ge`0Be`@0N]L008OG00<0emL0
0mL00`3Ge`0?e`<0O]L008SG00<0emL00]L00`3Ge`0;e`@0PML008WG00D0emOG0009e`@0QML008[G
0P000mL0e`04e`@0RML008cG0P000mL0000208gG002=e`80TML00?oG8ML00?oG8ML00?oG8ML00?oG
8ML00?oG8ML00?oG8ML00?oG8ML00?oG8ML00?oG8ML00?oG8ML00?oG8ML00?oG8ML00?oG8ML00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.188436, -0.0371894, \
0.00399928, 0.00399928}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{921, 763},
WindowMargins->{{172, Automatic}, {Automatic, 77}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 521, 15, 272, "Input"],
Cell[2251, 69, 35, 1, 31, "Output"],
Cell[2289, 72, 160, 4, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2486, 81, 42, 0, 32, "Input"],
Cell[2531, 83, 130, 3, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2698, 91, 453, 12, 212, "Input"],
Cell[3154, 105, 775, 14, 115, "Output"],
Cell[3932, 121, 11276, 319, 296, 3115, 214, "GraphicsData", "PostScript", \
"Graphics"],
Cell[15211, 442, 130, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15378, 450, 218, 8, 132, "Input"],
Cell[15599, 460, 342, 5, 52, "Output"]
}, Open  ]],
Cell[15956, 468, 659, 22, 432, "Input"],
Cell[16618, 492, 85, 3, 52, "Input"],
Cell[16706, 497, 51, 0, 32, "Input"],
Cell[16760, 499, 70, 0, 32, "Input"],

Cell[CellGroupData[{
Cell[16855, 503, 283, 12, 232, "Input"],
Cell[17141, 517, 228, 4, 36, "Message"],
Cell[17372, 523, 421, 7, 96, "Output"]
}, Open  ]],
Cell[17808, 533, 174, 7, 132, "Input"],

Cell[CellGroupData[{
Cell[18007, 544, 64, 3, 52, "Input"],
Cell[18074, 549, 62, 1, 32, "Print"],
Cell[18139, 552, 61, 1, 32, "Print"],
Cell[18203, 555, 56, 1, 32, "Print"],
Cell[18262, 558, 56, 1, 32, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18355, 564, 160, 4, 72, "Input"],
Cell[18518, 570, 137, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18692, 578, 65, 0, 32, "Input"],
Cell[18760, 580, 68462, 2305, 296, 27257, 1792, "GraphicsData", "PostScript", \
"Graphics"],
Cell[87225, 2887, 130, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[87392, 2895, 152, 4, 72, "Input"],
Cell[87547, 2901, 175043, 4284, 242, 145555, 3915, "GraphicsData", \
"PostScript", "Graphics"],
Cell[262593, 7187, 137, 3, 31, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

