(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     27516,        864]*)
(*NotebookOutlinePosition[     28146,        886]*)
(*  CellTagsIndexPosition[     28102,        882]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    RowBox[{\( (*\ c9 : \ Inhomogeneous\ boundary\ value\ problem\ *) \), 
      RowBox[{"(*", " ", 
        RowBox[{\(A\ problem\ is\ inhomogeneous\ if\ either\ the\ \
differential\ equation\ or\ the\ boundary\ values\ are\ inhomogeneous\), ",", 
          "\[IndentingNewLine]", 
          RowBox[{
          "see", "  ", "the", " ", "book", " ", "Mathematical", " ", 
            "Methods", " ", "in", " ", "Physics", " ", "and", " ", 
            "Engineering", " ", "with", " ", 
            StyleBox["Mathematica",
              FontSlant->"Italic"]}], 
          StyleBox[",",
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], \(CRC\ Press\), ",", 
          StyleBox[" ",
            FontSlant->"Italic"], 
          "\[IndentingNewLine]", \(ISBN\ 1584884029\)}], " ", "*)"}], 
      " ", \(Clear[y]\)}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(bsol = 
      NDSolve[{\(y''\)[x] + y[x] \[Equal] 0, y[0] \[Equal] 1. , 
          y[2. ] \[Equal] 2. }, y[x], {x, 0, Pi}]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{\(y[x]\), "\[Rule]", 
          RowBox[{
            
            TagBox[\(InterpolatingFunction[{{0.`, 3.141592653589793`}}, 
                "<>"]\),
              False,
              Editable->False], "[", "x", "]"}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Evaluate[y[x] /. bsol], {x, 0, Pi}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.303152 0.168033 0.153318 [
[.17539 .15553 -9 -9 ]
[.17539 .15553 9 0 ]
[.32696 .15553 -3 -9 ]
[.32696 .15553 3 0 ]
[.47854 .15553 -9 -9 ]
[.47854 .15553 9 0 ]
[.63011 .15553 -3 -9 ]
[.63011 .15553 3 0 ]
[.78169 .15553 -9 -9 ]
[.78169 .15553 9 0 ]
[.93327 .15553 -3 -9 ]
[.93327 .15553 3 0 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .32135 -6 -4.5 ]
[.01131 .32135 0 4.5 ]
[.01131 .47467 -6 -4.5 ]
[.01131 .47467 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .16803 m
.17539 .17428 L
s
[(0.5)] .17539 .15553 0 1 Mshowa
.32696 .16803 m
.32696 .17428 L
s
[(1)] .32696 .15553 0 1 Mshowa
.47854 .16803 m
.47854 .17428 L
s
[(1.5)] .47854 .15553 0 1 Mshowa
.63011 .16803 m
.63011 .17428 L
s
[(2)] .63011 .15553 0 1 Mshowa
.78169 .16803 m
.78169 .17428 L
s
[(2.5)] .78169 .15553 0 1 Mshowa
.93327 .16803 m
.93327 .17428 L
s
[(3)] .93327 .15553 0 1 Mshowa
.125 Mabswid
.05412 .16803 m
.05412 .17178 L
s
.08444 .16803 m
.08444 .17178 L
s
.11476 .16803 m
.11476 .17178 L
s
.14507 .16803 m
.14507 .17178 L
s
.2057 .16803 m
.2057 .17178 L
s
.23602 .16803 m
.23602 .17178 L
s
.26633 .16803 m
.26633 .17178 L
s
.29665 .16803 m
.29665 .17178 L
s
.35728 .16803 m
.35728 .17178 L
s
.38759 .16803 m
.38759 .17178 L
s
.41791 .16803 m
.41791 .17178 L
s
.44822 .16803 m
.44822 .17178 L
s
.50885 .16803 m
.50885 .17178 L
s
.53917 .16803 m
.53917 .17178 L
s
.56948 .16803 m
.56948 .17178 L
s
.5998 .16803 m
.5998 .17178 L
s
.66043 .16803 m
.66043 .17178 L
s
.69074 .16803 m
.69074 .17178 L
s
.72106 .16803 m
.72106 .17178 L
s
.75138 .16803 m
.75138 .17178 L
s
.81201 .16803 m
.81201 .17178 L
s
.84232 .16803 m
.84232 .17178 L
s
.87264 .16803 m
.87264 .17178 L
s
.90295 .16803 m
.90295 .17178 L
s
.96358 .16803 m
.96358 .17178 L
s
.9939 .16803 m
.9939 .17178 L
s
.25 Mabswid
0 .16803 m
1 .16803 L
s
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .32135 m
.03006 .32135 L
s
[(1)] .01131 .32135 1 0 Mshowa
.02381 .47467 m
.03006 .47467 L
s
[(2)] .01131 .47467 1 0 Mshowa
.125 Mabswid
.02381 .04538 m
.02756 .04538 L
s
.02381 .07604 m
.02756 .07604 L
s
.02381 .10671 m
.02756 .10671 L
s
.02381 .13737 m
.02756 .13737 L
s
.02381 .1987 m
.02756 .1987 L
s
.02381 .22936 m
.02756 .22936 L
s
.02381 .26002 m
.02756 .26002 L
s
.02381 .29069 m
.02756 .29069 L
s
.02381 .35202 m
.02756 .35202 L
s
.02381 .38268 m
.02756 .38268 L
s
.02381 .41334 m
.02756 .41334 L
s
.02381 .44401 m
.02756 .44401 L
s
.02381 .50533 m
.02756 .50533 L
s
.02381 .536 m
.02756 .536 L
s
.02381 .56666 m
.02756 .56666 L
s
.02381 .59732 m
.02756 .59732 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .32135 m
.06244 .37189 L
.10458 .42321 L
.14415 .46694 L
.18221 .5042 L
.22272 .53805 L
.26171 .5644 L
.28158 .57533 L
.30316 .58522 L
.32392 .59274 L
.33381 .59563 L
.34309 .59792 L
.35286 .5999 L
.36181 .60132 L
.36656 .60192 L
.37175 .60245 L
.37459 .60269 L
.37723 .60288 L
.37994 .60304 L
.38244 .60315 L
.3849 .60323 L
.38615 .60327 L
.38751 .60329 L
.38823 .6033 L
.38888 .60331 L
.38964 .60332 L
.39035 .60332 L
.39162 .60332 L
.39234 .60331 L
.393 .60331 L
.39419 .60329 L
.3953 .60327 L
.39652 .60324 L
.39783 .60321 L
.40051 .6031 L
.40296 .60297 L
.40729 .60268 L
.41202 .60226 L
.42157 .60109 L
.43184 .59935 L
.44118 .59734 L
.46213 .59135 L
.48131 .5841 L
.50211 .57435 L
.54303 .54964 L
.58243 .51928 L
.62032 .48449 L
.66066 .44204 L
.69948 .3966 L
.74076 .3442 L
Mistroke
.78052 .29063 L
.81876 .2371 L
.85946 .17896 L
.89864 .12278 L
.94028 .06394 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML00?oG8ML000oG00<0emL0omL?e`00
3mL00`3Ge`3oe`oG0007e`@01=L00`3Ge`3oe`oG0009e`030=OG00?G00<0emL0omL?e`002ML00`3G
e`03e`<0omL7e`030=OG00GG00000mL0000200CG00<0emL00mL00`3Ge`3oe`KG00<0emL01]L000WG
00<0emL00mL00`3Ge`3oe`KG00<0emL01]L000OG0`05e`030=OG0?oG1ML00`3Ge`07e`002ML00`3G
e`03e`030=OG0?oG1=L00`3Ge`08e`003mL00`3Ge`3oe`?G00<0emL02ML000oG00<0emL0omL3e`03
0=OG00WG000?e`030=OG0?oG0]L00`3Ge`0:e`003mL00`3Ge`3oe`7G00<0emL02mL000oG0P3oe`;G
00<0emL02mL000oG00<0emL0omL00`3Ge`0<e`003mL00`3Ge`3ne`030=OG00gG000?e`030=OG0?gG
00<0emL03]L000oG00<0emL0oML00`3Ge`0>e`003mL00`3Ge`3le`030=OG00oG000?e`030=OG0?_G
00<0emL04=L000oG00<0emL0n]L00`3Ge`0Ae`003mL20?_G00<0emL04ML000oG00<0emL0nML00`3G
e`0Be`003mL00`3Ge`3he`030=OG01?G000?e`030=OG0?OG00<0emL05=L000oG00<0emL0mmL00`3G
e`0De`003mL00`3Ge`3fe`030=OG01GG000?e`030=OG0?GG00<0emL05]L000oG00<0emL0m=L00`3G
e`0Ge`003mL00`3Ge`3de`030=OG01OG000?e`80m=L00`3Ge`0He`003mL00`3Ge`3be`030=OG01WG
000?e`030=OG0?7G00<0emL06]L000oG00<0emL0lML00`3Ge`0Je`003mL00`3Ge`3`e`030=OG01_G
000?e`030=OG0>oG00<0emL07=L000oG00<0emL0kmL00`3Ge`0Le`003mL00`3Ge`0Pe`801=L00`3G
e`02e`<08ML4023G1003e`030=OG00;G0`0Re`@08=L400?G00<0emL00]L301OG00<0emL02=L201?G
000?e`808=L0103Ge`0;e`030=OG023G00<0emL08ML00`3Ge`0:e`030=OG01oG00<0emL08ML00`3G
e`0<e`030=OG01?G00<0emL02=L0103Ge`0Be`003mL00`3Ge`0Oe`040=OG00_G00<0emL08=L00`3G
e`0Qe`030=OG00[G00<0emL08=L00`3Ge`0Qe`030=OG00_G00<0emL04mL00`3Ge`0;e`030=OG013G
000?e`030=OG01oG00@0emL02=L302?G00<0emL08ML00`3Ge`07e`<09=L00`3Ge`0Qe`030=OG00OG
0`0Ee`030=OG00[G0P0Ce`003mL00`3Ge`0Oe`040=OG00SG00<0emL08mL00`3Ge`0Qe`030=OG00OG
00<0emL09ML00`3Ge`0Qe`030=OG00KG00<0emL05=L00`3Ge`0=e`030=OG013G000?e`030=OG01oG
00@0emL02=L00`3Ge`0Qe`<08ML300WG00<0emL08]L0103Ge`0Pe`040=OG00SG00<0emL04mL00`3G
e`0;e`040=OG01;G000?e`030=OG023G0P09e`@08]L00`3Ge`0Qe`030=OG00OG100Re`808]L200WG
100Be`030=OG00cG0P0Ce`003mL00`3Ge`3Ye`030=OG02;G000?e`030=OG0>SG00<0emL08mL000oG
00<0emL0j=L00`3Ge`0Se`002=Oo01T0000?e`030=OG00GG00<0emL01]L00`3Ge`05e`030=OG00KG
00<0emL01ML00`3Ge`06e`030=OG00GG00<0emL01ML00`3Ge`06e`030=OG00GG00<0emL01]L00`3G
e`05e`030=OG00KG00<0emL01ML00`3Ge`05e`030=OG00KG00<0emL01ML00`3Ge`06e`030=OG00GG
00<0emL01]L00`3Ge`05e`030=OG00GG00<0emL01]L00`3Ge`05e`030=OG00KG00<0emL01ML00`3G
e`06e`030=OG00;G00@0emL02=L00`3Ge`05e`030=OG00GG00<0emL01]L1007G0ML000oG00<0emL0
9mL00`3Ge`0We`030=OG02OG00<0emL0:=L00`3Ge`0We`030=OG01?G00<0emL04ML00`3Ge`0Ae`00
3mL00`3Ge`3Ue`030=OG02KG000?e`030=OG0>CG00<0emL09mL000oG00<0emL0i=L00`3Ge`0We`00
3mL00`3Ge`3Se`030=OG02SG000?e`030=OG0>;G00<0emL0:ML000oG00<0emL0h]L00`3Ge`0Ye`00
3mL20>;G00<0emL0:]L000oG00<0emL0h=L00`3Ge`0[e`003mL00`3Ge`3Oe`030=OG02cG000?e`03
0=OG0=oG00<0emL0;=L000oG00<0emL0g]L00`3Ge`0]e`003mL00`3Ge`3Me`030=OG02kG000?e`03
0=OG0=gG00<0emL0;]L000oG00<0emL0g=L00`3Ge`0_e`003mL20=cG00<0emL0<=L000oG00<0emL0
fmL00`3Ge`0`e`003mL00`3Ge`3Je`030=OG037G000?e`030=OG0=WG00<0emL0<]L000oG00<0emL0
fML00`3Ge`0be`003mL00`3Ge`3He`030=OG03?G000?e`030=OG0=OG00<0emL0==L000oG00<0emL0
e]L00`3Ge`0ee`003mL00`3Ge`3Fe`030=OG03GG000?e`80e]L00`3Ge`0fe`003mL00`3Ge`3De`03
0=OG03OG000?e`030=OG0=?G00<0emL0>=L000oG00<0emL0dmL00`3Ge`0he`003mL00`3Ge`3Be`03
0=OG03WG000?e`030=OG0=7G00<0emL0>]L000oG00<0emL0d=L00`3Ge`0ke`003mL00`3Ge`3@e`03
0=OG03_G000?e`80d=L00`3Ge`0le`003mL00`3Ge`3>e`030=OG03gG000?e`030=OG0<kG00<0emL0
?ML000oG00<0emL0cML00`3Ge`0ne`003mL00`3Ge`3<e`030=OG03oG000?e`030=OG0<_G00<0emL0
@=L000oG00<0emL0bmL00`3Ge`10e`001mL400CG00<0emL0b]L00`3Ge`11e`002ML00`3Ge`03e`03
0=OG0<WG00<0emL0@]L000WG00<0emL00mL30<SG00<0emL0@mL000WG00<0emL00mL20<WG00<0emL0
@mL000WG00<0emL00mL00`3G0037e`030=OG04CG0007e`<01ML00`3G0036e`030=OG04GG0009e`03
0=OG00?G00@0emL0a=L00`3Ge`16e`003mL01@3GemL00<?G00<0emL0A]L000oG00<0emL00]L00`3G
e`2oe`030=OG04OG000?e`030=OG00;G00<0emL0_]L00`3Ge`18e`003mL200CG00<0emL0_ML00`3G
e`18e`003mL00`3Ge`04e`030=OG0;_G00<0emL0BML000oG00<0emL01ML00`3Ge`2ie`030=OG04[G
000?e`030=OG00KG00<0emL0]mL00`3Ge`1;e`003mL00`3Ge`06e`030=OG0;OG00<0emL0BmL000oG
00<0emL01mL00`3Ge`2ee`030=OG04cG000?e`030=OG00SG00<0emL0/mL00`3Ge`1=e`003mL00`3G
e`09e`030=OG0;7G00<0emL0C]L000oG00<0emL02]L00`3Ge`2`e`030=OG04kG000?e`802mL00`3G
e`2_e`030=OG04oG000?e`030=OG00_G00<0emL0[ML00`3Ge`1@e`003mL00`3Ge`0<e`030=OG0:_G
00<0emL0DML000oG00<0emL03ML00`3Ge`2Ze`030=OG057G000?e`030=OG00gG00<0emL0ZML00`3G
e`1Be`003mL00`3Ge`0>e`030=OG0:OG00<0emL0DmL000oG00<0emL03mL00`3Ge`2Ue`030=OG05CG
000?e`030=OG013G00<0emL0XmL00`3Ge`1Ee`003mL201;G00<0emL0XML00`3Ge`1Fe`003mL00`3G
e`0Ae`030=OG0:3G00<0emL0EmL000oG00<0emL04]L00`3Ge`2Ne`030=OG05SG000?e`030=OG01?G
00<0emL0WML00`3Ge`1He`003mL00`3Ge`0De`030=OG09_G00<0emL0FML000oG00<0emL05ML00`3G
e`2Ie`030=OG05[G000?e`030=OG01KG00<0emL0UmL00`3Ge`1Ke`003mL00`3Ge`0Ge`030=OG09GG
00<0emL0G=L000oG00<0emL06=L00`3Ge`2Ce`030=OG05gG000?e`806ML00`3Ge`2Be`030=OG05kG
000?e`030=OG01WG00<0emL0T=L00`3Ge`1Oe`003mL00`3Ge`0Je`030=OG08kG00<0emL0H=L000oG
00<0emL06mL00`3Ge`2<e`030=OG067G000?e`030=OG01cG00<0emL0R]L00`3Ge`1Re`003mL00`3G
e`0Me`030=OG08SG00<0emL0HmL000OG1004e`030=OG01kG00<0emL0QmL00`3Ge`1Se`001mL00`3G
e`05e`030=OG01oG00<0emL0QML00`3Ge`1Te`002=L00`3Ge`04e`<08=L00`3Ge`23e`030=OG06GG
0009e`030=OG00?G00<0emL08ML00`3Ge`21e`030=OG06KG000:e`030=OG00;G00<0emL08]L00`3G
e`1oe`030=OG06OG0007e`040=OG00CG00<0emL08mL00`3Ge`1me`030=OG06SG0008e`801ML00`3G
e`0Te`030=OG07_G00<0emL0JML000oG00<0emL09ML00`3Ge`1ie`030=OG06[G000?e`030=OG02KG
00<0emL0MmL00`3Ge`1[e`003mL00`3Ge`0We`030=OG07GG00<0emL0K=L000oG00<0emL0:=L00`3G
e`1be`80KmL000oG0P0Ze`030=OG073G00<0emL0KmL000oG00<0emL0:]L00`3Ge`1^e`030=OG073G
000?e`030=OG02_G0P1]e`030=OG077G000?e`030=OG02gG00<0emL0JML00`3Ge`1be`003mL00`3G
e`0^e`030=OG06OG00<0emL0LmL000oG00<0emL0;mL00`3Ge`1Te`80M]L000oG00<0emL0<=L00`3G
e`1Re`030=OG07KG000?e`030=OG037G0P1Qe`030=OG07OG000?e`80==L00`3Ge`1Le`80N]L000oG
00<0emL0==L00`3Ge`1Je`030=OG07[G000?e`030=OG03GG0P1Ie`030=OG07_G000?e`030=OG03OG
00<0emL0E=L207kG000?e`030=OG03SG0P1Ce`030=OG07kG000?e`030=OG03[G0P1?e`80PML000oG
00<0emL0?=L00`3Ge`1;e`030=OG087G000?e`030=OG03gG0P19e`80Q=L000oG00<0emL0?mL00`3G
e`14e`80Q]L000oG0P11e`80@mL00`3Ge`26e`003mL00`3Ge`12e`80?mL208WG000?e`030=OG04CG
0P0le`030=OG08WG000?e`030=OG04KG0P0he`80S=L000oG00<0emL0B=L203CG0P2>e`003mL00`3G
e`1:e`<0;]L3093G000?e`030=OG04gG0P0Ze`80TmL000oG00<0emL0CmL302?G102Ee`003mL205?G
0`0Ke`D0VML000oG00<0emL0EML5017G1@2Ne`003mL00`3Ge`1Jea40XmL000oG00<0emL0omL?e`00
3mL00`3Ge`3oe`oG000?e`030=OG0?oG3mL000oG00<0emL0omL?e`00omLQe`00omLQe`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.183564, -1.15979, \
0.0118596, 0.0234498}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(sol = 
        NDSolve[{\(y''\)[x] + \((1 + x^2)\)*y[x] \[Equal] \(-1. \), 
            y[\(-1. \)] == 0, y[1. ] \[Equal] 0}, 
          y, {x, \(-1. \), 1. }];\)\), "\[IndentingNewLine]", 
    \(Plot[Evaluate[y[x] /. sol], {x, \(-1. \), 1. }]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.0147151 0.631513 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.2619 .00222 -12 -9 ]
[.2619 .00222 12 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.4875 .14102 -18 -4.5 ]
[.4875 .14102 0 4.5 ]
[.4875 .26732 -18 -4.5 ]
[.4875 .26732 0 4.5 ]
[.4875 .39362 -18 -4.5 ]
[.4875 .39362 0 4.5 ]
[.4875 .51993 -18 -4.5 ]
[.4875 .51993 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-1)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-0.5)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(0.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .14102 m
.50625 .14102 L
s
[(0.2)] .4875 .14102 1 0 Mshowa
.5 .26732 m
.50625 .26732 L
s
[(0.4)] .4875 .26732 1 0 Mshowa
.5 .39362 m
.50625 .39362 L
s
[(0.6)] .4875 .39362 1 0 Mshowa
.5 .51993 m
.50625 .51993 L
s
[(0.8)] .4875 .51993 1 0 Mshowa
.125 Mabswid
.5 .04629 m
.50375 .04629 L
s
.5 .07787 m
.50375 .07787 L
s
.5 .10944 m
.50375 .10944 L
s
.5 .17259 m
.50375 .17259 L
s
.5 .20417 m
.50375 .20417 L
s
.5 .23574 m
.50375 .23574 L
s
.5 .2989 m
.50375 .2989 L
s
.5 .33047 m
.50375 .33047 L
s
.5 .36205 m
.50375 .36205 L
s
.5 .4252 m
.50375 .4252 L
s
.5 .45677 m
.50375 .45677 L
s
.5 .48835 m
.50375 .48835 L
s
.5 .5515 m
.50375 .5515 L
s
.5 .58308 m
.50375 .58308 L
s
.5 .61465 m
.50375 .61465 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .10142 L
.10458 .19004 L
.14415 .26668 L
.18221 .33374 L
.22272 .39746 L
.26171 .45098 L
.30316 .49923 L
.34309 .53712 L
.3815 .56555 L
.40095 .57693 L
.42237 .58711 L
.44268 .59448 L
.45178 .59707 L
.46172 .59938 L
.4671 .60041 L
.4721 .60122 L
.47727 .60193 L
.48196 .60244 L
.48658 .60284 L
.4887 .60298 L
.49093 .6031 L
.49332 .6032 L
.49438 .60323 L
.49552 .60327 L
.49675 .60329 L
.49789 .60331 L
.49859 .60331 L
.49925 .60332 L
.50049 .60332 L
.50163 .60331 L
.50286 .6033 L
.50401 .60328 L
.50508 .60325 L
.50754 .60317 L
.51014 .60304 L
.51268 .60289 L
.51504 .60271 L
.5204 .6022 L
.5293 .60101 L
.53882 .59927 L
.54906 .59684 L
.56016 .59358 L
.58032 .58597 L
.60019 .57632 L
.62123 .56379 L
.65912 .53525 L
.69946 .49645 L
.73829 .45099 L
.77956 .39409 L
Mistroke
.81932 .33118 L
.85757 .26349 L
.89827 .18427 L
.93745 .10166 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML00?oG8ML000kG100he`801=L00`3G
e`02e`<0LML200CG00<0emL00]L303SG100=e`004=L00`3Ge`0fe`040=OG00_G00<0emL0KML0103G
e`0;e`030=OG03OG00<0emL03=L0013G00<0emL0=]L0103Ge`0;e`030=OG06gG00@0emL02mL00`3G
e`0ge`030=OG00cG0008e`@01=L00`3Ge`0`e`@00]L0103Ge`08e`<0L=L0103Ge`08e`<0>]L00`3G
e`0<e`004=L00`3Ge`0fe`040=OG00SG00<0emL0L=L0103Ge`08e`030=OG03[G00<0emL03=L000kG
0`0he`040=OG00SG00<0emL0L=L0103Ge`08e`030=OG03SG0`0>e`004=L00`3Ge`0ge`802ML403KG
00<0emL0=mL200WG100ie`030=OG00cG002?e`030=OG08kG002?e`030=OG08kG002?e`030=OG08kG
0007eol04P08e`003ML00`3Ge`0:e`030=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL0
2]L00`3Ge`0:e`030=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL02]L00`3Ge`0:e`03
0=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL0
3=L000gG0P0oe`030=OG03kG00<0emL0?]L00`3Ge`0me`803]L000kG00<0emL0O]L00`3Ge`1ne`03
0=OG00gG000?e`030=OG07gG00<0emL0OML00`3Ge`0>e`003mL00`3Ge`1me`030=OG07gG00<0emL0
3]L0013G00<0emL0O=L00`3Ge`1le`030=OG00oG000@e`030=OG07cG00<0emL0O=L00`3Ge`0?e`00
4ML00`3Ge`1ke`030=OG07_G00<0emL04=L0017G00<0emL0NmL207cG00<0emL04=L001;G00<0emL0
N]L00`3Ge`1je`030=OG017G000Be`030=OG07[G00<0emL0N]L00`3Ge`0Ae`004]L00`3Ge`1je`03
0=OG07WG00<0emL04]L001?G00<0emL0NML00`3Ge`1ie`030=OG01;G000Ce`030=OG07WG00<0emL0
NML00`3Ge`0Be`005=L00`3Ge`1he`030=OG07SG00<0emL04mL001CG00<0emL0N=L00`3Ge`1he`03
0=OG01?G000Ee`030=OG07OG0P1he`030=OG01CG000Ee`030=OG07OG00<0emL0MmL00`3Ge`0De`00
5]L00`3Ge`1fe`030=OG07KG00<0emL05ML001KG00<0emL0M]L00`3Ge`1fe`030=OG01GG000Ge`03
0=OG07GG00<0emL0MML00`3Ge`0Fe`005mL00`3Ge`1ee`030=OG07GG00<0emL05]L001SG00<0emL0
M=L00`3Ge`1de`030=OG01OG000He`030=OG07CG00<0emL0M=L00`3Ge`0Ge`006=L00`3Ge`1de`03
0=OG07CG00<0emL05mL001WG00<0emL0LmL207CG00<0emL06=L001WG00<0emL0LmL00`3Ge`1ce`03
0=OG01SG000Je`030=OG07;G00<0emL0L]L00`3Ge`0Ie`006]L00`3Ge`1be`030=OG07;G00<0emL0
6ML001_G00<0emL0LML00`3Ge`1ae`030=OG01[G000Ke`030=OG077G00<0emL0LML00`3Ge`0Je`00
7=L00`3Ge`1Me`801=L00`3Ge`02e`@01=L00`3Ge`1`e`030=OG01_G000Le`030=OG05cG00@0emL0
2=L00`3Ge`05e`030=OG073G00<0emL06mL001gG00<0emL0FmL0103Ge`09e`030=OG00CG0`1_e`03
0=OG01cG000Me`030=OG05_G00@0emL02]L00`3Ge`03e`030=OG06oG00<0emL07=L001gG00<0emL0
FmL0103Ge`0;e`030=OG00;G00<0emL0KmL00`3Ge`0Le`007]L00`3Ge`1Je`040=OG00SG00@0emL0
1=L00`3Ge`1^e`030=OG01gG000Ne`030=OG05_G0P0:e`801ML00`3Ge`1^e`030=OG01gG000Oe`03
0=OG06gG00<0emL0KML00`3Ge`0Ne`007mL00`3Ge`1]e`030=OG06gG00<0emL07]L0023G00<0emL0
K=L00`3Ge`1/e`030=OG01oG000Pe`030=OG06cG00<0emL0K=L00`3Ge`0Oe`008ML00`3Ge`1[e`80
K=L00`3Ge`0Pe`008ML00`3Ge`1[e`030=OG06_G00<0emL08=L002;G00<0emL0J]L00`3Ge`1Ze`03
0=OG027G000Re`030=OG06[G00<0emL0J]L00`3Ge`0Qe`008mL00`3Ge`1Ye`030=OG06WG00<0emL0
8]L002?G00<0emL0JML00`3Ge`1Ye`030=OG02;G000Te`030=OG06SG00<0emL0J=L00`3Ge`0Se`00
9=L00`3Ge`1Xe`030=OG06SG00<0emL08mL002GG00<0emL0ImL00`3Ge`1We`030=OG02CG000Ue`03
0=OG06OG0P1Xe`030=OG02CG000Ve`030=OG06KG00<0emL0I]L00`3Ge`0Ue`009]L00`3Ge`1Ve`03
0=OG06KG00<0emL09ML002OG00<0emL0IML00`3Ge`1Ue`030=OG02KG000We`030=OG06GG00<0emL0
IML00`3Ge`0Ve`00:=L00`3Ge`1Te`030=OG06CG00<0emL09mL002SG00<0emL0I=L00`3Ge`1Te`03
0=OG02OG000Ye`030=OG06?G00<0emL0HmL00`3Ge`0Xe`00:ML00`3Ge`1Se`80I=L00`3Ge`0Xe`00
:]L00`3Ge`1Re`030=OG06;G00<0emL0:ML002[G00<0emL0H]L00`3Ge`1Re`030=OG02WG000[e`03
0=OG067G00<0emL0HML00`3Ge`0Ze`00:mL00`3Ge`1Qe`030=OG067G00<0emL0:]L002cG00<0emL0
H=L00`3Ge`1Pe`030=OG02_G000/e`030=OG063G00<0emL0H=L00`3Ge`0[e`00;ML00`3Ge`1<e`80
1=L00`3Ge`04e`030=OG00?G00<0emL0GmL00`3Ge`0/e`00;ML00`3Ge`1;e`040=OG00[G00<0emL0
0mL00`3Ge`1Oe`030=OG02cG000^e`030=OG04[G00@0emL01mL500CG0`1Ne`030=OG02gG000_e`03
0=OG04WG00@0emL01mL0103Ge`05e`030=OG05kG00<0emL0;ML002oG00<0emL0BML0103Ge`08e`03
0=L000GG00<0emL0GML00`3Ge`0^e`00<=L00`3Ge`18e`040=OG00WG0P05e`030=OG05gG00<0emL0
;]L0033G00<0emL0BML200_G00<0emL00mL00`3Ge`1Le`030=OG02oG000ae`030=OG05_G00<0emL0
FmL00`3Ge`0`e`00<ML00`3Ge`1Ke`030=OG05_G00<0emL0<=L003;G00<0emL0F]L00`3Ge`1Je`03
0=OG037G000be`030=OG05[G0P1Je`030=OG03;G000ce`030=OG05WG00<0emL0FML00`3Ge`0be`00
==L00`3Ge`1He`030=OG05SG00<0emL0<mL003CG00<0emL0F=L00`3Ge`1He`030=OG03?G000ee`03
0=OG05OG00<0emL0EmL00`3Ge`0de`00=ML00`3Ge`1Ge`030=OG05KG00<0emL0=ML003KG00<0emL0
E]L00`3Ge`1Fe`030=OG03GG000fe`030=OG05KG00<0emL0EML00`3Ge`0fe`00=mL00`3Ge`1Ee`03
0=OG05GG00<0emL0=]L003OG00<0emL0EML205GG00<0emL0=mL003SG00<0emL0E=L00`3Ge`1Ce`03
0=OG03SG000ie`030=OG05?G00<0emL0DmL00`3Ge`0he`00>ML00`3Ge`1Ce`030=OG05;G00<0emL0
>ML003[G00<0emL0D]L00`3Ge`1Ae`030=OG03[G000ke`030=OG057G00<0emL0DML00`3Ge`0je`00
>mL00`3Ge`1Ae`030=OG053G00<0emL0>mL003cG00<0emL0D=L00`3Ge`1?e`030=OG03cG000me`03
0=OG04oG00<0emL0CmL00`3Ge`0le`00?ML00`3Ge`1?e`80CmL00`3Ge`0me`00?]L00`3Ge`1>e`03
0=OG04kG00<0emL0?ML003kG00<0emL0C]L00`3Ge`1=e`030=OG03kG000oe`030=OG04gG00<0emL0
C=L00`3Ge`0oe`00@=L00`3Ge`1<e`030=OG04cG00<0emL0?mL0043G00<0emL0C=L00`3Ge`1;e`03
0=OG043G0011e`030=OG03SG0P04e`030=OG00?G0P05e`030=OG04[G00<0emL0@ML004;G00<0emL0
=]L0103Ge`08e`040=OG00CG00<0emL0B]L00`3Ge`11e`00@]L00`3Ge`0fe`040=OG00SG00@0emL0
1=L304WG00<0emL0@]L004?G00<0emL0=ML0103Ge`08e`<01ML00`3Ge`18e`030=OG04?G0014e`03
0=OG03CG00@0emL02=L00`3Ge`05e`030=OG04SG00<0emL0@mL004CG00<0emL0==L0103Ge`08e`03
0=OG00GG00<0emL0AmL00`3Ge`14e`00AML00`3Ge`0de`802]L300CG00<0emL0A]L00`3Ge`15e`00
A]L00`3Ge`16e`030=OG04KG00<0emL0AML004OG00<0emL0AML00`3Ge`15e`030=OG04KG0017e`03
0=OG04GG00<0emL0A=L00`3Ge`17e`00B=L00`3Ge`14e`030=OG04?G00<0emL0B=L004WG00<0emL0
@mL204CG00<0emL0B=L004[G00<0emL0@]L00`3Ge`12e`030=OG04WG001:e`030=OG04;G00<0emL0
@ML00`3Ge`1:e`00BmL00`3Ge`11e`030=OG047G00<0emL0B]L004cG00<0emL0@=L00`3Ge`10e`03
0=OG04_G001=e`030=OG03oG00<0emL0?mL00`3Ge`1<e`00CML00`3Ge`0oe`030=OG03oG00<0emL0
C=L004kG00<0emL0?]L00`3Ge`0ne`030=OG04gG001?e`030=OG03gG00<0emL0?ML00`3Ge`1>e`00
D=L00`3Ge`0le`80?ML00`3Ge`1?e`00DML00`3Ge`0ke`030=OG03_G00<0emL0D=L0057G00<0emL0
>mL00`3Ge`0je`030=OG057G001Be`030=OG03[G00<0emL0>ML00`3Ge`1Be`00DmL00`3Ge`0ie`03
0=OG03SG00<0emL0DmL005CG00<0emL0>=L00`3Ge`0he`030=OG05?G001Ee`030=OG03OG00<0emL0
=mL00`3Ge`1De`00E]L00`3Ge`0fe`030=OG03KG00<0emL0EML005KG00<0emL0=]L203KG00<0emL0
E]L005OG00<0emL0=ML00`3Ge`0de`030=OG05OG001He`030=OG03CG00<0emL0<mL00`3Ge`1He`00
FML00`3Ge`0ce`030=OG03;G00<0emL0FML005[G00<0emL0<]L00`3Ge`0ae`030=OG05[G001Ke`03
0=OG037G00<0emL0<=L00`3Ge`1Ke`00G=L00`3Ge`0`e`030=OG02oG00<0emL0G=L005gG00<0emL0
7=L200CG00<0emL00mL200GG00<0emL0;]L00`3Ge`1Me`00G]L201_G00@0emL02=L0103Ge`04e`03
0=OG02gG00<0emL0G]L0063G00<0emL06=L0103Ge`08e`040=OG00CG0`0/e`030=OG05oG001Qe`03
0=OG01OG00@0emL02ML200GG00<0emL0:mL00`3Ge`1Pe`00H]L00`3Ge`0Fe`040=OG00SG00@0emL0
1=L00`3Ge`0Ze`030=OG067G001Se`030=OG01GG00@0emL02=L0103Ge`04e`030=OG02WG00<0emL0
H]L006CG00<0emL05ML200[G0P05e`030=OG02SG00<0emL0HmL006GG0P0Xe`030=OG02OG00<0emL0
I=L006OG00<0emL09ML00`3Ge`0Ue`80ImL006SG00<0emL09=L00`3Ge`0Te`030=OG06OG001Ye`80
9=L202CG00<0emL0J=L006_G00<0emL08ML00`3Ge`0Re`030=OG06WG001/e`030=OG023G00<0emL0
8=L206cG001]e`808=L00`3Ge`0Oe`030=OG06cG001_e`030=OG01gG00<0emL07]L00`3Ge`1]e`00
L=L201gG00<0emL07=L2073G001be`806mL00`3Ge`0Je`80L]L007CG00<0emL06=L00`3Ge`0He`80
M=L007GG0P0He`030=OG01KG0P1fe`00MmL201KG0P0Ee`80N=L007WG0`0Ce`030=OG01;G0P1je`00
O=L2017G00<0emL03mL307cG001ne`<03]L00`3Ge`0<e`<0OmL0087G1@09e`030=OG00OG1@22e`00
Q]LC08OG002?e`030=OG08kG002?e`030=OG08kG002?e`030=OG08kG002?e`80SmL00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.10503, -0.0720502, \
0.00770056, 0.00580659}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{943, 631},
WindowMargins->{{81, Automatic}, {Automatic, 63}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 879, 19, 170, "Input"],

Cell[CellGroupData[{
Cell[2609, 73, 155, 3, 32, "Input"],
Cell[2767, 78, 316, 9, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3120, 92, 73, 1, 32, "Input"],
Cell[3196, 95, 11745, 387, 186, 4059, 288, "GraphicsData", "PostScript", \
"Graphics"],
Cell[14944, 484, 130, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15111, 492, 280, 5, 78, "Input"],
Cell[15394, 499, 11973, 357, 186, 3474, 248, "GraphicsData", "PostScript", \
"Graphics"],
Cell[27370, 858, 130, 3, 31, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

